﻿--[[
Name: LibBabble-Spell-3.0
Revision: $Rev: 53988 $
Author(s): ckknight (ckknight@gmail.com)
Website: http://ckknight.wowinterface.com/
Description: A library to provide localizations for spells.
Dependencies: None
License: MIT
]]

local MAJOR_VERSION = "LibBabble-Spell-3.0"
local MINOR_VERSION = "$Revision: 53988 $"

-- #AUTODOC_NAMESPACE prototype

do
	-- LibStub is hereby placed in the Public Domain
	-- Credits: Kaelten, Cladhaire, ckknight, Mikk, Ammo, Nevcairiel, joshborke
	local LIBSTUB_MAJOR, LIBSTUB_MINOR = "LibStub", 2  -- NEVER MAKE THIS AN SVN REVISION! IT NEEDS TO BE USABLE IN ALL REPOS!
	local LibStub = _G[LIBSTUB_MAJOR]

	-- Check to see is this version of the stub is obsolete
	if not LibStub or not LibStub.minors[LIBSTUB_MAJOR] or LibStub.minors[LIBSTUB_MAJOR] < LIBSTUB_MINOR then
		LibStub = LibStub or {libs = {}, minors = {} }
		_G[LIBSTUB_MAJOR] = LibStub
		LibStub.libs[LIBSTUB_MAJOR], LibStub.minors[LIBSTUB_MAJOR] = LibStub, LIBSTUB_MINOR

		-- LibStub:NewLibrary(major, minor)
		-- major (string) - the major version of the library
		-- minor (string or number ) - the minor version of the library
		--
		-- returns nil if a newer or same version of the lib is already present
		-- returns empty library object or old library object if upgrade is needed
		function LibStub:NewLibrary(major, minor)
			assert(type(major) == "string", "Bad argument #2 to `NewLibrary' (string expected)")
			minor = assert(tonumber(strmatch(minor, "%d+")), "Minor version must either be a number or contain a number.")

			local oldminor = self.minors[major]
			if oldminor and oldminor >= minor then return nil end
			self.minors[major], self.libs[major] = minor, self.libs[major] or {}
			return self.libs[major], oldminor
		end

		-- LibStub:GetLibrary(major, [silent])
		-- major (string) - the major version of the library
		-- silent (boolean) - if true, library is optional, silently return nil if its not found
		--
		-- throws an error if the library can not be found (except silent is set)
		-- returns the library object if found
		function LibStub:GetLibrary(major, silent)
			if not silent and not self.libs[major] then
				error(("Cannot find a library instance of %q."):format(tostring(major)), 2)
			end
			return self.libs[major], self.minors[major]
		end

		-- LibStub:IterateLibraries()
		--
		-- Returns an iterator for the currently registered libraries
		function LibStub:IterateLibraries()
			return pairs(self.libs)
		end

		setmetatable(LibStub, { __call = LibStub.GetLibrary })
	end
end

local GAME_LOCALE = GetLocale()
do
	-- LibBabble-Core-3.0 is hereby placed in the Public Domain
	-- Credits: ckknight
	local LIBBABBLE_MAJOR, LIBBABBLE_MINOR = "LibBabble-3.0", 1

	local LibBabble = LibStub:NewLibrary(LIBBABBLE_MAJOR, LIBBABBLE_MINOR)
	if LibBabble then
		local data = LibBabble.data or {}
		for k,v in pairs(LibBabble) do
			LibBabble[k] = nil
		end
		LibBabble.data = data

		local tablesToDB = {}

		local function warn(message)
			local _, ret = pcall(error, message, 3)
			geterrorhandler()(ret)
		end

		local lookup_mt = { __index = function(self, key)
			local db = tablesToDB[self]
			local current_key = db.current[key]
			if current_key then
				self[key] = current_key
				return current_key
			end
			local base_key = db.base[key]
			if base_key then
				warn(("%s: Translation %q not found for locale %q"):format(MAJOR_VERSION, key, GAME_LOCALE))
				rawset(self, key, base_key)
				return base_key
			end
			warn(("%s: Translation %q not found."):format(MAJOR_VERSION, key))
			rawset(self, key, key)
			return key
		end }

		local function initLookup(module, lookup)
			local db = tablesToDB[module]
			for k in pairs(lookup) do
				lookup[k] = nil
			end
			setmetatable(lookup, lookup_mt)
			tablesToDB[lookup] = db
			db.lookup = lookup
			return lookup
		end

		local function initReverse(module, reverse)
			local db = tablesToDB[module]
			for k in pairs(reverse) do
				reverse[k] = nil
			end
			for k,v in pairs(db.current) do
				reverse[v] = k
			end
			tablesToDB[reverse] = db
			db.reverse = reverse
			db.reverseIterators = nil
			return reverse
		end

		local prototype = {}
		local prototype_mt = {__index = prototype}

		--[[---------------------------------------------------------------------------
		Notes:
			* If you try to access a nonexistent key, it will warn but allow the code to pass through.
		Returns:
			A lookup table for english to localized words.
		Example:
			local B = LibStub("LibBabble-Module-3.0") -- where Module is what you want.
			local BL = B:GetLookupTable()
			assert(BL["Some english word"] == "Some localized word")
			DoSomething(BL["Some english word that doesn't exist"]) -- warning!
		-----------------------------------------------------------------------------]]
		function prototype:GetLookupTable()
			local db = tablesToDB[self]

			local lookup = db.lookup
			if lookup then
				return lookup
			end
			return initLookup(self, {})
		end
		--[[---------------------------------------------------------------------------
		Notes:
			* If you try to access a nonexistent key, it will return nil.
		Returns:
			A lookup table for english to localized words.
		Example:
			local B = LibStub("LibBabble-Module-3.0") -- where Module is what you want.
			local B_has = B:GetUnstrictLookupTable()
			assert(B_has["Some english word"] == "Some localized word")
			assert(B_has["Some english word that doesn't exist"] == nil)
		-----------------------------------------------------------------------------]]
		function prototype:GetUnstrictLookupTable()
			local db = tablesToDB[self]

			return db.current
		end
		--[[---------------------------------------------------------------------------
		Notes:
			* If you try to access a nonexistent key, it will return nil.
			* This is useful for checking if the base (English) table has a key, even if the localized one does not have it registered.
		Returns:
			A lookup table for english to localized words.
		Example:
			local B = LibStub("LibBabble-Module-3.0") -- where Module is what you want.
			local B_hasBase = B:GetBaseLookupTable()
			assert(B_hasBase["Some english word"] == "Some english word")
			assert(B_hasBase["Some english word that doesn't exist"] == nil)
		-----------------------------------------------------------------------------]]
		function prototype:GetBaseLookupTable()
			local db = tablesToDB[self]

			return db.base
		end
		--[[---------------------------------------------------------------------------
		Notes:
			* If you try to access a nonexistent key, it will return nil.
			* This will return only one English word that it maps to, if there are more than one to check, see :GetReverseIterator("word")
		Returns:
			A lookup table for localized to english words.
		Example:
			local B = LibStub("LibBabble-Module-3.0") -- where Module is what you want.
			local BR = B:GetReverseLookupTable()
			assert(BR["Some localized word"] == "Some english word")
			assert(BR["Some localized word that doesn't exist"] == nil)
		-----------------------------------------------------------------------------]]
		function prototype:GetReverseLookupTable()
			local db = tablesToDB[self]

			local reverse = db.reverse
			if reverse then
				return reverse
			end
			return initReverse(self, {})
		end
		local blank = {}
		local weakVal = {__mode='v'}
		--[[---------------------------------------------------------------------------
		Arguments:
			string - the localized word to chek for.
		Returns:
			An iterator to traverse all English words that map to the given key
		Example:
			local B = LibStub("LibBabble-Module-3.0") -- where Module is what you want.
			for word in B:GetReverseIterator("Some localized word") do
				DoSomething(word)
			end
		-----------------------------------------------------------------------------]]
		function prototype:GetReverseIterator(key)
			local db = tablesToDB[self]
			local reverseIterators = db.reverseIterators
			if not reverseIterators then
				reverseIterators = setmetatable({}, weakVal)
				db.reverseIterators = reverseIterators
			elseif reverseIterators[key] then
				return pairs(reverseIterators[key])
			end
			local t
			for k,v in pairs(db.current) do
				if v == key then
					if not t then
						t = {}
					end
					t[k] = true
				end
			end
			reverseIterators[key] = t or blank
			return pairs(reverseIterators[key])
		end
		--[[---------------------------------------------------------------------------
		Returns:
			An iterator to traverse all translations English to localized.
		Example:
			local B = LibStub("LibBabble-Module-3.0") -- where Module is what you want.
			for english, localized in B:Iterate() do
				DoSomething(english, localized)
			end
		-----------------------------------------------------------------------------]]
		function prototype:Iterate()
			local db = tablesToDB[self]

			return pairs(db.current)
		end

		-- #NODOC
		-- modules need to call this to set the base table
		function prototype:SetBaseTranslations(base)
			local db = tablesToDB[self]
			local oldBase = db.base
			if oldBase then
				for k in pairs(oldBase) do
					oldBase[k] = nil
				end
				for k, v in pairs(base) do
					oldBase[k] = v
				end
				base = oldBase
			else
				db.base = base
			end
			for k,v in pairs(base) do
				if v == true then
					base[k] = k
				end
			end
		end

		local function init(module)
			local db = tablesToDB[module]
			if db.lookup then
				initLookup(module, db.lookup)
			end
			if db.reverse then
				initReverse(module, db.reverse)
			end
			db.reverseIterators = nil
		end

		-- #NODOC
		-- modules need to call this to set the current table. if current is true, use the base table.
		function prototype:SetCurrentTranslations(current)
			local db = tablesToDB[self]
			if current == true then
				db.current = db.base
			else
				local oldCurrent = db.current
				if oldCurrent then
					for k in pairs(oldCurrent) do
						oldCurrent[k] = nil
					end
					for k, v in pairs(current) do
						oldCurrent[k] = v
					end
					current = oldCurrent
				else
					db.current = current
				end
			end
			init(self)
		end

		for namespace, db in pairs(data) do
			setmetatable(db.module, prototype_mt)
			init(db.module)
		end

		-- #NODOC
		-- modules need to call this to create a new namespace.
		function LibBabble:New(namespace, minor)
			local module, oldminor = LibStub:NewLibrary(namespace, minor)
			if not module then
				return
			end

			if not oldminor then
				local db = {
					module = module,
				}
				data[namespace] = db
				tablesToDB[module] = db
			else
				for k,v in pairs(module) do
					module[k] = nil
				end
			end

			setmetatable(module, prototype_mt)

			return module
		end
	end
end

local lib = LibStub("LibBabble-3.0"):New(MAJOR_VERSION, MINOR_VERSION)
if not lib then
	return
end

lib:SetBaseTranslations {
		["Abolish Disease"] = true,
		["Abolish Poison"] = true,
		["Abolish Poison Effect"] = true,
		["Activate MG Turret"] = true,
		["Adrenaline Rush"] = true,
		["Aftermath"] = true,
		["Aggression"] = true,
		["Aimed Shot"] = true,
		["Alchemy"] = true,
		["Ambush"] = true,
		["Ammunition"] = true,
		["Amplify Curse"] = true,
		["Amplify Magic"] = true,
		["Ancestral Fortitude"] = true,
		["Ancestral Healing"] = true,
		["Ancestral Knowledge"] = true,
		["Ancestral Spirit"] = true,
		["Ancient Hysteria"] = true,
		["Anesthetic Poison"] = true,
		["Anger Management"] = true,
		["Anguish"] = true,
		["Anticipation"] = true,
		["Aquatic Form"] = true,
		["Arcane Blast"] = true,
		["Arcane Brilliance"] = true,
		["Arcane Concentration"] = true,
		["Arcane Energy"] = true,
		["Arcane Explosion"] = true,
		["Arcane Focus"] = true,
		["Arcane Fortitude"] = true,
		["Arcane Impact"] = true,
		["Arcane Instability"] = true,
		["Arcane Intellect"] = true,
		["Arcane Meditation"] = true,
		["Arcane Mind"] = true,
		["Arcane Missiles"] = true,
		["Arcane Potency"] = true,
		["Arcane Power"] = true,
		["Arcane Resistance"] = true,
		["Arcane Shot"] = true,
		["Arcane Shroud"] = true,
		["Arcane Subtlety"] = true,
		["Arcane Torrent"] = true,
		["Arcane Weakness"] = true,
		["Arctic Reach"] = true,
		["Arctic Winds"] = true,
		["Armor of Faith"] = true,
		["Armorsmith"] = true,
		["Aspect of the Beast"] = true,
		["Aspect of the Cheetah"] = true,
		["Aspect of the Hawk"] = true,
		["Aspect of the Monkey"] = true,
		["Aspect of the Pack"] = true,
		["Aspect of the Viper"] = true,
		["Aspect of the Wild"] = true,
		["Astral Recall"] = true,
		["Attack"] = true,
		["Attacking"] = true,
		["Auto Shot"] = true,
		["Avenger's Shield"] = true,
		["Avenging Wrath"] = true,
		["Avoidance"] = true,
		["Axe Specialization"] = true,
		["Backlash"] = true,
		["Backstab"] = true,
		["Badge of the Swarmguard"] = true,
		["Balance of Power"] = true,
		["Bane"] = true,
		["Banish"] = true,
		["Banker"] = true,
		["Banshee Curse"] = true,
		["Barkskin"] = true,
		["Barrage"] = true,
		["Bash"] = true,
		["Basic Campfire"] = true,
		["Battle Rush"] = true,
		["Battle Shout"] = true,
		["Battle Stance"] = true,
		["Battle Stance Passive"] = true,
		["BattleMaster"] = true,
		["Bear Form"] = true,
		["Beast Lore"] = true,
		["Beast Slaying"] = true,
		["Beast Training"] = true,
		["Benediction"] = true,
		["Berserker Rage"] = true,
		["Berserker Stance"] = true,
		["Berserker Stance Passive"] = true,
		["Berserking"] = true,
		["Bestial Discipline"] = true,
		["Bestial Swiftness"] = true,
		["Bestial Wrath"] = true,
		["Binding Heal"] = true,
		["Bite"] = true,
		["Black Arrow"] = true,
		["Blackout"] = true,
		["Blacksmithing"] = true,
		["Blade Flurry"] = true,
		["Blade Turning"] = true,
		["Blade Twisting"] = true,
		["Blast Wave"] = true,
		["Blazing Speed"] = true,
		["Blessed Recovery"] = true,
		["Blessed Resilience"] = true,
		["Blessing of Auchindoun"] = true,
		["Blessing of Freedom"] = true,
		["Blessing of Kings"] = true,
		["Blessing of Light"] = true,
		["Blessing of Might"] = true,
		["Blessing of Protection"] = true,
		["Blessing of Sacrifice"] = true,
		["Blessing of Salvation"] = true,
		["Blessing of Sanctuary"] = true,
		["Blessing of Wisdom"] = true,
		["Blind"] = true,
		["Blinding Powder"] = true,
		["Blink"] = true,
		["Blizzard"] = true,
		["Block"] = true,
		["Blood Craze"] = true,
		["Blood Frenzy"] = true,
		["Blood Fury"] = true,
		["Blood Pact"] = true,
		["Bloodlust"] = true,
		["Bloodrage"] = true,
		["Bloodthirst"] = true,
		["Boar Charge"] = true,
		["Booming Voice"] = true,
		["Bow Specialization"] = true,
		["Bows"] = true,
		["Bright Campfire"] = true,
		["Brittle Armor"] = true,
		["Brutal Impact"] = true,
		["Burning Adrenaline"] = true,
		["Burning Soul"] = true,
		["Burning Wish"] = true,
		["Call Pet"] = true,
		["Call of Flame"] = true,
		["Call of Thunder"] = true,
		["Call of the Nexus"] = true,
		["Camouflage"] = true,
		["Cannibalize"] = true,
		["Cat Form"] = true,
		["Cataclysm"] = true,
		["Celestial Focus"] = true,
		["Chain Heal"] = true,
		["Chain Lightning"] = true,
		["Challenging Roar"] = true,
		["Challenging Shout"] = true,
		["Charge"] = true,
		["Charge Rage Bonus Effect"] = true,
		["Charge Stun"] = true,
		["Cheap Shot"] = true,
		["Chilled"] = true,
		["Circle of Healing"] = true,
		["Class Trainer"] = true,
		["Claw"] = true,
		["Cleanse"] = true,
		["Clearcasting"] = true,
		["Cleave"] = true,
		["Clever Traps"] = true,
		["Cloak of Shadows"] = true,
		["Closing"] = true,
		["Cloth"] = true,
		["Coarse Sharpening Stone"] = true,
		["Cobra Reflexes"] = true,
		["Cold Blood"] = true,
		["Cold Snap"] = true,
		["Combat Endurance"] = true,
		["Combustion"] = true,
		["Command"] = true,
		["Commanding Presence"] = true,
		["Commanding Shout"] = true,
		["Concentration Aura"] = true,
		["Concussion"] = true,
		["Concussion Blow"] = true,
		["Concussive Barrage"] = true,
		["Concussive Shot"] = true,
		["Cone of Cold"] = true,
		["Conflagrate"] = true,
		["Conflagration"] = true,
		["Conjure Food"] = true,
		["Conjure Mana Agate"] = true,
		["Conjure Mana Citrine"] = true,
		["Conjure Mana Emerald"] = true,
		["Conjure Mana Jade"] = true,
		["Conjure Mana Ruby"] = true,
		["Conjure Water"] = true,
		["Consecration"] = true,
		["Consume Magic"] = true,
		["Consume Shadows"] = true,
		["Contagion"] = true,
		["Convection"] = true,
		["Conviction"] = true,
		["Cooking"] = true,
		["Corruption"] = true,
		["Counterattack"] = true,
		["Counterspell"] = true,
		["Counterspell - Silenced"] = true,
		["Cower"] = true,
		["Create Firestone"] = true,
		["Create Firestone (Greater)"] = true,
		["Create Firestone (Lesser)"] = true,
		["Create Firestone (Major)"] = true,
		["Create Healthstone"] = true,
		["Create Healthstone (Greater)"] = true,
		["Create Healthstone (Lesser)"] = true,
		["Create Healthstone (Major)"] = true,
		["Create Healthstone (Minor)"] = true,
		["Create Soulstone"] = true,
		["Create Soulstone (Greater)"] = true,
		["Create Soulstone (Lesser)"] = true,
		["Create Soulstone (Major)"] = true,
		["Create Soulstone (Minor)"] = true,
		["Create Spellstone"] = true,
		["Create Spellstone (Greater)"] = true,
		["Create Spellstone (Major)"] = true,
		["Create Spellstone (Master)"] = true,
		["Cripple"] = true,
		["Crippling Poison"] = true,
		["Crippling Poison II"] = true,
		["Critical Mass"] = true,
		["Crossbows"] = true,
		["Cruelty"] = true,
		["Crusade"] = true,
		["Crusader Aura"] = true,
		["Crusader Strike"] = true,
		["Cultivation"] = true,
		["Cure Disease"] = true,
		["Cure Poison"] = true,
		["Curse of Agony"] = true,
		["Curse of Doom"] = true,
		["Curse of Doom Effect"] = true,
		["Curse of Exhaustion"] = true,
		["Curse of Idiocy"] = true,
		["Curse of Recklessness"] = true,
		["Curse of Shadow"] = true,
		["Curse of Tongues"] = true,
		["Curse of Weakness"] = true,
		["Curse of the Elements"] = true,
		["Cyclone"] = true,
		["Dagger Specialization"] = true,
		["Daggers"] = true,
		["Dampen Magic"] = true,
		["Dark Pact"] = true,
		["Darkness"] = true,
		["Dash"] = true,
		["Dawnstone Crab"] = true,
		["Dazed"] = true,
		["Deadly Interrupt Effect"] = true,
		["Deadly Poison"] = true,
		["Deadly Poison II"] = true,
		["Deadly Poison III"] = true,
		["Deadly Poison IV"] = true,
		["Deadly Poison V"] = true,
		["Deadly Poison VI"] = true,
		["Deadly Poison VII"] = true,
		["Deadly Throw"] = true,
		["Death Coil"] = true,
		["Death Wish"] = true,
		["Deep Wound"] = true,
		["Deep Wounds"] = true,
		["Defense"] = true,
		["Defensive Stance"] = true,
		["Defensive Stance Passive"] = true,
		["Defiance"] = true,
		["Deflection"] = true,
		["Delusions of Jin'do"] = true,
		["Demon Armor"] = true,
		["Demon Skin"] = true,
		["Demonic Aegis"] = true,
		["Demonic Embrace"] = true,
		["Demonic Frenzy"] = true,
		["Demonic Knowledge"] = true,
		["Demonic Resilience"] = true,
		["Demonic Sacrifice"] = true,
		["Demonic Tactics"] = true,
		["Demoralizing Roar"] = true,
		["Demoralizing Shout"] = true,
		["Dense Sharpening Stone"] = true,
		["Desperate Prayer"] = true,
		["Destructive Reach"] = true,
		["Detect"] = true,
		["Detect Greater Invisibility"] = true,
		["Detect Invisibility"] = true,
		["Detect Lesser Invisibility"] = true,
		["Detect Magic"] = true,
		["Detect Traps"] = true,
		["Deterrence"] = true,
		["Devastate"] = true,
		["Devastation"] = true,
		["Devotion Aura"] = true,
		["Devour Magic"] = true,
		["Devour Magic Effect"] = true,
		["Devouring Plague"] = true,
		["Diplomacy"] = true,
		["Dire Bear Form"] = true,
		["Dirty Deeds"] = true,
		["Dirty Tricks"] = true,
		["Disarm"] = true,
		["Disarm Trap"] = true,
		["Disease Cleansing Totem"] = true,
		["Disenchant"] = true,
		["Disengage"] = true,
		["Dismiss Pet"] = true,
		["Dispel Magic"] = true,
		["Distract"] = true,
		["Distracting Shot"] = true,
		["Dive"] = true,
		["Divine Favor"] = true,
		["Divine Fury"] = true,
		["Divine Illumination"] = true,
		["Divine Intellect"] = true,
		["Divine Intervention"] = true,
		["Divine Protection"] = true,
		["Divine Shield"] = true,
		["Divine Spirit"] = true,
		["Divine Strength"] = true,
		["Divine Wrath"] = true,
		["Dodge"] = true,
		["Doomfire"] = true,
		["Dragon's Breath"] = true,
		["Dragonscale Leatherworking"] = true,
		["Drain Life"] = true,
		["Drain Mana"] = true,
		["Drain Soul"] = true,
		["Dreamless Sleep"] = true,
		["Drink"] = true,
		["Dual Wield"] = true,
		["Dual Wield Specialization"] = true,
		["Duel"] = true,
		["Dust Cloud"] = true,
		["Eagle Eye"] = true,
		["Earth Elemental Totem"] = true,
		["Earth Shield"] = true,
		["Earth Shock"] = true,
		["Earthbind"] = true,
		["Earthbind Totem"] = true,
		["Earthstrike"] = true,
		["Efficiency"] = true,
		["Elemental Devastation"] = true,
		["Elemental Focus"] = true,
		["Elemental Fury"] = true,
		["Elemental Leatherworking"] = true,
		["Elemental Mastery"] = true,
		["Elemental Precision"] = true,
		["Elemental Sharpening Stone"] = true,
		["Elemental Weapons"] = true,
		["Elune's Grace"] = true,
		["Elusiveness"] = true,
		["Emberstorm"] = true,
		["Empowered Arcane Missiles"] = true,
		["Empowered Corruption"] = true,
		["Empowered Fireball"] = true,
		["Empowered Frostbolt"] = true,
		["Empowered Healing"] = true,
		["Empowered Rejuvenation"] = true,
		["Empowered Touch"] = true,
		["Enamored Water Spirit"] = true,
		["Enchanting"] = true,
		["Endurance"] = true,
		["Endurance Training"] = true,
		["Engineering"] = true,
		["Engineering Specialization"] = true,
		["Enrage"] = true,
		["Enriched Manna Biscuit"] = true,
		["Enslave Demon"] = true,
		["Entangling Roots"] = true,
		["Entrapment"] = true,
		["Envenom"] = true,
		["Escape Artist"] = true,
		["Evasion"] = true,
		["Eviscerate"] = true,
		["Evocation"] = true,
		["Execute"] = true,
		["Exorcism"] = true,
		["Expansive Mind"] = true,
		["Explosive Trap"] = true,
		["Explosive Trap Effect"] = true,
		["Expose Armor"] = true,
		["Expose Weakness"] = true,
		["Extract Gas"] = true,
		["Eye for an Eye"] = true,
		["Eye of Kilrogg"] = true,
		["Eye of the Storm"] = true,
		["Eyes of the Beast"] = true,
		["Fade"] = true,
		["Faerie Fire"] = true,
		["Faerie Fire (Feral)"] = true,
		["Fanaticism"] = true,
		["Far Sight"] = true,
		["Fatal Attraction"] = true,
		["Fear"] = true,
		["Fear Ward"] = true,
		["Feed Pet"] = true,
		["Feed Pet Effect"] = true,
		["Feedback"] = true,
		["Feign Death"] = true,
		["Feint"] = true,
		["Fel Armor"] = true,
		["Fel Concentration"] = true,
		["Fel Domination"] = true,
		["Fel Energy"] = true,
		["Fel Intellect"] = true,
		["Fel Rage"] = true,
		["Fel Stamina"] = true,
		["Felfire"] = true,
		["Feline Grace"] = true,
		["Feral Aggression"] = true,
		["Feral Charge"] = true,
		["Feral Instinct"] = true,
		["Feral Swiftness"] = true,
		["Ferocious Bite"] = true,
		["Ferocious Inspiration"] = true,
		["Ferocity"] = true,
		["Fetish"] = true,
		["Find Fish"] = true,
		["Find Herbs"] = true,
		["Find Minerals"] = true,
		["Find Treasure"] = true,
		["Find Weakness"] = true,
		["Fire Blast"] = true,
		["Fire Breath"] = true,
		["Fire Elemental Totem"] = true,
		["Fire Nova Totem"] = true,
		["Fire Power"] = true,
		["Fire Resistance"] = true,
		["Fire Resistance Aura"] = true,
		["Fire Resistance Totem"] = true,
		["Fire Shield"] = true,
		["Fire Vulnerability"] = true,
		["Fire Ward"] = true,
		["Fire Weakness"] = true,
		["Fireball"] = true,
		["Firebolt"] = true,
		["First Aid"] = true,
		["Fishing"] = true,
		["Fishing Poles"] = true,
		["Fist Weapon Specialization"] = true,
		["Fist Weapons"] = true,
		["Flame Shock"] = true,
		["Flame Throwing"] = true,
		["Flamestrike"] = true,
		["Flamethrower"] = true,
		["Flametongue Attack"] = true,
		["Flametongue Totem"] = true,
		["Flametongue Weapon"] = true,
		["Flare"] = true,
		["Flash Heal"] = true,
		["Flash of Light"] = true,
		["Flight Form"] = true,
		["FlightMaster"] = true,
		["Flurry"] = true,
		["Focused Casting"] = true,
		["Focused Mind"] = true,
		["Focused Power"] = true,
		["Focused Rage"] = true,
		["Focused Starlight"] = true,
		["Food"] = true,
		["Food & Drink"] = true,
		["Forbearance"] = true,
		["Force of Nature"] = true,
		["Force of Will"] = true,
		["Freezing Trap"] = true,
		["Freezing Trap Effect"] = true,
		["Frenzied Regeneration"] = true,
		["Frenzy"] = true,
		["Frenzy Effect"] = true,
		["Frost Armor"] = true,
		["Frost Blast"] = true,
		["Frost Channeling"] = true,
		["Frost Nova"] = true,
		["Frost Resistance"] = true,
		["Frost Resistance Aura"] = true,
		["Frost Resistance Totem"] = true,
		["Frost Shock"] = true,
		["Frost Trap"] = true,
		["Frost Trap Aura"] = true,
		["Frost Ward"] = true,
		["Frost Warding"] = true,
		["Frost Weakness"] = true,
		["Frostbite"] = true,
		["Frostbolt"] = true,
		["Frostbrand Attack"] = true,
		["Frostbrand Weapon"] = true,
		["Frozen Core"] = true,
		["Furious Howl"] = true,
		["Furor"] = true,
		["Fury of the Crashing Waves"] = true,
		["Garrote"] = true,
		["Garrote - Silence"] = true,
		["Ghost Wolf"] = true,
		["Ghostly Strike"] = true,
		["Gift of Life"] = true,
		["Gift of Nature"] = true,
		["Gift of the Naaru"] = true,
		["Gift of the Wild"] = true,
		["Gouge"] = true,
		["Grace of Air"] = true,
		["Grace of Air Totem"] = true,
		["Great Stamina"] = true,
		["Greater Blessing of Kings"] = true,
		["Greater Blessing of Light"] = true,
		["Greater Blessing of Might"] = true,
		["Greater Blessing of Salvation"] = true,
		["Greater Blessing of Sanctuary"] = true,
		["Greater Blessing of Wisdom"] = true,
		["Greater Dreamless Sleep"] = true,
		["Greater Heal"] = true,
		["Grim Reach"] = true,
		["Grounding Totem"] = true,
		["Grounding Totem Effect"] = true,
		["Grovel"] = true,
		["Growl"] = true,
		["Guardian's Favor"] = true,
		["Gun Specialization"] = true,
		["Guns"] = true,
		["Hammer of Justice"] = true,
		["Hammer of Wrath"] = true,
		["Hamstring"] = true,
		["Harass"] = true,
		["Hardiness"] = true,
		["Haste"] = true,
		["Hawk Eye"] = true,
		["Heal"] = true,
		["Healing Focus"] = true,
		["Healing Light"] = true,
		["Healing Stream"] = true,
		["Healing Stream Totem"] = true,
		["Healing Touch"] = true,
		["Healing Wave"] = true,
		["Healing Way"] = true,
		["Health Funnel"] = true,
		["Heart of the Wild"] = true,
		["Heavy Sharpening Stone"] = true,
		["Hellfire"] = true,
		["Hellfire Effect"] = true,
		["Hellfire Superiority"] = true,
		["Hemorrhage"] = true,
		["Herb Gathering"] = true,
		["Herbalism"] = true,
		["Heroic Strike"] = true,
		["Heroism"] = true,
		["Hex of Weakness"] = true,
		["Hibernate"] = true,
		["Holy Fire"] = true,
		["Holy Light"] = true,
		["Holy Nova"] = true,
		["Holy Power"] = true,
		["Holy Reach"] = true,
		["Holy Shield"] = true,
		["Holy Shock"] = true,
		["Holy Specialization"] = true,
		["Holy Wrath"] = true,
		["Honorless Target"] = true,
		["Horse Riding"] = true,
		["Howl of Terror"] = true,
		["Humanoid Slaying"] = true,
		["Hunter's Mark"] = true,
		["Hurricane"] = true,
		["Hypothermia"] = true,
		["Ice Armor"] = true,
		["Ice Barrier"] = true,
		["Ice Block"] = true,
		["Ice Floes"] = true,
		["Ice Lance"] = true,
		["Ice Shards"] = true,
		["Ignite"] = true,
		["Ignite Mana"] = true,
		["Illumination"] = true,
		["Immolate"] = true,
		["Immolation Trap"] = true,
		["Immolation Trap Effect"] = true,
		["Impact"] = true,
		["Impale"] = true,
		["Impaling Spine"] = true,
		["Improved Ambush"] = true,
		["Improved Arcane Missiles"] = true,
		["Improved Arcane Shot"] = true,
		["Improved Aspect of the Hawk"] = true,
		["Improved Aspect of the Monkey"] = true,
		["Improved Backstab"] = true,
		["Improved Barrage"] = true,
		["Improved Berserker Rage"] = true,
		["Improved Blessing of Might"] = true,
		["Improved Blessing of Wisdom"] = true,
		["Improved Blink"] = true,
		["Improved Blizzard"] = true,
		["Improved Bloodrage"] = true,
		["Improved Chain Heal"] = true,
		["Improved Chain Lightning"] = true,
		["Improved Challenging Shout"] = true,
		["Improved Charge"] = true,
		["Improved Cleave"] = true,
		["Improved Concentration Aura"] = true,
		["Improved Concussive Shot"] = true,
		["Improved Cone of Cold"] = true,
		["Improved Corruption"] = true,
		["Improved Counterspell"] = true,
		["Improved Curse of Agony"] = true,
		["Improved Curse of Weakness"] = true,
		["Improved Demoralizing Shout"] = true,
		["Improved Devotion Aura"] = true,
		["Improved Disarm"] = true,
		["Improved Drain Life"] = true,
		["Improved Drain Soul"] = true,
		["Improved Enrage"] = true,
		["Improved Enslave Demon"] = true,
		["Improved Eviscerate"] = true,
		["Improved Execute"] = true,
		["Improved Expose Armor"] = true,
		["Improved Eyes of the Beast"] = true,
		["Improved Fade"] = true,
		["Improved Feign Death"] = true,
		["Improved Fire Blast"] = true,
		["Improved Fire Totems"] = true,
		["Improved Fire Ward"] = true,
		["Improved Fireball"] = true,
		["Improved Firebolt"] = true,
		["Improved Flamestrike"] = true,
		["Improved Flash of Light"] = true,
		["Improved Frost Nova"] = true,
		["Improved Frostbolt"] = true,
		["Improved Ghost Wolf"] = true,
		["Improved Gouge"] = true,
		["Improved Hammer of Justice"] = true,
		["Improved Hamstring"] = true,
		["Improved Healing"] = true,
		["Improved Healing Touch"] = true,
		["Improved Healing Wave"] = true,
		["Improved Health Funnel"] = true,
		["Improved Healthstone"] = true,
		["Improved Heroic Strike"] = true,
		["Improved Holy Shield"] = true,
		["Improved Howl of Terror"] = true,
		["Improved Hunter's Mark"] = true,
		["Improved Immolate"] = true,
		["Improved Imp"] = true,
		["Improved Inner Fire"] = true,
		["Improved Intercept"] = true,
		["Improved Intimidating Shout"] = true,
		["Improved Judgement"] = true,
		["Improved Kick"] = true,
		["Improved Kidney Shot"] = true,
		["Improved Lash of Pain"] = true,
		["Improved Lay on Hands"] = true,
		["Improved Leader of the Pack"] = true,
		["Improved Life Tap"] = true,
		["Improved Lightning Bolt"] = true,
		["Improved Lightning Shield"] = true,
		["Improved Magma Totem"] = true,
		["Improved Mana Burn"] = true,
		["Improved Mana Shield"] = true,
		["Improved Mana Spring Totem"] = true,
		["Improved Mark of the Wild"] = true,
		["Improved Mend Pet"] = true,
		["Improved Mind Blast"] = true,
		["Improved Moonfire"] = true,
		["Improved Mortal Strike"] = true,
		["Improved Nature's Grasp"] = true,
		["Improved Overpower"] = true,
		["Improved Power Word: Fortitude"] = true,
		["Improved Power Word: Shield"] = true,
		["Improved Prayer of Healing"] = true,
		["Improved Psychic Scream"] = true,
		["Improved Regrowth"] = true,
		["Improved Reincarnation"] = true,
		["Improved Rejuvenation"] = true,
		["Improved Rend"] = true,
		["Improved Renew"] = true,
		["Improved Retribution Aura"] = true,
		["Improved Revenge"] = true,
		["Improved Revive Pet"] = true,
		["Improved Righteous Fury"] = true,
		["Improved Rupture"] = true,
		["Improved Scorch"] = true,
		["Improved Scorpid Sting"] = true,
		["Improved Seal of Righteousness"] = true,
		["Improved Seal of the Crusader"] = true,
		["Improved Searing Pain"] = true,
		["Improved Serpent Sting"] = true,
		["Improved Shadow Bolt"] = true,
		["Improved Shadow Word: Pain"] = true,
		["Improved Shield Bash"] = true,
		["Improved Shield Block"] = true,
		["Improved Shield Wall"] = true,
		["Improved Sinister Strike"] = true,
		["Improved Slam"] = true,
		["Improved Slice and Dice"] = true,
		["Improved Sprint"] = true,
		["Improved Stings"] = true,
		["Improved Succubus"] = true,
		["Improved Sunder Armor"] = true,
		["Improved Taunt"] = true,
		["Improved Thunder Clap"] = true,
		["Improved Tranquility"] = true,
		["Improved Vampiric Embrace"] = true,
		["Improved Vanish"] = true,
		["Improved Voidwalker"] = true,
		["Improved Weapon Totems"] = true,
		["Improved Whirlwind"] = true,
		["Improved Wing Clip"] = true,
		["Incinerate"] = true,
		["Incineration"] = true,
		["Inferno"] = true,
		["Initiative"] = true,
		["Innkeeper"] = true,
		["Inner Fire"] = true,
		["Inner Focus"] = true,
		["Innervate"] = true,
		["Insect Swarm"] = true,
		["Insidious Whisper"] = true,
		["Insignifigance"] = true,
		["Inspiration"] = true,
		["Instant Poison"] = true,
		["Instant Poison II"] = true,
		["Instant Poison III"] = true,
		["Instant Poison IV"] = true,
		["Instant Poison V"] = true,
		["Instant Poison VI"] = true,
		["Instant Poison VII"] = true,
		["Intensity"] = true,
		["Intercept"] = true,
		["Intercept Stun"] = true,
		["Intervene"] = true,
		["Intimidating Shout"] = true,
		["Intimidation"] = true,
		["Invisibility"] = true,
		["Iron Will"] = true,
		["Jewelcrafting"] = true,
		["Jom Gabbar"] = true,
		["Judgement"] = true,
		["Judgement of Blood"] = true,
		["Judgement of Command"] = true,
		["Judgement of Justice"] = true,
		["Judgement of Light"] = true,
		["Judgement of Reckoning"] = true,
		["Judgement of Righteousness"] = true,
		["Judgement of Wisdom"] = true,
		["Judgement of the Crusader"] = true,
		["Kick"] = true,
		["Kick - Silenced"] = true,
		["Kidney Shot"] = true,
		["Kill Command"] = true,
		["Killer Instinct"] = true,
		["Kiss of the Spider"] = true,
		["Kodo Riding"] = true,
		["Lacerate"] = true,
		["Lash of Pain"] = true,
		["Last Stand"] = true,
		["Lay on Hands"] = true,
		["Leader of the Pack"] = true,
		["Leather"] = true,
		["Leatherworking"] = true,
		["Lesser Heal"] = true,
		["Lesser Healing Wave"] = true,
		["Lesser Invisibility"] = true,
		["Lethal Shots"] = true,
		["Lethality"] = true,
		["Levitate"] = true,
		["Libram"] = true,
		["Life Tap"] = true,
		["Lifebloom"] = true,
		["Light's Grace"] = true,
		["Lightning Bolt"] = true,
		["Lightning Breath"] = true,
		["Lightning Mastery"] = true,
		["Lightning Reflexes"] = true,
		["Lightning Shield"] = true,
		["Lightning Speed"] = true,
		["Lightwell"] = true,
		["Lightwell Renew"] = true,
		["Lockpicking"] = true,
		["Long Daze"] = true,
		["Lust for Battle"] = true,
		["Mace Specialization"] = true,
		["Mace Stun Effect"] = true,
		["Mage Armor"] = true,
		["Magic Absorption"] = true,
		["Magic Attunement"] = true,
		["Magma Totem"] = true,
		["Mail"] = true,
		["Maim"] = true,
		["Major Dreamless Sleep"] = true,
		["Malediction"] = true,
		["Malice"] = true,
		["Mana Burn"] = true,
		["Mana Feed"] = true,
		["Mana Shield"] = true,
		["Mana Spring"] = true,
		["Mana Spring Totem"] = true,
		["Mana Tap"] = true,
		["Mana Tide"] = true,
		["Mana Tide Totem"] = true,
		["Mangle"] = true,
		["Mangle (Bear)"] = true,
		["Mangle (Cat)"] = true,
		["Mark of the Wild"] = true,
		["Martyrdom"] = true,
		["Mass Dispel"] = true,
		["Master Conjuror"] = true,
		["Master Demonologist"] = true,
		["Master Summoner"] = true,
		["Master Tactician"] = true,
		["Master of Deception"] = true,
		["Master of Elements"] = true,
		["Master of Subtlety"] = true,
		["Maul"] = true,
		["Mechanostrider Piloting"] = true,
		["Meditation"] = true,
		["Melee Specialization"] = true,
		["Melt Armor"] = true,
		["Mend Pet"] = true,
		["Mental Agility"] = true,
		["Mental Strength"] = true,
		["Mind Blast"] = true,
		["Mind Control"] = true,
		["Mind Flay"] = true,
		["Mind Mastery"] = true,
		["Mind Soothe"] = true,
		["Mind Vision"] = true,
		["Mind-numbing Poison"] = true,
		["Mind-numbing Poison II"] = true,
		["Mind-numbing Poison III"] = true,
		["Mining"] = true,
		["Misdirection"] = true,
		["Misery"] = true,
		["Mocking Blow"] = true,
		["Molten Armor"] = true,
		["Molten Fury"] = true,
		["Mongoose Bite"] = true,
		["Monster Slaying"] = true,
		["Moonfire"] = true,
		["Moonfury"] = true,
		["Moonglow"] = true,
		["Moonkin Aura"] = true,
		["Moonkin Form"] = true,
		["Mortal Shots"] = true,
		["Mortal Strike"] = true,
		["Multi-Shot"] = true,
		["Murder"] = true,
		["Mutilate"] = true,
		["Natural Armor"] = true,
		["Natural Perfection"] = true,
		["Natural Shapeshifter"] = true,
		["Naturalist"] = true,
		["Nature Resistance"] = true,
		["Nature Resistance Totem"] = true,
		["Nature Weakness"] = true,
		["Nature's Focus"] = true,
		["Nature's Grace"] = true,
		["Nature's Grasp"] = true,
		["Nature's Guidance"] = true,
		["Nature's Reach"] = true,
		["Nature's Swiftness"] = true,
		["Negative Charge"] = true,
		["Nether Protection"] = true,
		["Netherstorm Flag"] = true,
		["Nightfall"] = true,
		["Nurturing Instinct"] = true,
		["Omen of Clarity"] = true,
		["One-Handed Axes"] = true,
		["One-Handed Maces"] = true,
		["One-Handed Swords"] = true,
		["One-Handed Weapon Specialization"] = true,
		["Opening"] = true,
		["Opening - No Text"] = true,
		["Opportunity"] = true,
		["Overpower"] = true,
		["Pain Suppression"] = true,
		["Panic"] = true,
		["Paranoia"] = true,
		["Parasitic Shadowfiend"] = true,
		["Parry"] = true,
		["Pathfinding"] = true,
		["Perceived Weakness"] = true,
		["Perception"] = true,
		["Permafrost"] = true,
		["Pet Aggression"] = true,
		["Pet Hardiness"] = true,
		["Pet Recovery"] = true,
		["Pet Resistance"] = true,
		["Phase Shift"] = true,
		["Pick Lock"] = true,
		["Pick Pocket"] = true,
		["Piercing Howl"] = true,
		["Piercing Ice"] = true,
		["Plate Mail"] = true,
		["Playing with Fire"] = true,
		["Poison Cleansing Totem"] = true,
		["Poison Spit"] = true,
		["Poisons"] = true,
		["Polearms"] = true,
		["Poleaxe Specialization"] = true,
		["Polymorph"] = true,
		["Polymorph: Pig"] = true,
		["Polymorph: Turtle"] = true,
		["Portal: Darnassus"] = true,
		["Portal: Exodar"] = true,
		["Portal: Ironforge"] = true,
		["Portal: Orgrimmar"] = true,
		["Portal: Shattrath"] = true,
		["Portal: Silvermoon"] = true,
		["Portal: Stormwind"] = true,
		["Portal: Thunder Bluff"] = true,
		["Portal: Undercity"] = true,
		["Positive Charge"] = true,
		["Pounce"] = true,
		["Pounce Bleed"] = true,
		["Power Infusion"] = true,
		["Power Word: Fortitude"] = true,
		["Power Word: Shield"] = true,
		["Prayer of Fortitude"] = true,
		["Prayer of Healing"] = true,
		["Prayer of Mending"] = true,
		["Prayer of Shadow Protection"] = true,
		["Prayer of Spirit"] = true,
		["Precision"] = true,
		["Predatory Instincts"] = true,
		["Predatory Strikes"] = true,
		["Premeditation"] = true,
		["Preparation"] = true,
		["Presence of Mind"] = true,
		["Primal Fury"] = true,
		["Prismatic Cloak"] = true,
		["Profession Trainers"] = true,
		["Prospecting"] = true,
		["Prowl"] = true,
		["Psychic Scream"] = true,
		["Pummel"] = true,
		["Purge"] = true,
		["Purification"] = true,
		["Purify"] = true,
		["Purifying Power"] = true,
		["Pursuit of Justice"] = true,
		["Pyroblast"] = true,
		["Pyroclasm"] = true,
		["Pyromaniac"] = true,
		["Quick Recovery"] = true,
		["Quick Shots"] = true,
		["Quickness"] = true,
		["Rage of the Unraveller"] = true,
		["Rain of Fire"] = true,
		["Rake"] = true,
		["Ram Riding"] = true,
		["Rampage"] = true,
		["Ranged Weapon Specialization"] = true,
		["Rapid Fire"] = true,
		["Rapid Killing"] = true,
		["Raptor Riding"] = true,
		["Raptor Strike"] = true,
		["Ravage"] = true,
		["Readiness"] = true,
		["Reagents"] = true,
		["Rebirth"] = true,
		["Reckless Charge"] = true,
		["Recklessness"] = true,
		["Reckoning"] = true,
		["Redemption"] = true,
		["Redoubt"] = true,
		["Reflection"] = true,
		["Regeneration"] = true,
		["Regrowth"] = true,
		["Reincarnation"] = true,
		["Reinforced Shield"] = true,
		["Rejuvenation"] = true,
		["Relentless Strikes"] = true,
		["Remorseless"] = true,
		["Remorseless Attacks"] = true,
		["Remote Toy"] = true,
		["Remove Curse"] = true,
		["Remove Insignia"] = true,
		["Remove Lesser Curse"] = true,
		["Rend"] = true,
		["Renew"] = true,
		["Repair"] = true,
		["Repentance"] = true,
		["Restless Strength"] = true,
		["Restorative Totems"] = true,
		["Resurrection"] = true,
		["Retaliation"] = true,
		["Retribution Aura"] = true,
		["Revenge"] = true,
		["Revenge Stun"] = true,
		["Reverberation"] = true,
		["Revive Pet"] = true,
		["Righteous Defense"] = true,
		["Righteous Fury"] = true,
		["Rip"] = true,
		["Riposte"] = true,
		["Ritual of Doom"] = true,
		["Ritual of Doom Effect"] = true,
		["Ritual of Souls"] = true,
		["Ritual of Summoning"] = true,
		["Rockbiter Weapon"] = true,
		["Rough Sharpening Stone"] = true,
		["Ruin"] = true,
		["Rupture"] = true,
		["Ruthlessness"] = true,
		["Sacrifice"] = true,
		["Safe Fall"] = true,
		["Sanctified Crusader"] = true,
		["Sanctified Judgement"] = true,
		["Sanctified Light"] = true,
		["Sanctity Aura"] = true,
		["Sap"] = true,
		["Savage Fury"] = true,
		["Savage Strikes"] = true,
		["Scare Beast"] = true,
		["Scatter Shot"] = true,
		["Scorch"] = true,
		["Scorpid Poison"] = true,
		["Scorpid Sting"] = true,
		["Screech"] = true,
		["Seal Fate"] = true,
		["Seal of Blood"] = true,
		["Seal of Command"] = true,
		["Seal of Justice"] = true,
		["Seal of Light"] = true,
		["Seal of Righteousness"] = true,
		["Seal of Vengeance"] = true,
		["Seal of Wisdom"] = true,
		["Seal of the Crusader"] = true,
		["Searing Light"] = true,
		["Searing Pain"] = true,
		["Searing Totem"] = true,
		["Second Wind"] = true,
		["Seduction"] = true,
		["Seed of Corruption"] = true,
		["Seethe"] = true,
		["Sense Demons"] = true,
		["Sense Undead"] = true,
		["Sentry Totem"] = true,
		["Serpent Sting"] = true,
		["Serrated Blades"] = true,
		["Setup"] = true,
		["Shackle Undead"] = true,
		["Shadow Affinity"] = true,
		["Shadow Bolt"] = true,
		["Shadow Embrace"] = true,
		["Shadow Focus"] = true,
		["Shadow Mastery"] = true,
		["Shadow Power"] = true,
		["Shadow Protection"] = true,
		["Shadow Reach"] = true,
		["Shadow Resistance"] = true,
		["Shadow Resistance Aura"] = true,
		["Shadow Trance"] = true,
		["Shadow Vulnerability"] = true,
		["Shadow Ward"] = true,
		["Shadow Weakness"] = true,
		["Shadow Weaving"] = true,
		["Shadow Word: Death"] = true,
		["Shadow Word: Pain"] = true,
		["Shadow and Flame"] = true,
		["Shadow of Death"] = true,
		["Shadowburn"] = true,
		["Shadowfiend"] = true,
		["Shadowform"] = true,
		["Shadowfury"] = true,
		["Shadowguard"] = true,
		["Shadowmeld"] = true,
		["Shadowmeld Passive"] = true,
		["Shadowstep"] = true,
		["Shamanistic Rage"] = true,
		["Sharpened Claws"] = true,
		["Shatter"] = true,
		["Shell Shield"] = true,
		["Shield"] = true,
		["Shield Bash"] = true,
		["Shield Bash - Silenced"] = true,
		["Shield Block"] = true,
		["Shield Slam"] = true,
		["Shield Specialization"] = true,
		["Shield Wall"] = true,
		["Shiv"] = true,
		["Shoot"] = true,
		["Shoot Bow"] = true,
		["Shoot Gun"] = true,
		["Shred"] = true,
		["Shredding Attacks"] = true,
		["Silence"] = true,
		["Silencing Shot"] = true,
		["Silent Resolve"] = true,
		["Silverwing Flag"] = true,
		["Sinister Strike"] = true,
		["Siphon Life"] = true,
		["Skinning"] = true,
		["Slam"] = true,
		["Slayer's Crest"] = true,
		["Sleep"] = true,
		["Slice and Dice"] = true,
		["Slow"] = true,
		["Slow Fall"] = true,
		["Smelting"] = true,
		["Smite"] = true,
		["Snake Trap"] = true,
		["Solid Sharpening Stone"] = true,
		["Sonic Burst"] = true,
		["Soothe Animal"] = true,
		["Soothing Kiss"] = true,
		["Soul Fire"] = true,
		["Soul Leech"] = true,
		["Soul Link"] = true,
		["Soul Siphon"] = true,
		["Soulshatter"] = true,
		["Soulstone Resurrection"] = true,
		["Spell Haste"] = true,
		["Spell Lock"] = true,
		["Spell Power"] = true,
		["Spell Reflection"] = true,
		["Spell Vulnerability"] = true,
		["Spell Warding"] = true,
		["Spellsteal"] = true,
		["Spirit Bond"] = true,
		["Spirit Tap"] = true,
		["Spirit of Redemption"] = true,
		["Spiritual Attunement"] = true,
		["Spiritual Focus"] = true,
		["Spiritual Guidance"] = true,
		["Spiritual Healing"] = true,
		["Spiteful Fury"] = true,
		["Sprint"] = true,
		["StableMaster"] = true,
		["Stance Mastery"] = true,
		["Starfire"] = true,
		["Starfire Stun"] = true,
		["Starlight Wrath"] = true,
		["Starshards"] = true,
		["Static Charge"] = true,
		["Staves"] = true,
		["Steady Shot"] = true,
		["Stealth"] = true,
		["Stoneclaw Stun"] = true,
		["Stoneclaw Totem"] = true,
		["Stoneform"] = true,
		["Stoneskin"] = true,
		["Stoneskin Totem"] = true,
		["Stormstrike"] = true,
		["Strength of Earth"] = true,
		["Strength of Earth Totem"] = true,
		["Strength of the Halaani"] = true,
		["Stuck"] = true,
		["Stun"] = true,
		["Subtlety"] = true,
		["Suffering"] = true,
		["Summon Charger"] = true,
		["Summon Dreadsteed"] = true,
		["Summon Felguard"] = true,
		["Summon Felhunter"] = true,
		["Summon Felsteed"] = true,
		["Summon Imp"] = true,
		["Summon Succubus"] = true,
		["Summon Voidwalker"] = true,
		["Summon Warhorse"] = true,
		["Summon Water Elemental"] = true,
		["Sunder Armor"] = true,
		["Suppression"] = true,
		["Surefooted"] = true,
		["Surge of Light"] = true,
		["Surprise Attacks"] = true,
		["Survivalist"] = true,
		["Sweeping Strikes"] = true,
		["Swift Flight Form"] = true,
		["Swiftmend"] = true,
		["Swipe"] = true,
		["Sword Specialization"] = true,
		["Symbol of Hope"] = true,
		["Tactical Mastery"] = true,
		["Tailoring"] = true,
		["Tainted Blood"] = true,
		["Tainted Mind"] = true,
		["Tame Beast"] = true,
		["Taunt"] = true,
		["Teleport: Darnassus"] = true,
		["Teleport: Exodar"] = true,
		["Teleport: Ironforge"] = true,
		["Teleport: Moonglade"] = true,
		["Teleport: Orgrimmar"] = true,
		["Teleport: Shattrath"] = true,
		["Teleport: Silvermoon"] = true,
		["Teleport: Stormwind"] = true,
		["Teleport: Thunder Bluff"] = true,
		["Teleport: Undercity"] = true,
		["Temporal Rift"] = true,
		["The Beast Within"] = true,
		["The Human Spirit"] = true,
		["Thick Hide"] = true,
		["Thorns"] = true,
		["Thrill of the Hunt"] = true,
		["Throw"] = true,
		["Throwing Specialization"] = true,
		["Thrown"] = true,
		["Thunder Clap"] = true,
		["Thunderfury"] = true,
		["Thundering Strikes"] = true,
		["Thunderstomp"] = true,
		["Tidal Focus"] = true,
		["Tidal Mastery"] = true,
		["Tiger Riding"] = true,
		["Tiger's Fury"] = true,
		["Time's Favor"] = true,
		["Torment"] = true,
		["Totem"] = true,
		["Totem of Wrath"] = true,
		["Totemic Call"] = true,
		["Totemic Focus"] = true,
		["Touch of Shadow"] = true,
		["Touch of Weakness"] = true,
		["Toughness"] = true,
		["Traces of Silithyst"] = true,
		["Track Beasts"] = true,
		["Track Demons"] = true,
		["Track Dragonkin"] = true,
		["Track Elementals"] = true,
		["Track Giants"] = true,
		["Track Hidden"] = true,
		["Track Humanoids"] = true,
		["Track Undead"] = true,
		["Tranquil Air"] = true,
		["Tranquil Air Totem"] = true,
		["Tranquil Spirit"] = true,
		["Tranquility"] = true,
		["Tranquilizing Shot"] = true,
		["Trap Mastery"] = true,
		["Travel Form"] = true,
		["Tree of Life"] = true,
		["Tremor Totem"] = true,
		["Tribal Leatherworking"] = true,
		["Trueshot Aura"] = true,
		["Turn Undead"] = true,
		["Twin Spire Blessing"] = true,
		["Two-Handed Axes"] = true,
		["Two-Handed Axes and Maces"] = true,
		["Two-Handed Maces"] = true,
		["Two-Handed Swords"] = true,
		["Two-Handed Weapon Specialization"] = true,
		["Unarmed"] = true,
		["Unbreakable Will"] = true,
		["Unbridled Wrath"] = true,
		["Undead Horsemanship"] = true,
		["Underwater Breathing"] = true,
		["Unending Breath"] = true,
		["Unholy Power"] = true,
		["Unleashed Fury"] = true,
		["Unleashed Rage"] = true,
		["Unstable Affliction"] = true,
		["Unstable Power"] = true,
		["Unyielding Faith"] = true,
		["Vampiric Embrace"] = true,
		["Vampiric Touch"] = true,
		["Vanish"] = true,
		["Vanished"] = true,
		["Vengeance"] = true,
		["Venomous Totem"] = true,
		["Victory Rush"] = true,
		["Vigor"] = true,
		["Vile Beam"] = true,
		["Vile Poisons"] = true,
		["Vindication"] = true,
		["Viper Sting"] = true,
		["Volley"] = true,
		["Wand Specialization"] = true,
		["Wands"] = true,
		["War Stomp"] = true,
		["Warp"] = true,
		["Warsong Flag"] = true,
		["Water Breathing"] = true,
		["Water Shield"] = true,
		["Water Tomb"] = true,
		["Water Walking"] = true,
		["Waterbolt"] = true,
		["Watery Grave"] = true,
		["Weakened Soul"] = true,
		["Weapon Mastery"] = true,
		["Weaponsmith"] = true,
		["Whirlwind"] = true,
		["Will of the Forsaken"] = true,
		["Windfury"] = true,
		["Windfury Attack"] = true,
		["Windfury Totem"] = true,
		["Windfury Weapon"] = true,
		["Windwall"] = true,
		["Windwall Totem"] = true,
		["Wing Clip"] = true,
		["Winter's Chill"] = true,
		["Wisp Spirit"] = true,
		["Wolf Riding"] = true,
		["Wound Poison"] = true,
		["Wound Poison II"] = true,
		["Wound Poison III"] = true,
		["Wound Poison IV"] = true,
		["Wound Poison V"] = true,
		["Wrath"] = true,
		["Wrath of Air Totem"] = true,
		["Wrath of Cenarius"] = true,
		["Wrath of the Astromancer"] = true,
		["Wyvern Sting"] = true,
}

if GAME_LOCALE == "enUS" then
	lib:SetCurrentTranslations(true)
elseif GAME_LOCALE == "deDE" then
	lib:SetCurrentTranslations {
		["Abolish Disease"] = "Krankheit aufheben",
		["Abolish Poison"] = "Vergiftung aufheben",
		["Abolish Poison Effect"] = "Vergiftung aufheben - Effekt",
		["Activate MG Turret"] = "MG-Turm aktivieren",
		["Adrenaline Rush"] = "Adrenalinrausch",
		["Aftermath"] = "Nachwirkung",
		["Aggression"] = "Aggression",
		["Aimed Shot"] = "Gezielter Schuss",
		["Alchemy"] = "Alchimie",
		["Ambush"] = "Hinterhalt",
		["Ammunition"] = "Munition", --check
		["Amplify Curse"] = "Fluch verst\195\164rken",
		["Amplify Magic"] = "Magie verst\195\164rken",
		["Ancestral Fortitude"] = "Seelenst\195\164rke der Ahnen",
		["Ancestral Healing"] = "Heilung der Ahnen",
		["Ancestral Knowledge"] = "Wissen der Ahnen",
		["Ancestral Spirit"] = "Geist der Ahnen",
		["Ancient Hysteria"] = "Uralte Hysterie",
		["Anesthetic Poison"] = "Beruhigendes Gift",
		["Anger Management"] = "Aggressionskontrolle",
		["Anguish"] = "Seelenpein",
		["Anticipation"] = "Vorahnung",
		["Aquatic Form"] = "Wassergestalt",
		["Arcane Blast"] = "Arkanschlag",
		["Arcane Brilliance"] = "Arkane Brillanz",
		["Arcane Concentration"] = "Arkane Konzentration",
		["Arcane Energy"] = "Arkane Energie",
		["Arcane Explosion"] = "Arkane Explosion",
		["Arcane Focus"] = "Arkaner Fokus",
		["Arcane Fortitude"] = "Arkane Seelenst\195\164rke",
		["Arcane Impact"] = "Arkaner Einschlag",
		["Arcane Instability"] = "Arkane Instabilit\195\164t",
		["Arcane Intellect"] = "Arkane Intelligenz",
		["Arcane Meditation"] = "Arkane Meditation",
		["Arcane Mind"] = "Arkaner Geist",
		["Arcane Missiles"] = "Arkane Geschosse",
		["Arcane Potency"] = "Arkane Kraft",
		["Arcane Power"] = "Arkane Macht",
		["Arcane Resistance"] = "Arkanwiderstand",
		["Arcane Shot"] = "Arkaner Schuss",
		["Arcane Shroud"] = "Arkaner Schleier",
		["Arcane Subtlety"] = "Arkanes Feingef\195\188hl",
		["Arcane Torrent"] = "Arkaner Strom",
		["Arcane Weakness"] = "Arkane Verwundbarkeit",
		["Arctic Reach"] = "Arktische Reichweite",
		["Arctic Winds"] = "Arktische Winde",
		["Armor of Faith"] = "R\195\188stung des Glaubens",
		["Armorsmith"] = "R\195\188stungsschmied",
		["Aspect of the Beast"] = "Aspekt des Wildtiers",
		["Aspect of the Cheetah"] = "Aspekt des Geparden",
		["Aspect of the Hawk"] = "Aspekt des Falken",
		["Aspect of the Monkey"] = "Aspekt des Affen",
		["Aspect of the Pack"] = "Aspekt des Rudels",
		["Aspect of the Viper"] = "Aspekt der Viper",
		["Aspect of the Wild"] = "Aspekt der Wildnis",
		["Astral Recall"] = "Astraler R\195\188ckruf",
		["Attack"] = "Angreifen",
		["Attacking"] = "Angreifen",
		["Auto Shot"] = "Automatischer Schuss",
		["Avenger's Shield"] = "Schild des R\195\164chers",
		["Avenging Wrath"] = "Zornige Vergeltung",
		["Avoidance"] = "Vermeidung",
		["Axe Specialization"] = "Axt-Spezialisierung",
		["Backlash"] = "Heimzahlen",
		["Backstab"] = "Meucheln",
		["Badge of the Swarmguard"] = "Abzeichen der Schwarmwache",
		["Balance of Power"] = "Gleichgewicht der Kr\195\164fte",
		["Bane"] = "Dunkle Macht",
		["Banish"] = "Verbannen",
		["Banker"] = "Bankier",
		["Barkskin"] = "Baumrinde",
		["Barrage"] = "Sperrfeuer",
		["Bash"] = "Hieb",
		["Basic Campfire"] = "Einfaches Lagerfeuer",
		["BattleMaster"] = "Kampfmeister",
		["Battle Rush"] = "Kampfsturm",
		["Battle Shout"] = "Schlachtruf",
		["Battle Stance"] = "Kampfhaltung",
		["Battle Stance Passive"] = "Kampfhaltung Passiv",
		["Bear Form"] = "B\195\164rengestalt",
		["Beast Lore"] = "Wildtierkunde",
		["Beast Slaying"] = "Wildtierschl\195\164chter",
		["Beast Training"] = "Wildtierausbildung",
		["Benediction"] = "Segnung",
		["Berserker Rage"] = "Berserkerwut",
		["Berserker Stance"] = "Berserkerhaltung",
		["Berserker Stance Passive"] = "Berserkerhaltung - Passiv",
		["Berserking"] = "Berserker",
		["Bestial Discipline"] = "Wildtierdisziplin",
		["Bestial Swiftness"] = "Erh\195\182hte Tiergeschwindigkeit",
		["Bestial Wrath"] = "Zorn des Wildtiers",
		["Binding Heal"] = "Verbindende Heilung",
		["Bite"] = "Bei\195\159en",
		["Black Arrow"] = "Schwarzer Pfeil",
		["Blackout"] = "Verdunkelung",
		["Blacksmithing"] = "Schmiedekunst",
		["Blade Flurry"] = "Klingenwirbel",
		["Blade Turning"] = "Klingendrehen",
		["Blade Twisting"] = "Klingenwendung",
		["Blast Wave"] = "Druckwelle",
		["Blazing Speed"] = "Hei\195\159e Sohlen",
		["Blessed Recovery"] = "Gesegnete Erholung",
		["Blessed Resilience"] = "Gesegnete Abh\195\164rtung",
		["Blessing of Auchindoun"] = "Segen von Auchindoun",
		["Blessing of Freedom"] = "Segen der Freiheit",
		["Blessing of Kings"] = "Segen der K\195\182nige",
		["Blessing of Light"] = "Segen des Lichts",
		["Blessing of Might"] = "Segen der Macht",
		["Blessing of Protection"] = "Segen des Schutzes",
		["Blessing of Sacrifice"] = "Segen der Opferung",
		["Blessing of Salvation"] = "Segen der Rettung",
		["Blessing of Sanctuary"] = "Segen des Refugiums",
		["Blessing of Wisdom"] = "Segen der Weisheit",
		["Blind"] = "Blenden",
		["Blinding Powder"] = "Blendungspulver",
		["Blink"] = "Blinzeln",
		["Blizzard"] = "Blizzard",
		["Block"] = "Blocken",
		["Blood Craze"] = "Blutwahnsinn",
		["Blood Frenzy"] = "Blutraserei",
		["Blood Fury"] = "Kochendes Blut",
		["Blood Pact"] = "Blutpakt",
		["Bloodlust"] = "Kampfrausch",
		["Bloodrage"] = "Blutrausch",
		["Bloodthirst"] = "Blutdurst",
		["Boar Charge"] = "Eber Strumangriff",
		["Booming Voice"] = "Donnernde Stimme",
		["Bow Specialization"] = "Bogenspezialisierung",
		["Bows"] = "Bogen",
		["Bright Campfire"] = "Helles Lagerfeuer",
		["Brittle Armor"] = "Spr\195\182de Rustung",
		["Brutal Impact"] = "Brutaler Hieb",
		["Burning Adrenaline"] = "Brennendes Adrenalin",
		["Burning Soul"] = "Brennende Seele",
		["Burning Wish"] = "Brennender Wunsch",
		["Call Pet"] = "Tier rufen",
		["Call of Flame"] = "Ruf der Flamme",
		["Call of Thunder"] = "Ruf des Donners",
		["Call of the Nexus"] = "Ruf des Nexus",
		["Camouflage"] = "Tarnung",
		["Cannibalize"] = "Kannibalismus",
		["Cat Form"] = "Katzengestalt",
		["Cataclysm"] = "Katastrophe",
		["Celestial Focus"] = "Verbessertes Sternenfeuer",
		["Chain Heal"] = "Kettenheilung",
		["Chain Lightning"] = "Kettenblitzschlag",
		["Challenging Roar"] = "Herausforderndes Gebr\195\188ll",
		["Challenging Shout"] = "Herausforderungsruf",
		["Charge"] = "Sturmangriff",
		["Charge Rage Bonus Effect"] = "Wut-Aufladung-Bonus-Effekt",
		["Charge Stun"] = "Sturmangriffsbet\195\164ubung",
		["Cheap Shot"] = "Fieser Trick",
		["Chilled"] = "K\195\164lte",
		["Circle of Healing"] = "Kreis der Heilung",
		["Class Trainer"] = "Lehrer fur eine Klasse",
		["Claw"] = "Klaue",
		["Cleanse"] = "Reinigung des Glaubens",
		["Clearcasting"] = "Freizaubern",
		["Cleave"] = "Spalten",
		["Clever Traps"] = "Falleneffizienz",
		["Cloak of Shadows"] = "Mantel der Schatten",
		["Closing"] = "Schlie\195\159en",
		["Cloth"] = "Stoff",
		["Coarse Sharpening Stone"] = "Grober Wetzstein",
		["Cobra Reflexes"] = "Kobrareflexe",
		["Cold Blood"] = "Kaltbl\195\188tigkeit",
		["Cold Snap"] = "K\195\164lteeinbruch",
		["Combat Endurance"] = "Durchhalteverm\195\182gen des K\195\164mpfers",
		["Combustion"] = "Verbrennung",
		["Command"] = "Befehlsgewalt",
		["Commanding Presence"] = "Verbesserter Schlachtruf",
		["Commanding Shout"] = "Befehlsruf",
		["Concentration Aura"] = "Aura der Konzentration",
		["Concussion"] = "Ersch\195\188tterung",
		["Concussion Blow"] = "Ersch\195\188tternder Schlag",
		["Concussive Barrage"] = "Ersch\195\188tterndes Sperrfeuer",
		["Concussive Shot"] = "Ersch\195\188tternder Schuss",
		["Cone of Cold"] = "K\195\164ltekegel",
		["Conflagrate"] = "Feuersbrunst",
		["Conjure Food"] = "Essen herbeizaubern",
		["Conjure Mana Agate"] = "Manaachat herbeizaubern",
		["Conjure Mana Citrine"] = "Manacitrin herbeizaubern",
		["Conjure Mana Emerald"] = "Manasmaragd herbeizaubern",
		["Conjure Mana Jade"] = "Manajadestein herbeizaubern",
		["Conjure Mana Ruby"] = "Manarubin herbeizaubern",
		["Conjure Water"] = "Wasser herbeizaubern",
		["Consecration"] = "Weihe",
		["Consume Magic"] = "Magie verzehren",
		["Consume Shadows"] = "Schatten verzehren",
		["Contagion"] = "Ansteckung",
		["Convection"] = "Konvektion",
		["Conviction"] = "\195\156berzeugung",
		["Cooking"] = "Kochkunst",
		["Corruption"] = "Verderbnis",
		["Counterattack"] = "Gegenangriff",
		["Counterspell"] = "Gegenzauber",
		["Counterspell - Silenced"] = "Gegenzauber - zum Schweigen gebracht",
		["Cower"] = "Ducken",
		["Create Firestone"] = "Feuerstein herstellen",
		["Create Firestone (Greater)"] = "Feuerstein herstellen (Gr\195\182\sser)",
		["Create Firestone (Lesser)"] = "Feuerstein herstellen (Kleiner)",
		["Create Firestone (Major)"] = "Feuerstein herstellen (Gro\195\159er)",
		["Create Healthstone"] = "Gesundheitsstein herstellen",
		["Create Healthstone (Greater)"] = "Gesundheitsstein herstellen (Gr\195\182\sser)",
		["Create Healthstone (Lesser)"] = "Gesundheitsstein herstellen (Kleiner)",
		["Create Healthstone (Major)"] = "Gesundheitsstein herstellen (Gro\195\159er)",
		["Create Healthstone (Minor)"] = "Gesundheitsstein herstellen (Klein)",
		["Create Soulstone"] = "Seelenstein herstellen",
		["Create Soulstone (Greater)"] = "Seelenstein herstellen (Gr\195\182\sser)",
		["Create Soulstone (Lesser)"] = "Seelenstein herstellen (Kleiner)",
		["Create Soulstone (Major)"] = "Seelenstein herstellen (Gro\195\159er)",
		["Create Soulstone (Minor)"] = "Seelenstein herstellen (Klein)",
		["Create Spellstone"] = "Zauberstein herstellen",
		["Create Spellstone (Greater)"] = "Zauberstein herstellen (Gr\195\182\sser)",
		["Create Spellstone (Major)"] = "Zauberstein herstellen (Gro\195\159er)",
		["Create Spellstone (Master)"] = "Zauberstein herstellen (meisterlich)",
		["Cripple"] = "Verkr\195\188ppeln",
		["Crippling Poison"] = "Verkr\195\188ppelndes Gift",
		["Crippling Poison II"] = "Verkr\195\188ppelndes Gift II",
		["Critical Mass"] = "Kritische Masse",
		["Crossbows"] = "Armbr\195\188ste",
		["Cruelty"] = "Grausamkeit",
		["Crusade"] = "Kreuzzug",
		["Crusader Aura"] = "Aura des Kreuzfahrers",
		["Crusader Strike"] = "Kreuzfahrersto\195\159",
		["Cultivation"] = "Gr\195\188ner Daumen",
		["Cure Disease"] = "Krankheit heilen",
		["Cure Poison"] = "Vergiftung heilen",
		["Curse of Agony"] = "Fluch der Pein",
		["Curse of Doom"] = "Fluch der Verdammnis",
		["Curse of Doom Effect"] = "Fluch der Verdammnis'-Effekt",
		["Curse of Exhaustion"] = "Fluch der Ersch\195\182pfung",
		["Curse of Idiocy"] = "Fluch der Torheit",
		["Curse of Recklessness"] = "Fluch der Tollk\195\188hnheit",
		["Curse of Shadow"] = "Fluch der Schatten",
		["Curse of Tongues"] = "Fluch der Sprachen",
		["Curse of Weakness"] = "Fluch der Schw\195\164che",
		["Curse of the Elements"] = "Fluch der Elemente",
		["Cyclone"] = "Wirbelsturm",
		["Dagger Specialization"] = "Dolch-Spezialisierung",
		["Daggers"] = "Dolche",
		["Dampen Magic"] = "Magie d\195\164mpfen",
		["Dark Pact"] = "Dunkler Pakt",
		["Darkness"] = "Dunkelheit",
		["Dash"] = "Spurt",
		["Dazed"] = "Benommen",
		["Dawnstone Crab"] = "D\195\164mmersteinkrebs",
		["Deadly Interrupt Effect"] = "T\195\182tlicher Unterbrechungseffekt",
		["Deadly Poison"] = "T\195\182dliches Gift",
		["Deadly Poison II"] = "T\195\182dliches Gift II",
		["Deadly Poison III"] = "T\195\182dliches Gift III",
		["Deadly Poison IV"] = "T\195\182dliches Gift IV",
		["Deadly Poison V"] = "T\195\182dliches Gift V",
		["Deadly Poison VI"] = "T\195\182dliches Gift VI",
		["Deadly Poison VII"] = "T\195\182dliches Gift VII",
		["Deadly Throw"] = "T\195\182dlicher Wurf",
		["Death Coil"] = "Todesmantel",
		["Death Wish"] = "Todeswunsch",
		["Deep Wound"] = "Tiefe Wunde",
		["Deep Wounds"] = "Tiefe Wunden",
		["Defense"] = "Verteidigung",
		["Defensive Stance"] = "Verteidigungshaltung",
		["Defensive Stance Passive"] = "Verteidigungshaltung - Passiv",
		["Defiance"] = "Trotz",
		["Deflection"] = "Abwehr",
		["Delusions of Jin'do"] = "Irrbilder von Jin'do",
		["Demon Armor"] = "D\195\164monenr\195\188stung",
		["Demon Skin"] = "D\195\164monenhaut",
		["Demonic Aegis"] = "D\195\164monische \195\132gide",
		["Demonic Embrace"] = "D\195\164monische Umarmung",
		["Demonic Frenzy"] = "D\195\164monische Raserei",
		["Demonic Knowledge"] = "D\195\164monisches Wissen",
		["Demonic Resilience"] = "D\195\164monische Seelenst\195\164rke",
		["Demonic Sacrifice"] = "D\195\164monische Opferung",
		["Demonic Tactics"] = "D\195\164monische Taktiken",
		["Demoralizing Roar"] = "Demoralisierendes Gebr\195\188ll",
		["Demoralizing Shout"] = "Demoralisierender Ruf",
		["Dense Sharpening Stone"] = "Verdichteter Wetzstein",
		["Desperate Prayer"] = "Verzweifeltes Gebet",
		["Destructive Reach"] = "Zerst\195\182rerische Reichweite",
		["Detect"] = "Entdecken",
		["Detect Greater Invisibility"] = "Gro\195\159e Unsichtbarkeit entdecken",
		["Detect Invisibility"] = "Unsichtbarkeit entdecken",
		["Detect Lesser Invisibility"] = "Geringe Unsichtbarkeit entdecken",
		["Detect Magic"] = "Magie entdecken",
		["Detect Traps"] = "Fallen entdecken",
		["Deterrence"] = "Abschreckung",
		["Devastate"] = "Verw\195\188sten",
		["Devastation"] = "Verw\195\188stung",
		["Devotion Aura"] = "Aura der Hingabe",
		["Devour Magic"] = "Magie verschlingen",
		["Devour Magic Effect"] = "Magie verschlingen' - Effekt",
		["Devouring Plague"] = "Verschlingende Seuche",
		["Diplomacy"] = "Diplomatie",
		["Dire Bear Form"] = "Terrorb\195\164rengestalt",
		["Dirty Deeds"] = "Gemeinheiten",
		["Dirty Tricks"] = "Verbesserte Kopfnuss",
		["Disarm"] = "Entwaffnen",
		["Disarm Trap"] = "Falle entsch\195\164rfen",
		["Disease Cleansing Totem"] = "Totem der Krankheitsreinigung",
		["Disenchant"] = "Entzaubern",
		["Disengage"] = "R\195\188ckzug",
		["Dismiss Pet"] = "Tier freigeben",
		["Dispel Magic"] = "Magiebannung",
		["Distract"] = "Ablenken",
		["Distracting Shot"] = "Ablenkender Schuss",
		["Dive"] = "Sturzflug",
		["Divine Favor"] = "G\195\182ttliche Gunst",
		["Divine Fury"] = "G\195\182ttlicher Furor",
		["Divine Illumination"] = "G\195\182ttliche Eingebung",
		["Divine Intellect"] = "G\195\182ttliche Weisheit",
		["Divine Intervention"] = "G\195\182ttliches Eingreifen",
		["Divine Protection"] = "G\195\182ttlicher Schutz",
		["Divine Shield"] = "Gottesschild",
		["Divine Spirit"] = "G\195\182ttlicher Willen",
		["Divine Strength"] = "G\195\182ttliche St\195\164rke",
		["Dodge"] = "Ausweichen",
		["Dragon's Breath"] = "Drachenodem",
		["Dragonscale Leatherworking"] = "Drachenschuppenlederverarbeitung",
		["Drain Life"] = "Blutsauger",
		["Drain Mana"] = "Mana entziehen",
		["Drain Soul"] = "Seelendieb",
		["Dreamless Sleep"] = "Traumloser Schlaf",
		["Drink"] = "Trinken",
		["Dual Wield"] = "Beidh\195\164ndigkeit",
		["Dual Wield Specialization"] = "Beidh\195\164ndigkeits-Spezialisierung",
		["Duel"] = "Duell",
		["Dust Cloud"] = "Staubwolke",
		["Eagle Eye"] = "Adlerauge",
		["Earth Elemental Totem"] = "Totem des Erdelementars",
		["Earth Shield"] = "Erdschild",
		["Earth Shock"] = "Erdschock",
		["Earthbind"] = "Erdbindung",
		["Earthbind Totem"] = "Totem der Erdbindung",
		["Earthstrike"] = "Erdschlag",
		["Efficiency"] = "Effizienz",
		["Elemental Devastation"] = "Elementare Verw\195\188stung",
		["Elemental Focus"] = "Elementarfokus",
		["Elemental Fury"] = "Elementarfuror",
		["Elemental Leatherworking"] = "Elementarlederverarbeitung",
		["Elemental Mastery"] = "Elementarbeherrschung",
		["Elemental Precision"] = "Elementare Pr\195\164zision",
		["Elemental Sharpening Stone"] = "Elementarwetzstein",
		["Elemental Weapons"] = "Elementarwaffen",
		["Elune's Grace"] = "Elunes Anmut",
		["Elusiveness"] = "Fl\195\188chtigkeit",
		["Emberstorm"] = "Glutsturm",
		["Empowered Arcane Missiles"] = "Machtvolle arkane Geschosse",
		["Empowered Corruption"] = "Machtvolle Verderbnis",
		["Empowered Fireball"] = "Machtvoller Feuerball",
		["Empowered Frostbolt"] = "Machtvoller Frostblitz",
		["Empowered Healing"] = "Machtvolle Heilung",
		["Empowered Rejuvenation"] = "Machtvolle Verj\195\188ngung",
		["Empowered Touch"] = "Machtvolle Ber\195\188hrung",
		["Enamored Water Spirit"] = "Entz\195\188ckter Wassergeist",
		["Enchanting"] = "Verzauberkunst",
		["Endurance"] = "Durchhalteverm\195\182gen",
		["Endurance Training"] = "Belastbarkeit-Ausbildung",
		["Engineering"] = "Ingenieurskunst",
		["Engineering Specialization"] = "Technologist",
		["Enrage"] = "Wutanfall",
		["Enriched Manna Biscuit"] = "Angereicherter Manakeks",
		["Enslave Demon"] = "D\195\164monensklave",
		["Entangling Roots"] = "Wucherwurzeln",
		["Entrapment"] = "Einfangen",
		["Envenom"] = "Vergiften",
		["Escape Artist"] = "Entfesselungsk\195\188nstler",
		["Evasion"] = "Entrinnen",
		["Eviscerate"] = "Ausweiden",
		["Evocation"] = "Hervorrufung",
		["Execute"] = "Hinrichten",
		["Exorcism"] = "Exorzismus",
		["Expansive Mind"] = "Wacher Geist",
		["Explosive Trap"] = "Sprengfalle",
		["Explosive Trap Effect"] = "Sprengfalle'-Effekt",
		["Expose Armor"] = "R\195\188stung schw\195\164chen",
		["Expose Weakness"] = "Schw\195\164che aufdecken",
		["Extract Gas"] = "Gas extrahieren",
		["Eye for an Eye"] = "Auge um Auge",
		["Eye of Kilrogg"] = "Auge von Kilrogg",
		["Eye of the Storm"] = "Auge des Sturms",
		["Eyes of the Beast"] = "Augen des Wildtiers",
		["Fade"] = "Verblassen",
		["Faerie Fire"] = "Feenfeuer",
		["Faerie Fire (Feral)"] = "Feenfeuer (Tiergestalt)",
		["Fanaticism"] = "Fanatismus",
		["Far Sight"] = "Fernsicht",
		["Fear"] = "Furcht",
		["Fear Ward"] = "Furchtzauberschutz",
		["Feed Pet"] = "Tier f\195\188ttern",
		["Feed Pet Effect"] = "Tier f\195\188ttern Effekt",
		["Feedback"] = "R\195\188ckkopplung",
		["Feign Death"] = "Totstellen",
		["Feint"] = "Finte",
		["Fel Armor"] = "Teufelsr\195\188stung",
		["Fel Concentration"] = "Teufelskonzentration",
		["Fel Domination"] = "Teufelsbeherrschung",
		["Fel Energy"] = "Teufelsenergie",
		["Fel Intellect"] = "Teufelsintelligenz",
		["Fel Rage"] = "Teufelswut",
		["Fel Stamina"] = "Teufelsausdauer",
		["Felfire"] = "Teufelsfeuer",
		["Feline Grace"] = "Katzenhafte Anmut",
		["Feral Aggression"] = "Wilde Aggression",
		["Feral Charge"] = "Wilde Attacke",
		["Feral Instinct"] = "Instinkt der Wildnis",
		["Feral Swiftness"] = "Katzenhafte Schnelligkeit",
		["Ferocious Bite"] = "Wilder Biss",
		["Ferocious Inspiration"] = "Wilde Eingebung",
		["Ferocity"] = "Wildheit",
		["Fetish"] = "Fetisch",
		["Find Fish"] = "Fischesuche",
		["Find Herbs"] = "Kr\195\164utersuche",
		["Find Minerals"] = "Mineraliensuche",
		["Find Treasure"] = "Schatzsucher",
		["Find Weakness"] = "Schw\195\164chen aufsp\195\188ren",
		["Fire Blast"] = "Feuerschlag",
		["Fire Breath"] = "Feueratem",
		["Fire Elemental Totem"] = "Totem des Feuerelementars",
		["Fire Nova Totem"] = "Totem der Feuernova",
		["Fire Power"] = "Feuermacht",
		["Fire Resistance"] = "Feuerwiderstand",
		["Fire Resistance Aura"] = "Aura des Feuerwiderstands",
		["Fire Resistance Totem"] = "Totem des Feuerwiderstands",
		["Fire Shield"] = "Feuerschild",
		["Fire Vulnerability"] = "Feuerverwundbarkeit",
		["Fire Ward"] = "Feuerzauberschutz",
		["Fire Weakness"] = "Feuer Verwundbarkeit",
		["Fireball"] = "Feuerball",
		["Firebolt"] = "Feuerblitz",
		["First Aid"] = "Erste Hilfe",
		["Fishing"] = "Angeln",
		["Fishing Poles"] = "Angel",
		["Fist Weapon Specialization"] = "Faustwaffen-Spezialisierung",
		["Fist Weapons"] = "Faustwaffen",
		["Flame Shock"] = "Flammenschock",
		["Flame Throwing"] = "Flammenwerfen",
		["Flamestrike"] = "Flammensto\195\159",
		["Flamethrower"] = "Flammenwerfer",
		["Flametongue Attack"] = "Angriff der Flammenzunge",
		["Flametongue Totem"] = "Totem der Flammenzunge",
		["Flametongue Weapon"] = "Waffe der Flammenzunge",
		["Flare"] = "Leuchtfeuer",
		["Flash Heal"] = "Blitzheilung",
		["Flash of Light"] = "Lichtblitz",
		["Flight Form"] = "Fluggestalt",
		["FlightMaster"] = "Flugmeister",
		["Flurry"] = "Schlaghagel",
		["Focused Casting"] = "Fokussiertes Zauberwirken",
		["Focused Mind"] = "Fokussierte Gedanken",
		["Focused Power"] = "Fokussierte Energie",
		["Focused Rage"] = "Fokussierte Wut",
		["Focused Starlight"] = "Geb\195\188ndeltes Sternenlicht",
		["Food"] = "Essen",
		["Food & Drink"] = "Essen & Trinken",
		["Forbearance"] = "Vorahnung",
		["Force of Nature"] = "Naturgewalt",
		["Force of Will"] = "Macht des Willens",
		["Freezing Trap"] = "Eisk\195\164ltefalle",
		["Freezing Trap Effect"] = "Eisk\195\164ltefalle",
		["Frenzied Regeneration"] = "Rasende Regeneration",
		["Frenzy"] = "Raserei",
		["Frenzy Effect"] = "Wilde Eingebung",
		["Frost Armor"] = "Frostr\195\188stung",
		["Frost Blast"] = "Frostschlag",
		["Frost Channeling"] = "Frost-Kanalisierung",
		["Frost Nova"] = "Frostnova",
		["Frost Resistance"] = "Frostwiderstand",
		["Frost Resistance Aura"] = "Aura des Frostwiderstands",
		["Frost Resistance Totem"] = "Totem des Frostwiderstands",
		["Frost Shock"] = "Frostschock",
		["Frost Trap"] = "Frostfalle",
		["Frost Trap Aura"] = "Frostfalle-Aura",
		["Frost Ward"] = "Frostzauberschutz",
		["Frost Warding"] = "Schutz des Frostes",
		["Frost Weakness"] = "Frost Verwundbarkeit",
		["Frostbite"] = "Erfrierung",
		["Frostbolt"] = "Frostblitz",
		["Frostbrand Attack"] = "Frostbrandangriff",
		["Frostbrand Weapon"] = "Waffe des Frostbrands",
		["Frozen Core"] = "Tiefgefroren",
		["Furious Howl"] = "Wutgeheul",
		["Furor"] = "Furor",
		["Fury of the Crashing Waves"] = "Wut der zerschmetternden Wellen",
		["Garrote"] = "Erdrosseln",
		["Garrote - Silence"] = "Erdrossseln - Stille",
		["Ghost Wolf"] = "Geisterwolf",
		["Ghostly Strike"] = "Geisterhafter Sto\195\159",
		["Gift of Life"] = "Geschenk des Lebens",
		["Gift of Nature"] = "Geschenk der Natur",
		["Gift of the Naaru"] = "Gabe der Naaru",
		["Gift of the Wild"] = "Gabe der Wildnis",
		["Gouge"] = "Solarplexus",
		["Grace of Air"] = "Luftgleiche Anmut",
		["Grace of Air Totem"] = "Totem der luftgleichen Anmut",
		["Great Stamina"] = "Gro\195\159e Ausdauer",
		["Greater Blessing of Kings"] = "Gro\195\159er Segen der K\195\182nige",
		["Greater Blessing of Light"] = "Gro\195\159er Segen des Lichts",
		["Greater Blessing of Might"] = "Gro\195\159er Segen der Macht",
		["Greater Blessing of Salvation"] = "Gro\195\159er Segen der Rettung",
		["Greater Blessing of Sanctuary"] = "Gro\195\159er Segen des Refugiums",
		["Greater Blessing of Wisdom"] = "Gro\195\159er Segen der Weisheit",
		["Greater Dreamless Sleep"] = "Gro\195\159er traumloser Schlaf",
		["Greater Heal"] = "Gro\195\159e Heilung",
		["Grim Reach"] = "Grimmige Reichweite",
		["Grounding Totem"] = "Totem der Erdung",
		["Grounding Totem Effect"] = "Totem der Erdung Effekt",
		["Grovel"] = "Kriechen",
		["Growl"] = "Knurren",
		["Guardian's Favor"] = "Gunst des H\195\188ters",
		["Gun Specialization"] = "Schusswaffenspezialisierung",
		["Guns"] = "Schusswaffen",
		["Hammer of Justice"] = "Hammer der Gerechtigkeit",
		["Hammer of Wrath"] = "Hammer des Zorns",
		["Hamstring"] = "Kniesehne",
		["Harass"] = "Bel\195\164stigen",
		["Hardiness"] = "Z\195\164higkeit",
		["Haste"] = "Eile",
		["Hawk Eye"] = "Falkenauge",
		["Heal"] = "Heilen",
		["Healing Focus"] = "Heilfokus",
		["Healing Light"] = "Heilendes Licht",
		["Healing Stream"] = "Heilender Fluss",
		["Healing Stream Totem"] = "Totem des heilenden Flusses",
		["Healing Touch"] = "Heilende Ber\195\188hrung",
		["Healing Wave"] = "Welle der Heilung",
		["Healing Way"] = "Pfad der Heilung",
		["Health Funnel"] = "Lebenslinie",
		["Heart of the Wild"] = "Herz der Wildnis",
		["Heavy Sharpening Stone"] = "Schwerer Wetzstein",
		["Hellfire"] = "H\195\182llenfeuer",
		["Hellfire Effect"] = "H\195\182llenfeuer - Effekt",
		["Hellfire Superiority"] = "\195\156berlegenheit des H\195\182llenfeuers",
		["Hemorrhage"] = "Blutsturz",
		["Herb Gathering"] = "Kr\195\164utersammeln",
		["Herbalism"] = "Kr\195\164uterkunde",
		["Heroic Strike"] = "Heldenhafter Sto\195\159",
		["Heroism"] = "Heldentum",
		["Hex of Weakness"] = "Verhexung der Schw\195\164che",
		["Hibernate"] = "Winterschlaf",
		["Holy Fire"] = "Heiliges Feuer",
		["Holy Light"] = "Heiliges Licht",
		["Holy Nova"] = "Heilige Nova",
		["Holy Power"] = "Heilige Macht",
		["Holy Reach"] = "Heilige Reichweite",
		["Holy Shield"] = "Heiliger Schild",
		["Holy Shock"] = "Heiliger Schock",
		["Holy Specialization"] = "Macht des Glaubens",
		["Holy Wrath"] = "Heiliger Zorn",
		["Honorless Target"] = "Ehrenloses Ziel",
		["Horse Riding"] = "Pferdreiten",
		["Howl of Terror"] = "Schreckgeheul",
		["Humanoid Slaying"] = "Humanoident\195\182ten",
		["Hunter's Mark"] = "Mal des J\195\164gers",
		["Hurricane"] = "Hurrikan",
		["Hypothermia"] = "Hypothermie",
		["Ice Armor"] = "Eisr\195\188stung",
		["Ice Barrier"] = "Eisbarriere",
		["Ice Block"] = "Eisblock",
		["Ice Floes"] = "Eisschollen",
		["Ice Lance"] = "Eislanze",
		["Ice Shards"] = "Eissplitter",
		["Ignite"] = "Entz\195\188nden",
		["Ignite Mana"] = "Mana entz\195\188nden",
		["Illumination"] = "Illumination",
		["Immolate"] = "Feuerbrand",
		["Immolation Trap"] = "Feuerbrandfalle",
		["Immolation Trap Effect"] = "Feuerbrandfalle",
		["Impact"] = "Einschlag",
		["Impale"] = "Durchbohren",
		["Improved Ambush"] = "Verbesserter Hinterhalt",
		["Improved Arcane Missiles"] = "Verbesserte arkane Geschosse",
		["Improved Arcane Shot"] = "Verbesserter Arkaner Schuss",
		["Improved Aspect of the Hawk"] = "Verbesserter Aspekt des Falken",
		["Improved Aspect of the Monkey"] = "Verbesserter Aspekt des Affen",
		["Improved Backstab"] = "Verbessertes Meucheln",
		["Improved Barrage"] = "Verbessertes Sperrfeuer",
		["Improved Berserker Rage"] = "Verbesserte Berserkerwut",
		["Improved Blessing of Might"] = "Verbesserter Segen der Macht",
		["Improved Blessing of Wisdom"] = "Verbesserter Segen der Weisheit",
		["Improved Blink"] = "Verbessertes Blinzeln",
		["Improved Blizzard"] = "Verbesserter Blizzard",
		["Improved Bloodrage"] = "Verbesserter Blutrausch",
		["Improved Chain Heal"] = "Verbesserte Kettenheilung",
		["Improved Chain Lightning"] = "Verbesserter Kettenblitzschlag",
		["Improved Challenging Shout"] = "Verbesserter Herausforderungsruf",
		["Improved Charge"] = "Verbesserter Sturmangriff",
		["Improved Cleave"] = "Verbessertes Spalten",
		["Improved Concentration Aura"] = "Verbesserte Aura der Konzentration",
		["Improved Concussive Shot"] = "Verbesserter Ersch\195\188tternder Schuss",
		["Improved Cone of Cold"] = "Verbesserter K\195\164ltekegel",
		["Improved Corruption"] = "Verbesserte Verderbnis",
		["Improved Counterspell"] = "Verbesserter Gegenzauber",
		["Improved Curse of Agony"] = "Verbesserter Fluch der Pein",
		["Improved Curse of Weakness"] = "Verbesserter Fluch der Schw\195\164che",
		["Improved Demoralizing Shout"] = "Verbesserter Demoralisierender Ruf",
		["Improved Devotion Aura"] = "Verbesserte Aura der Hingabe",
		["Improved Disarm"] = "Verbessertes Entwaffnen",
		["Improved Drain Life"] = "Verbesserter Blutsauger",
		["Improved Drain Soul"] = "Verbesserter Seelendieb",
		["Improved Enrage"] = "Verbesserter Wutanfall",
		["Improved Enslave Demon"] = "Verbesserter D\195\164monensklave",
		["Improved Eviscerate"] = "Verbessertes Ausweiden",
		["Improved Execute"] = "Verbessertes Hinrichten",
		["Improved Expose Armor"] = "Verbessertes R\195\188stung schw\195\164chen",
		["Improved Eyes of the Beast"] = "Verbesserte Augen des Wildtiers",
		["Improved Fade"] = "Verbessertes Verblassen",
		["Improved Feign Death"] = "Verbessertes Totstellen",
		["Improved Fire Blast"] = "Verbesserter Feuerschlag",
		["Improved Fire Totems"] = "Verbesserte Feuertotems",
		["Improved Fire Ward"] = "Verbesserter Feuerzauberschutz",
		["Improved Fireball"] = "Verbesserter Feuerball",
		["Improved Firebolt"] = "Verbesserter Feuerblitz",
		["Improved Flamestrike"] = "Verbesserter Flammensto\195\159",
		["Improved Flash of Light"] = "Verbesserter Lichtblitz",
		["Improved Frost Nova"] = "Verbesserte Frostnova",
		["Improved Frostbolt"] = "Verbesserter Frostblitz",
		["Improved Ghost Wolf"] = "Verbesserter Geisterwolf",
		["Improved Gouge"] = "Verbesserter Solarplexus",
		["Improved Hammer of Justice"] = "Verbesserter Hammer der Gerechtigkeit",
		["Improved Hamstring"] = "Verbesserte Kniesehne",
		["Improved Healing"] = "Verbesserte Heilung",
		["Improved Healing Touch"] = "Verbesserte Heilende Ber\195\188hrung",
		["Improved Healing Wave"] = "Verbesserte Welle der Heilung",
		["Improved Health Funnel"] = "Verbesserte Lebenslinie",
		["Improved Healthstone"] = "Verbesserter Gesundheitsstein",
		["Improved Heroic Strike"] = "Verbesserter Heldenhafter Sto\195\159",
		["Improved Holy Shield"] = "Verbesserter Heiliger Schild",
		["Improved Howl of Terror"] = "Verbessertes Schreckensgeheul",
		["Improved Hunter's Mark"] = "Verbessertes Mal des J\195\164gers",
		["Improved Immolate"] = "Verbesserter Feuerbrand",
		["Improved Imp"] = "Verbesserter Wichtel",
		["Improved Inner Fire"] = "Verbessertes Inneres Feuer",
		["Improved Intercept"] = "Verbessertes Abfangen",
		["Improved Intimidating Shout"] = "Verbesserter Drohruf",
		["Improved Judgement"] = "Verbessertes Richturteil",
		["Improved Kick"] = "Verbesserter Tritt",
		["Improved Kidney Shot"] = "Verbesserter Nierenhieb",
		["Improved Lash of Pain"] = "Verbesserte Schmerzenspeitsche",
		["Improved Lay on Hands"] = "Verbesserte Handauflegung",
		["Improved Leader of the Pack"] = "Verbesserte Rudelf\195\188hrer",
		["Improved Life Tap"] = "Verbesserter Aderlass",
		["Improved Lightning Bolt"] = "Verbesserter Blitzschlag",
		["Improved Lightning Shield"] = "Verbesserter Blitzschlag-Schild",
		["Improved Magma Totem"] = "Verbessertes Totem der gl\195\188henden Magma",
		["Improved Mana Burn"] = "Verbesserter Manabrand",
		["Improved Mana Shield"] = "Verbesserter Manaschild",
		["Improved Mana Spring Totem"] = "Verbessertes Totem der Manaquelle",
		["Improved Mark of the Wild"] = "Verbessertes Mal der Wildnis",
		["Improved Mend Pet"] = "Verbessertes Tier heilen",
		["Improved Mind Blast"] = "Verbesserter Gedankenschlag",
		["Improved Moonfire"] = "Verbessertes Mondfeuer",
		["Improved Mortal Strike"] = "Verbesserter t\195\182dlicher Sto\195\159",
		["Improved Nature's Grasp"] = "Verbesserter Griff der Natur",
		["Improved Overpower"] = "Verbessertes \195\156berw\195\164ltigen",
		["Improved Power Word: Fortitude"] = "Verbessertes Machtwort: Seelenst\195\164rke",
		["Improved Power Word: Shield"] = "Verbessertes Machtwort: Schild",
		["Improved Prayer of Healing"] = "Verbessertes Gebet der Heilung",
		["Improved Psychic Scream"] = "Verbesserter Psychischer Schrei",
		["Improved Regrowth"] = "Verbessertes Nachwachsen",
		["Improved Reincarnation"] = "Verbesserte Reinkarnation",
		["Improved Rejuvenation"] = "Verbesserte Verj\195\188ngung",
		["Improved Rend"] = "Verbessertes Verwunden",
		["Improved Renew"] = "Verbesserte Erneuerung",
		["Improved Retribution Aura"] = "Verbesserte Aura der Vergeltung",
		["Improved Revenge"] = "Verbesserte Rache",
		["Improved Revive Pet"] = "Verbessertes Tier wiederbeleben",
		["Improved Righteous Fury"] = "Verbesserter Zorn der Gerechtigkeit",
		["Improved Rupture"] = "Verbesserte Blutung",
		["Improved Scorch"] = "Verbessertes Versengen",
		["Improved Scorpid Sting"] = "Verbesserter Skorpidstich",
		["Improved Seal of Righteousness"] = "Verbessertes Siegel der Rechtschaffenheit",
		["Improved Seal of the Crusader"] = "Verbessertes Siegel des Kreuzfahrers",
		["Improved Searing Pain"] = "Verbesserter Sengender Schmerz",
		["Improved Serpent Sting"] = "Verbesserter Schlangenbiss",
		["Improved Shadow Bolt"] = "Verbesserter Schattenblitz",
		["Improved Shadow Word: Pain"] = "Verbessertes Schattenwort: Schmerz",
		["Improved Shield Bash"] = "Verbesserter Schildhieb",
		["Improved Shield Block"] = "Verbesserter Schildblock",
		["Improved Shield Wall"] = "Verbesserter Schildwall",
		["Improved Sinister Strike"] = "Verbesserter Finsterer Sto\195\159",
		["Improved Slam"] = "Verbessertes Zerschmettern",
		["Improved Slice and Dice"] = "Verbessertes Zerh\195\164ckseln",
		["Improved Sprint"] = "Verbessertes Sprinten",
		["Improved Stings"] = "Verbesserte Stiche und Bisse",
		["Improved Succubus"] = "Verbesserter Sukkubus",
		["Improved Sunder Armor"] = "Verbessertes R\195\188stung zerrei\195\159en",
		["Improved Taunt"] = "Verbesserter Spott",
		["Improved Thunder Clap"] = "Verbesserter Donnerknall",
		["Improved Tranquility"] = "Verbesserte Gelassenheit",
		["Improved Vampiric Embrace"] = "Verbesserte Vampirumarmung",
		["Improved Vanish"] = "Verbessertes Verschwinden",
		["Improved Voidwalker"] = "Verbesserter Leerwandler",
		["Improved Weapon Totems"] = "Verbesserte Waffentotems",
		["Improved Whirlwind"] = "Verbesserter Wirbelwind",
		["Improved Wing Clip"] = "Verbessertes Zurechtstutzen",
		["Incinerate"] = "Verbrennen",
		["Incineration"] = "Verbrennung",
		["Inferno"] = "Inferno",
		["Initiative"] = "Initiative",
		["Inner Fire"] = "Inneres Feuer",
		["Inner Focus"] = "Innerer Fokus",
		["Innkeeper"] = "Gastwirt",
		["Innervate"] = "Anregen",
		["Insect Swarm"] = "Insektenschwarm",
		["Insidious Whisper"] = "Heimtuckisches Gefluster",
		["Insignifigance"] = "Bedeutungslosigkeit",
		["Inspiration"] = "Inspiration",
		["Instant Poison"] = "Sofort wirkendes Gift",
		["Instant Poison II"] = "Sofort wirkendes Gift II",
		["Instant Poison III"] = "Sofort wirkendes Gift III",
		["Instant Poison IV"] = "Sofort wirkendes Gift IV",
		["Instant Poison V"] = "Sofort wirkendes Gift V",
		["Instant Poison VI"] = "Sofort wirkendes Gift VI",
		["Instant Poison VII"] = "Sofort wirkendes Gift VII",
		["Intensity"] = "Intensit\195\164t",
		["Intercept"] = "Abfangen",
		["Intercept Stun"] = "Bet\195\164ubung abfangen",
		["Intervene"] = "Einschreiten",
		["Intimidating Shout"] = "Drohruf",
		["Intimidation"] = "Einsch\195\188chterung",
		["Invisibility"] = "Unsichtbarkeit",
		["Iron Will"] = "Eiserner Wille",
		["Jewelcrafting"] = "Juwelenschleifen",
		["Jom Gabbar"] = "Jom Gabbar",
		["Judgement"] = "Richturteil",
		["Judgement of Blood"] = "Richturteil des Blutes",
		["Judgement of Reckoning"] = "Richturteil der Abrechnung",
		["Judgement of Command"] = "Richturteil des Befehls",
		["Judgement of Justice"] = "Richturteil der Gerechtigkeit",
		["Judgement of Light"] = "Richturteil des Lichts",
		["Judgement of Righteousness"] = "Richturteil der Rechtschaffenheit",
		["Judgement of Wisdom"] = "Richturteil der Weisheit",
		["Judgement of the Crusader"] = "Richturteil des Kreuzfahrers",
		["Kick"] = "Tritt",
		["Kick - Silenced"] = "Tritt - zum Schweigen gebracht",
		["Kidney Shot"] = "Nierenhieb",
		["Kill Command"] = "Fass!",
		["Killer Instinct"] = "T\195\182tungstrieb",
		["Kiss of the Spider"] = "Kuss der Spinne",
		["Kodo Riding"] = "Kodoreiten",
		["Lacerate"] = "Aufschlitzen",
		["Lash of Pain"] = "Schmerzenspeitsche",
		["Last Stand"] = "Letztes Gefecht",
		["Lay on Hands"] = "Handauflegung",
		["Leader of the Pack"] = "Rudelf\195\188hrer",
		["Leather"] = "Leder",
		["Leatherworking"] = "Lederverarbeitung",
		["Lesser Heal"] = "Geringes Heilen",
		["Lesser Healing Wave"] = "Geringe Welle der Heilung",
		["Lesser Invisibility"] = "Geringe Unsichtbarkeit",
		["Lethal Shots"] = "T\195\182dliche Sch\195\188sse",
		["Lethality"] = "T\195\182dlichkeit",
		["Levitate"] = "Levitieren",
		["Libram"] = "Buchband",
		["Life Tap"] = "Aderlass",
		["Lifebloom"] = "Bl\195\188hendes Leben",
		["Light's Grace"] = "Anmut des Lichts",
		["Lightning Bolt"] = "Blitzschlag",
		["Lightning Breath"] = "Blitzschlagatem",
		["Lightning Mastery"] = "Blitzschlagbeherrschung",
		["Lightning Reflexes"] = "Blitzartige Reflexe",
		["Lightning Shield"] = "Blitzschlagschild",
		["Lightning Speed"] = "Blitzschnell",
		["Lightwell"] = "Brunnen des Lichts",
		["Lightwell Renew"] = "Erneuerung des Lichtbrunnens",
		["Lockpicking"] = "Schlossknacken",
		["Long Daze"] = "Lange Benommenheit",
		["Lust for Battle"] = "Kampfeslust",
		["Mace Specialization"] = "Streitkolben-Spezialisierung",
		["Mace Stun Effect"] = "Streitkolbenbet\195\164ubung",
		["Mage Armor"] = "Magische R\195\188stung",
		["Magic Absorption"] = "Magische Vereinnahmung",
		["Magic Attunement"] = "Einklang der Magie",
		["Magma Totem"] = "Totem des gl\195\188henden Magmas",
		["Mail"] = "Panzer",
		["Maim"] = "Zerfleddern",
		["Major Dreamless Sleep"] = "Erheblicher traumloser Schlaf",
		["Malediction"] = "Verh\195\164ngnis",
		["Malice"] = "T\195\188cke",
		["Mana Burn"] = "Manabrand",
		["Mana Feed"] = "Mananachschub",
		["Mana Shield"] = "Manaschild",
		["Mana Spring"] = "Manaquelle",
		["Mana Spring Totem"] = "Totem der Manaquelle",
		["Mana Tap"] = "Manaanzapfen",
		["Mana Tide"] = "Manaflut",
		["Mana Tide Totem"] = "Totem der Manaflut",
		["Mangle"] = "Fleddern",
		["Mangle (Bear)"] = "Zerfleischen (B\195\164r)",
		["Mangle (Cat)"] = "Zerfleischen (Katze)",
		["Mark of the Wild"] = "Mal der Wildnis",
		["Martyrdom"] = "M\195\164rtyrertum",
		["Mass Dispel"] = "Massenbannung",
		["Master Conjuror"] = "Meister der Herbeizauberung",
		["Master Demonologist"] = "Meister der D\195\164monologie",
		["Master Summoner"] = "Meister der Beschw\195\182rung",
		["Master Tactician"] = "Meister der Taktik",
		["Master of Deception"] = "Meister der T\195\164uschung",
		["Master of Elements"] = "Meister der Elemente",
		["Master of Subtlety"] = "Meister der Subtilit\195\164t",
		["Maul"] = "Zermalmen",
		["Mechanostrider Piloting"] = "Roboschreiter-Lenken",
		["Meditation"] = "Meditation",
		["Melee Specialization"] = "Nahkampf-Spezialisierung",
		["Mend Pet"] = "Tier heilen",
		["Mental Agility"] = "Mentale Beweglichkeit",
		["Mental Strength"] = "Mentale St\195\164rke",
		["Mind Blast"] = "Gedankenschlag",
		["Mind Control"] = "Gedankenkontrolle",
		["Mind Flay"] = "Gedankenschinden",
		["Mind Mastery"] = "Geistesbeherrschung",
		["Mind Soothe"] = "Gedankenbes\195\164nftigung",
		["Mind Vision"] = "Gedankensicht",
		["Mind-numbing Poison"] = "Gedankenbenebelndes Gift",
		["Mind-numbing Poison II"] = "Gedankenbenebelndes Gift II",
		["Mind-numbing Poison III"] = "Gedankenbenebelndes Gift III",
		["Mining"] = "Bergbau",
		["Misdirection"] = "Irref\195\188hrung",
		["Misery"] = "Elend",
		["Mocking Blow"] = "Sp\195\182ttischer Schlag",
		["Molten Armor"] = "Gl\195\188hende R\195\188stung",
		["Molten Fury"] = "Gl\195\188hender Zorn",
		["Mongoose Bite"] = "Mungobiss",
		["Monster Slaying"] = "Monstert\195\182ten",
		["Moonfire"] = "Mondfeuer",
		["Moonfury"] = "Mondfuror",
		["Moonglow"] = "Mondschein",
		["Moonkin Aura"] = "Aura des Moonkin",
		["Moonkin Form"] = "Moonkingestalt",
		["Mortal Shots"] = "Todbringende Sch\195\188sse",
		["Mortal Strike"] = "T\195\182dlicher Sto\195\159",
		["Multi-Shot"] = "Mehrfachschuss",
		["Murder"] = "Mord",
		["Mutilate"] = "Verst\195\188mmeln",
		["Natural Armor"] = "Nat\195\188rliche R\195\188stung",
		["Natural Perfection"] = "Vollkommenheit der Natur",
		["Natural Shapeshifter"] = "Schnellwandlung",
		["Naturalist"] = "Naturalist",
		["Nature Resistance"] = "Naturwiderstand",
		["Nature Resistance Totem"] = "Totem des Naturwiderstands",
		["Nature Weakness"] = "Natur Verwundbarkeit",
		["Nature's Focus"] = "Naturfokus",
		["Nature's Grace"] = "Anmut der Natur",
		["Nature's Grasp"] = "Griff der Natur",
		["Nature's Guidance"] = "Weisheit der Natur",
		["Nature's Reach"] = "Reichweite der Natur",
		["Nature's Swiftness"] = "Schnelligkeit der Natur",
		["Negative Charge"] = "Negative Ladung",
		["Nether Protection"] = "Netherschutz",
		["Netherstorm Flag"] = "Nethersturmbanner",
		["Nightfall"] = "Einbruch der Nacht",
		["Nurturing Instinct"] = "Besch\195\188tzerinstinkt",
		["Omen of Clarity"] = "Omen der Klarsicht",
		["One-Handed Axes"] = "Einhand\195\164xte",
		["One-Handed Maces"] = "Einhandstreitkolben",
		["One-Handed Swords"] = "Einhandschwerter",
		["One-Handed Weapon Specialization"] = "Einhandwaffen-Spezialisierung",
		["Opening"] = "\195\150ffnen",
		["Opening - No Text"] = "\195\150ffnen - Kein Text",
		["Opportunity"] = "G\195\188nstige Gelegenheit",
		["Overpower"] = "\195\156berw\195\164ltigen",
		["Pain Suppression"] = "Schmerzunterdr\195\188ckung",
		["Panic"] = "Panik",
		["Paranoia"] = "Paranoia",
		["Parry"] = "Parieren",
		["Pathfinding"] = "Orientierung",
		["Perceived Weakness"] = "Schwache aufdecken",
		["Perception"] = "Wachsamkeit",
		["Permafrost"] = "Dauerfrost",
		["Pet Aggression"] = "Tieraggression",
		["Pet Hardiness"] = "Tier-Widerstandskraft",
		["Pet Recovery"] = "Tiererholung",
		["Pet Resistance"] = "Tier-Widerstand",
		["Phase Shift"] = "Phasenverschiebung",
		["Pick Lock"] = "Schloss knacken",
		["Pick Pocket"] = "Taschendiebstahl",
		["Piercing Howl"] = "Durchdringendes Heulen",
		["Piercing Ice"] = "Stechendes Eis",
		["Plate Mail"] = "Plattenpanzer",
		["Playing with Fire"] = "Spiel mit dem Feuer",
		["Poison Cleansing Totem"] = "Totem der Giftreinigung",
		["Poison Spit"] = "Giftspucke",
		["Poisons"] = "Gifte",
		["Polearms"] = "Stangenwaffen",
		["Poleaxe Specialization"] = "Stangenwaffen-Spezialisierung",
		["Polymorph"] = "Verwandlung",
		["Polymorph: Pig"] = "Verwandlung: Schwein",
		["Polymorph: Turtle"] = "Verwandlung: Schildkr\195\182te",
		["Portal: Darnassus"] = "Portal: Darnassus",
		["Portal: Exodar"] = "Portal: Exodar",
		["Portal: Ironforge"] = "Portal: Eisenschmiede",
		["Portal: Orgrimmar"] = "Portal: Orgrimmar",
		["Portal: Shattrath"] = "Portal: Shattrath",
		["Portal: Silvermoon"] = "Portal: Silbermond",
		["Portal: Stormwind"] = "Portal: Sturmwind",
		["Portal: Thunder Bluff"] = "Portal: Donnerfels",
		["Portal: Undercity"] = "Portal: Unterstadt",
		["Positive Charge"] = "Positive Ladung",
		["Pounce"] = "Anspringen",
		["Pounce Bleed"] = "Anspringblutung",
		["Power Infusion"] = "Seele der Macht",
		["Power Word: Fortitude"] = "Machtwort: Seelenst\195\164rke",
		["Power Word: Shield"] = "Machtwort: Schild",
		["Prayer of Fortitude"] = "Gebet der Seelenst\195\164rke",
		["Prayer of Healing"] = "Gebet der Heilung",
		["Prayer of Mending"] = "Gebet der Besserung",
		["Prayer of Shadow Protection"] = "Gebet des Schattenschutzes",
		["Prayer of Spirit"] = "Gebet der Willenskraft",
		["Precision"] = "Pr\195\164zision",
		["Predatory Instincts"] = "Instinkt des Raubtiers",
		["Predatory Strikes"] = "Raubtierschl\195\164ge",
		["Premeditation"] = "Konzentration",
		["Preparation"] = "Vorbereitung",
		["Presence of Mind"] = "Geistesgegenwart",
		["Primal Fury"] = "Urfuror",
		["Prismatic Cloak"] = "Prismatischer Mantel",
		["Profession Trainers"] = "Lehrer fur einen Beruf",
		["Prospecting"] = "Sondieren",
		["Prowl"] = "Schleichen",
		["Psychic Scream"] = "Psychischer Schrei",
		["Pummel"] = "Zuschlagen",
		["Purge"] = "Reinigen",
		["Purification"] = "L\195\164uterung",
		["Purify"] = "L\195\164utern",
		["Purifying Power"] = "Reinigende Kraft",
		["Pursuit of Justice"] = "Streben nach Gerechtigkeit",
		["Pyroblast"] = "Pyroschlag",
		["Pyroclasm"] = "Feuerschwall",
		["Pyromaniac"] = "Brandstifter",
		["Quick Recovery"] = "Schnelle Erholung",
		["Quick Shots"] = "Schnelle Sch\195\188sse",
		["Quickness"] = "Schnelligkeit",
		["Rage of the Unraveller"] = "Zorn des Entwirrers",
		["Rain of Fire"] = "Feuerregen",
		["Rake"] = "Krallenhieb",
		["Ram Riding"] = "Widderreiten",
		["Rampage"] = "Toben",
		["Ranged Weapon Specialization"] = "Distanzwaffen-Spezialisierung",
		["Rapid Fire"] = "Schnellfeuer",
		["Rapid Killing"] = "Schneller Tod",
		["Raptor Riding"] = "Raptorreiten",
		["Raptor Strike"] = "Raptorsto\195\159",
		["Ravage"] = "Verheeren",
		["Reagents"] = "Reagentien",
		["Rebirth"] = "Wiedergeburt",
		["Reckless Charge"] = "Rucksichtsloser Sturmangriff",
		["Recklessness"] = "Tollk\195\188hnheit",
		["Reckoning"] = "Abrechnung",
		["Redemption"] = "Erl\195\182sung",
		["Redoubt"] = "Verschanzen",
		["Reflection"] = "Reflexion",
		["Regeneration"] = "Regeneration",
		["Regrowth"] = "Nachwachsen",
		["Reincarnation"] = "Reinkarnation",
		["Reinforced Shield"] = "Verst\195\164rktes Schild",
		["Rejuvenation"] = "Verj\195\188ngung",
		["Relentless Strikes"] = "Unerbittliche St\195\182\195\159e",
		["Remorseless"] = "Gnadenlos",
		["Remorseless Attacks"] = "Gnadenlose Angriffe",
		["Remove Curse"] = "Fluch aufheben",
		["Remove Insignia"] = "Abzeichen entfernen",
		["Remove Lesser Curse"] = "Geringen Fluch aufheben",
		["Rend"] = "Verwunden",
		["Renew"] = "Erneuerung",
		["Repair"] = "Reparieren",
		["Repentance"] = "Bu\195\159e",
		["Restless Strength"] = "Ruhelose St\195\164rke",
		["Restorative Totems"] = "Regenerationstotems",
		["Resurrection"] = "Auferstehung",
		["Retaliation"] = "Gegenschlag",
		["Retribution Aura"] = "Aura der Vergeltung",
		["Revenge"] = "Rache",
		["Revenge Stun"] = "Rachebet\195\164ubung",
		["Reverberation"] = "Nachklingen",
		["Revive Pet"] = "Tier wiederbeleben",
		["Righteous Defense"] = "Rechtschaffene Verteidigung",
		["Righteous Fury"] = "Zorn der Gerechtigkeit",
		["Rip"] = "Zerfetzen",
		["Riposte"] = "Riposte",
		["Ritual of Doom"] = "Ritual der Verdammnis",
		["Ritual of Doom Effect"] = "Ritual der Verdammnis'-Effekt",
		["Ritual of Souls"] = "Ritual der Seelen",
		["Ritual of Summoning"] = "Ritual der Beschw\195\182rung",
		["Rockbiter Weapon"] = "Waffe des Felsbei\195\159ers",
		["Rough Sharpening Stone"] = "Rauher Wetzstein",
		["Ruin"] = "Verderben",
		["Rupture"] = "Blutung",
		["Ruthlessness"] = "Skrupellosigkeit",
		["Sacrifice"] = "Opferung",
		["Safe Fall"] = "Sicheres Fallen",
		["Sanctified Crusader"] = "Geweihter Kreuzfahrer",
		["Sanctified Judgement"] = "Geweihtes Richturteil",
		["Sanctified Light"] = "Geheiligtes Licht",
		["Sanctity Aura"] = "Aura der Heiligkeit",
		["Sap"] = "Kopfnuss",
		["Savage Fury"] = "Ungez\195\164hmte Wut",
		["Savage Strikes"] = "Wilde Schl\195\164ge",
		["Scare Beast"] = "Wildtier \195\164ngstigen",
		["Scatter Shot"] = "Streuschuss",
		["Scorch"] = "Versengen",
		["Scorpid Poison"] = "Skorpidgift",
		["Scorpid Sting"] = "Skorpidstich",
		["Screech"] = "Schrei",
		["Seal Fate"] = "Schicksal besiegeln",
		["Seal of Blood"] = "Siegel des Blutes",
		["Seal of Command"] = "Siegel des Befehls",
		["Seal of Justice"] = "Siegel der Gerechtigkeit",
		["Seal of Light"] = "Siegel des Lichts",
		["Seal of Righteousness"] = "Siegel der Rechtschaffenheit",
		["Seal of Vengeance"] = "Siegel der Vergeltung",
		["Seal of Wisdom"] = "Siegel der Weisheit",
		["Seal of the Crusader"] = "Siegel des Kreuzfahrers",
		["Searing Light"] = "Sengendes Licht",
		["Searing Pain"] = "Sengender Schmerz",
		["Searing Totem"] = "Totem der Verbrennung",
		["Second Wind"] = "Kr\195\164fte sammeln",
		["Seduction"] = "Verf\195\188hrung",
		["Seed of Corruption"] = "Saat der Verderbnis",
		["Seethe"] = "Sieden", -- Check!
		["Sense Demons"] = "D\195\164monen sp\195\188ren",
		["Sense Undead"] = "Untote sp\195\188ren",
		["Sentry Totem"] = "Totem des Wachens",
		["Serpent Sting"] = "Schlangenbiss",
		["Serrated Blades"] = "Gezahnte Klingen",
		["Setup"] = "Reinlegen",
		["Shackle Undead"] = "Untote fesseln",
		["Shadow Affinity"] = "Schattenaffinit\195\164t",
		["Shadow Bolt"] = "Schattenblitz",
		["Shadow Embrace"] = "Umschlingende Schatten",
		["Shadow Focus"] = "Schattenfokus",
		["Shadow Mastery"] = "Schattenbeherrschung",
		["Shadow Power"] = "Schattenmacht",
		["Shadow Protection"] = "Schattenschutz",
		["Shadow Reach"] = "Schattenreichweite",
		["Shadow Resistance"] = "Schattenwiderstand",
		["Shadow Resistance Aura"] = "Aura des Schattenwiderstands",
		["Shadow Trance"] = "Schattentrance",
		["Shadow Vulnerability"] = "Schattenverwundbarkeit",
		["Shadow Ward"] = "Schattenzauberschutz",
		["Shadow Weakness"] = "Schatten Verwundbarkeit",
		["Shadow Weaving"] = "Schattenwirken",
		["Shadow Word: Death"] = "Schattenwort: Tod",
		["Shadow Word: Pain"] = "Schattenwort: Schmerz",
		["Shadow and Flame"] = "Schatten und Flamme",
		["Shadowburn"] = "Schattenbrand",
		["Shadowfiend"] = "Schattengeist",
		["Shadowform"] = "Schattengestalt",
		["Shadowfury"] = "Schattenfurie",
		["Shadowguard"] = "Schattenschild",
		["Shadowmeld"] = "Schattenhaftigkeit",
		["Shadowmeld Passive"] = "Schattenmimik Passiv",
		["Shadowstep"] = "Schattenschritt",
		["Shamanistic Rage"] = "Schamanistische Wut",
		["Sharpened Claws"] = "Gesch\195\164rfte Klauen",
		["Shatter"] = "Zertr\195\188mmern",
		["Shell Shield"] = "Panzerschild",
		["Shield"] = "Schild",
		["Shield Bash"] = "Schildhieb",
		["Shield Bash - Silenced"] = "Schildhieb - zum Schweigen gebracht",
		["Shield Block"] = "Schildblock",
		["Shield Slam"] = "Schildschlag",
		["Shield Specialization"] = "Schild-Spezialisierung",
		["Shield Wall"] = "Schildwall",
		["Shiv"] = "T\195\188ckische Klinge",
		["Shoot"] = "Schie\195\159en",
		["Shoot Bow"] = "Bogenschuss",
		["Shoot Gun"] = "Schusswaffe abfeuern",
		["Shred"] = "Schreddern",
		["Shredding Attacks"] = "Schreddernde Angriffe",
		["Silence"] = "Stille",
		["Silencing Shot"] = "Unterdr\195\188ckender Schuss",
		["Silent Resolve"] = "Schweigsame Entschlossenheit",
		["Silverwing Flag"] = "Flagge der Silberschwingen",
		["Sinister Strike"] = "Finsterer Sto\195\159",
		["Siphon Life"] = "Lebensentzug",
		["Skinning"] = "K\195\188rschnerei",
		["Slam"] = "Zerschmettern",
		["Slayer's Crest"] = "Wappen des Schl\195\164chters",
		["Sleep"] = "Schlaf",
		["Slice and Dice"] = "Zerh\195\164ckseln",
		["Slow"] = "Verlangsamen",
		["Slow Fall"] = "Langsamer Fall",
		["Smelting"] = "Verh\195\188ttung",
		["Smite"] = "G\195\182ttliche Pein",
		["Snake Trap"] = "Schlangenfalle",
		["Solid Sharpening Stone"] = "Robuster Wetzstein",
		["Sonic Burst"] = "Schallexplosion",
		["Soothe Animal"] = "Tier bes\195\164nftigen",
		["Soothing Kiss"] = "Bes\195\164nftigender Kuss",
		["Soul Fire"] = "Seelenfeuer",
		["Soul Leech"] = "Seele entziehen",
		["Soul Link"] = "Seelenverbindung",
		["Soul Siphon"] = "Seelen-Siphon",
		["Soulshatter"] = "Seele brechen",
		["Soulstone Resurrection"] = "Seelensteinauferstehung",
		["Spell Haste"] = "Zaubertempo",
		["Spell Lock"] = "Zaubersperre",
		["Spell Power"] = "Zauberkraft",
		["Spell Reflection"] = "Zauberreflexion",
		["Spell Vulnerability"] = "Zauber Empfindlichkeit",
		["Spell Warding"] = "Zauberschutz",
		["Spellsteal"] = "Zauberraub",
		["Spirit Bond"] = "Geistbande",
		["Spirit Tap"] = "Willensentzug",
		["Spirit of Redemption"] = "Geist der Erl\195\182sung",
		["Spiritual Attunement"] = "Einklang des Geistes",
		["Spiritual Focus"] = "Spiritueller Fokus",
		["Spiritual Guidance"] = "Geistige F\195\188hrung",
		["Spiritual Healing"] = "Spirituelle Heilung",
		["Spiteful Fury"] = "Boshafter Furor",
		["Sprint"] = "Sprinten",
		["StableMaster"] = "Stallmeister",
		["Stance Mastery"] = "Haltung bewahren",
		["Starfire"] = "Sternenfeuer",
		["Starfire Stun"] = "Sternenfeuerbet\195\164ubung",
		["Starlight Wrath"] = "Zorniges Sternenlicht",
		["Starshards"] = "Sternensplitter",
		["Static Charge"] = "Statische Aufladung",
		["Staves"] = "St\195\164be",
		["Steady Shot"] = "Zuverl\195\164ssiger Schuss",
		["Stealth"] = "Verstohlenheit",
		["Stoneclaw Stun"] = "Steinklauenbet\195\164uben",
		["Stoneclaw Totem"] = "Totem der Steinklaue",
		["Stoneform"] = "Steingestalt",
		["Stoneskin"] = "Steinhaut",
		["Stoneskin Totem"] = "Totem der Steinhaut",
		["Stormstrike"] = "Sturmschlag",
		["Strength of Earth"] = "Erdst\195\164rke",
		["Strength of Earth Totem"] = "Totem der Erdst\195\164rke",
		["Strength of the Halaani"] = "St\195\164rke der Halaani",
		["Stuck"] = "Feststecken",
		["Stun"] = "Bet\195\164ubt",
		["Subtlety"] = "Feingef\195\188hl",
		["Suffering"] = "Leiden",
		["Summon Charger"] = "Streitross beschw\195\182ren",
		["Summon Dreadsteed"] = "Schreckensross herbeirufen",
		["Summon Felguard"] = "Teufelswache beschw\195\182ren",
		["Summon Felhunter"] = "Teufelsj\195\164ger beschw\195\182ren",
		["Summon Felsteed"] = "Teufelsross beschw\195\182ren",
		["Summon Imp"] = "Wichtel beschw\195\182ren",
		["Summon Succubus"] = "Sukkubus beschw\195\182ren",
		["Summon Voidwalker"] = "Leerwandler beschw\195\182ren",
		["Summon Warhorse"] = "Schlachtross beschw\195\182ren",
		["Summon Water Elemental"] = "Wasserelementar beschw\195\182ren",
		["Sunder Armor"] = "R\195\188stung zerrei\195\159en",
		["Suppression"] = "Unterdr\195\188ckung",
		["Surefooted"] = "Sicherer Stand",
		["Surge of Light"] = "Woge des Lichts",
		["Surprise Attacks"] = "\195\156berraschungsangriffe",
		["Survivalist"] = "\195\156berlebensk\195\188nstler",
		["Sweeping Strikes"] = "Weitreichende St\195\182\195\159e",
		["Swift Flight Form"] = "Schnelle Fluggestalt",
		["Swiftmend"] = "Rasche Heilung",
		["Swipe"] = "Prankenhieb",
		["Sword Specialization"] = "Schwert-Spezialisierung",
		["Symbol of Hope"] = "Symbol der Hoffnung",
		["Tactical Mastery"] = "Taktiker",
		["Tailoring"] = "Schneiderei",
		["Tainted Blood"] = "Besudeltes Blut",
		["Tainted Mind"] = "Besudelte Gedanken",
		["Tame Beast"] = "Wildtier z\195\164hmen",
		["Taunt"] = "Spott",
		["Teleport: Darnassus"] = "Teleportieren: Darnassus",
		["Teleport: Exodar"] = "Teleportieren: Exodar",
		["Teleport: Ironforge"] = "Teleportieren: Eisenschmiede",
		["Teleport: Moonglade"] = "Teleportieren: Mondlichtung",
		["Teleport: Orgrimmar"] = "Teleportieren: Orgrimmar",
		["Teleport: Shattrath"] = "Teleportieren: Shattrath",
		["Teleport: Silvermoon"] = "Teleportieren: Silbermond",
		["Teleport: Stormwind"] = "Teleportieren: Sturmwind",
		["Teleport: Thunder Bluff"] = "Teleportieren: Donnerfels",
		["Teleport: Undercity"] = "Teleportieren: Unterstadt",
		["Temporal Rift"] = "Temporalriss",
		["The Beast Within"] = "Wildes Herz",
		["The Human Spirit"] = "Unbeugsamkeit",
		["Thick Hide"] = "Dickes Fell",
		["Thorns"] = "Dornen",
		["Thrill of the Hunt"] = "Jagdfieber",
		["Throw"] = "Werfen",
		["Throwing Specialization"] = "Wurfwaffen-Spezialisierung",
		["Thrown"] = "Wurfwaffe",
		["Thunder Clap"] = "Donnerknall",
		["Thunderfury"] = "Donnerzorn",
		["Thundering Strikes"] = "Donnernde St\195\182\195\159e",
		["Thunderstomp"] = "Donnerstampfer",
		["Tidal Focus"] = "Gezeitenfokus",
		["Tidal Mastery"] = "Gezeitenbeherrschung",
		["Tiger Riding"] = "Tigerreiten",
		["Tiger's Fury"] = "Tigerfuror",
		["Time's Favor"] = "Gunst der Zeit",
		["Torment"] = "Qual",
		["Totem"] = "Totem",
		["Totem of Wrath"] = "Totem des Ingrimms",
		["Totemic Call"] = "Ruf der Totems",
		["Totemic Focus"] = "Totemfokus",
		["Touch of Shadow"] = "Ber\195\188hrung des Schattens",
		["Touch of Weakness"] = "Ber\195\188hrung der Schw\195\164che",
		["Toughness"] = "Z\195\164higkeit",
		["Traces of Silithyst"] = "Spuren von Silithyst",
		["Track Beasts"] = "Wildtiere aufsp\195\188ren",
		["Track Demons"] = "D\195\164monen aufsp\195\188ren",
		["Track Dragonkin"] = "Drachkin aufsp\195\188ren",
		["Track Elementals"] = "Elementare aufsp\195\188ren",
		["Track Giants"] = "Riesen aufsp\195\188ren",
		["Track Hidden"] = "Verborgenes aufsp\195\188ren",
		["Track Humanoids"] = "Humanoide aufsp\195\188ren",
		["Track Undead"] = "Untote aufsp\195\188ren",
		["Tranquil Air"] = "Beruhigenden Winde",
		["Tranquil Air Totem"] = "Totem der beruhigenden Winde",
		["Tranquil Spirit"] = "Gelassener Geist",
		["Tranquility"] = "Gelassenheit",
		["Tranquilizing Shot"] = "Einlullender Schuss",
		["Trap Mastery"] = "Fallenbeherrschung",
		["Travel Form"] = "Reisegestalt",
		["Tree of Life"] = "Baum des Lebens",
		["Tremor Totem"] = "Totem des Erdsto\195\159es",
		["Tribal Leatherworking"] = "Stammeslederverarbeitung",
		["Trueshot Aura"] = "Aura des Volltreffers",
		["Turn Undead"] = "Untote vertreiben",
		["Twin Spire Blessing"] = "Segen der Zwillingsspitze",
		["Two-Handed Axes"] = "Zweihand\195\164xte",
		["Two-Handed Axes and Maces"] = "Zweihand\195\164xte und -Streitkolben",
		["Two-Handed Maces"] = "Zweihandstreitkolben",
		["Two-Handed Swords"] = "Zweihandschwerter",
		["Two-Handed Weapon Specialization"] = "Zweihandwaffen-Spezialisierung",
		["Unarmed"] = "Unbewaffnet",
		["Unbreakable Will"] = "Unbezwingbarer Wille",
		["Unbridled Wrath"] = "Entfesselter Zorn",
		["Undead Horsemanship"] = "Untotenreitkunst",
		["Underwater Breathing"] = "Unterwasseratmung",
		["Unending Breath"] = "Unendlicher Atem",
		["Unholy Power"] = "Unheilige Macht",
		["Unleashed Fury"] = "Entfesselter Zorn",
		["Unleashed Rage"] = "Entfesselte Wut",
		["Unstable Affliction"] = "Instabiles Gebrechen",
		["Unstable Power"] = "Instabile Energie",
		["Unyielding Faith"] = "Unumst\195\182\195\159licher Glaube",
		["Vampiric Embrace"] = "Vampirumarmung",
		["Vampiric Touch"] = "Vampirber\195\188hrung",
		["Vanish"] = "Verschwinden",
		["Vanished"] = "Verschwunden",
		["Vengeance"] = "Rache",
		["Venomous Totem"] = "Gifttotem",
		["Victory Rush"] = "Siegesrausch",
		["Vigor"] = "Lebenskraft",
		["Vile Poisons"] = "\195\156ble Gifte",
		["Vindication"] = "Rechtschaffene Schw\195\164chung",
		["Viper Sting"] = "Vipernbiss",
		["Volley"] = "Salve",
		["Wand Specialization"] = "Zauberstab-Spezialisierung",
		["Wands"] = "Zauberst\195\164be",
		["War Stomp"] = "Kriegsdonner",
		["Warp"] = "Verzerrt",
		["Warsong Flag"] = "Warsong Flagge",
		["Water Breathing"] = "Wasseratmung",
		["Water Shield"] = "Wasserschild",
		["Water Tomb"] = "Wassergrab",
		["Water Walking"] = "Wasserwandeln",
		["Waterbolt"] = "Wasserblitz",
		["Watery Grave"] = "Nasses Grab",
		["Weakened Soul"] = "Geschw\195\164chte Seele",
		["Weapon Mastery"] = "Waffenbeherschung",
		["Weaponsmith"] = "Waffenschmied",
		["Whirlwind"] = "Wirbelwind",
		["Will of the Forsaken"] = "Wille der Verlassenen",
		["Windfury"] = "Windfuror",
		["Windfury Attack"] = "Angriff des Windzorns",
		["Windfury Totem"] = "Totem des Windzorns",
		["Windfury Weapon"] = "Waffe des Windzorns",
		["Windwall"] = "Windmauer",
		["Windwall Totem"] = "Totem der Windmauer",
		["Wing Clip"] = "Zurechtstutzen",
		["Winter's Chill"] = "Winterk\195\164lte",
		["Wisp Spirit"] = "Irrwisch-Geist",
		["Wolf Riding"] = "Wolfreiten",
		["Wound Poison"] = "Wundgift",
		["Wound Poison II"] = "Wundgift II",
		["Wound Poison III"] = "Wundgift III",
		["Wound Poison IV"] = "Wundgift IV",
		["Wound Poison V"] = "Wundgift V",
		["Wrath"] = "Zorn",
		["Wrath of Air Totem"] = "Totem des st\195\188rmischen Zorns",
		["Wrath of Cenarius"] = "Zorn des Cenarius",
		["Wrath of the Astromancer"] = "Zorn des Astronomen",
		["Wyvern Sting"] = "Stich des Fl\195\188geldrachen",
	}
elseif GAME_LOCALE == "frFR" then
	lib:SetCurrentTranslations {
		["Abolish Disease"] = "Abolir maladie",
		["Abolish Poison"] = "Abolir le poison",
		["Abolish Poison Effect"] = "Effet Abolir le poison",
		["Activate MG Turret"] = "Activation de la tourelle de mitrailleuse",
		["Adrenaline Rush"] = "Poussee d'adrenaline",
		["Aftermath"] = "Consequences",
		["Aggression"] = "Agressivite",
		["Aimed Shot"] = "Visee",
		["Alchemy"] = "Alchimie",
		["Ambush"] = "Embuscade",
		["Ammunition"] = "Munitions", -- to be checked
		["Amplify Curse"] = "Malediction amplifiee",
		["Amplify Magic"] = "Amplification de la magie",
		["Ancestral Fortitude"] = "Robustesse des anciens",
		["Ancestral Healing"] = "Guerison des anciens",
		["Ancestral Knowledge"] = "Connaissance ancestrale",
		["Ancestral Spirit"] = "Esprit ancestral",
		["Ancient Hysteria"] = "Hysterie ancienne",
		["Anesthetic Poison"] = "Poison anesthesiant",
		["Anger Management"] = "Maitrise de la Rage",
		["Anguish"] = "Angoisse",
		["Anticipation"] = "Anticipation",
		["Aquatic Form"] = "Forme aquatique",
		["Arcane Blast"] = "Deflagration des arcanes",
		["Arcane Brilliance"] = "Illumination des arcanes",
		["Arcane Concentration"] = "Concentration des arcanes",
		["Arcane Energy"] = "Energie des arcanes",
		["Arcane Explosion"] = "Explosion des arcanes",
		["Arcane Focus"] = "Focalisation des arcanes",
		["Arcane Fortitude"] = "Robustesse des arcanes",
		["Arcane Impact"] = "Impact des arcanes",
		["Arcane Instability"] = "Instabilite des arcanes",
		["Arcane Intellect"] = "Intelligence des arcanes",
		["Arcane Meditation"] = "Meditation des arcanes",
		["Arcane Mind"] = "Esprit des arcanes",
		["Arcane Missiles"] = "Projectiles des arcanes",
		["Arcane Potency"] = "Toute-puissance des arcanes",
		["Arcane Power"] = "Pouvoir des arcanes",
		["Arcane Resistance"] = "Resistance aux Arcanes",
		["Arcane Shot"] = "Tir des arcanes",
		["Arcane Shroud"] = "Voile des arcanes",
		["Arcane Subtlety"] = "Subtilite des arcanes",
		["Arcane Torrent"] = "Torrent arcanique",
		["Arcane Weakness"] = "Sensibilite aux Arcanes",
		["Arctic Reach"] = "Allonge arctique",
		["Arctic Winds"] = "Vents arctiques",
		["Armor of Faith"] = "Armure de la Foi",
		["Armorsmith"] = "Fabricant d'armures",
		["Aspect of the Beast"] = "Aspect de la bete",
		["Aspect of the Cheetah"] = "Aspect du guepard",
		["Aspect of the Hawk"] = "Aspect du faucon",
		["Aspect of the Monkey"] = "Aspect du singe",
		["Aspect of the Pack"] = "Aspect de la meute",
		["Aspect of the Viper"] = "Aspect de la vipere",
		["Aspect of the Wild"] = "Aspect de la nature",
		["Astral Recall"] = "Rappel astral",
		["Attack"] = "Attaque",
		["Attacking"] = "Attaque",
		["Auto Shot"] = "Tir automatique",
		["Avenger's Shield"] = "Bouclier du vengeur",
		["Avenging Wrath"] = "Courroux vengeur",
		["Avoidance"] = "Evitement",
		["Axe Specialization"] = "Specialisation Hache",
		["Backlash"] = "Contrecoup",
		["Backstab"] = "Attaque sournoise",
		["Badge of the Swarmguard"] = "Insigne de garde-essaim",
		["Balance of Power"] = "Equilibre de la puissance",
		["Bane"] = "Fleau",
		["Banish"] = "Bannir",
		["Banker"] = "Banquier",
		["Banshee Curse"] = "Malediction de la Banshee",
		["Barkskin"] = "Ecorce",
		["Barrage"] = "Barrage",
		["Bash"] = "Sonner",
		["Basic Campfire"] = "Feu de camp basique",
		["Battle Rush"] = "Ivresse de la bataille",
		["Battle Shout"] = "Cri de guerre",
		["Battle Stance"] = "Posture de combat",
		["Battle Stance Passive"] = "Posture de combat",
		["BattleMaster"] = "Maitre de guerre",
		["Bear Form"] = "Forme d'ours",
		["Beast Lore"] = "Connaissance des betes",
		["Beast Slaying"] = "Tueur de betes",
		["Beast Training"] = "Dressage des betes",
		["Benediction"] = "Benediction",
		["Berserker Rage"] = "Rage berserker",
		["Berserker Stance"] = "Posture berserker",
		["Berserker Stance Passive"] = "Posture berserker",
		["Berserking"] = "Berserker",
		["Bestial Discipline"] = "Discipline bestiale",
		["Bestial Swiftness"] = "Rapidite bestiale",
		["Bestial Wrath"] = "Courroux bestial",
		["Binding Heal"] = "Soins de lien",
		["Bite"] = "Morsure",
		["Black Arrow"] = "Fleche noire",
		["Blackout"] = "Aveuglement",
		["Blacksmithing"] = "Forge",
		["Blade Flurry"] = "Deluge de lames",
		["Blade Turning"] = "Froissement",
		["Blade Twisting"] = "Tournoiement de lames",
		["Blast Wave"] = "Vague explosive",
		["Blazing Speed"] = "Vitesse flamboyante",
		["Blessed Recovery"] = "Retablissement beni",
		["Blessed Resilience"] = "Resilience benie",
		["Blessing of Auchindoun"] = "Benediction d'Auchindoun",
		["Blessing of Freedom"] = "Benediction de liberte",
		["Blessing of Kings"] = "Benediction des rois",
		["Blessing of Light"] = "Benediction de lumiere",
		["Blessing of Might"] = "Benediction de puissance",
		["Blessing of Protection"] = "Benediction de protection",
		["Blessing of Sacrifice"] = "Benediction de sacrifice",
		["Blessing of Salvation"] = "Benediction de salut",
		["Blessing of Sanctuary"] = "Benediction du sanctuaire",
		["Blessing of Wisdom"] = "Benediction de sagesse",
		["Blind"] = "Cecite",
		["Blinding Powder"] = "Poudre aveuglante",
		["Blink"] = "Transfert",
		["Blizzard"] = "Blizzard",
		["Block"] = "Bloquer",
		["Blood Craze"] = "Folie sanguinaire",
		["Blood Frenzy"] = "Frenesie sanglante",
		["Blood Fury"] = "Fureur sanguinaire",
		["Blood Pact"] = "Pacte de sang",
		["Bloodlust"] = "Furie sanguinaire",
		["Bloodrage"] = "Rage sanguinaire",
		["Bloodthirst"] = "Sanguinaire",
		["Boar Charge"] = "Boutoir",
		["Booming Voice"] = "Voix tonitruante",
		["Bow Specialization"] = "Specialisation Arc",
		["Bows"] = "Arcs",
		["Bright Campfire"] = "Feu de camp eclatant",
		["Brittle Armor"] = "Armure fragile",
		["Brutal Impact"] = "Impact brutal",
		["Burning Adrenaline"] = "Montee d'adrenaline",
		["Burning Soul"] = "Ame ardente",
		["Burning Wish"] = "Souhait ardent",
		["Call Pet"] = "Appel du familier",
		["Call of Flame"] = "Appel des flammes",
		["Call of Thunder"] = "Appel de la foudre",
		["Call of the Nexus"] = "Appel du nexus",
		["Camouflage"] = "Dissimulation",
		["Cannibalize"] = "Cannibalisme",
		["Cat Form"] = "Forme de felin",
		["Cataclysm"] = "Cataclysme",
		["Celestial Focus"] = "Focalisation celeste",
		["Chain Heal"] = "Salve de guerison",
		["Chain Lightning"] = "Chaine d'eclairs",
		["Challenging Roar"] = "Rugissement provocateur",
		["Challenging Shout"] = "Cri de defi",
		["Charge"] = "Charge",
		["Charge Rage Bonus Effect"] = "Effet Bonus de Rage de la Charge",
		["Charge Stun"] = "Charge etourdissante",
		["Cheap Shot"] = "Coup bas",
		["Chilled"] = "Transi",
		["Class Trainer"] = "Maitre de classe",
		["Circle of Healing"] = "Cercle de soins",
		["Claw"] = "Griffe",
		["Cleanse"] = "Epuration",
		["Clearcasting"] = "Idees claires",
		["Cleave"] = "Enchainement",
		["Clever Traps"] = "Pieges astucieux",
		["Cloak of Shadows"] = "Cape d'ombre",
		["Closing"] = "Fermeture",
		["Cloth"] = "Tissu",
		["Coarse Sharpening Stone"] = "Pierre a aiguiser grossiere",
		["Cobra Reflexes"] = "Reflexes du cobra",
		["Cold Blood"] = "Sang froid",
		["Cold Snap"] = "Morsure de glace",
		["Combat Endurance"] = "Endurance de combat",
		["Combustion"] = "Combustion",
		["Command"] = "Commandement",
		["Commanding Presence"] = "Presence de commandement",
		["Commanding Shout"] = "Cri de commandement",
		["Concentration Aura"] = "Aura de concentration",
		["Concussion"] = "Commotion",
		["Concussion Blow"] = "Bourrasque",
		["Concussive Barrage"] = "Barrage commotionnant",
		["Concussive Shot"] = "Trait de choc",
		["Cone of Cold"] = "Cone de froid",
		["Conflagrate"] = "Conflagration",
		["Conflagration"] = "Deflagration",
		["Conjure Food"] = "Invocation de nourriture",
		["Conjure Mana Agate"] = "Invocation d'une agate de mana",
		["Conjure Mana Citrine"] = "Invocation d'une citrine de mana",
		["Conjure Mana Emerald"] = "Invocation d'une emeraude de mana",
		["Conjure Mana Jade"] = "Invocation d'une jade de mana",
		["Conjure Mana Ruby"] = "Invocation d'un rubis de mana",
		["Conjure Water"] = "Invocation d'eau",
		["Consecration"] = "Consecration",
		["Consume Magic"] = "Consumer la magie",
		["Consume Shadows"] = "Consumer les ombres",
		["Contagion"] = "Contagion",
		["Convection"] = "Convection",
		["Conviction"] = "Conviction",
		["Cooking"] = "Cuisine",
		["Corruption"] = "Corruption",
		["Counterattack"] = "Contre-attaque",
		["Counterspell"] = "Contresort",
		["Counterspell - Silenced"] = "Contresort - Silencieux",
		["Cower"] = "Derobade",
		["Create Firestone"] = "Creation de Pierre de feu",
		["Create Firestone (Greater)"] = "Creation de Pierre de feu (superieure)",
		["Create Firestone (Lesser)"] = "Creation de Pierre de feu (inferieure)",
		["Create Firestone (Major)"] = "Creation de Pierre de feu (majeure)",
		["Create Healthstone"] = "Creation de Pierre de soins",
		["Create Healthstone (Greater)"] = "Creation de Pierre de soins (superieure)",
		["Create Healthstone (Lesser)"] = "Creation de Pierre de soins (inferieure)",
		["Create Healthstone (Major)"] = "Creation de Pierre de soins (majeure)",
		["Create Healthstone (Minor)"] = "Creation de Pierre de soins (mineure)",
		["Create Soulstone"] = "Creation de Pierre d'ame",
		["Create Soulstone (Greater)"] = "Creation de Pierre d'ame (superieure)",
		["Create Soulstone (Lesser)"] = "Creation de Pierre d'ame (inferieure)",
		["Create Soulstone (Major)"] = "Creation de Pierre d'ame (majeure)",
		["Create Soulstone (Minor)"] = "Creation de Pierre d'ame (mineure)",
		["Create Spellstone"] = "Creation de Pierre de sort",
		["Create Spellstone (Greater)"] = "Creation de Pierre de sort (superieure)",
		["Create Spellstone (Major)"] = "Creation de Pierre de sort (majeure)",
		["Create Spellstone (Master)"] = "Creation de Pierre de sort (magistrale)",
		["Cripple"] = "Faiblesse",
		["Crippling Poison"] = "Poison affaiblissant",
		["Crippling Poison II"] = "Poison affaiblissant II",
		["Critical Mass"] = "Masse critique",
		["Crossbows"] = "Arbaletes",
		["Cruelty"] = "Cruaute",
		["Crusade"] = "Croisade",
		["Crusader Aura"] = "Aura de croise",
		["Crusader Strike"] = "Inquisition",
		["Cultivation"] = "Culture",
		["Cure Disease"] = "Guerison des maladies",
		["Cure Poison"] = "Guerison du poison",
		["Curse of Agony"] = "Malediction d'agonie",
		["Curse of Doom"] = "Malediction funeste",
		["Curse of Doom Effect"] = "Effet Malediction funeste",
		["Curse of Exhaustion"] = "Malediction de fatigue",
		["Curse of Idiocy"] = "Malediction d'idiotie",
		["Curse of Recklessness"] = "Malediction de temerite",
		["Curse of Shadow"] = "Malediction de l'ombre",
		["Curse of Tongues"] = "Malediction des langages",
		["Curse of Weakness"] = "Malediction de faiblesse",
		["Curse of the Elements"] = "Malediction des elements",
		["Cyclone"] = "Cyclone",
		["Dagger Specialization"] = "Specialisation Dague",
		["Daggers"] = "Dagues",
		["Dampen Magic"] = "Attenuation de la magie",
		["Dark Pact"] = "Pacte noir",
		["Darkness"] = "Tenebres",
		["Dash"] = "Celerite",
		["Dawnstone Crab"] = "Crabe de pierre d'aube",
		["Dazed"] = "Hebetement",
		["Deadly Interrupt Effect"] = "Effet d'interruption mortel",
		["Deadly Poison"] = "Poison mortel",
		["Deadly Poison II"] = "Poison mortel II",
		["Deadly Poison III"] = "Poison mortel III",
		["Deadly Poison IV"] = "Poison mortel IV",
		["Deadly Poison V"] = "Poison mortel V",
		["Deadly Poison VI"] = "Poison mortel VI",
		["Deadly Poison VII"] = "Poison mortel VII",
		["Deadly Throw"] = "Lancer mortel",
		["Death Coil"] = "Voile mortel",
		["Death Wish"] = "Souhait mortel",
		["Deep Wound"] = "Blessure profonde", -- a verifier
		["Deep Wounds"] = "Blessures profondes",
		["Defense"] = "Defense",
		["Defensive Stance"] = "Posture defensive",
		["Defensive Stance Passive"] = "Posture defensive",
		["Defiance"] = "Defi",
		["Deflection"] = "Deviation",
		["Delusions of Jin'do"] = "Illusions de Jin'do",
		["Demon Armor"] = "Armure demoniaque",
		["Demon Skin"] = "Peau de demon",
		["Demonic Aegis"] = "Egide demoniaque",
		["Demonic Embrace"] = "Baiser demoniaque",
		["Demonic Frenzy"] = "Frenesie demoniaque",
		["Demonic Knowledge"] = "Connaissance demoniaque",
		["Demonic Resilience"] = "Resilience demoniaque",
		["Demonic Sacrifice"] = "Sacrifice demoniaque",
		["Demonic Tactics"] = "Tactique demoniaque",
		["Demoralizing Roar"] = "Rugissement demoralisant",
		["Demoralizing Shout"] = "Cri demoralisant",
		["Dense Sharpening Stone"] = "Pierre a aiguiser dense",
		["Desperate Prayer"] = "Priere du desespoir",
		["Destructive Reach"] = "Allonge de destruction",
		["Detect"] = "Detection",
		["Detect Greater Invisibility"] = "Detection de l'invisibilite superieure",
		["Detect Invisibility"] = "Detection de l'invisibilite",
		["Detect Lesser Invisibility"] = "Detection de l'invisibilite inferieure",
		["Detect Magic"] = "Detection de la magie",
		["Detect Traps"] = "Detection des pieges",
		["Deterrence"] = "Dissuasion",
		["Devastate"] = "Devaster",
		["Devastation"] = "Devastation",
		["Devotion Aura"] = "Aura de devotion",
		["Devour Magic"] = "Devorer la magie",
		["Devour Magic Effect"] = "Effet devorer la magie",
		["Devouring Plague"] = "Peste devorante",
		["Diplomacy"] = "Diplomatie",
		["Dire Bear Form"] = "Forme d'ours redoutable",
		["Dirty Deeds"] = "Coups fourres",
		["Dirty Tricks"] = "Coup tordu",
		["Disarm"] = "Desarmement",
		["Disarm Trap"] = "Desarmement de piege",
		["Disease Cleansing Totem"] = "Totem de Purification des maladies",
		["Disenchant"] = "Desenchanter",
		["Disengage"] = "Desengagement",
		["Dismiss Pet"] = "Renvoyer le familier",
		["Dispel Magic"] = "Dissipation de la magie",
		["Distract"] = "Distraction",
		["Distracting Shot"] = "Trait provocateur",
		["Dive"] = "Plongeon",
		["Divine Favor"] = "Faveur divine",
		["Divine Fury"] = "Fureur divine",
		["Divine Illumination"] = "Illumination divine",
		["Divine Intellect"] = "Intelligence divine",
		["Divine Intervention"] = "Intervention divine",
		["Divine Protection"] = "Protection divine",
		["Divine Shield"] = "Bouclier divin",
		["Divine Spirit"] = "Esprit divin",
		["Divine Strength"] = "Force divine",
		["Divine Wrath"] = "Courroux divin",
		["Dodge"] = "Esquiver",
		["Doomfire"] = "Feu funeste",
		["Dragon's Breath"] = "Souffle du dragon",
		["Dragonscale Leatherworking"] = "Travail du cuir d'ecailles de dragon",
		["Drain Life"] = "Drain de vie",
		["Drain Mana"] = "Drain de mana",
		["Drain Soul"] = "Drain d'ame",
		["Dreamless Sleep"] = "Sommeil sans reve",
		["Drink"] = "Boisson",
		["Dual Wield"] = "Ambidextrie",
		["Dual Wield Specialization"] = "Specialisation Ambidextrie",
		["Duel"] = "Duel",
		["Dust Cloud"] = "Nuage de poussiere",
		["Eagle Eye"] = "Oeil d'aigle",
		["Earth Elemental Totem"] = "Totem elementaire de terre",
		["Earth Shield"] = "Bouclier de terre",
		["Earth Shock"] = "Horion de terre",
		["Earthbind"] = "Lien a la terre",
		["Earthbind Totem"] = "Totem de lien terrestre",
		["Earthstrike"] = "Choc de terre",
		["Efficiency"] = "Efficacite",
		["Elemental Devastation"] = "Devastation elementaire",
		["Elemental Focus"] = "Focalisation elementaire",
		["Elemental Fury"] = "Fureur elementaire",
		["Elemental Leatherworking"] = "Travail du cuir elementaire",
		["Elemental Mastery"] = "Maitrise elementaire",
		["Elemental Precision"] = "Precision elementaire",
		["Elemental Sharpening Stone"] = "Pierre a aiguiser elementaire",
		["Elemental Weapons"] = "Armes elementaires",
		["Elune's Grace"] = "Grace d'Elune",
		["Elusiveness"] = "Insaisissable",
		["Emberstorm"] = "Tempete ardente",
		["Empowered Arcane Missiles"] = "Projectiles des arcanes surpuissants",
		["Empowered Corruption"] = "Corruption surpuissante",
		["Empowered Fireball"] = "Boule de feu surpuissante",
		["Empowered Frostbolt"] = "Eclair de givre surpuissant",
		["Empowered Healing"] = "Soins surpuissants",
		["Empowered Rejuvenation"] = "Recuperation surpuissante",
		["Empowered Touch"] = "Toucher surpuissant",
		["Enamored Water Spirit"] = "Esprit de l'eau amoureux",
		["Enchanting"] = "Enchantement",
		["Endurance"] = "Endurance",
		["Endurance Training"] = "Entrainement a l'Endurance",
		["Engineering"] = "Ingenierie",
		["Engineering Specialization"] = "Specialisation",
		["Enrage"] = "Enrager",
		["Enriched Manna Biscuit"] = "Biscuit enrichi en manne",
		["Enslave Demon"] = "Asservir demon",
		["Entangling Roots"] = "Sarments",
		["Entrapment"] = "Piege",
		["Envenom"] = "Envenimer",
		["Escape Artist"] = "Maitre de l'evasion",
		["Evasion"] = "Evasion",
		["Eviscerate"] = "Evisceration",
		["Evocation"] = "Evocation",
		["Execute"] = "Execution",
		["Exorcism"] = "Exorcisme",
		["Expansive Mind"] = "Pensee expansive",
		["Explosive Trap"] = "Piege explosif",
		["Explosive Trap Effect"] = "Effet Piege explosif",
		["Expose Armor"] = "Exposer l'armure",
		["Expose Weakness"] = "Perce-faille",
		["Extract Gas"] = "Extraction de gaz",
		["Eye for an Eye"] = "Oeil pour oeil",
		["Eye of Kilrogg"] = "Oeil de Kilrogg",
		["Eye of the Storm"] = "Oeil du cyclone",
		["Eyes of the Beast"] = "Oeil de la bete",
		["Fade"] = "Oubli",
		["Faerie Fire"] = "Lucioles",
		["Faerie Fire (Feral)"] = "Lucioles (farouche)",
		["Fanaticism"] = "Fanatisme",
		["Far Sight"] = "Double vue",
		["Fatal Attraction"] = "Liaison fatale",
		["Fear"] = "Peur",
		["Fear Ward"] = "Gardien de peur",
		["Feed Pet"] = "Nourrir le familier",
		["Feed Pet Effect"] = "Effet Nourrir le familier",
		["Feedback"] = "Reaction",
		["Feign Death"] = "Feindre la mort",
		["Feint"] = "Feinte",
		["Fel Armor"] = "Gangrarmure",
		["Fel Concentration"] = "Concentration corrompue",
		["Fel Domination"] = "Domination corrompue",
		["Fel Energy"] = "Energie corrompue",
		["Fel Intellect"] = "Intelligence corrompue",
		["Fel Rage"] = "Gangrerage",
		["Fel Stamina"] = "Endurance corrompue",
		["Felfire"] = "Gangrefeu",
		["Feline Grace"] = "Grace feline",
		["Feral Aggression"] = "Agressivite farouche",
		["Feral Charge"] = "Charge farouche",
		["Feral Instinct"] = "Instinct farouche",
		["Feral Swiftness"] = "Celerite farouche",
		["Ferocious Bite"] = "Morsure feroce",
		["Ferocious Inspiration"] = "Inspiration feroce",
		["Ferocity"] = "Ferocite",
		["Fetish"] = "Fetiche",
		["Find Fish"] = "Decouverte de poisson", -- to be checked
		["Find Herbs"] = "Decouverte d'herbes",
		["Find Minerals"] = "Decouverte de gisements",
		["Find Treasure"] = "Decouverte de tresors",
		["Find Weakness"] = "Decouverte des faiblesses",
		["Fire Blast"] = "Trait de feu",
		["Fire Breath"] = "Souffle de feu",
		["Fire Elemental Totem"] = "Totem elementaire de feu",
		["Fire Nova Totem"] = "Totem Nova de feu",
		["Fire Power"] = "Puissance du feu",
		["Fire Resistance"] = "Resistance au Feu",
		["Fire Resistance Aura"] = "Aura de resistance au Feu",
		["Fire Resistance Totem"] = "Totem de resistance au Feu",
		["Fire Shield"] = "Bouclier de feu",
		["Fire Vulnerability"] = "Vulnerabilite au Feu",
		["Fire Ward"] = "Gardien de feu",
		["Fire Weakness"] = "Sensibilite au Feu",
		["Fireball"] = "Boule de feu",
		["Firebolt"] = "Eclair de feu",
		["First Aid"] = "Premiers soins",
		["Fishing"] = "Peche",
		["Fishing Poles"] = "Cannes a peche",
		["Fist Weapon Specialization"] = "Specialisation Arme de pugilat",
		["Fist Weapons"] = "Armes de pugilat",
		["Flame Shock"] = "Horion de flammes",
		["Flame Throwing"] = "Jet de flammes",
		["Flamestrike"] = "Choc de flammes",
		["Flamethrower"] = "Lance-flammes",
		["Flametongue Attack"] = "Attaque Langue de feu", -- a verifier
		["Flametongue Totem"] = "Totem Langue de feu",
		["Flametongue Weapon"] = "Arme Langue de feu",
		["Flare"] = "Fusee eclairante",
		["Flash Heal"] = "Soins rapides",
		["Flash of Light"] = "Eclair lumineux",
		["Flight Form"] = "Forme de vol",
		["FlightMaster"] = "Maitre de vol",
		["Flurry"] = "Rafale",
		["Focused Casting"] = "Incantation focalisee",
		["Focused Mind"] = "Esprit focalise",
		["Focused Power"] = "Puissance focalisee",
		["Focused Rage"] = "Rage focalisee",
		["Focused Starlight"] = "Lumiere stellaire focalisee",
		["Food"] = "Nourriture",
		["Food & Drink"] = "Nourriture et boisson",
		["Forbearance"] = "Longanimite",
		["Force of Nature"] = "Force de la nature",
		["Force of Will"] = "Force de volonte",
		["Freezing Trap"] = "Piege givrant",
		["Freezing Trap Effect"] = "Effet Piege givrant",
		["Frenzied Regeneration"] = "Regeneration frenetique",
		["Frenzy"] = "Frenesie",
		["Frenzy Effect"] = "Effet de frenesie",
		["Frost Armor"] = "Armure de givre",
		["Frost Blast"] = "Trait de givre",
		["Frost Channeling"] = "Canalisation du givre",
		["Frost Nova"] = "Nova de givre",
		["Frost Resistance"] = "Resistance au Givre",
		["Frost Resistance Aura"] = "Aura de resistance au Givre",
		["Frost Resistance Totem"] = "Totem de resistance au Givre",
		["Frost Shock"] = "Horion de givre",
		["Frost Trap"] = "Piege de givre",
		["Frost Trap Aura"] = "Aura Piege de givre",
		["Frost Ward"] = "Gardien de givre",
		["Frost Warding"] = "Protection contre le Givre",
		["Frost Weakness"] = "Sensibilite au Givre",
		["Frostbite"] = "Morsure de givre",
		["Frostbolt"] = "Eclair de givre",
		["Frostbrand Attack"] = "Attaque Arme de givre",
		["Frostbrand Weapon"] = "Arme de givre",
		["Frozen Core"] = "Cœur de gel",
		["Furious Howl"] = "Hurlement furieux",
		["Furor"] = "Fureur",
		["Fury of the Crashing Waves"] = "Fureur des deferlantes",
		["Garrote"] = "Garrot",
		["Garrote - Silence"] = "Garrot - Silence",
		["Ghost Wolf"] = "Loup fantome",
		["Ghostly Strike"] = "Frappe fantomatique",
		["Gift of Life"] = "Don de vie",
		["Gift of Nature"] = "Don de la Nature",
		["Gift of the Naaru"] = "Don des naaru",
		["Gift of the Wild"] = "Don du fauve",
		["Gouge"] = "Suriner",
		["Grace of Air"] = "Grace aerienne",
		["Grace of Air Totem"] = "Totem de Grace aerienne",
		["Great Stamina"] = "Endurance superieure",
		["Greater Blessing of Kings"] = "Benediction des rois superieure",
		["Greater Blessing of Light"] = "Benediction de lumiere superieure",
		["Greater Blessing of Might"] = "Benediction de puissance superieure",
		["Greater Blessing of Salvation"] = "Benediction de salut superieure",
		["Greater Blessing of Sanctuary"] = "Benediction du sanctuaire superieure",
		["Greater Blessing of Wisdom"] = "Benediction de sagesse superieure",
		["Greater Dreamless Sleep"] = "Sommeil sans reve superieur",
		["Greater Heal"] = "Soins superieurs",
		["Grim Reach"] = "Allonge sinistre",
		["Grounding Totem"] = "Totem de Glebe",
		["Grounding Totem Effect"] = "Effet Totem de Glebe",
		["Grovel"] = "Ramper",
		["Growl"] = "Grondement",
		["Guardian's Favor"] = "Faveur du Gardien",
		["Gun Specialization"] = "Specialisation Armes a feu",
		["Guns"] = "Armes a feu",
		["Hammer of Justice"] = "Marteau de la justice",
		["Hammer of Wrath"] = "Marteau de courroux",
		["Hamstring"] = "Brise-genou",
		["Harass"] = "Harcelement",
		["Hardiness"] = "Solidite",
		["Haste"] = "Hate",
		["Hawk Eye"] = "Oeil de faucon",
		["Heal"] = "Soins",
		["Healing Focus"] = "Focalisation des soins",
		["Healing Light"] = "Lumiere guerisseuse",
		["Healing Stream"] = "Guerisseur",
		["Healing Stream Totem"] = "Totem guerisseur",
		["Healing Touch"] = "Toucher guerisseur",
		["Healing Wave"] = "Vague de soins",
		["Healing Way"] = "Flots de soins",
		["Health Funnel"] = "Captation de vie",
		["Heart of the Wild"] = "Cœur de fauve",
		["Heavy Sharpening Stone"] = "Pierre a aiguiser lourde",
		["Hellfire"] = "Flammes infernales",
		["Hellfire Effect"] = "Effet Flammes infernales",
		["Hellfire Superiority"] = "Superiorite des Flammes infernales",
		["Hemorrhage"] = "Hemorragie",
		["Herb Gathering"] = "Cueillette",
		["Herbalism"] = "Herboristerie",
		["Heroic Strike"] = "Frappe heroique",
		["Heroism"] = "Heroisme",
		["Hex of Weakness"] = "Malefice de faiblesse",
		["Hibernate"] = "Hibernation",
		["Holy Fire"] = "Flammes sacrees",
		["Holy Light"] = "Lumiere sacree",
		["Holy Nova"] = "Nova sacree",
		["Holy Power"] = "Puissance sacree",
		["Holy Reach"] = "Allonge du Sacre",
		["Holy Shield"] = "Bouclier sacre",
		["Holy Shock"] = "Horion sacre",
		["Holy Specialization"] = "Specialisation",
		["Holy Wrath"] = "Colere divine",
		["Honorless Target"] = "Cible sans honneur",
		["Horse Riding"] = "Equitation",
		["Howl of Terror"] = "Hurlement de terreur",
		["Humanoid Slaying"] = "Tueur d'humanoides",
		["Hunter's Mark"] = "Marque du chasseur",
		["Hurricane"] = "Ouragan",
		["Hypothermia"] = "Hypothermie",
		["Ice Armor"] = "Armure de glace",
		["Ice Barrier"] = "Barriere de glace",
		["Ice Block"] = "Bloc de glace",
		["Ice Floes"] = "Iceberg",
		["Ice Lance"] = "Javelot de glace",
		["Ice Shards"] = "Eclats de glace",
		["Ignite"] = "Enflammer",
		["Ignite Mana"] = "Enflammer le mana",
		["Illumination"] = "Illumination",
		["Immolate"] = "Immolation",
		["Immolation Trap"] = "Piege d'immolation",
		["Immolation Trap Effect"] = "Effet de Piege d'immolation",
		["Impact"] = "Impact",
		["Impale"] = "Empaler",
		["Impaling Spine"] = "Epine de perforation",
		["Improved Ambush"] = "Embuscade amelioree",
		["Improved Arcane Missiles"] = "Projectiles des arcanes ameliores",
		["Improved Arcane Shot"] = "Tir des arcanes ameliore",
		["Improved Aspect of the Hawk"] = "Aspect du faucon ameliore",
		["Improved Aspect of the Monkey"] = "Aspect du singe ameliore",
		["Improved Backstab"] = "Attaque sournoise amelioree",
		["Improved Barrage"] = "Barrage ameliore",
		["Improved Berserker Rage"] = "Rage berserker amelioree",
		["Improved Blessing of Might"] = "Benediction de puissance amelioree",
		["Improved Blessing of Wisdom"] = "Benediction de sagesse amelioree",
		["Improved Blink"] = "Transfert ameliore",
		["Improved Blizzard"] = "Blizzard ameliore",
		["Improved Bloodrage"] = "Rage sanguinaire amelioree",
		["Improved Chain Heal"] = "Salve de guerison amelioree",
		["Improved Chain Lightning"] = "Chaine d'eclairs amelioree",
		["Improved Challenging Shout"] = "Cri de defi ameliore",
		["Improved Charge"] = "Charge amelioree",
		["Improved Cleave"] = "Enchainement ameliore",
		["Improved Concentration Aura"] = "Aura de concentration amelioree",
		["Improved Concussive Shot"] = "Trait de choc ameliore",
		["Improved Cone of Cold"] = "Cone de froid ameliore",
		["Improved Corruption"] = "Corruption amelioree",
		["Improved Counterspell"] = "Contresort ameliore",
		["Improved Curse of Agony"] = "Malediction d'agonie amelioree",
		["Improved Curse of Weakness"] = "Malediction de faiblesse amelioree",
		["Improved Demoralizing Shout"] = "Cri demoralisant ameliore",
		["Improved Devotion Aura"] = "Aura de devotion amelioree",
		["Improved Disarm"] = "Desarmement ameliore",
		["Improved Drain Life"] = "Drain de vie ameliore",
		["Improved Drain Soul"] = "Siphon d'ame ameliore",
		["Improved Enrage"] = "Enrager ameliore",
		["Improved Enslave Demon"] = "Asservir demon ameliore",
		["Improved Eviscerate"] = "Evisceration amelioree",
		["Improved Execute"] = "Execution amelioree",
		["Improved Expose Armor"] = "Exposer l'armure ameliore",
		["Improved Eyes of the Beast"] = "Oeil de la bete ameliore",
		["Improved Fade"] = "Oubli ameliore",
		["Improved Feign Death"] = "Feindre la mort ameliore",
		["Improved Fire Blast"] = "Trait de feu ameliore",
		["Improved Fire Totems"] = "Totems de Feu ameliores",
		["Improved Fire Ward"] = "Gardien de feu ameliore",
		["Improved Fireball"] = "Boule de feu amelioree",
		["Improved Firebolt"] = "Eclair de feu ameliore",
		["Improved Flamestrike"] = "Choc de flammes ameliore",
		["Improved Flash of Light"] = "Eclair lumineux ameliore",
		["Improved Frost Nova"] = "Nova de givre amelioree",
		["Improved Frostbolt"] = "Eclair de givre ameliore",
		["Improved Ghost Wolf"] = "Loup fantome ameliore",
		["Improved Gouge"] = "Suriner ameliore",
		["Improved Hammer of Justice"] = "Marteau de la justice ameliore",
		["Improved Hamstring"] = "Brise-genou ameliore",
		["Improved Healing"] = "Soin ameliore",
		["Improved Healing Touch"] = "Toucher guerisseur ameliore",
		["Improved Healing Wave"] = "Vague de soins amelioree",
		["Improved Health Funnel"] = "Captation de vie amelioree",
		["Improved Healthstone"] = "Pierre de soins amelioree",
		["Improved Heroic Strike"] = "Frappe heroique amelioree",
		["Improved Holy Shield"] = "Bouclier sacre ameliore",
		["Improved Howl of Terror"] = "Hurlement de terreur ameliore",
		["Improved Hunter's Mark"] = "Marque du chasseur amelioree",
		["Improved Immolate"] = "Immolation amelioree",
		["Improved Imp"] = "Diablotin ameliore",
		["Improved Inner Fire"] = "Feu interieur ameliore",
		["Improved Intercept"] = "Interception amelioree",
		["Improved Intimidating Shout"] = "Cri d’intimidation ameliore",
		["Improved Judgement"] = "Jugement ameliore",
		["Improved Kick"] = "Coup de pied ameliore",
		["Improved Kidney Shot"] = "Aiguillon perfide ameliore",
		["Improved Lash of Pain"] = "Fouet de la douleur ameliore",
		["Improved Lay on Hands"] = "Imposition des mains amelioree",
		["Improved Leader of the Pack"] = "Chef de la meute ameliore",
		["Improved Life Tap"] = "Connexion amelioree",
		["Improved Lightning Bolt"] = "Eclair ameliore",
		["Improved Lightning Shield"] = "Bouclier de foudre ameliore",
		["Improved Magma Totem"] = "Totem de Magma ameliore",
		["Improved Mana Burn"] = "Brulure de mana amelioree",
		["Improved Mana Shield"] = "Bouclier de mana ameliore",
		["Improved Mana Spring Totem"] = "Totem Fontaine de mana ameliore",
		["Improved Mark of the Wild"] = "Marque du fauve amelioree",
		["Improved Mend Pet"] = "Guerison du familier amelioree",
		["Improved Mind Blast"] = "Attaque mentale amelioree",
		["Improved Moonfire"] = "Eclat lunaire ameliore",
		["Improved Mortal Strike"] = "Frappe mortelle amelioree",
		["Improved Nature's Grasp"] = "Emprise de la nature amelioree",
		["Improved Overpower"] = "Fulgurance amelioree",
		["Improved Power Word: Fortitude"] = "Mot de pouvoir?: Robustesse ameliore",
		["Improved Power Word: Shield"] = "Mot de pouvoir?: Bouclier ameliore",
		["Improved Prayer of Healing"] = "Priere de soins amelioree",
		["Improved Psychic Scream"] = "Cri psychique ameliore",
		["Improved Regrowth"] = "Retablissement ameliore",
		["Improved Reincarnation"] = "Reincarnation amelioree",
		["Improved Rejuvenation"] = "Recuperation amelioree",
		["Improved Rend"] = "Pourfendre ameliore",
		["Improved Renew"] = "Renovation amelioree",
		["Improved Retribution Aura"] = "Aura de vindicte amelioree",
		["Improved Revenge"] = "Vengeance amelioree",
		["Improved Revive Pet"] = "Ressusciter le familier ameliore",
		["Improved Righteous Fury"] = "Fureur vertueuse amelioree",
		["Improved Rupture"] = "Rupture amelioree",
		["Improved Scorch"] = "Brulure amelioree",
		["Improved Scorpid Sting"] = "Piqure de scorpide amelioree",
		["Improved Seal of Righteousness"] = "Sceau de piete ameliore",
		["Improved Seal of the Crusader"] = "Sceau du Croise ameliore",
		["Improved Searing Pain"] = "Douleur brulante amelioree",
		["Improved Serpent Sting"] = "Morsure de serpent amelioree",
		["Improved Shadow Bolt"] = "Trait de l'ombre ameliore",
		["Improved Shadow Word: Pain"] = "Mot de l'ombre?: Douleur ameliore",
		["Improved Shield Bash"] = "Coup de bouclier ameliore",
		["Improved Shield Block"] = "Maitrise du blocage amelioree",
		["Improved Shield Wall"] = "Mur protecteur ameliore",
		["Improved Sinister Strike"] = "Attaque pernicieuse amelioree",
		["Improved Slam"] = "Heurtoir ameliore",
		["Improved Slice and Dice"] = "Debiter ameliore",
		["Improved Sprint"] = "Sprint ameliore",
		["Improved Stings"] = "Morsures et piqures ameliorees",
		["Improved Succubus"] = "Succube amelioree",
		["Improved Sunder Armor"] = "Fracasser armure ameliore",
		["Improved Taunt"] = "Provocation amelioree",
		["Improved Thunder Clap"] = "Coup de tonnerre ameliore",
		["Improved Tranquility"] = "Tranquillite amelioree",
		["Improved Vampiric Embrace"] = "Etreinte vampirique amelioree",
		["Improved Vanish"] = "Disparition amelioree",
		["Improved Voidwalker"] = "Marcheur du Vide ameliore",
		["Improved Weapon Totems"] = "Totems d'armes ameliores",
		["Improved Whirlwind"] = "Tourbillon ameliore",
		["Improved Wing Clip"] = "Coupure d'ailes amelioree",
		["Incinerate"] = "Incinerer",
		["Incineration"] = "Incineration",
		["Inferno"] = "Inferno",
		["Initiative"] = "Initiative",
		["Innkeeper"] = "Aubergiste",
		["Inner Fire"] = "Feu interieur",
		["Inner Focus"] = "Focalisation amelioree",
		["Innervate"] = "Innervation",
		["Insect Swarm"] = "Essaim d'insectes",
		["Insidious Whisper"] = "Murmure insidieux",
		["Inspiration"] = "Inspiration",
		["Insignifigance"] = "Insignifiance",
		["Instant Poison"] = "Poison instantane",
		["Instant Poison II"] = "Poison instantane II",
		["Instant Poison III"] = "Poison instantane III",
		["Instant Poison IV"] = "Poison instantane IV",
		["Instant Poison V"] = "Poison instantane V",
		["Instant Poison VI"] = "Poison instantane VI",
		["Instant Poison VII"] = "Poison instantane VII",
		["Intensity"] = "Intensite",
		["Intercept"] = "Interception",
		["Intercept Stun"] = "Interception etourdissante",
		["Intervene"] = "Intervention",
		["Intimidating Shout"] = "Cri d’intimidation",
		["Intimidation"] = "Intimidation",
		["Invisibility"] = "Invisibilite",
		["Iron Will"] = "Volonte de fer",
		["Jewelcrafting"] = "Joaillerie",
		["Jom Gabbar"] = "Jom Gabbar",
		["Judgement"] = "Jugement",
		["Judgement of Blood"] = "Jugement de sang",
		["Judgement of Command"] = "Jugement d'autorite",
		["Judgement of Justice"] = "Jugement de justice",
		["Judgement of Light"] = "Jugement de lumiere",
		["Judgement of Reckoning"] = "Jugement de vengeance",
		["Judgement of Righteousness"] = "Jugement de piete",
		["Judgement of Wisdom"] = "Jugement de sagesse",
		["Judgement of the Crusader"] = "Jugement du Croise",
		["Kick"] = "Coup de pied",
		["Kick - Silenced"] = "Coup de pied - Silencieux",
		["Kidney Shot"] = "Aiguillon perfide",
		["Kill Command"] = "Ordre de tuer",
		["Killer Instinct"] = "Instinct du tueur",
		["Kiss of the Spider"] = "Baiser de l'araignee",
		["Kodo Riding"] = "Monte de kodo",
		["Lacerate"] = "Lacerer",
		["Lash of Pain"] = "Fouet de la douleur",
		["Last Stand"] = "Dernier rempart",
		["Lay on Hands"] = "Imposition des mains",
		["Leader of the Pack"] = "Chef de la meute",
		["Leather"] = "Cuir",
		["Leatherworking"] = "Travail du cuir",
		["Lesser Heal"] = "Soins inferieurs",
		["Lesser Healing Wave"] = "Vague de soins inferieurs",
		["Lesser Invisibility"] = "Invisibilite inferieure",
		["Lethal Shots"] = "Coups fatals",
		["Lethality"] = "Mortalite",
		["Levitate"] = "Levitation",
		["Libram"] = "Libram",
		["Life Tap"] = "Connexion",
		["Lifebloom"] = "Fleur de vie",
		["Light's Grace"] = "Grace de la lumiere",
		["Lightning Bolt"] = "Eclair",
		["Lightning Breath"] = "Souffle de foudre",
		["Lightning Mastery"] = "Maitrise de la foudre",
		["Lightning Reflexes"] = "Reflexes eclairs",
		["Lightning Shield"] = "Bouclier de foudre",
		["Lightning Speed"] = "Vitesse de l'eclair",
		["Lightwell"] = "Puits de lumiere",
		["Lightwell Renew"] = "Renovation du Puits de lumiere",
		["Lockpicking"] = "Crochetage",
		["Long Daze"] = "Hebetement prolonge",
		["Lust for Battle"] = "Soif de bataille",
		["Mace Specialization"] = "Specialisation Masse",
		["Mace Stun Effect"] = "Effet etourdissant de la masse",
		["Mage Armor"] = "Armure du mage",
		["Magic Absorption"] = "Absorption de magie",
		["Magic Attunement"] = "Harmonisation de la magie",
		["Magma Totem"] = "Totem de Magma",
		["Mail"] = "Mailles",
		["Maim"] = "Estropier",
		["Major Dreamless Sleep"] = "Sommeil sans reve majeur",
		["Malediction"] = "Imprecation",
		["Malice"] = "Malice",
		["Mana Burn"] = "Brulure de mana",
		["Mana Feed"] = "Festin de mana",
		["Mana Shield"] = "Bouclier de mana",
		["Mana Spring"] = "Fontaine de mana",
		["Mana Spring Totem"] = "Totem Fontaine de mana",
		["Mana Tap"] = "Ponction de mana",
		["Mana Tide"] = "Vague de mana",
		["Mana Tide Totem"] = "Totem de Vague de mana",
		["Mangle"] = "Mutilation",
		["Mangle (Bear)"] = "Mutilation (ours)",
		["Mangle (Cat)"] = "Mutilation (felin)",
		["Mark of the Wild"] = "Marque du fauve",
		["Martyrdom"] = "Martyre",
		["Mass Dispel"] = "Dissipation de masse",
		["Master Conjuror"] = "Maitre conjurateur",
		["Master Demonologist"] = "Maitre demonologue",
		["Master Summoner"] = "Maitre invocateur",
		["Master Tactician"] = "Maitre tacticien",
		["Master of Deception"] = "Maitre des illusions",
		["Master of Elements"] = "Maitre des elements",
		["Master of Subtlety"] = "Maitre de la discretion",
		["Maul"] = "Mutiler",
		["Mechanostrider Piloting"] = "Pilotage de mecanotrotteur",
		["Meditation"] = "Meditation",
		["Melee Specialization"] = "Specialisation Melee",
		["Melt Armor"] = "Fondre armure",
		["Mend Pet"] = "Guerison du familier",
		["Mental Agility"] = "Sagacite",
		["Mental Strength"] = "Force mentale",
		["Mind Blast"] = "Attaque mentale",
		["Mind Control"] = "Controle mental",
		["Mind Flay"] = "Fouet mental",
		["Mind Mastery"] = "Maitrise mentale",
		["Mind Soothe"] = "Apaisement",
		["Mind Vision"] = "Vision telepathique",
		["Mind-numbing Poison"] = "Poison de distraction mentale",
		["Mind-numbing Poison II"] = "Poison de distraction mentale II",
		["Mind-numbing Poison III"] = "Poison de distraction mentale III",
		["Mining"] = "Minage",
		["Misdirection"] = "Detournement",
		["Misery"] = "Misere",
		["Mocking Blow"] = "Coup railleur",
		["Molten Armor"] = "Armure de la fournaise",
		["Molten Fury"] = "Sang de la fournaise",
		["Mongoose Bite"] = "Morsure de la mangouste",
		["Monster Slaying"] = "Tueur de monstres",
		["Moonfire"] = "Eclat lunaire",
		["Moonfury"] = "Fureur lunaire",
		["Moonglow"] = "Lueur de la lune",
		["Moonkin Aura"] = "Aura de selenien",
		["Moonkin Form"] = "Forme de selenien",
		["Mortal Shots"] = "Coups mortels",
		["Mortal Strike"] = "Frappe mortelle",
		["Multi-Shot"] = "Fleches multiples",
		["Murder"] = "Meurtre",
		["Mutilate"] = "Estropier",
		["Natural Armor"] = "Armure naturelle",
		["Natural Perfection"] = "Perfection naturelle",
		["Natural Shapeshifter"] = "Changeforme naturel",
		["Naturalist"] = "Naturaliste",
		["Nature Resistance"] = "Resistance a la Nature",
		["Nature Resistance Totem"] = "Totem de resistance a la Nature",
		["Nature Weakness"] = "Sensibilite a la Nature",
		["Nature's Focus"] = "Focalisation de la nature",
		["Nature's Grace"] = "Grace de la nature",
		["Nature's Grasp"] = "Emprise de la nature",
		["Nature's Guidance"] = "Soutien de la nature",
		["Nature's Reach"] = "Allonge de la Nature",
		["Nature's Swiftness"] = "Rapidite de la nature",
		["Negative Charge"] = "Charge negative",
		["Nether Protection"] = "Protection du Neant",
		["Netherstorm Flag"] = "Drapeau de Raz-de-Neant",
		["Nightfall"] = "Crepuscule",
		["Nurturing Instinct"] = "Instinct Nourricier",
		["Omen of Clarity"] = "Augure de clarte",
		["One-Handed Axes"] = "Haches a une main",
		["One-Handed Maces"] = "Masses a une main",
		["One-Handed Swords"] = "Epees a une main",
		["One-Handed Weapon Specialization"] = "Specialisation Arme 1M",
		["Opening"] = "Ouverture",
		["Opening - No Text"] = "Ouverture - pas de texte",
		["Opportunity"] = "Opportunite",
		["Overpower"] = "Fulgurance",
		["Pain Suppression"] = "Suppression de la douleur",
		["Panic"] = "Panique",
		["Paranoia"] = "Paranoia",
		["Parasitic Shadowfiend"] = "Ombrefiel parasite",
		["Parry"] = "Parade",
		["Pathfinding"] = "Science des chemins",
		["Perceived Weakness"] = "Faiblesse percue",
		["Perception"] = "Perception",
		["Permafrost"] = "Gel prolonge",
		["Pet Aggression"] = "Agressivite du familier",
		["Pet Hardiness"] = "Robustesse du familier",
		["Pet Recovery"] = "Retablissement du familier",
		["Pet Resistance"] = "Resistance du familier",
		["Phase Shift"] = "Changement de phase",
		["Pick Lock"] = "Crochetage",
		["Pick Pocket"] = "Vol a la tire",
		["Piercing Howl"] = "Hurlement percant",
		["Piercing Ice"] = "Glace percante",
		["Plate Mail"] = "Armure en plaques",
		["Playing with Fire"] = "Jouer avec le feu",
		["Poison Cleansing Totem"] = "Totem de Purification du poison",
		["Poison Spit"] = "Crachat de poison",
		["Poisons"] = "Poisons",
		["Polearms"] = "Armes d'hast",
		["Poleaxe Specialization"] = "Specialisation Arme d'hast",
		["Polymorph"] = "Metamorphose",
		["Polymorph: Pig"] = "Metamorphose?: cochon",
		["Polymorph: Turtle"] = "Metamorphose?: tortue",
		["Portal: Darnassus"] = "Portail?: Darnassus",
		["Portal: Exodar"] = "Portail?: Exodar",
		["Portal: Ironforge"] = "Portail?: Forgefer",
		["Portal: Orgrimmar"] = "Portail?: Orgrimmar",
		["Portal: Shattrath"] = "Portail?: Shattrath",
		["Portal: Silvermoon"] = "Portail?: Lune-d'argent",
		["Portal: Stormwind"] = "Portail?: Hurlevent",
		["Portal: Thunder Bluff"] = "Portail?: les Pitons du Tonnerre",
		["Portal: Undercity"] = "Portail?: Fossoyeuse",
		["Positive Charge"] = "Charge positive",
		["Pounce"] = "Traquenard",
		["Pounce Bleed"] = "Traquenard sanglant",
		["Power Infusion"] = "Infusion de puissance",
		["Power Word: Fortitude"] = "Mot de pouvoir?: Robustesse",
		["Power Word: Shield"] = "Mot de pouvoir?: Bouclier",
		["Prayer of Fortitude"] = "Priere de robustesse",
		["Prayer of Healing"] = "Priere de soins",
		["Prayer of Mending"] = "Priere de guerison",
		["Prayer of Shadow Protection"] = "Priere de protection contre l'Ombre",
		["Prayer of Spirit"] = "Priere d'Esprit",
		["Precision"] = "Precision",
		["Predatory Instincts"] = "Instincts de predateur",
		["Predatory Strikes"] = "Frappes de predateur",
		["Premeditation"] = "Premeditation",
		["Preparation"] = "Preparation",
		["Presence of Mind"] = "Presence spirituelle",
		["Primal Fury"] = "Fureur primitive",
		["Prismatic Cloak"] = "Cape prismatique",
		["Profession Trainers"] = "Maitres des professions",
		["Prospecting"] = "Prospection",
		["Prowl"] = "Roder",
		["Psychic Scream"] = "Cri psychique",
		["Pummel"] = "Volee de coups",
		["Purge"] = "Expiation",
		["Purification"] = "Purification",
		["Purify"] = "Purification",
		["Purifying Power"] = "Puissance purifiante",
		["Pursuit of Justice"] = "Poursuite de la justice",
		["Pyroblast"] = "Explosion pyrotechnique",
		["Pyroclasm"] = "Pyroclasme",
		["Pyromaniac"] = "Pyromane",
		["Quick Recovery"] = "Retablissement rapide",
		["Quick Shots"] = "Tir rapide",
		["Quickness"] = "Rapidite",
		["Rage of the Unraveller"] = "Rage du detrameur",
		["Rain of Fire"] = "Pluie de feu",
		["Rake"] = "Griffure",
		["Ram Riding"] = "Monte de belier",
		["Rampage"] = "Saccager",
		["Ranged Weapon Specialization"] = "Specialisation Armes a distance",
		["Rapid Fire"] = "Tir rapide",
		["Rapid Killing"] = "Tueur rapide",
		["Raptor Riding"] = "Monte de raptor",
		["Raptor Strike"] = "Attaque du raptor",
		["Ravage"] = "Ravage",
		["Readiness"] = "Promptitude",
		["Reagents"] = "Reagent",
		["Rebirth"] = "Renaissance",
		["Reckless Charge"] = "Charge furieuse",
		["Recklessness"] = "Temerite",
		["Reckoning"] = "Retribution",
		["Redemption"] = "Redemption",
		["Redoubt"] = "Redoute",
		["Reflection"] = "Renvoi",
		["Regeneration"] = "Regeneration",
		["Regrowth"] = "Retablissement",
		["Reincarnation"] = "Reincarnation",
		["Reinforced Shield"] = "Bouclier renforce",
		["Rejuvenation"] = "Recuperation",
		["Relentless Strikes"] = "Frappes implacables",
		["Remorseless"] = "Impitoyable",
		["Remorseless Attacks"] = "Attaques impitoyables",
		["Remote Toy"] = "Jouet a distance",
		["Remove Curse"] = "Delivrance de la malediction",
		["Remove Insignia"] = "Enlever l'insigne",
		["Remove Lesser Curse"] = "Delivrance de la malediction mineure",
		["Rend"] = "Pourfendre",
		["Renew"] = "Renovation",
		["Repair"] = "Reparer",
		["Repentance"] = "Repentir",
		["Restless Strength"] = "Force inconstante",
		["Restorative Totems"] = "Totems de restauration",
		["Resurrection"] = "Resurrection",
		["Retaliation"] = "Represailles",
		["Retribution Aura"] = "Aura de vindicte",
		["Revenge"] = "Vengeance",
		["Revenge Stun"] = "Etourdissement vengeur",
		["Reverberation"] = "Reverberation",
		["Revive Pet"] = "Ressusciter le familier",
		["Righteous Defense"] = "Defense vertueuse",
		["Righteous Fury"] = "Fureur vertueuse",
		["Rip"] = "Dechirure",
		["Riposte"] = "Riposte",
		["Ritual of Doom"] = "Rituel de malediction",
		["Ritual of Doom Effect"] = "Effet Rituel de malediction",
		["Ritual of Souls"] = "Rituel des ames",
		["Ritual of Summoning"] = "Rituel d'invocation",
		["Rockbiter Weapon"] = "Arme Croque-roc",
		["Rough Sharpening Stone"] = "Pierre a aiguiser brute",
		["Ruin"] = "Ruine",
		["Rupture"] = "Rupture",
		["Ruthlessness"] = "Nemesis",
		["Sacrifice"] = "Sacrifice",
		["Safe Fall"] = "Chute amortie",
		["Sanctified Crusader"] = "Croise sanctifie",
		["Sanctified Judgement"] = "Jugement sanctifie",
		["Sanctified Light"] = "Lumiere sanctifiee",
		["Sanctity Aura"] = "Aura de saintete",
		["Sap"] = "Assommer",
		["Savage Fury"] = "Furie sauvage",
		["Savage Strikes"] = "Frappes sauvages",
		["Scare Beast"] = "Effrayer une bete",
		["Scatter Shot"] = "Fleche de dispersion",
		["Scorch"] = "Brulure",
		["Scorpid Poison"] = "Poison de scorpide",
		["Scorpid Sting"] = "Piqure de scorpide",
		["Screech"] = "Hurlement",
		["Seal Fate"] = "Scelle le destin",
		["Seal of Blood"] = "Sceau de sang",
		["Seal of Command"] = "Sceau d'autorite",
		["Seal of Justice"] = "Sceau de justice",
		["Seal of Light"] = "Sceau de lumiere",
		["Seal of Righteousness"] = "Sceau de piete",
		["Seal of Vengeance"] = "Sceau de vengeance",
		["Seal of Wisdom"] = "Sceau de sagesse",
		["Seal of the Crusader"] = "Sceau du Croise",
		["Searing Light"] = "Lumiere incendiaire",
		["Searing Pain"] = "Douleur brulante",
		["Searing Totem"] = "Totem incendiaire",
		["Second Wind"] = "Second souffle",
		["Seduction"] = "Seduction",
		["Seed of Corruption"] = "Graine de Corruption",
		["Seethe"] = "Bouillant de rage",
		["Sense Demons"] = "Detection des demons",
		["Sense Undead"] = "Detection des morts-vivants",
		["Sentry Totem"] = "Totem Sentinelle",
		["Serpent Sting"] = "Morsure de serpent",
		["Serrated Blades"] = "Lames dentelees",
		["Setup"] = "Preparatifs",
		["Shackle Undead"] = "Entraves des morts-vivants",
		["Shadow Affinity"] = "Affinite avec l'ombre",
		["Shadow Bolt"] = "Trait de l'ombre",
		["Shadow Embrace"] = "Etreinte de l'ombre",
		["Shadow Focus"] = "Focalisation de l'ombre",
		["Shadow Mastery"] = "Maitrise de l'ombre",
		["Shadow Power"] = "Puissance de l'ombre",
		["Shadow Protection"] = "Protection contre l'Ombre",
		["Shadow Reach"] = "Allonge de l'Ombre",
		["Shadow Resistance"] = "Resistance a l'Ombre",
		["Shadow Resistance Aura"] = "Aura de resistance a l'Ombre",
		["Shadow Trance"] = "Transe de l'ombre",
		["Shadow Vulnerability"] = "Vulnerabilite a l'Ombre",
		["Shadow Ward"] = "Gardien de l'ombre",
		["Shadow Weakness"] = "Sensibilite a l'Ombre",
		["Shadow Weaving"] = "Tissage de l'ombre",
		["Shadow Word: Death"] = "Mot de l'ombre?: Mort",
		["Shadow Word: Pain"] = "Mot de l'ombre?: Douleur",
		["Shadow and Flame"] = "Ombre et flammes",
		["Shadow of Death"] = "Ombre de la mort",
		["Shadowburn"] = "Brulure de l'ombre",
		["Shadowfiend"] = "Ombrefiel",
		["Shadowform"] = "Forme d'Ombre",
		["Shadowfury"] = "Furie de l'ombre",
		["Shadowguard"] = "Garde de l'ombre",
		["Shadowmeld"] = "Camouflage dans l'ombre",
		["Shadowmeld Passive"] = "Camouflage dans l'ombre",
		["Shadowstep"] = "Pas de l'ombre",
		["Shamanistic Rage"] = "Rage du chaman",
		["Sharpened Claws"] = "Griffes aiguisees",
		["Shatter"] = "Fracasser",
		["Shell Shield"] = "Carapace bouclier",
		["Shield"] = "Bouclier",
		["Shield Bash"] = "Coup de bouclier",
		["Shield Bash - Silenced"] = "Coup de bouclier - silencieux",
		["Shield Block"] = "Maitrise du blocage",
		["Shield Slam"] = "Heurt de bouclier",
		["Shield Specialization"] = "Specialisation Bouclier",
		["Shield Wall"] = "Mur protecteur",
		["Shiv"] = "Kriss",
		["Shoot"] = "Tir",
		["Shoot Bow"] = "Tir a l'arc",
		["Shoot Gun"] = "Tir avec une arme a feu",
		["Shred"] = "Lambeau",
		["Shredding Attacks"] = "Attaques lacerantes",
		["Silence"] = "Silence",
		["Silencing Shot"] = "Fleche-baillon",
		["Silent Resolve"] = "Resolution silencieuse",
		["Silverwing Flag"] = "Drapeau d'Aile-argent",
		["Sinister Strike"] = "Attaque pernicieuse",
		["Siphon Life"] = "Siphon de vie",
		["Skinning"] = "Depecage",
		["Slam"] = "Heurtoir",
		["Slayer's Crest"] = "Blason de tueur",
		["Sleep"] = "Sommeil",
		["Slice and Dice"] = "Debiter",
		["Slow"] = "Lenteur",
		["Slow Fall"] = "Chute lente",
		["Smelting"] = "Fondre",
		["Smite"] = "Chatiment",
		["Snake Trap"] = "Piege a serpent",
		["Solid Sharpening Stone"] = "Pierre a aiguiser solide",
		["Sonic Burst"] = "Explosion sonore",
		["Soothe Animal"] = "Apaiser les animaux",
		["Soothing Kiss"] = "Baiser apaisant",
		["Soul Fire"] = "Feu de l'ame",
		["Soul Leech"] = "Suceur d'ame",
		["Soul Link"] = "Lien spirituel",
		["Soul Siphon"] = "Siphon d'ame",
		["Soulshatter"] = "Brise-ame",
		["Soulstone Resurrection"] = "Resurrection de Pierre d'ame",
		["Spell Haste"] = "Hate des sorts",
		["Spell Lock"] = "Verrou magique",
		["Spell Power"] = "Puissance des sorts",
		["Spell Reflection"] = "Renvoi de sort",
		["Spell Vulnerability"] = "Vulnerabilite aux sorts",
		["Spell Warding"] = "Protection contre les sorts",
		["Spellsteal"] = "Vol de sort",
		["Spirit Bond"] = "Engagement spirituel",
		["Spirit Tap"] = "Connexion spirituelle",
		["Spirit of Redemption"] = "Esprit de redemption",
		["Spiritual Attunement"] = "Harmonisation spirituelle",
		["Spiritual Focus"] = "Focalisation spirituelle",
		["Spiritual Guidance"] = "Direction spirituelle",
		["Spiritual Healing"] = "Soins spirituels",
		["Spiteful Fury"] = "Fureur malveillante",
		["Sprint"] = "Sprint",
		["StableMaster"] = "Maitre des ecuries", -- to be checked
		["Stance Mastery"] = "Maitrise des postures",
		["Starfire"] = "Feu stellaire",
		["Starfire Stun"] = "Feu stellaire etourdissant",
		["Starlight Wrath"] = "Colere stellaire",
		["Starshards"] = "Eclats stellaires",
		["Static Charge"] = "Charge statique",
		["Staves"] = "Batons",
		["Steady Shot"] = "Tir assure",
		["Stealth"] = "Camouflage",
		["Stoneclaw Stun"] = "Etourdissement de Griffes de pierre",
		["Stoneclaw Totem"] = "Totem de Griffes de pierre",
		["Stoneform"] = "Forme de pierre",
		["Stoneskin"] = "Peau de pierre",
		["Stoneskin Totem"] = "Totem de Peau de pierre",
		["Stormstrike"] = "Courroux naturel",
		["Strength of Earth"] = "Force de la Terre",
		["Strength of Earth Totem"] = "Totem de Force de la Terre",
		["Strength of the Halaani"] = "Force des Halaani",
		["Stuck"] = "Bloque",
		["Stun"] = "Etourdi",
		["Subtlety"] = "Discretion",
		["Suffering"] = "Souffrance",
		["Summon Charger"] = "Invocation de destrier",
		["Summon Dreadsteed"] = "Invocation d'un destrier de l'effroi",
		["Summon Felguard"] = "Invocation d'un gangregarde",
		["Summon Felhunter"] = "Invocation d'un chasseur corrompu",
		["Summon Felsteed"] = "Invocation d'un palefroi corrompu",
		["Summon Imp"] = "Invocation d'un diablotin",
		["Summon Succubus"] = "Invocation d'une succube",
		["Summon Voidwalker"] = "Invocation d'un marcheur du Vide",
		["Summon Warhorse"] = "Invocation d'un cheval de guerre",
		["Summon Water Elemental"] = "Invocation d'un elementaire d'eau",
		["Sunder Armor"] = "Fracasser armure",
		["Suppression"] = "Suppression",
		["Surefooted"] = "Pied sur",
		["Surge of Light"] = "Vague de lumiere",
		["Surprise Attacks"] = "Attaques surprises",
		["Survivalist"] = "Survivant",
		["Sweeping Strikes"] = "Attaques circulaires",
		["Swift Flight Form"] = "Forme de vol rapide",
		["Swiftmend"] = "Prompte guerison",
		["Swipe"] = "Balayage",
		["Sword Specialization"] = "Specialisation Epee",
		["Symbol of Hope"] = "Symbole d'espoir",
		["Tactical Mastery"] = "Maitre tacticien",
		["Tailoring"] = "Couture",
		["Tainted Blood"] = "Corruption sanguine",
		["Tainted Mind"] = "Esprit corrompu",
		["Tame Beast"] = "Dompte une bete",
		["Taunt"] = "Provocation",
		["Teleport: Darnassus"] = "Teleportation?: Darnassus",
		["Teleport: Exodar"] = "Teleportation?: Exodar",
		["Teleport: Ironforge"] = "Teleportation?: Forgefer",
		["Teleport: Moonglade"] = "Teleportation?: Reflet-de-Lune",
		["Teleport: Orgrimmar"] = "Teleportation?: Orgrimmar",
		["Teleport: Shattrath"] = "Teleportation?: Shattrath",
		["Teleport: Silvermoon"] = "Teleportation?: Lune-d'argent",
		["Teleport: Stormwind"] = "Teleportation?: Hurlevent",
		["Teleport: Thunder Bluff"] = "Teleportation?: les Pitons du Tonnerre",
		["Teleport: Undercity"] = "Teleportation?: Fossoyeuse",
		["Temporal Rift"] = "Faille temporelle",
		["The Beast Within"] = "La bete interieure",
		["The Human Spirit"] = "L'esprit humain",
		["Thick Hide"] = "Peau epaisse",
		["Thorns"] = "Epines",
		["Thrill of the Hunt"] = "Frisson de la chasse",
		["Throw"] = "Lancer",
		["Throwing Specialization"] = "Specialisation Armes de jet",
		["Thrown"] = "Armes de jet",
		["Thunder Clap"] = "Coup de tonnerre",
		["Thunderfury"] = "Lame-tonnerre",
		["Thundering Strikes"] = "Frappe foudroyante",
		["Thunderstomp"] = "Grondeterre",
		["Tidal Focus"] = "Focalisation des flots",
		["Tidal Mastery"] = "Maitrise des flots",
		["Tiger Riding"] = "Monte de tigre",
		["Tiger's Fury"] = "Fureur du tigre",
		["Time's Favor"] = "Faveur du temps",
		["Torment"] = "Tourment",
		["Totem"] = "Totem",
		["Totem of Wrath"] = "Totem de courroux",
		["Totemic Call"] = "Appel totemique",
		["Totemic Focus"] = "Focalisation totemique",
		["Touch of Shadow"] = "Toucher de l'ombre",
		["Touch of Weakness"] = "Toucher de faiblesse",
		["Toughness"] = "Resistance",
		["Traces of Silithyst"] = "Traces de silithyste",
		["Track Beasts"] = "Pistage des betes",
		["Track Demons"] = "Pistage des demons",
		["Track Dragonkin"] = "Pistage des draconiens",
		["Track Elementals"] = "Pistage des elementaires",
		["Track Giants"] = "Pistage des geants",
		["Track Hidden"] = "Pistage des camoufles",
		["Track Humanoids"] = "Pistage des humanoides",
		["Track Undead"] = "Pistage des morts-vivants",
		["Tranquil Air"] = "Tranquillite de l'air",
		["Tranquil Air Totem"] = "Totem de Tranquillite de l'air",
		["Tranquil Spirit"] = "Tranquillite de l'esprit",
		["Tranquility"] = "Tranquillite",
		["Tranquilizing Shot"] = "Tir tranquillisant",
		["Trap Mastery"] = "Maitrise des pieges",
		["Travel Form"] = "Forme de voyage",
		["Tree of Life"] = "Arbre de vie",
		["Tremor Totem"] = "Totem de Seisme",
		["Tribal Leatherworking"] = "Travail du cuir tribal",
		["Trueshot Aura"] = "Aura de precision",
		["Turn Undead"] = "Renvoi des morts-vivants",
		["Twin Spire Blessing"] = "Benediction des fleches jumelles",
		["Two-Handed Axes"] = "Haches a deux mains",
		["Two-Handed Axes and Maces"] = "Haches et masses a deux mains",
		["Two-Handed Maces"] = "Masses a deux mains",
		["Two-Handed Swords"] = "Epees a deux mains",
		["Two-Handed Weapon Specialization"] = "Specialisation Arme 2M",
		["Unarmed"] = "Mains nues",
		["Unbreakable Will"] = "Volonte inflexible",
		["Unbridled Wrath"] = "Colere dechainee",
		["Undead Horsemanship"] = "Monte de cheval squelette",
		["Underwater Breathing"] = "Respiration aquatique",
		["Unending Breath"] = "Respiration interminable",
		["Unholy Power"] = "Puissance impie",
		["Unleashed Fury"] = "Fureur liberee",
		["Unleashed Rage"] = "Rage liberee",
		["Unstable Affliction"] = "Affliction instable",
		["Unstable Power"] = "Puissance instable",
		["Unyielding Faith"] = "Foi inflexible",
		["Vampiric Embrace"] = "Etreinte vampirique",
		["Vampiric Touch"] = "Toucher vampirique",
		["Vanish"] = "Disparition",
		["Vanished"] = "Invisible",
		["Vengeance"] = "Vengeance",
		["Venomous Totem"] = "Totem venimeux",
		["Victory Rush"] = "Ivresse de la victoire",
		["Vigor"] = "Vigueur",
		["Vile Beam"] = "Rayon abominable",
		["Vile Poisons"] = "Poisons abominables",
		["Vindication"] = "Justification",
		["Viper Sting"] = "Morsure de vipere",
		["Volley"] = "Salve",
		["Wand Specialization"] = "Specialisation Baguette",
		["Wands"] = "Baguettes",
		["War Stomp"] = "Choc martial",
		["Warp"] = "Distorsion",
		["Warsong Flag"] = "Drapeau Chanteguerre",
		["Water Breathing"] = "Respiration aquatique",
		["Water Shield"] = "Bouclier d'eau",
		["Water Tomb"] = "Tombe aquatique",
		["Water Walking"] = "Marcher sur l’eau",
		["Waterbolt"] ="Eclair d'eau",
		["Watery Grave"] = "Tombeau aquatique",
		["Weakened Soul"] = "Ame affaiblie",
		["Weapon Mastery"] = "Maitrise des armes",
		["Weaponsmith"] = "Fabricant d'armes",
		["Whirlwind"] = "Tourbillon",
		["Will of the Forsaken"] = "Volonte des Reprouves",
		["Windfury"] = "Furie-des-vents",
		["Windfury Attack"] = "Attaque Furie-des-vents", -- a verifier
		["Windfury Totem"] = "Totem Furie-des-vents",
		["Windfury Weapon"] = "Arme Furie-des-vents",
		["Windwall"] = "Mur des vents",
		["Windwall Totem"] = "Totem de Mur des vents",
		["Wing Clip"] = "Coupure d'ailes",
		["Winter's Chill"] = "Froid hivernal",
		["Wisp Spirit"] = "Esprit feu follet",
		["Wolf Riding"] = "Monte de loup",
		["Wound Poison"] = "Poison douloureux",
		["Wound Poison II"] = "Poison douloureux II",
		["Wound Poison III"] = "Poison douloureux III",
		["Wound Poison IV"] = "Poison douloureux IV",
		["Wound Poison V"] = "Poison douloureux V",
		["Wrath"] = "Colere",
		["Wrath of Air Totem"] = "Totem de courroux de l'air",
		["Wrath of Cenarius"] = "Colere de Cenarius",
		["Wrath of the Astromancer"] = "Courroux de l'astromancienne",
		["Wyvern Sting"] = "Piqure de wyverne",
	}
elseif GAME_LOCALE == "zhCN" then
	lib:SetCurrentTranslations {
		["Abolish Disease"] = "?除疾病",
		["Abolish Poison"] = "?毒?",
		["Abolish Poison Effect"] = "?毒?效果",
		["Activate MG Turret"] = "?射MGs",--???台
		["Adrenaline Rush"] = "??",
		["Aftermath"] = "?算",
		["Aggression"] = "侵犯",
		["Aimed Shot"] = "?准射?",
		["Alchemy"] = "?金?",
		["Ambush"] = "伏?",
		["Ammunition"] = "Ammunition",
		["Amplify Curse"] = "??增幅",
		["Amplify Magic"] = "魔法增效",
		["Ancestral Fortitude"] = "先祖??",
		["Ancestral Healing"] = "先祖治?",
		["Ancestral Knowledge"] = "先祖知?",
		["Ancestral Spirit"] = "先祖之魂",
		["Ancient Hysteria"] = "上古狂?",
		["Anesthetic Poison"] = "麻醉?膏",
		["Anger Management"] = "?怒掌控",
		["Anguish"] = "痛楚",
		["Anticipation"] = "?知",
		["Aquatic Form"] = "水栖形?",
		["Arcane Blast"] = "????",
		["Arcane Brilliance"] = "??光?",
		["Arcane Concentration"] = "???注",
		["Arcane Energy"] = "??能量",
		["Arcane Explosion"] = "魔爆?",
		["Arcane Focus"] = "??集中",
		["Arcane Fortitude"] = "????",
		["Arcane Impact"] = "????",
		["Arcane Instability"] = "??增效",
		["Arcane Intellect"] = "??智慧",
		["Arcane Meditation"] = "??冥想",
		["Arcane Mind"] = "??心智",
		["Arcane Missiles"] = "????",
		["Arcane Potency"] = "???能",
		["Arcane Power"] = "??强化",
		["Arcane Resistance"] = "??抗性",
		["Arcane Shot"] = "??射?",
		["Arcane Shroud"] = "????",
		["Arcane Subtlety"] = "??精妙",
		["Arcane Torrent"] = "??洪流",
		["Arcane Weakness"] = "???弱",
		["Arctic Reach"] = "?寒延伸",
		["Arctic Winds"] = "?寒之?",
		["Armor of Faith"] = "信仰",
		["Armorsmith"] = "防具?造",
		["Aspect of the Beast"] = "野?守?",
		["Aspect of the Cheetah"] = "?豹守?",
		["Aspect of the Hawk"] = "雄?守?",
		["Aspect of the Monkey"] = "??守?",
		["Aspect of the Pack"] = "豹群守?",
		["Aspect of the Viper"] = "?蛇守?",
		["Aspect of the Wild"] = "野性守?",
		["Astral Recall"] = "星界?送",
		["Attack"] = "攻?",
		["Attacking"] = "攻?",
		["Auto Shot"] = "自?射?",
		["Avenger's Shield"] = "?仇者之盾",
		["Avenging Wrath"] = "?仇之怒",
		["Avoidance"] = "?避",
		["Axe Specialization"] = "斧?精",
		["Backlash"] = "反?",
		["Backstab"] = "背刺",
		["Badge of the Swarmguard"] = "?群?士徽章",
		["Balance of Power"] = "能量平衡",
		["Bane"] = "??",
		["Banish"] = "放逐?",
		["Banker"] = "Banker",
		["Banshee Curse"] = "女妖??",
		["Barkskin"] = "?皮?",
		["Barrage"] = "?幕",
		["Bash"] = "猛?",
		["Basic Campfire"] = "基??火",
		["Battle Rush"] = "?斗?刺",
		["Battle Shout"] = "?斗怒吼",
		["Battle Stance"] = "?斗姿?",
		["Battle Stance Passive"] = "?斗姿?（被?）",
		["BattleMaster"] = "BattleMaster",
		["Bear Form"] = "熊形?",
		["Beast Lore"] = "野?知?",
		["Beast Slaying"] = "野??手",
		["Beast Training"] = "??野?",
		["Benediction"] = "祈福",
		["Berserker Rage"] = "狂暴之怒",
		["Berserker Stance"] = "狂暴姿?",
		["Berserker Stance Passive"] = "狂暴姿?（被?）",
		["Berserking"] = "狂暴",
		["Bestial Discipline"] = "野?戒律",
		["Bestial Swiftness"] = "野?迅捷",
		["Bestial Wrath"] = "狂野怒火",
		["Binding Heal"] = "??治?",
		["Bite"] = "?咬",
		["Black Arrow"] = "黑箭",
		["Blackout"] = "昏?",
		["Blacksmithing"] = "?造",
		["Blade Flurry"] = "?刃?舞",
		["Blade Turning"] = "?刃??",
		["Blade Twisting"] = "利刃??",
		["Blast Wave"] = "??波",
		["Blazing Speed"] = "??疾速",
		["Blessed Recovery"] = "神恩回?",
		["Blessed Resilience"] = "神佑之?",
		["Blessing of Auchindoun"] = "?金?的祝福",
		["Blessing of Freedom"] = "自由祝福",
		["Blessing of Kings"] = "王者祝福",
		["Blessing of Light"] = "光明祝福",
		["Blessing of Might"] = "力量祝福",
		["Blessing of Protection"] = "保?祝福",
		["Blessing of Sacrifice"] = "?牲祝福",
		["Blessing of Salvation"] = "拯救祝福",
		["Blessing of Sanctuary"] = "庇?祝福",
		["Blessing of Wisdom"] = "智慧祝福",
		["Blind"] = "致盲",
		["Blinding Powder"] = "致盲粉",
		["Blink"] = "???",
		["Blizzard"] = "暴?雪",
		["Block"] = "格?",
		["Blood Craze"] = "血之狂?",
		["Blood Frenzy"] = "血之狂暴",
		["Blood Fury"] = "血性狂暴",
		["Blood Pact"] = "血之契印",
		["Bloodlust"] = "嗜血",
		["Bloodrage"] = "血性狂暴",
		["Bloodthirst"] = "嗜血",
		["Boar Charge"] = "野猪?撞",
		["Booming Voice"] = "震耳?音",
		["Bow Specialization"] = "弓箭?精",
		["Bows"] = "弓",
		["Bright Campfire"] = "明亮?火",
		["Brittle Armor"] = "脆弱?甲",
		["Brutal Impact"] = "野??撞",
		["Burning Adrenaline"] = "燃?刺激",
		["Burning Soul"] = "燃?之魂",
		["Burning Wish"] = "燃?之愿",
		["Call Pet"] = "召??物",
		["Call of Flame"] = "烈焰召?",
		["Call of Thunder"] = "雷霆召?",
		["Call of the Nexus"] = "?点召?",
		["Camouflage"] = "??",
		["Cannibalize"] = "食尸",
		["Cat Form"] = "?豹形?",
		["Cataclysm"] = "??",
		["Celestial Focus"] = "星空?注",
		["Chain Heal"] = "治??",
		["Chain Lightning"] = "???",
		["Challenging Roar"] = "挑?咆哮",
		["Challenging Shout"] = "挑?怒吼",
		["Charge"] = "??",
		["Charge Rage Bonus Effect"] = "??怒?加成效果",
		["Charge Stun"] = "???昏",
		["Cheap Shot"] = "??",
		["Chilled"] = "??",
		["Circle of Healing"] = "治?之?",
		["Claw"] = "爪?",
		["Class Trainer"] = "Class Trainer",
		["Cleanse"] = "???",
		["Clearcasting"] = "?能施法",
		["Cleave"] = "?劈?",
		["Clever Traps"] = "?巧陷?",
		["Cloak of Shadows"] = "暗影斗?",
		["Closing"] = "??",
		["Cloth"] = "布甲",
		["Coarse Sharpening Stone"] = "粗制磨刀石",
		["Cobra Reflexes"] = "毒蛇反射",
		["Cold Blood"] = "冷血",
		["Cold Snap"] = "急速冷却",
		["Combat Endurance"] = "作?持久",
		["Combustion"] = "燃?",
		["Command"] = "命令",
		["Commanding Presence"] = "?御之力",
		["Commanding Shout"] = "命令怒吼",
		["Concentration Aura"] = "?注光?",
		["Concussion"] = "震?",
		["Concussion Blow"] = "震?猛?",
		["Concussive Barrage"] = "???幕",
		["Concussive Shot"] = "震?射?",
		["Cone of Cold"] = "???",
		["Conflagrate"] = "燃?",
		["Conflagration"] = "燃?",
		["Conjure Food"] = "造食?",
		["Conjure Mana Agate"] = "制造魔法?瑙",
		["Conjure Mana Citrine"] = "制造魔法?水晶",
		["Conjure Mana Emerald"] = "制造魔法玉石",
		["Conjure Mana Jade"] = "制造魔法翡翠",
		["Conjure Mana Ruby"] = "制造魔法??石",
		["Conjure Water"] = "造水?",
		["Consecration"] = "奉?",
		["Consume Magic"] = "??魔法",
		["Consume Shadows"] = "??暗影",
		["Contagion"] = "?染",
		["Convection"] = "??",
		["Conviction"] = "定罪",
		["Cooking"] = "烹?",
		["Corruption"] = "腐??",
		["Counterattack"] = "反?",
		["Counterspell"] = "法?反制",
		["Counterspell - Silenced"] = "法?反制 - ?默",
		["Cower"] = "畏?",
		["Create Firestone"] = "制造火焰石",
		["Create Firestone (Greater)"] = "制造强效火焰石",
		["Create Firestone (Lesser)"] = "制造次?火焰石",
		["Create Firestone (Major)"] = "制造特效火焰石",
		["Create Healthstone"] = "制造治?石",
		["Create Healthstone (Greater)"] = "制造强效治?石",
		["Create Healthstone (Lesser)"] = "制造次?治?石",
		["Create Healthstone (Major)"] = "制造特效治?石",
		["Create Healthstone (Minor)"] = "制造初?治?石",
		["Create Soulstone"] = "制造?魂石",
		["Create Soulstone (Greater)"] = "制造强效?魂石",
		["Create Soulstone (Lesser)"] = "制造次??魂石",
		["Create Soulstone (Major)"] = "制造特效?魂石",
		["Create Soulstone (Minor)"] = "制造初??魂石",
		["Create Spellstone"] = "制造法?石",
		["Create Spellstone (Greater)"] = "制造强效法?石",
		["Create Spellstone (Major)"] = "制造特效法?石",
		["Create Spellstone (Master)"] = "制造?效法?石",
		["Cripple"] = "???",
		["Crippling Poison"] = "?速?膏",
		["Crippling Poison II"] = "?速?膏 II",
		["Critical Mass"] = "火焰重?",
		["Crossbows"] = "弩",
		["Cruelty"] = "?忍",
		["Crusade"] = "征伐",
		["Crusader Aura"] = "十字?光?",
		["Crusader Strike"] = "十字?打?",
		["Cultivation"] = "栽培",
		["Cure Disease"] = "祛病?",
		["Cure Poison"] = "消毒?",
		["Curse of Agony"] = "痛苦??",
		["Curse of Doom"] = "厄???",
		["Curse of Doom Effect"] = "厄???效果",
		["Curse of Exhaustion"] = "疲???",
		["Curse of Idiocy"] = "痴???",
		["Curse of Recklessness"] = "?莽??",
		["Curse of Shadow"] = "暗影??",
		["Curse of Tongues"] = "?言??",
		["Curse of Weakness"] = "?弱??",
		["Curse of the Elements"] = "元素??",
		["Cyclone"] = "???",
		["Dagger Specialization"] = "匕首?精",
		["Daggers"] = "匕首",
		["Dampen Magic"] = "魔法抑制",
		["Dark Pact"] = "黑暗契?",
		["Darkness"] = "黑暗",
		["Dash"] = "急奔",
		["Dawnstone Crab"] = "黎明石?蟹",
		["Dazed"] = "眩?",
		["Deadly Interrupt Effect"] = "致命中?效果",
		["Deadly Poison"] = "致命?膏",
		["Deadly Poison II"] = "致命?膏 II",
		["Deadly Poison III"] = "致命?膏 III",
		["Deadly Poison IV"] = "致命?膏 IV",
		["Deadly Poison V"] = "致命?膏 V",
		["Deadly Poison VI"] = "致命?膏 VI",
		["Deadly Poison VII"] = "致命?膏 VII",
		["Deadly Throw"] = "致命投?",
		["Death Coil"] = "死亡??",
		["Death Wish"] = "死亡之愿",
		["Deep Wound"] = "重?",
		["Deep Wounds"] = "重?",
		["Defense"] = "防御",
		["Defensive Stance"] = "防御姿?",
		["Defensive Stance Passive"] = "防御姿?（被?）",
		["Defiance"] = "挑?",
		["Deflection"] = "偏斜",
		["Delusions of Jin'do"] = "金度的欺?",
		["Demon Armor"] = "魔甲?",
		["Demon Skin"] = "?魔皮?",
		["Demonic Aegis"] = "?魔庇?",
		["Demonic Embrace"] = "?魔之?",
		["Demonic Frenzy"] = "?魔之狂",
		["Demonic Knowledge"] = "?魔知?",
		["Demonic Resilience"] = "?魔?性",
		["Demonic Sacrifice"] = "?魔?牲",
		["Demonic Tactics"] = "?魔??",
		["Demoralizing Roar"] = "挫志咆哮",
		["Demoralizing Shout"] = "挫志怒吼",
		["Dense Sharpening Stone"] = "致密磨刀石",
		["Desperate Prayer"] = "?望?言",
		["Destructive Reach"] = "毁?延伸",
		["Detect"] = "??",
		["Detect Greater Invisibility"] = "??强效?形",
		["Detect Invisibility"] = "???形",
		["Detect Lesser Invisibility"] = "??次??形",
		["Detect Magic"] = "??魔法",
		["Detect Traps"] = "??陷?",
		["Deterrence"] = "威?",
		["Devastate"] = "毁?打?",
		["Devastation"] = "毁?",
		["Devotion Aura"] = "虔?光?",
		["Devour Magic"] = "??魔法",
		["Devour Magic Effect"] = "??魔法效果",
		["Devouring Plague"] = "??瘟疫",
		["Diplomacy"] = "外交",
		["Dire Bear Form"] = "巨熊形?",
		["Dirty Deeds"] = "卑鄙",
		["Dirty Tricks"] = "邪???",
		["Disarm"] = "?械",
		["Disarm Trap"] = "解除陷?",
		["Disease Cleansing Totem"] = "祛病??",
		["Disenchant"] = "分解",
		["Disengage"] = "逃?",
		["Dismiss Pet"] = "解散野?",
		["Dispel Magic"] = "?散魔法",
		["Distract"] = "??",
		["Distracting Shot"] = "??射?",
		["Dive"] = "俯?",
		["Divine Favor"] = "神恩?",
		["Divine Fury"] = "神?之怒",
		["Divine Illumination"] = "神?",
		["Divine Intellect"] = "神?智慧",
		["Divine Intervention"] = "神?干涉",
		["Divine Protection"] = "?佑?",
		["Divine Shield"] = "?盾?",
		["Divine Spirit"] = "神?之?",
		["Divine Strength"] = "神?之力",
    ["Divine Wrath"] = "神??怒",
		["Dodge"] = "??",
		["Dragon's Breath"] = "?息?",
		["Dragonscale Leatherworking"] = "??制皮",
		["Drain Life"] = "吸取生命",
		["Drain Mana"] = "吸取法力",
		["Drain Soul"] = "吸取?魂",
		["Dreamless Sleep"] = "无?睡眠",
		["Drink"] = "喝水",
		["Dual Wield"] = "?武器",
		["Dual Wield Specialization"] = "?武器?精",
		["Duel"] = "?斗",
		["Dust Cloud"] = "??之云",
		["Eagle Eye"] = "?眼?",
		["Earth Elemental Totem"] = "土元素??",
		["Earth Shield"] = "大地之盾",
		["Earth Shock"] = "地震?",
		["Earthbind"] = "地??",
		["Earthbind Totem"] = "地???",
		["Earthstrike"] = "大地之?",
		["Efficiency"] = "效率",
		["Elemental Devastation"] = "元素浩劫",
		["Elemental Focus"] = "元素集中",
		["Elemental Fury"] = "元素之怒",
		["Elemental Leatherworking"] = "元素制皮",
		["Elemental Mastery"] = "元素掌握",
		["Elemental Precision"] = "元素精准",
		["Elemental Sharpening Stone"] = "元素磨刀石",
		["Elemental Weapons"] = "元素武器",
		["Elune's Grace"] = "艾露恩的?福",
		["Elusiveness"] = "?忽不定",
		["Emberstorm"] = "灰??暴",
		["Empowered Arcane Missiles"] = "????增效",
		["Empowered Corruption"] = "腐?增效",
		["Empowered Fireball"] = "火球增效",
		["Empowered Frostbolt"] = "寒?箭增效",
		["Empowered Healing"] = "治?增效",
		["Empowered Rejuvenation"] = "回春增效",
		["Empowered Touch"] = "治?之?增效",
		["Enamored Water Spirit"] = "被迷惑的水之魂",
		["Enchanting"] = "附魔",
		["Endurance"] = "耐久",
		["Endurance Training"] = "耐久??",
		["Engineering"] = "工程?",
		["Engineering Specialization"] = "工程??精",
		["Enrage"] = "激怒",
		["Enriched Manna Biscuit"] = "可口的魔法点心",
		["Enslave Demon"] = "奴役?魔",
		["Entangling Roots"] = "??根?",
		["Entrapment"] = "?捕",
		["Envenom"] = "毒?",
		["Escape Artist"] = "逃命?家",
		["Evasion"] = "?避",
		["Eviscerate"] = "刺骨",
		["Evocation"] = "?醒",
		["Execute"] = "??",
		["Exorcism"] = "?邪?",
		["Expansive Mind"] = "??思?",
		["Explosive Trap"] = "爆炸陷?",
		["Explosive Trap Effect"] = "爆炸陷?效果",
		["Expose Armor"] = "破甲",
		["Expose Weakness"] = "破甲?弱",
		["Extract Gas"] = "提???",
		["Eye for an Eye"] = "以眼?眼",
		["Eye of Kilrogg"] = "基??格之眼",
		["Eye of the Storm"] = "?暴之眼",
		["Eyes of the Beast"] = "野?之眼",
		["Fade"] = "???",
		["Faerie Fire"] = "精?之火",
		["Faerie Fire (Feral)"] = "精?之火（野性）",
		["Fanaticism"] = "狂?",
		["Far Sight"] = "?界?",
		["Fatal Attraction"] = "致命吸引",
		["Fear"] = "恐?",
		["Fear Ward"] = "防?恐??界",
		["Feed Pet"] = "???物",
		["Feed Pet Effect"] = "???物效果",
		["Feedback"] = "回?",
		["Feign Death"] = "假死",
		["Feint"] = "佯攻",
		["Fel Armor"] = "邪甲?",
		["Fel Concentration"] = "?魔?注",
		["Fel Domination"] = "?魔支配",
		["Fel Energy"] = "?魔能量",
		["Fel Intellect"] = "?魔智力",
		["Fel Rage"] = "邪能狂怒",
		["Fel Stamina"] = "?魔耐力",
		["Felfire"] = "魔火",
		["Feline Grace"] = "豹之?雅",
		["Feral Aggression"] = "野性侵略",
		["Feral Charge"] = "野性??",
		["Feral Instinct"] = "野性本能",
		["Feral Swiftness"] = "豹之迅捷",
		["Ferocious Bite"] = "凶猛?咬",
		["Ferocious Inspiration"] = "凶猛?感",
		["Ferocity"] = "凶暴",
		["Fetish"] = "神像",
		["Find Fish"] = "Find Fish",
		["Find Herbs"] = "??草?",
		["Find Minerals"] = "???物",
		["Find Treasure"] = "????",
		["Find Weakness"] = "??弱点",
		["Fire Blast"] = "火焰??",
		["Fire Breath"] = "火焰吐息",
		["Fire Elemental Totem"] = "火元素??",
		["Fire Nova Totem"] = "火焰新星??",
		["Fire Power"] = "火焰强化",
		["Fire Resistance"] = "火焰抗性",
		["Fire Resistance Aura"] = "火焰抗性光?",
		["Fire Resistance Totem"] = "抗火??",
		["Fire Shield"] = "火焰之盾",
		["Fire Vulnerability"] = "火焰易?",
		["Fire Ward"] = "防?火焰?界",
		["Fire Weakness"] = "火焰?弱",
		["Fireball"] = "火球?",
		["Firebolt"] = "火焰箭",
		["First Aid"] = "急救",
		["Fishing"] = "??",
		["Fishing Poles"] = "?竿",
		["Fist Weapon Specialization"] = "拳套?精",
		["Fist Weapons"] = "拳套",
		["Flame Shock"] = "烈焰震?",
		["Flame Throwing"] = "烈焰投?",
		["Flamestrike"] = "烈焰?暴",
		["Flamethrower"] = "?射火焰?射器",
		["Flametongue Attack"] = "火舌攻?",
		["Flametongue Totem"] = "火舌??",
		["Flametongue Weapon"] = "火舌武器",
		["Flare"] = "照明?",
		["Flash Heal"] = "快速治?",
		["Flash of Light"] = "?光??",
		["Flight Form"] = "?行形?",
		["FlightMaster"] = "FlightMaster",
		["Flurry"] = "?舞",
		["Focused Casting"] = "?注施法",
		["Focused Mind"] = "心??注",
		["Focused Power"] = "能量集中",
		["Focused Rage"] = "怒火?注",
		["Focused Starlight"] = "?聚星光",
		["Food"] = "?食",
		["Food & Drink"] = "Food & Drink",
		["Forbearance"] = "自律",
		["Force of Nature"] = "自然之力",
		["Force of Will"] = "意志之力",
		["Freezing Trap"] = "??陷?",
		["Freezing Trap Effect"] = "??陷?效果",
		["Frenzied Regeneration"] = "狂暴回?",
		["Frenzy"] = "狂?",
		["Frenzy Effect"] = "狂?效果",
		["Frost Armor"] = "霜甲?",
		["Frost Blast"] = "?霜??",
		["Frost Channeling"] = "?霜?能",
		["Frost Nova"] = "?霜新星",
		["Frost Resistance"] = "?霜抗性",
		["Frost Resistance Aura"] = "?霜抗性光?",
		["Frost Resistance Totem"] = "抗寒??",
		["Frost Shock"] = "?霜震?",
		["Frost Trap"] = "?霜陷?",
		["Frost Trap Aura"] = "?霜陷?光?",
		["Frost Ward"] = "防??霜?界",
		["Frost Warding"] = "?霜障壁",
		["Frost Weakness"] = "?霜?弱",
		["Frostbite"] = "霜寒刺骨",
		["Frostbolt"] = "寒?箭",
		["Frostbrand Attack"] = "?封攻?",
		["Frostbrand Weapon"] = "?封武器",
		["Frozen Core"] = "??之心",
		["Furious Howl"] = "狂怒之?",
		["Furor"] = "激怒",
		["Fury of the Crashing Waves"] = "波?之怒",
		["Garrote"] = "?喉",
		["Garrote - Silence"] = "?喉?默",
		["Ghost Wolf"] = "幽魂之狼",
		["Ghostly Strike"] = "鬼魅攻?",
		["Gift of Life"] = "生命?福",
		["Gift of Nature"] = "自然?福",
		["Gift of the Naaru"] = "??的?福",
		["Gift of the Wild"] = "野性?福",
		["Gouge"] = "??",
		["Grace of Air"] = "?之?雅",
		["Grace of Air Totem"] = "?之?雅??",
		["Great Stamina"] = "持久耐力",
		["Greater Blessing of Kings"] = "强效王者祝福",
		["Greater Blessing of Light"] = "强效光明祝福",
		["Greater Blessing of Might"] = "强效力量祝福",
		["Greater Blessing of Salvation"] = "强效拯救祝福",
		["Greater Blessing of Sanctuary"] = "强效庇?祝福",
		["Greater Blessing of Wisdom"] = "强效智慧祝福",
		["Greater Dreamless Sleep"] = "强效昏睡",
		["Greater Heal"] = "强效治??",
		["Grim Reach"] = "无情延伸",
		["Grounding Totem"] = "根基??",
		["Grounding Totem Effect"] = "根基??效果",
		["Grovel"] = "匍匐",
		["Growl"] = "低吼",
		["Guardian's Favor"] = "守?者的??",
		["Gun Specialization"] = "?械?精",
		["Guns"] = "?械",
		["Hammer of Justice"] = "制裁之?",
		["Hammer of Wrath"] = "?怒之?",
		["Hamstring"] = "?筋",
		["Harass"] = "侵?",
		["Hardiness"] = "??",
		["Haste"] = "加速",
		["Hawk Eye"] = "?眼",
		["Heal"] = "治??",
		["Healing Focus"] = "治??注",
		["Healing Light"] = "治?之光",
		["Healing Stream"] = "治?之泉",
		["Healing Stream Totem"] = "治?之泉??",
		["Healing Touch"] = "治?之?",
		["Healing Wave"] = "治?波",
		["Healing Way"] = "治?之道",
		["Health Funnel"] = "生命通道",
		["Heart of the Wild"] = "野性之心",
		["Heavy Sharpening Stone"] = "重磨刀石",
		["Hellfire"] = "地?烈焰",
		["Hellfire Effect"] = "地?烈焰效果",
		["Hellfire Superiority"] = "地?火主宰",
		["Hemorrhage"] = "出血",
		["Herb Gathering"] = "采集草?",
		["Herbalism"] = "草??",
		["Heroic Strike"] = "英勇打?",
		["Heroism"] = "英雄",
		["Hex of Weakness"] = "?弱妖?",
		["Hibernate"] = "休眠",
		["Holy Fire"] = "神?之火",
		["Holy Light"] = "?光?",
		["Holy Nova"] = "神?新星",
		["Holy Power"] = "神?能量",
		["Holy Reach"] = "神?延伸",
		["Holy Shield"] = "神?之盾",
		["Holy Shock"] = "神?震?",
		["Holy Specialization"] = "神??精",
		["Holy Wrath"] = "神??怒",
		["Honorless Target"] = "无??目?",
		["Horse Riding"] = "??：?",
		["Howl of Terror"] = "恐??叫",
		["Humanoid Slaying"] = "人型生物?手",
		["Hunter's Mark"] = "?人印?",
		["Hurricane"] = "??",
		["Hypothermia"] = "低?",
		["Ice Armor"] = "?甲?",
		["Ice Barrier"] = "寒???",
		["Ice Block"] = "寒??障",
		["Ice Floes"] = "浮?",
		["Ice Lance"] = "???",
		["Ice Shards"] = "寒?碎片",
		["Ignite"] = "点燃",
		["Ignite Mana"] = "点燃法力",
		["Illumination"] = "??",
		["Immolate"] = "?祭",
		["Immolation Trap"] = "?祭陷?",
		["Immolation Trap Effect"] = "?祭陷?效果",
		["Impact"] = "??",
		["Impale"] = "穿刺",
		["Impaling Spine"] = "穿刺之脊",
		["Improved Ambush"] = "强化伏?",
		["Improved Arcane Missiles"] = "强化????",
		["Improved Arcane Shot"] = "强化??射?",
		["Improved Aspect of the Hawk"] = "强化雄?守?",
		["Improved Aspect of the Monkey"] = "强化??守?",
		["Improved Backstab"] = "强化背刺",
		["Improved Barrage"] = "强化?幕",
		["Improved Berserker Rage"] = "强化狂暴之怒",
		["Improved Blessing of Might"] = "强化力量祝福",
		["Improved Blessing of Wisdom"] = "强化智慧祝福",
		["Improved Blink"] = "强化???",
		["Improved Blizzard"] = "强化暴?雪",
		["Improved Bloodrage"] = "强化血性狂暴",
		["Improved Chain Heal"] = "强化治??",
		["Improved Chain Lightning"] = "强化???",
		["Improved Challenging Shout"] = "强化挑?怒吼",
		["Improved Charge"] = "强化??",
		["Improved Cleave"] = "强化?劈?",
		["Improved Concentration Aura"] = "强化?注光?",
		["Improved Concussive Shot"] = "强化震?射?",
		["Improved Cone of Cold"] = "强化???",
		["Improved Corruption"] = "强化腐??",
		["Improved Counterspell"] = "强化法?反制",
		["Improved Curse of Agony"] = "强化痛苦??",
		["Improved Curse of Weakness"] = "强化?弱??",
		["Improved Demoralizing Shout"] = "强化挫志怒吼",
		["Improved Devotion Aura"] = "强化虔?光?",
		["Improved Disarm"] = "强化?械",
		["Improved Drain Life"] = "强化吸取生命",
		["Improved Drain Soul"] = "强化吸取?魂",
		["Improved Enrage"] = "强化狂怒",
		["Improved Enslave Demon"] = "强化奴役?魔",
		["Improved Eviscerate"] = "强化刺骨",
		["Improved Execute"] = "强化??",
		["Improved Expose Armor"] = "强化破甲",
		["Improved Eyes of the Beast"] = "强化野?之眼",
		["Improved Fade"] = "强化???",
		["Improved Feign Death"] = "强化假死",
		["Improved Fire Blast"] = "强化火焰??",
		["Improved Fire Totems"] = "强化火焰??",
		["Improved Fire Ward"] = "强化防?火焰?界",
		["Improved Fireball"] = "强化火球?",
		["Improved Firebolt"] = "强化火焰箭",
		["Improved Flamestrike"] = "强化烈焰?暴",
		["Improved Flash of Light"] = "强化?光??",
		["Improved Frost Nova"] = "强化?霜新星",
		["Improved Frostbolt"] = "强化寒?箭",
		["Improved Ghost Wolf"] = "强化幽魂之狼",
		["Improved Gouge"] = "强化??",
		["Improved Hammer of Justice"] = "强化制裁之?",
		["Improved Hamstring"] = "强化?筋",
		["Improved Healing"] = "强化治??",
		["Improved Healing Touch"] = "强化治?之?",
		["Improved Healing Wave"] = "强化治?波",
		["Improved Health Funnel"] = "强化生命通道",
		["Improved Healthstone"] = "强化治?石",
		["Improved Heroic Strike"] = "强化英勇打?",
		["Improved Holy Shield"] = "强化神?之盾",
		["Improved Howl of Terror"] = "强化恐??叫",
		["Improved Hunter's Mark"] = "强化?人印?",
		["Improved Immolate"] = "强化?祭",
		["Improved Imp"] = "强化小鬼",
		["Improved Inner Fire"] = "强化心?之火",
		["Improved Intercept"] = "强化?截",
		["Improved Intimidating Shout"] = "强化破?怒吼",
		["Improved Judgement"] = "强化?判",
		["Improved Kick"] = "强化脚?",
		["Improved Kidney Shot"] = "强化??",
		["Improved Lash of Pain"] = "强化?痛鞭笞",
		["Improved Lay on Hands"] = "强化???",
		["Improved Leader of the Pack"] = "强化?群?袖",
		["Improved Life Tap"] = "强化生命分流",
		["Improved Lightning Bolt"] = "强化??箭",
		["Improved Lightning Shield"] = "强化??之盾",
		["Improved Magma Totem"] = "强化熔岩??",
		["Improved Mana Burn"] = "强化法力燃?",
		["Improved Mana Shield"] = "强化法力?盾",
		["Improved Mana Spring Totem"] = "强化法力之泉??",
		["Improved Mark of the Wild"] = "强化野性印?",
		["Improved Mend Pet"] = "强化治??物",
		["Improved Mind Blast"] = "强化心?震爆",
		["Improved Moonfire"] = "强化月火?",
		["Improved Mortal Strike"] = "强化致死打?",
		["Improved Nature's Grasp"] = "强化自然之握",
		["Improved Overpower"] = "强化?制",
		["Improved Power Word: Fortitude"] = "强化?言?：?",
		["Improved Power Word: Shield"] = "强化?言?：盾",
		["Improved Prayer of Healing"] = "强化治??言",
		["Improved Psychic Scream"] = "强化心?尖?",
		["Improved Regrowth"] = "强化愈合",
		["Improved Reincarnation"] = "强化?生",
		["Improved Rejuvenation"] = "强化回春?",
		["Improved Rend"] = "强化?裂",
		["Improved Renew"] = "强化恢?",
		["Improved Retribution Aura"] = "强化??光?",
		["Improved Revenge"] = "强化?仇",
		["Improved Revive Pet"] = "强化?活?物",
		["Improved Righteous Fury"] = "强化正?之怒",
		["Improved Rupture"] = "强化割裂",
		["Improved Scorch"] = "强化灼?",
		["Improved Scorpid Sting"] = "强化毒蝎?刺",
		["Improved Seal of Righteousness"] = "强化正??印",
		["Improved Seal of the Crusader"] = "强化十字??印",
		["Improved Searing Pain"] = "强化灼?之痛",
		["Improved Serpent Sting"] = "强化毒蛇?刺",
		["Improved Shadow Bolt"] = "强化暗影箭",
		["Improved Shadow Word: Pain"] = "强化暗言?：痛",
		["Improved Shield Bash"] = "强化盾?",
		["Improved Shield Block"] = "强化盾牌格?",
		["Improved Shield Wall"] = "强化盾?",
		["Improved Sinister Strike"] = "强化影?",
		["Improved Slam"] = "强化猛?",
		["Improved Slice and Dice"] = "强化切割",
		["Improved Sprint"] = "强化疾?",
		["Improved Stings"] = "强化?刺",
		["Improved Succubus"] = "强化魅魔",
		["Improved Sunder Armor"] = "强化破甲攻?",
		["Improved Taunt"] = "强化嘲?",
		["Improved Thunder Clap"] = "强化雷霆一?",
		["Improved Tranquility"] = "强化??",
		["Improved Vampiric Embrace"] = "强化吸血鬼的?抱",
		["Improved Vanish"] = "强化消失",
		["Improved Voidwalker"] = "强化?空行者",
		["Improved Weapon Totems"] = "强化武器??",
		["Improved Whirlwind"] = "强化旋??",
		["Improved Wing Clip"] = "强化??",
		["Incinerate"] = "??",
		["Incineration"] = "??",
		["Inferno"] = "地?火",
		["Initiative"] = "先?制人",
		["Inner Fire"] = "心?之火",
		["Inner Focus"] = "心??注",
		["Innervate"] = "激活",
		["Innkeeper"] = "Innkeeper",
		["Insect Swarm"] = "?群",
		["Insidious Whisper"] = "因斯迪安低?",
		["Insignifigance"] = "毫无意?",
		["Inspiration"] = "?感",
		["Instant Poison"] = "速效?膏",
		["Instant Poison II"] = "速效?膏 II",
		["Instant Poison III"] = "速效?膏 III",
		["Instant Poison IV"] = "速效?膏 IV",
		["Instant Poison V"] = "速效?膏 V",
		["Instant Poison VI"] = "速效?膏 VI",
		["Instant Poison VII"] = "速效?膏 VII",
		["Intensity"] = "强烈",
		["Intercept"] = "?截",
		["Intercept Stun"] = "?截昏迷",
		["Intervene"] = "援?",
		["Intimidating Shout"] = "破?怒吼",
		["Intimidation"] = "?迫",
		["Invisibility"] = "?形?",
		["Iron Will"] = "??意志",
		["Jewelcrafting"] = "珠?加工",
		["Jom Gabbar"] = "沙?之毒",
		["Judgement"] = "?判",
		["Judgement of Blood"] = "?血?判",
		["Judgement of Command"] = "命令?判",
		["Judgement of Justice"] = "公正?判",
		["Judgement of Light"] = "?光?判",
		["Judgement of Reckoning"] = "?算?判",
		["Judgement of Righteousness"] = "正??判",
		["Judgement of Wisdom"] = "智慧?判",
		["Judgement of the Crusader"] = "十字??判",
		["Kick"] = "脚?",
		["Kick - Silenced"] = "脚? - ?默",
		["Kidney Shot"] = "??",
		["Kill Command"] = "?戮命令",
		["Killer Instinct"] = "?戮本能",
		["Kiss of the Spider"] = "蜘蛛之吻",
		["Kodo Riding"] = "??：科多?",
		["Lacerate"] = "割?",
		["Lash of Pain"] = "?痛鞭笞",
		["Last Stand"] = "破釜?舟",
		["Lay on Hands"] = "???",
		["Leader of the Pack"] = "?群?袖",
		["Leather"] = "皮革",
		["Leatherworking"] = "制皮",
		["Lesser Heal"] = "次?治??",
		["Lesser Healing Wave"] = "次?治?波",
		["Lesser Invisibility"] = "次??形?",
		["Lethal Shots"] = "?命射?",
		["Lethality"] = "致命??",
		["Levitate"] = "漂浮?",
		["Libram"] = "?物",
		["Life Tap"] = "生命分流",
		["Lifebloom"] = "生命?放",
		["Light's Grace"] = "光之?雅",
		["Lightning Bolt"] = "??箭",
		["Lightning Breath"] = "??吐息",
		["Lightning Mastery"] = "??掌握",
		["Lightning Reflexes"] = "??反射",
		["Lightning Shield"] = "??之盾",
		["Lightning Speed"] = "??之速",
		["Lightwell"] = "光明之泉",
		["Lightwell Renew"] = "光明之泉回?",
		["Lockpicking"] = "??",
		["Long Daze"] = "???眩?",
		["Lust for Battle"] = "?斗欲望",
		["Mace Specialization"] = "??武器?精",
		["Mace Stun Effect"] = "??昏迷效果",
		["Mage Armor"] = "法??甲",
		["Magic Absorption"] = "魔法吸收",
		["Magic Attunement"] = "魔法??",
		["Magma Totem"] = "熔岩??",
		["Mail"] = "?甲",
		["Maim"] = "割碎",
		["Major Dreamless Sleep"] = "特效无?睡眠",
		["Malediction"] = "邪?",
		["Malice"] = "?意",
		["Mana Burn"] = "法力燃?",
		["Mana Feed"] = "法力?食",
		["Mana Shield"] = "法力?盾",
		["Mana Spring"] = "法力之泉",
		["Mana Spring Totem"] = "法力之泉??",
		["Mana Tap"] = "法力分流",
		["Mana Tide"] = "法力之潮",
		["Mana Tide Totem"] = "法力之潮??",
		["Mangle"] = "裂?",
		["Mangle (Bear)"] = "裂?（熊）",
		["Mangle (Cat)"] = "裂?（豹）",
		["Mark of the Wild"] = "野性印?",
		["Martyrdom"] = "殉?",
		["Mass Dispel"] = "群??散",
		["Master Conjuror"] = "魔石大?",
		["Master Demonologist"] = "?魔??大?",
		["Master Summoner"] = "召?大?",
		["Master Tactician"] = "??大?",
		["Master of Deception"] = "欺?高手",
		["Master of Elements"] = "元素大?",
		["Master of Subtlety"] = "敏?大?",
		["Maul"] = "重?",
		["Mechanostrider Piloting"] = "??：机械?行?",
		["Meditation"] = "冥想",
		["Melee Specialization"] = "近??精",
		["Melt Armor"] = "熔化?甲",
		["Mend Pet"] = "治??物",
		["Mental Agility"] = "精神敏?",
		["Mental Strength"] = "心?之力",
		["Mind Blast"] = "心?震爆",
		["Mind Control"] = "精神控制",
		["Mind Flay"] = "精神鞭笞",
		["Mind Mastery"] = "心?掌握",
		["Mind Soothe"] = "安?心?",
		["Mind Vision"] = "心??界",
		["Mind-numbing Poison"] = "麻??膏",
		["Mind-numbing Poison II"] = "麻??膏 II",
		["Mind-numbing Poison III"] = "麻??膏 III",
		["Mining"] = "采?",
		["Misdirection"] = "??",
		["Misery"] = "悲?",
		["Mocking Blow"] = "?戒痛?",
		["Molten Armor"] = "熔岩?甲",
		["Molten Fury"] = "熔岩之怒",
		["Mongoose Bite"] = "猫??咬",
		["Monster Slaying"] = "怪物?手",
		["Moonfire"] = "月火?",
		["Moonfury"] = "月怒",
		["Moonglow"] = "月光",
		["Moonkin Aura"] = "??光?",
		["Moonkin Form"] = "??形?",
		["Mortal Shots"] = "致死射?",
		["Mortal Strike"] = "致死打?",
		["Multi-Shot"] = "多重射?",
		["Murder"] = "??",
		["Mutilate"] = "毁?",
		["Natural Armor"] = "自然?甲",
		["Natural Perfection"] = "天然完美",
		["Natural Shapeshifter"] = "自然?形",
		["Naturalist"] = "自然主?",
		["Nature Resistance"] = "自然抗性",
		["Nature Resistance Totem"] = "自然抗性??",
		["Nature Weakness"] = "自然?弱",
		["Nature's Focus"] = "自然集中",
		["Nature's Grace"] = "自然之?",
		["Nature's Grasp"] = "自然之握",
		["Nature's Guidance"] = "自然指引",
		["Nature's Reach"] = "自然延伸",
		["Nature's Swiftness"] = "自然迅捷",
		["Negative Charge"] = "?能量?荷",
		["Nether Protection"] = "?空防?",
		["Netherstorm Flag"] = "?空?暴旗?",
		["Nightfall"] = "夜幕",
		["Nurturing Instinct"] = "治愈本能",
		["Omen of Clarity"] = "???兆",
		["One-Handed Axes"] = "?手斧",
		["One-Handed Maces"] = "?手?",
		["One-Handed Swords"] = "?手?",
		["One-Handed Weapon Specialization"] = "?手武器?精",
		["Opening"] = "打?",
		["Opening - No Text"] = "Opening - No Text",
		["Opportunity"] = "伺机而?",
		["Overpower"] = "?制",
		["Pain Suppression"] = "痛苦?制",
		["Panic"] = "恐慌",
		["Paranoia"] = "多疑",
		["Parasitic Shadowfiend"] = "寄生暗影魔",
		["Parry"] = "招架",
		["Pathfinding"] = "?路",
		["Perceived Weakness"] = "察?弱点",
		["Perception"] = "感知",
		["Permafrost"] = "?寒?霜",
		["Pet Aggression"] = "?物好斗",
		["Pet Hardiness"] = "?物耐久",
		["Pet Recovery"] = "?物恢?",
		["Pet Resistance"] = "?物抗魔",
		["Phase Shift"] = "相位??",
		["Pick Lock"] = "??",
		["Pick Pocket"] = "搜索",
		["Piercing Howl"] = "刺耳怒吼",
		["Piercing Ice"] = "刺骨寒?",
		["Plate Mail"] = "板甲",
		["Playing with Fire"] = "玩火自焚",
		["Poison Cleansing Totem"] = "?毒??",
		["Poison Spit"] = "毒液?吐",
		["Poisons"] = "毒?",
		["Polearms"] = "?柄武器",
		["Poleaxe Specialization"] = "?柄?精",
		["Polymorph"] = "?形?",
		["Polymorph: Pig"] = "?形?：猪",
		["Polymorph: Turtle"] = "?形?：?",
		["Portal: Darnassus"] = "?送?：???斯",
		["Portal: Exodar"] = "?送?：埃索?",
		["Portal: Ironforge"] = "?送?：??堡",
		["Portal: Orgrimmar"] = "?送?：?格瑞?",
		["Portal: Shattrath"] = "?送?：沙塔斯",
		["Portal: Silvermoon"] = "?送?：?月城",
		["Portal: Stormwind"] = "?送?：暴?城",
		["Portal: Thunder Bluff"] = "?送?：雷霆崖",
		["Portal: Undercity"] = "?送?：幽暗城",
		["Positive Charge"] = "正能量?荷",
		["Pounce"] = "突?",
		["Pounce Bleed"] = "血?",
		["Power Infusion"] = "能量灌注",
		["Power Word: Fortitude"] = "?言?：?",
		["Power Word: Shield"] = "?言?：盾",
		["Prayer of Fortitude"] = "???言",
		["Prayer of Healing"] = "治??言",
		["Prayer of Mending"] = "愈合?言",
		["Prayer of Shadow Protection"] = "暗影防??言",
		["Prayer of Spirit"] = "精神?言",
		["Precision"] = "精?",
		["Predatory Instincts"] = "狩?天性",
		["Predatory Strikes"] = "猛?攻?",
		["Premeditation"] = "??",
		["Preparation"] = "伺机待?",
		["Presence of Mind"] = "?定神?",
		["Primal Fury"] = "原始狂怒",
		["Prismatic Cloak"] = "多彩?障",
		["Profession Trainers"] = "Profession Trainers",
		["Prospecting"] = "??",
		["Prowl"] = "?行",
		["Psychic Scream"] = "心?尖?",
		["Pummel"] = "拳?",
		["Purge"] = "?化?",
		["Purification"] = "?化",
		["Purify"] = "???",
		["Purifying Power"] = "?化之力",
		["Pursuit of Justice"] = "正?追?",
		["Pyroblast"] = "炎爆?",
		["Pyroclasm"] = "火焰?撞",
		["Pyromaniac"] = "?火",
		["Quick Recovery"] = "快速恢?",
		["Quick Shots"] = "快速射?",
		["Quickness"] = "迅捷",
		["Rage of the Unraveller"] = "瓦解者之怒",
		["Rain of Fire"] = "火焰之雨",
		["Rake"] = "斜掠",
		["Ram Riding"] = "??：羊",
		["Rampage"] = "暴跳如雷",
		["Ranged Weapon Specialization"] = "?程武器?精",
		["Rapid Fire"] = "急速射?",
		["Rapid Killing"] = "疾速?戮",
		["Raptor Riding"] = "??：迅猛?",
		["Raptor Strike"] = "猛禽一?",
		["Ravage"] = "毁?",
		["Readiness"] = "准?就?",
		["Reagents"] = "Reagents",
		["Rebirth"] = "?生",
		["Reckless Charge"] = "无畏??",
		["Recklessness"] = "?莽",
		["Reckoning"] = "?算",
		["Redemption"] = "救?",
		["Redoubt"] = "盾牌壁?",
		["Reflection"] = "反射",
		["Regeneration"] = "再生",
		["Regrowth"] = "愈合",
		["Reincarnation"] = "?生",
		["Reinforced Shield"] = "援?之盾",
		["Rejuvenation"] = "回春?",
		["Relentless Strikes"] = "无情打?",
		["Remorseless"] = "冷酷",
		["Remorseless Attacks"] = "冷酷攻?",
    ["Remote Toy"] = "?控玩具",
		["Remove Curse"] = "解除??",
		["Remove Insignia"] = "解除徽?",
		["Remove Lesser Curse"] = "解除次???",
		["Rend"] = "?裂",
		["Renew"] = "恢?",
		["Repair"] = "Repair",
		["Repentance"] = "?悔",
		["Restless Strength"] = "充沛之力",
		["Restorative Totems"] = "恢???",
		["Resurrection"] = "?活?",
		["Retaliation"] = "反??暴",
		["Retribution Aura"] = "??光?",
		["Revenge"] = "?仇",
		["Revenge Stun"] = "?仇昏迷",
		["Reverberation"] = "回?",
		["Revive Pet"] = "?活?物",
		["Righteous Defense"] = "正?防御",
		["Righteous Fury"] = "正?之怒",
		["Rip"] = "割裂",
		["Riposte"] = "??",
		["Ritual of Doom"] = "末日?式",
		["Ritual of Doom Effect"] = "末日?式效果",
		["Ritual of Souls"] = "?魂?式",
		["Ritual of Summoning"] = "召??式",
		["Rockbiter Weapon"] = "石化武器",
		["Rough Sharpening Stone"] = "劣?磨刀石",
		["Ruin"] = "毁?",
		["Rupture"] = "割裂",
		["Ruthlessness"] = "无情",
		["Sacrifice"] = "?牲",
		["Safe Fall"] = "安全降落",
		["Sanctified Crusader"] = "神?十字?",
		["Sanctified Judgement"] = "神??判",
		["Sanctified Light"] = "神?光芒",
		["Sanctity Aura"] = "??光?",
		["Sap"] = "?棍",
		["Savage Fury"] = "野?暴怒",
		["Savage Strikes"] = "野?打?",
		["Scare Beast"] = "恐?野?",
		["Scatter Shot"] = "?散射?",
		["Scorch"] = "灼?",
		["Scorpid Poison"] = "蝎毒",
		["Scorpid Sting"] = "毒蝎?刺",
		["Screech"] = "尖?",
		["Seal Fate"] = "封印命?",
		["Seal of Blood"] = "?血?印",
		["Seal of Command"] = "命令?印",
		["Seal of Justice"] = "公正?印",
		["Seal of Light"] = "光明?印",
		["Seal of Righteousness"] = "正??印",
		["Seal of Vengeance"] = "?仇?印",
		["Seal of Wisdom"] = "智慧?印",
		["Seal of the Crusader"] = "十字??印",
		["Searing Light"] = "灼?之光",
		["Searing Pain"] = "灼?之痛",
		["Searing Totem"] = "灼???",
		["Second Wind"] = "??之?",
		["Seduction"] = "?惑",
		["Seed of Corruption"] = "腐?之?",
		["Seethe"] = "沸?",
		["Sense Demons"] = "感知?魔",
		["Sense Undead"] = "感知亡?",
		["Sentry Totem"] = "?哨??",
		["Serpent Sting"] = "毒蛇?刺",
		["Serrated Blades"] = "??利刃",
		["Setup"] = "?整",
		["Shackle Undead"] = "束?亡?",
		["Shadow Affinity"] = "暗影?和",
		["Shadow Bolt"] = "暗影箭",
		["Shadow Embrace"] = "暗影之?",
		["Shadow Focus"] = "暗影集中",
		["Shadow Mastery"] = "暗影掌握",
		["Shadow Power"] = "暗影强化",
		["Shadow Protection"] = "防?暗影",
		["Shadow Reach"] = "暗影延伸",
		["Shadow Resistance"] = "暗影抗性",
		["Shadow Resistance Aura"] = "暗影抗性光?",
		["Shadow Trance"] = "暗影冥思",
		["Shadow Vulnerability"] = "暗影易?",
		["Shadow Ward"] = "防?暗影?界",
		["Shadow Weakness"] = "暗影?弱",
		["Shadow Weaving"] = "暗影之波",
		["Shadow Word: Death"] = "暗言?：?",
		["Shadow Word: Pain"] = "暗言?：痛",
		["Shadow and Flame"] = "暗影烈焰",
		["Shadow of Death"] = "死亡之影",
		["Shadowburn"] = "暗影灼?",
		["Shadowfiend"] = "暗影?魔",
		["Shadowform"] = "暗影形?",
		["Shadowfury"] = "暗影之怒",
		["Shadowguard"] = "暗影守?",
		["Shadowmeld"] = "影遁",
		["Shadowmeld Passive"] = "影遁",
		["Shadowstep"] = "暗影步",
		["Shamanistic Rage"] = "??之怒",
		["Sharpened Claws"] = "?利?爪",
		["Shatter"] = "碎?",
		["Shell Shield"] = "甲??盾",
		["Shield"] = "盾牌",
		["Shield Bash"] = "盾?",
		["Shield Bash - Silenced"] = "盾? - ?默",
		["Shield Block"] = "盾牌格?",
		["Shield Slam"] = "盾牌猛?",
		["Shield Specialization"] = "盾牌?精",
		["Shield Wall"] = "盾?",
		["Shiv"] = "毒刃",
		["Shoot"] = "射?",
		["Shoot Bow"] = "弓箭射?",
		["Shoot Gun"] = "Shoot Gun",
		["Shred"] = "?碎",
		["Shredding Attacks"] = "?碎攻?",
		["Silence"] = "?默",
		["Silencing Shot"] = "?默射?",
		["Silent Resolve"] = "无?消退",
		["Silverwing Flag"] = "?翼?旗",
		["Sinister Strike"] = "影?",
		["Siphon Life"] = "生命虹吸",
		["Skinning"] = "?皮",
		["Slam"] = "猛?",
		["Slayer's Crest"] = "屠?者的?章",
		["Sleep"] = "催眠?",
		["Slice and Dice"] = "切割",
		["Slow"] = "?速?",
		["Slow Fall"] = "?落?",
		["Smelting"] = "熔?",
		["Smite"] = "??",
		["Snake Trap"] = "毒蛇陷?",
		["Solid Sharpening Stone"] = "?固的磨刀石",
		["Sonic Burst"] = "音素爆破",
		["Soothe Animal"] = "安??物",
		["Soothing Kiss"] = "安?之吻",
		["Soul Fire"] = "?魂之火",
		["Soul Leech"] = "?魂?取",
		["Soul Link"] = "?魂?接",
		["Soul Siphon"] = "?魂虹吸",
		["Soulshatter"] = "?魂碎裂",
		["Soulstone Resurrection"] = "?魂石?活",
		["Spell Haste"] = "法?急速",
		["Spell Lock"] = "法?封?",
		["Spell Power"] = "法?能量",
		["Spell Reflection"] = "法?反射",
		["Spell Vulnerability"] = "法?易?",
		["Spell Warding"] = "法??障",
		["Spellsteal"] = "法??取",
		["Spirit Bond"] = "?魂??",
		["Spirit Tap"] = "精神分流",
		["Spirit of Redemption"] = "救?之魂",
		["Spiritual Attunement"] = "?魂??",
		["Spiritual Focus"] = "精神集中",
		["Spiritual Guidance"] = "精神指引",
		["Spiritual Healing"] = "精神治?",
		["Spiteful Fury"] = "仇恨之怒",
		["Sprint"] = "疾?",
		["StableMaster"] = "StableMaster",
		["Stance Mastery"] = "姿?掌握",
		["Starfire"] = "星火?",
		["Starfire Stun"] = "星火昏迷",
		["Starlight Wrath"] = "星光之怒",
		["Starshards"] = "星辰碎片",
		["Static Charge"] = "??充能",
		["Staves"] = "法杖",
		["Steady Shot"] = "?固射?",
		["Stealth"] = "?行",
		["Stoneclaw Stun"] = "石爪昏迷",
		["Stoneclaw Totem"] = "石爪??",
		["Stoneform"] = "石像形?",
		["Stoneskin"] = "石??",
		["Stoneskin Totem"] = "石???",
		["Stormstrike"] = "?暴打?",
		["Strength of Earth"] = "大地之力",
		["Strength of Earth Totem"] = "大地之力??",
		["Strength of the Halaani"] = "哈?之力",
		["Stuck"] = "?死",
		["Stun"] = "昏迷",
		["Subtlety"] = "微妙",
		["Suffering"] = "受?",
		["Summon Charger"] = "召???",
		["Summon Dreadsteed"] = "召?恐???",
		["Summon Felguard"] = "召??魔?士",
		["Summon Felhunter"] = "召?地??犬",
		["Summon Felsteed"] = "召?地???",
		["Summon Imp"] = "召?小鬼",
		["Summon Succubus"] = "召?魅魔",
		["Summon Voidwalker"] = "召??空行者",
		["Summon Warhorse"] = "召???",
		["Summon Water Elemental"] = "召?水元素",
		["Sunder Armor"] = "破甲攻?",
		["Suppression"] = "??",
		["Surefooted"] = "?固",
		["Surge of Light"] = "?光涌?",
		["Surprise Attacks"] = "突?",
		["Survivalist"] = "生存?家",
		["Sweeping Strikes"] = "??攻?",
		["Swift Flight Form"] = "迅捷?行形?",
		["Swiftmend"] = "迅捷治愈",
		["Swipe"] = "??",
		["Sword Specialization"] = "??武器?精",
		["Symbol of Hope"] = "希望符?",
		["Tactical Mastery"] = "??掌握",
		["Tailoring"] = "裁?",
		["Tainted Blood"] = "腐?之血",
		["Tainted Mind"] = "??之魂",
		["Tame Beast"] = "?服野?",
		["Taunt"] = "嘲?",
		["Teleport: Darnassus"] = "?送：???斯",
		["Teleport: Exodar"] = "?送：埃索?",
		["Teleport: Ironforge"] = "?送：??堡",
		["Teleport: Moonglade"] = "?送：月光林地",
		["Teleport: Orgrimmar"] = "?送：?格瑞?",
		["Teleport: Shattrath"] = "?送：沙塔斯",
		["Teleport: Silvermoon"] = "?送：?月城",
		["Teleport: Stormwind"] = "?送：暴?城",
		["Teleport: Thunder Bluff"] = "?送：雷霆崖",
		["Teleport: Undercity"] = "?送：幽暗城",
		["Temporal Rift"] = "?光裂隙",
		["The Beast Within"] = "野?之心",
		["The Human Spirit"] = "人?精魂",
		["Thick Hide"] = "厚皮",
		["Thorns"] = "?棘?",
		["Thrill of the Hunt"] = "狩?刺激",
		["Throw"] = "投?",
		["Throwing Specialization"] = "投??精",
		["Thrown"] = "投?",
		["Thunder Clap"] = "雷霆一?",
		["Thunderfury"] = "雷霆之怒",
		["Thundering Strikes"] = "雷?猛?",
		["Thunderstomp"] = "雷霆?踏",
		["Tidal Focus"] = "潮汐集中",
		["Tidal Mastery"] = "潮汐掌握",
		["Tiger Riding"] = "??：豹",
		["Tiger's Fury"] = "猛虎之怒",
		["Time's Favor"] = "?之?福",
		["Torment"] = "折磨",
		["Totem"] = "??",
		["Totem of Wrath"] = "天怒??",
		["Totemic Call"] = "??召?",
		["Totemic Focus"] = "??集中",
		["Touch of Shadow"] = "暗影之?",
		["Touch of Weakness"] = "?弱之?",
		["Toughness"] = "??",
		["Traces of Silithyst"] = "水晶?迹",
		["Track Beasts"] = "追踪野?",
		["Track Demons"] = "追踪?魔",
		["Track Dragonkin"] = "追踪??",
		["Track Elementals"] = "追踪元素生物",
		["Track Giants"] = "追踪巨人",
		["Track Hidden"] = "追踪?藏生物",
		["Track Humanoids"] = "追踪人型生物",
		["Track Undead"] = "追踪亡?",
		["Tranquil Air"] = "??之?",
		["Tranquil Air Totem"] = "??之???",
		["Tranquil Spirit"] = "??之魂",
		["Tranquility"] = "??",
		["Tranquilizing Shot"] = "?神射?",
		["Trap Mastery"] = "陷?掌握",
		["Travel Form"] = "旅行形?",
		["Tree of Life"] = "生命之?",
		["Tremor Totem"] = "?栗??",
		["Tribal Leatherworking"] = "部族制皮",
		["Trueshot Aura"] = "强?光?",
		["Turn Undead"] = "超度亡?",
		["Twin Spire Blessing"] = "?塔的祝福",
		["Two-Handed Axes"] = "?手斧",
		["Two-Handed Axes and Maces"] = "?手斧和?",
		["Two-Handed Maces"] = "?手?",
		["Two-Handed Swords"] = "?手?",
		["Two-Handed Weapon Specialization"] = "?手武器?精",
		["Unarmed"] = "徒手",
		["Unbreakable Will"] = "?定意志",
		["Unbridled Wrath"] = "怒不可?",
		["Undead Horsemanship"] = "??：骸骨??",
		["Underwater Breathing"] = "水下呼吸",
		["Unending Breath"] = "魔息?",
		["Unholy Power"] = "邪?强化",
		["Unleashed Fury"] = "狂怒?放",
		["Unleashed Rage"] = "怒火?放",
		["Unstable Affliction"] = "痛苦无常",
		["Unstable Power"] = "能量无常",
		["Unyielding Faith"] = "不?信仰",
		["Vampiric Embrace"] = "吸血鬼的?抱",
		["Vampiric Touch"] = "吸血鬼之?",
		["Vanish"] = "消失",
		["Vanished"] = "消失",
		["Vengeance"] = "?仇",
		["Venomous Totem"] = "毒性??",
		["Victory Rush"] = "乘?追?",
		["Vigor"] = "精力",
		["Vile Beam"] = "?德射?",
		["Vile Poisons"] = "?毒",
		["Vindication"] = "??",
		["Viper Sting"] = "?蛇?刺",
		["Volley"] = "?射",
		["Wand Specialization"] = "魔杖?精",
		["Wands"] = "魔杖",
		["War Stomp"] = "???踏",
		["Warp"] = "??",
		["Warsong Flag"] = "?歌?旗",
		["Water Breathing"] = "水下呼吸",
		["Water Shield"] = "水之?盾",
		["Water Tomb"] = "水之墓",
		["Water Walking"] = "水上行走",
		["Waterbolt"] = "水箭",
		["Watery Grave"] = "水之墓穴",
		["Weakened Soul"] = "?弱?魂",
		["Weapon Mastery"] = "武器掌握",
		["Weaponsmith"] = "武器?造",
		["Whirlwind"] = "旋??",
		["Will of the Forsaken"] = "亡?意志",
		["Windfury"] = "?怒",
		["Windfury Attack"] = "?怒攻?",
		["Windfury Totem"] = "?怒??",
		["Windfury Weapon"] = "?怒武器",
		["Windwall"] = "??",
		["Windwall Totem"] = "????",
		["Wing Clip"] = "??",
		["Winter's Chill"] = "深冬之寒",
		["Wisp Spirit"] = "精?之魂",
		["Wolf Riding"] = "??：狼",
		["Wound Poison"] = "致??膏",
		["Wound Poison II"] = "致??膏 II",
		["Wound Poison III"] = "致??膏 III",
		["Wound Poison IV"] = "致??膏 IV",
		["Wound Poison V"] = "致??膏 V",
		["Wrath"] = "?怒",
		["Wrath of Air Totem"] = "空?之怒??",
		["Wrath of Cenarius"] = "塞?留斯之怒",
		["Wrath of the Astromancer"] = "星??之怒",
		["Wyvern Sting"] = "翼??刺",
	}
elseif GAME_LOCALE == "zhTW" then
	lib:SetCurrentTranslations {
		["Abolish Disease"] = "驅除疾病",
		["Abolish Poison"] = "驅毒術",
		["Abolish Poison Effect"] = "驅毒術效果",
		["Activate MG Turret"] = "?動MG砲塔",
		["Adrenaline Rush"] = "能量刺激",
		["Aftermath"] = "?算",
		["Aggression"] = "侵略",
		["Aimed Shot"] = "?準射擊",
		["Alchemy"] = "鍊金術",
		["Ambush"] = "伏擊",
		["Ammunition"] = "彈藥",
		["Amplify Curse"] = "詛?增幅",
		["Amplify Magic"] = "魔法增效",
		["Ancestral Fortitude"] = "先祖堅?",
		["Ancestral Healing"] = "先祖治療",
		["Ancestral Knowledge"] = "先祖知識",
		["Ancestral Spirit"] = "先祖之魂",
		["Ancient Hysteria"] = "上古狂亂",
		["Anesthetic Poison"] = "麻醉毒藥",
		["Anger Management"] = "憤怒掌控",
		["Anguish"] = "苦痛",
		["Anticipation"] = "預知",
		["Aquatic Form"] = "水棲形態",
		["Arcane Blast"] = "秘法衝擊",
		["Arcane Brilliance"] = "秘法光輝",
		["Arcane Concentration"] = "秘法專注",
		["Arcane Energy"] = "秘法能量",
		["Arcane Explosion"] = "魔爆術",
		["Arcane Focus"] = "秘法集中",
		["Arcane Fortitude"] = "秘法轉化",
		["Arcane Impact"] = "秘法?撞",
		["Arcane Instability"] = "秘法增效",
		["Arcane Intellect"] = "秘法智慧",
		["Arcane Meditation"] = "秘法冥想",
		["Arcane Mind"] = "秘法心智",
		["Arcane Missiles"] = "秘法飛彈",
		["Arcane Potency"] = "秘法潛能",
		["Arcane Power"] = "秘法?化",
		["Arcane Resistance"] = "秘法抗性",
		["Arcane Shot"] = "秘法射擊",
		["Arcane Shroud"] = "秘法環繞",
		["Arcane Subtlety"] = "秘法精妙",
		["Arcane Torrent"] = "奧流之術",
		["Arcane Weakness"] = "秘法虛弱",
		["Arctic Reach"] = "極寒延伸",
		["Arctic Winds"] = "極地之風",
		["Armor of Faith"] = "信仰護盾",
		["Armorsmith"] = "護甲鍛造師",
		["Aspect of the Beast"] = "野獸守護",
		["Aspect of the Cheetah"] = "獵豹守護",
		["Aspect of the Hawk"] = "雄鷹守護",
		["Aspect of the Monkey"] = "靈?守護",
		["Aspect of the Pack"] = "豹群守護",
		["Aspect of the Viper"] = "?蛇守護",
		["Aspect of the Wild"] = "野性守護",
		["Astral Recall"] = "星界傳送",
		["Attack"] = "攻擊",
		["Attacking"] = "攻擊",
		["Auto Shot"] = "自動射擊",
		["Avenger's Shield"] = "復仇之盾",
		["Avenging Wrath"] = "復仇之怒",
		["Avoidance"] = "?避",
		["Axe Specialization"] = "斧專精",
		["Backlash"] = "反衝",
		["Backstab"] = "背刺",
		["Badge of the Swarmguard"] = "蟲群守衛徽章",
		["Balance of Power"] = "平衡之力",
		["Bane"] = "災禍",
		["Banish"] = "放逐術",
		["Banker"] = "銀行",
		["Banshee Curse"] = "女妖詛?",
		["Barkskin"] = "樹皮術",
		["Barrage"] = "彈幕",
		["Bash"] = "重擊",
		["Basic Campfire"] = "基礎營火",
		["Battle Rush"] = "戰?猛攻",
		["Battle Shout"] = "戰?怒吼",
		["Battle Stance"] = "戰?姿態",
		["Battle Stance Passive"] = "戰?姿態被動",
--		["BattleMaster"] = "BattleMaster",
		["Bear Form"] = "熊形態",
		["Beast Lore"] = "野獸知識",
		["Beast Slaying"] = "野獸殺手",
		["Beast Training"] = "訓練野獸",
		["Benediction"] = "祈福",
		["Berserker Rage"] = "狂暴之怒",
		["Berserker Stance"] = "狂暴姿態",
		["Berserker Stance Passive"] = "狂暴姿態(被動)",
		["Berserking"] = "狂暴",
		["Bestial Discipline"] = "野獸戒律",
		["Bestial Swiftness"] = "野獸迅捷",
		["Bestial Wrath"] = "狂野怒火",
		["Binding Heal"] = "束縛治療",
		["Bite"] = "?咬",
		["Black Arrow"] = "黑箭",
		["Blackout"] = "昏厥",
		["Blacksmithing"] = "鍛造",
		["Blade Flurry"] = "劍刃亂舞",
		["Blade Turning"] = "劍刃轉向",
		["Blade Twisting"] = "旋轉劍刃",
		["Blast Wave"] = "衝擊波",
		["Blazing Speed"] = "熾烈迅捷",
		["Blessed Recovery"] = "祝福復元",
		["Blessed Resilience"] = "祝福?性",
		["Blessing of Auchindoun"] = "奧齊頓的祝福",
		["Blessing of Freedom"] = "自由祝福",
		["Blessing of Kings"] = "王者祝福",
		["Blessing of Light"] = "光明祝福",
		["Blessing of Might"] = "力量祝福",
		["Blessing of Protection"] = "保護祝福",
		["Blessing of Sacrifice"] = "犧牲祝福",
		["Blessing of Salvation"] = "拯救祝福",
		["Blessing of Sanctuary"] = "庇護祝福",
		["Blessing of Wisdom"] = "智慧祝福",
		["Blind"] = "致盲",
		["Blinding Powder"] = "致盲粉",
		["Blink"] = "閃現術",
		["Blizzard"] = "暴風雪",
		["Block"] = "格?",
		["Blood Craze"] = "血之狂熱",
		["Blood Frenzy"] = "血之狂暴",
		["Blood Fury"] = "血性狂暴",
		["Blood Pact"] = "血之契印",
		["Bloodlust"] = "嗜血術",
		["Bloodrage"] = "血性狂暴",
		["Bloodthirst"] = "嗜血",
		["Boar Charge"] = "野?衝鋒",
		["Booming Voice"] = "震耳?音",
		["Bow Specialization"] = "弓箭專精",
		["Bows"] = "弓",
		["Bright Campfire"] = "明亮?火",
		["Brittle Armor"] = "脆弱護甲",
		["Brutal Impact"] = "野蠻衝撞",
		["Burning Adrenaline"] = "燃燒刺激",
		["Burning Soul"] = "燃燒之魂",
		["Burning Wish"] = "燃燒之願",
		["Call Pet"] = "召喚寵物",
		["Call of Flame"] = "烈焰呼喚",
		["Call of Thunder"] = "雷霆呼喚",
		["Call of the Nexus"] = "奈薩斯的精神感召",
		["Camouflage"] = "?裝",
		["Cannibalize"] = "食屍",
		["Cat Form"] = "獵豹形態",
		["Cataclysm"] = "災變",
		["Celestial Focus"] = "星空專注",
		["Chain Heal"] = "治療鍊",
		["Chain Lightning"] = "閃電?",
		["Challenging Roar"] = "挑戰咆哮",
		["Challenging Shout"] = "挑戰怒吼",
		["Charge"] = "衝鋒",
		["Charge Rage Bonus Effect"] = "衝鋒怒氣加成效果",
		["Charge Stun"] = "衝鋒昏迷",
		["Cheap Shot"] = "?襲",
		["Chilled"] = "?凍",
		["Circle of Healing"] = "治療之環",
		["Class Trainer"] = "職業訓練師",
		["Claw"] = "爪擊",
		["Cleanse"] = "淨化術",
		["Clearcasting"] = "節能施法",
		["Cleave"] = "順劈斬",
		["Clever Traps"] = "靈巧陷?",
		["Cloak of Shadows"] = "暗影披風",
		["Closing"] = "關閉",
		["Cloth"] = "布甲",
		["Coarse Sharpening Stone"] = "粗製磨刀石",
		["Cobra Reflexes"] = "毒蛇反射",
		["Cold Blood"] = "冷血",
		["Cold Snap"] = "急速冷?",
		["Combat Endurance"] = "作戰持久",
		["Combustion"] = "燃燒",
		["Command"] = "命令",
		["Commanding Presence"] = "命令風采",
		["Commanding Shout"] = "命令之吼",
		["Concentration Aura"] = "專注光環",
		["Concussion"] = "震?",
		["Concussion Blow"] = "震?猛擊",
		["Concussive Barrage"] = "震?狙擊",
		["Concussive Shot"] = "震?射擊",
		["Cone of Cold"] = "?錐術",
		["Conflagrate"] = "燃燒",
		["Conflagration"] = "燃燒",
		["Conjure Food"] = "造食術",
		["Conjure Mana Agate"] = "製造法力瑪瑙",
		["Conjure Mana Citrine"] = "製造法力黃水晶",
		["Conjure Mana Emerald"] = "製造法力綠寶石",
		["Conjure Mana Jade"] = "製造法力翡翠",
		["Conjure Mana Ruby"] = "製造法力紅寶石",
		["Conjure Water"] = "造水術",
		["Consecration"] = "奉獻",
		["Consume Magic"] = "??魔法",
		["Consume Shadows"] = "??暗影",
		["Contagion"] = "傳染",
		["Convection"] = "傳導",
		["Conviction"] = "定罪",
		["Cooking"] = "烹?",
		["Corruption"] = "腐蝕術",
		["Counterattack"] = "反擊",
		["Counterspell"] = "法術反制",
		["Counterspell - Silenced"] = "法術反制 - ?默",
		["Cower"] = "畏縮",
		["Create Firestone"] = "製造火焰石",
		["Create Firestone (Greater)"] = "製造?效火焰石",
		["Create Firestone (Lesser)"] = "製造次級火焰石",
		["Create Firestone (Major)"] = "製造極效火焰石",
		["Create Healthstone"] = "製造治療石",
		["Create Healthstone (Greater)"] = "製造治療石(?效)",
		["Create Healthstone (Lesser)"] = "製造治療石(次級)",
		["Create Healthstone (Major)"] = "製造治療石(極效)",
		["Create Healthstone (Minor)"] = "製造治療石(初級)",
		["Create Soulstone"] = "製造靈魂石",
		["Create Soulstone (Greater)"] = "製造靈魂石 (?效)",
		["Create Soulstone (Lesser)"] = "製造靈魂石 (次級)",
		["Create Soulstone (Major)"] = "製造靈魂石 (極效)",
		["Create Soulstone (Minor)"] = "製造靈魂石 (初級)",
		["Create Spellstone"] = "製造法術石",
		["Create Spellstone (Greater)"] = "製造?效法術石",
		["Create Spellstone (Major)"] = "製造極效法術石",
		["Create Spellstone (Master)"] = "製造極?效法術石",
		["Cripple"] = "殘廢術",
		["Crippling Poison"] = "致殘毒藥",
		["Crippling Poison II"] = "致殘毒藥 II",
		["Critical Mass"] = "火焰重擊",
		["Crossbows"] = "弩",
		["Cruelty"] = "殘忍",
		["Crusade"] = "十字軍",
		["Crusader Aura"] = "十字軍光環",
		["Crusader Strike"] = "十字軍聖擊",
		["Cultivation"] = "栽培",
		["Cure Disease"] = "祛病術",
		["Cure Poison"] = "消毒術",
		["Curse of Agony"] = "痛苦詛?",
		["Curse of Doom"] = "厄運詛?",
		["Curse of Doom Effect"] = "厄運詛?效果",
		["Curse of Exhaustion"] = "疲勞詛?",
		["Curse of Idiocy"] = "癡?詛?",
		["Curse of Recklessness"] = "魯莽詛?",
		["Curse of Shadow"] = "暗影詛?",
		["Curse of Tongues"] = "語言詛?",
		["Curse of Weakness"] = "虛弱詛?",
		["Curse of the Elements"] = "元素詛?",
		["Cyclone"] = "?風術",
		["Dagger Specialization"] = "匕首專精",
		["Daggers"] = "匕首",
		["Dampen Magic"] = "魔法抑制",
		["Dark Pact"] = "黑暗契約",
		["Darkness"] = "黑暗",
		["Dash"] = "突進",
		["Dawnstone Crab"] = "黎明石蟹",
		["Dazed"] = "暈眩",
		["Deadly Interrupt Effect"] = "致命中斷效果",
		["Deadly Poison"] = "致命毒藥",
		["Deadly Poison II"] = "致命毒藥 II",
		["Deadly Poison III"] = "致命毒藥 III",
		["Deadly Poison IV"] = "致命毒藥 IV",
		["Deadly Poison V"] = "致命毒藥 V",
		["Deadly Poison VI"] = "致命毒藥 VI",
		["Deadly Poison VII"] = "致命毒藥 VII",
		["Deadly Throw"] = "擲殺",
		["Death Coil"] = "死亡纏繞",
		["Death Wish"] = "死亡之願",
		["Deep Wound"] = "重傷",
		["Deep Wounds"] = "重傷",
		["Defense"] = "防禦",
		["Defensive Stance"] = "防禦姿態",
		["Defensive Stance Passive"] = "防禦姿態被動",
		["Defiance"] = "挑?",
		["Deflection"] = "偏斜",
		["Delusions of Jin'do"] = "金度的欺騙",
		["Demon Armor"] = "魔甲術",
		["Demon Skin"] = "惡魔皮膚",
		["Demonic Aegis"] = "惡魔庇護",
		["Demonic Embrace"] = "惡魔之擁",
		["Demonic Frenzy"] = "惡魔狂怒",
		["Demonic Knowledge"] = "惡魔知識",
		["Demonic Resilience"] = "惡魔?性",
		["Demonic Sacrifice"] = "惡魔犧牲",
		["Demonic Tactics"] = "惡魔策略",
		["Demoralizing Roar"] = "挫志咆哮",
		["Demoralizing Shout"] = "挫志怒吼",
		["Dense Sharpening Stone"] = "緻密磨刀石",
		["Desperate Prayer"] = "?望禱言",
		["Destructive Reach"] = "?滅延伸",
		["Detect"] = "偵測",
		["Detect Greater Invisibility"] = "偵測?效隱形",
		["Detect Invisibility"] = "偵測隱形",
		["Detect Lesser Invisibility"] = "偵測次級隱形術",
		["Detect Magic"] = "偵測魔法",
		["Detect Traps"] = "偵測陷?",
		["Deterrence"] = "威?",
		["Devastate"] = "挫敗",
		["Devastation"] = "破壞",
		["Devotion Aura"] = "虔誠光環",
		["Devour Magic"] = "??魔法",
		["Devour Magic Effect"] = "??魔法效果",
		["Devouring Plague"] = "?靈瘟疫",
		["Diplomacy"] = "外交",
		["Dire Bear Form"] = "巨熊形態",
		["Dirty Deeds"] = "陰險動作",
		["Dirty Tricks"] = "卑鄙技倆",
		["Disarm"] = "?械",
		["Disarm Trap"] = "解除陷?",
		["Disease Cleansing Totem"] = "祛病圖騰",
		["Disenchant"] = "分解",
		["Disengage"] = "逃脫",
		["Dismiss Pet"] = "解散野獸",
		["Dispel Magic"] = "驅散魔法",
		["Distract"] = "擾亂",
		["Distracting Shot"] = "擾亂射擊",
		["Dive"] = "俯衝",
		["Divine Favor"] = "神恩術",
		["Divine Fury"] = "神聖之怒",
		["Divine Illumination"] = "神聖?發",
		["Divine Intellect"] = "神聖智慧",
		["Divine Intervention"] = "神聖干涉",
		["Divine Protection"] = "聖佑術",
		["Divine Shield"] = "聖盾術",
		["Divine Spirit"] = "神聖之靈",
		["Divine Strength"] = "神聖之力",
		["Divine Wrath"] = "神聖之怒",
		["Dodge"] = "閃?",
		["Doomfire"] = "?滅之火",
		["Dragon's Breath"] = "龍之吐息",
		["Dragonscale Leatherworking"] = "龍鱗製皮",
		["Drain Life"] = "吸取生命",
		["Drain Mana"] = "吸取法力",
		["Drain Soul"] = "吸取靈魂",
		["Dreamless Sleep"] = "無夢睡眠",
		["Drink"] = "喝?料",
		["Dual Wield"] = "雙武器",
		["Dual Wield Specialization"] = "雙武器專精",
		["Duel"] = "決?",
		["Dust Cloud"] = "塵霧之雲",
		["Eagle Eye"] = "鷹眼術",
		["Earth Elemental Totem"] = "土元素圖騰",
		["Earth Shield"] = "大地之盾",
		["Earth Shock"] = "地震術",
		["Earthbind"] = "地縛術",
		["Earthbind Totem"] = "地縛圖騰",
		["Earthstrike"] = "大地之擊",
		["Efficiency"] = "效率",
		["Elemental Devastation"] = "元素破壞",
		["Elemental Focus"] = "元素集中",
		["Elemental Fury"] = "元素之怒",
		["Elemental Leatherworking"] = "元素製皮",
		["Elemental Mastery"] = "精通元素",
		["Elemental Precision"] = "元素準確",
		["Elemental Sharpening Stone"] = "元素磨刀石",
		["Elemental Weapons"] = "元素武器",
		["Elune's Grace"] = "伊露恩的賜福",
		["Elusiveness"] = "飄忽不定",
		["Emberstorm"] = "餘燼風暴",
		["Empowered Arcane Missiles"] = "?力秘法飛彈",
		["Empowered Corruption"] = "?力腐蝕術",
		["Empowered Fireball"] = "?力火球術",
		["Empowered Frostbolt"] = "?力寒?箭",
		["Empowered Healing"] = "?力治療術",
		["Empowered Rejuvenation"] = "?力回春術",
		["Empowered Touch"] = "?力之觸",
		["Enamored Water Spirit"] = "被迷惑的水之靈",
		["Enchanting"] = "附魔",
		["Endurance"] = "耐久",
		["Endurance Training"] = "耐久訓練",
		["Engineering"] = "工程學",
		["Engineering Specialization"] = "工程學專精",
		["Enrage"] = "狂怒",
		["Enriched Manna Biscuit"] = "可口的魔法點心",
		["Enslave Demon"] = "奴役惡魔",
		["Entangling Roots"] = "糾纏根鬚",
		["Entrapment"] = "誘捕",
		["Envenom"] = "毒化",
		["Escape Artist"] = "逃命專家",
		["Evasion"] = "閃避",
		["Eviscerate"] = "剔骨",
		["Evocation"] = "喚醒",
		["Execute"] = "斬殺",
		["Exorcism"] = "驅邪術",
		["Expansive Mind"] = "開闊思維",
		["Explosive Trap"] = "爆炸陷?",
		["Explosive Trap Effect"] = "爆炸陷?效果",
		["Expose Armor"] = "破甲",
		["Expose Weakness"] = "弱點識破",
		["Extract Gas"] = "提煉氣體雲",
		["Eye for an Eye"] = "以眼還眼",
		["Eye of Kilrogg"] = "基爾羅格之眼",
		["Eye of the Storm"] = "暴風之眼",
		["Eyes of the Beast"] = "野獸之眼",
		["Fade"] = "漸隱術",
		["Faerie Fire"] = "精靈之火",
		["Faerie Fire (Feral)"] = "精靈之火(野性)",
		["Fanaticism"] = "狂熱",
		["Far Sight"] = "視界術",
		["Fatal Attraction"] = "致命的吸引力",
		["Fear"] = "恐懼術",
		["Fear Ward"] = "防護恐懼結界",
		["Feed Pet"] = "?養寵物",
		["Feed Pet Effect"] = "?養寵物效果",
		["Feedback"] = "回饋",
		["Feign Death"] = "假死",
		["Feint"] = "佯攻",
		["Fel Armor"] = "獄甲術",
		["Fel Concentration"] = "惡魔專注",
		["Fel Domination"] = "惡魔支配",
		["Fel Energy"] = "惡魔能量",
		["Fel Intellect"] = "惡魔智力",
		["Fel Rage"] = "惡魔之怒",
		["Fel Stamina"] = "惡魔耐力",
		["Felfire"] = "惡魔烈焰",
		["Feline Grace"] = "豹之優雅",
		["Feral Aggression"] = "野性侵略",
		["Feral Charge"] = "野性衝鋒",
		["Feral Instinct"] = "野性本能",
		["Feral Swiftness"] = "野性迅捷",
		["Ferocious Bite"] = "兇猛?咬",
		["Ferocious Inspiration"] = "兇性鼓舞",
		["Ferocity"] = "兇暴",
		["Fetish"] = "神像",
		["Find Fish"] = "尋?魚群",
		["Find Herbs"] = "尋?草藥",
		["Find Minerals"] = "尋??物",
		["Find Treasure"] = "尋?財寶",
		["Find Weakness"] = "?尋弱點",
		["Fire Blast"] = "火焰衝擊",
		["Fire Breath"] = "火焰之息",
		["Fire Elemental Totem"] = "火元素圖騰",
		["Fire Nova Totem"] = "火焰新星圖騰",
		["Fire Power"] = "火焰?化",
		["Fire Resistance"] = "火焰抗性",
		["Fire Resistance Aura"] = "火焰抗性光環",
		["Fire Resistance Totem"] = "抗火圖騰",
		["Fire Shield"] = "火焰之盾",
		["Fire Vulnerability"] = "火焰易傷",
		["Fire Ward"] = "防護火焰結界",
		["Fire Weakness"] = "火焰虛弱",
		["Fireball"] = "火球術",
		["Firebolt"] = "火焰箭",
		["First Aid"] = "急救",
		["Fishing"] = "釣魚",
		["Fishing Poles"] = "魚竿",
		["Fist Weapon Specialization"] = "拳套專精",
		["Fist Weapons"] = "拳套",
		["Flame Shock"] = "烈焰震擊",
		["Flame Throwing"] = "烈焰投擲",
		["Flamestrike"] = "烈焰風暴",
		["Flamethrower"] = "火焰噴射器",
		["Flametongue Attack"] = "火舌攻擊",
		["Flametongue Totem"] = "火舌圖騰",
		["Flametongue Weapon"] = "火舌武器",
		["Flare"] = "照明彈",
		["Flash Heal"] = "快速治療",
		["Flash of Light"] = "聖光閃現",
		["Flight Form"] = "飛行形態",
		["FlightMaster"] = "飛行管理員",
		["Flurry"] = "亂舞",
		["Focused Casting"] = "專注施法",
		["Focused Mind"] = "精神專注",
		["Focused Power"] = "能量專注",
		["Focused Rage"] = "專注之怒",
		["Focused Starlight"] = "專注星光",
		["Food"] = "進食",
		["Food & Drink"] = "食物 & ?水",
		["Forbearance"] = "自律",
		["Force of Nature"] = "自然之力",
		["Force of Will"] = "意志之力",
		["Freezing Trap"] = "?凍陷?",
		["Freezing Trap Effect"] = "?凍陷?效果",
		["Frenzied Regeneration"] = "狂暴恢復",
		["Frenzy"] = "狂亂",
		["Frenzy Effect"] = "狂亂效果",
		["Frost Armor"] = "霜甲術",
		["Frost Blast"] = "?霜衝擊",
		["Frost Channeling"] = "?霜導能",
		["Frost Nova"] = "?霜新星",
		["Frost Resistance"] = "?霜抗性",
		["Frost Resistance Aura"] = "?霜抗性光環",
		["Frost Resistance Totem"] = "抗寒圖騰",
		["Frost Shock"] = "?霜震擊",
		["Frost Trap"] = "?霜陷?",
		["Frost Trap Aura"] = "?霜陷?光環",
		["Frost Ward"] = "防護?霜結界",
		["Frost Warding"] = "?霜結界",
		["Frost Weakness"] = "?霜虛弱",
		["Frostbite"] = "霜寒刺骨",
		["Frostbolt"] = "寒?箭",
		["Frostbrand Attack"] = "?封攻擊",
		["Frostbrand Weapon"] = "?封武器",
		["Frozen Core"] = "?霜之心",
		["Furious Howl"] = "狂怒之?",
		["Furor"] = "激怒",
		["Fury of the Crashing Waves"] = "浪潮之怒",
		["Garrote"] = "絞喉",
		["Garrote - Silence"] = "絞喉 - ?默",
		["Ghost Wolf"] = "鬼魂之狼",
		["Ghostly Strike"] = "鬼魅攻擊",
		["Gift of Life"] = "生命賜福",
		["Gift of Nature"] = "自然賜福",
		["Gift of the Naaru"] = "那魯的祝福",
		["Gift of the Wild"] = "野性賜福",
		["Gouge"] = "鑿擊",
		["Grace of Air"] = "風之優雅",
		["Grace of Air Totem"] = "風之優雅圖騰",
		["Great Stamina"] = "?效耐力",
		["Greater Blessing of Kings"] = "?效王者祝福",
		["Greater Blessing of Light"] = "?效光明祝福",
		["Greater Blessing of Might"] = "?效力量祝福",
		["Greater Blessing of Salvation"] = "?效拯救祝福",
		["Greater Blessing of Sanctuary"] = "?效庇護祝福",
		["Greater Blessing of Wisdom"] = "?效智慧祝福",
		["Greater Dreamless Sleep"] = "?效昏睡",
		["Greater Heal"] = "?效治療術",
		["Grim Reach"] = "無情延伸",
		["Grounding Totem"] = "根基圖騰",
		["Grounding Totem Effect"] = "根基圖騰效果",
		["Grovel"] = "匍匐",
		["Growl"] = "低吼",
		["Guardian's Favor"] = "守護者的恩眷",
		["Gun Specialization"] = "槍械專精",
		["Guns"] = "槍械",
		["Hammer of Justice"] = "制裁之錘",
		["Hammer of Wrath"] = "憤怒之錘",
		["Hamstring"] = "斷筋",
		["Harass"] = "侵擾",
		["Hardiness"] = "堅?",
		["Haste"] = "加速",
		["Hawk Eye"] = "鷹眼",
		["Heal"] = "治療術",
		["Healing Focus"] = "專注治療",
		["Healing Light"] = "治療之光",
		["Healing Stream"] = "治療之泉",
		["Healing Stream Totem"] = "治療之泉圖騰",
		["Healing Touch"] = "治療之觸",
		["Healing Wave"] = "治療波",
		["Healing Way"] = "治療之路",
		["Health Funnel"] = "生命通道",
		["Heart of the Wild"] = "野性之心",
		["Heavy Sharpening Stone"] = "重磨刀石",
		["Hellfire"] = "地獄烈焰",
		["Hellfire Effect"] = "地獄烈焰效果",
		["Hellfire Superiority"] = "地獄火優勢",
		["Hemorrhage"] = "出血",
		["Herb Gathering"] = "採集草藥",
		["Herbalism"] = "草藥學",
		["Heroic Strike"] = "英勇打擊",
		["Heroism"] = "英勇氣?",
		["Hex of Weakness"] = "虛弱妖術",
		["Hibernate"] = "休眠",
		["Holy Fire"] = "神聖之火",
		["Holy Light"] = "聖光術",
		["Holy Nova"] = "神聖新星",
		["Holy Power"] = "神聖?化",
		["Holy Reach"] = "神聖延伸",
		["Holy Shield"] = "神聖之盾",
		["Holy Shock"] = "神聖震擊",
		["Holy Specialization"] = "神聖專精",
		["Holy Wrath"] = "神聖憤怒",
		["Honorless Target"] = "無榮譽目標",
		["Horse Riding"] = "騎術:馬",
		["Howl of Terror"] = "恐懼?叫",
		["Humanoid Slaying"] = "人型生物殺手",
		["Hunter's Mark"] = "獵人印記",
		["Hurricane"] = "?風",
		["Hypothermia"] = "體溫過低",
		["Ice Armor"] = "?甲術",
		["Ice Barrier"] = "寒?護體",
		["Ice Block"] = "寒??障",
		["Ice Floes"] = "浮?",
		["Ice Lance"] = "?霜長矛",
		["Ice Shards"] = "寒?裂片",
		["Ignite"] = "點燃",
		["Ignite Mana"] = "點燃法力",
		["Illumination"] = "?發",
		["Immolate"] = "獻祭",
		["Immolation Trap"] = "獻祭陷?",
		["Immolation Trap Effect"] = "獻祭陷?效果",
		["Impact"] = "衝擊",
		["Impale"] = "刺穿",
		["Impaling Spine"] = "尖刺脊椎",
		["Improved Ambush"] = "?化伏擊",
		["Improved Arcane Missiles"] = "?化秘法飛彈",
		["Improved Arcane Shot"] = "?化秘法射擊",
		["Improved Aspect of the Hawk"] = "?化雄鷹守護",
		["Improved Aspect of the Monkey"] = "?化靈?守護",
		["Improved Backstab"] = "?化背刺",
		["Improved Barrage"] = "?化彈幕",
		["Improved Berserker Rage"] = "?化狂暴之怒",
		["Improved Blessing of Might"] = "?化力量祝福",
		["Improved Blessing of Wisdom"] = "?化智慧祝福",
		["Improved Blink"] = "?化閃現術",
		["Improved Blizzard"] = "?化暴風雪",
		["Improved Bloodrage"] = "?化血性狂暴",
		["Improved Chain Heal"] = "?化治療鍊",
		["Improved Chain Lightning"] = "?化閃電?",
		["Improved Challenging Shout"] = "?化挑戰怒吼",
		["Improved Charge"] = "?化衝鋒",
		["Improved Cleave"] = "?化順劈斬",
		["Improved Concentration Aura"] = "?化專注光環",
		["Improved Concussive Shot"] = "?化震?射擊",
		["Improved Cone of Cold"] = "?化?錐術",
		["Improved Corruption"] = "?化腐蝕術",
		["Improved Counterspell"] = "?化法術反制",
		["Improved Curse of Agony"] = "?化痛苦詛?",
		["Improved Curse of Weakness"] = "?化虛弱詛?",
		["Improved Demoralizing Shout"] = "?化挫志怒吼",
		["Improved Devotion Aura"] = "?化虔誠光環",
		["Improved Disarm"] = "?化?械",
		["Improved Drain Life"] = "?化吸取生命",
		["Improved Drain Soul"] = "?化吸取靈魂",
		["Improved Enrage"] = "?化狂怒",
		["Improved Enslave Demon"] = "?化奴役惡魔",
		["Improved Eviscerate"] = "?化剔骨",
		["Improved Execute"] = "?化斬殺",
		["Improved Expose Armor"] = "?化破甲",
		["Improved Eyes of the Beast"] = "?化野獸之眼",
		["Improved Fade"] = "?化漸隱術",
		["Improved Feign Death"] = "?化假死",
		["Improved Fire Blast"] = "?化火焰衝擊",
		["Improved Fire Totems"] = "?化火焰圖騰",
		["Improved Fire Ward"] = "?化防護火焰結界",
		["Improved Fireball"] = "?化火球術",
		["Improved Firebolt"] = "?化火焰箭",
		["Improved Flamestrike"] = "?化烈焰風暴",
		["Improved Flash of Light"] = "?化聖光閃現",
		["Improved Frost Nova"] = "?化?霜新星",
		["Improved Frostbolt"] = "?化寒?箭",
		["Improved Ghost Wolf"] = "?化鬼魂之狼",
		["Improved Gouge"] = "?化鑿擊",
		["Improved Hammer of Justice"] = "?化制裁之錘",
		["Improved Hamstring"] = "?化斷筋",
		["Improved Healing"] = "?化治療術",
		["Improved Healing Touch"] = "?化治療之觸",
		["Improved Healing Wave"] = "?化治療波",
		["Improved Health Funnel"] = "?化生命通道",
		["Improved Healthstone"] = "?化治療石",
		["Improved Heroic Strike"] = "?化英勇打擊",
		["Improved Holy Shield"] = "?化神聖之盾",
		["Improved Howl of Terror"] = "?化恐懼?叫",
		["Improved Hunter's Mark"] = "?化獵人印記",
		["Improved Immolate"] = "?化獻祭",
		["Improved Imp"] = "?化小鬼",
		["Improved Inner Fire"] = "?化心靈之火",
		["Improved Intercept"] = "?化?截",
		["Improved Intimidating Shout"] = "?化破膽怒吼",
		["Improved Judgement"] = "?化審判",
		["Improved Kick"] = "?化??",
		["Improved Kidney Shot"] = "?化腎擊",
		["Improved Lash of Pain"] = "?化劇痛鞭笞",
		["Improved Lay on Hands"] = "?化聖療術",
		["Improved Leader of the Pack"] = "?化獸群領袖",
		["Improved Life Tap"] = "?化生命分流",
		["Improved Lightning Bolt"] = "?化閃電箭",
		["Improved Lightning Shield"] = "?化閃電之盾",
		["Improved Magma Totem"] = "?化熔岩圖騰",
		["Improved Mana Burn"] = "?化法力燃燒",
		["Improved Mana Shield"] = "?化法力護盾",
		["Improved Mana Spring Totem"] = "?化法力之泉圖騰",
		["Improved Mark of the Wild"] = "?化野性印記",
		["Improved Mend Pet"] = "?化治療寵物",
		["Improved Mind Blast"] = "?化心靈震爆",
		["Improved Moonfire"] = "?化月火術",
		["Improved Mortal Strike"] = "?化致死打擊",
		["Improved Nature's Grasp"] = "?化自然之握",
		["Improved Overpower"] = "?化壓制",
		["Improved Power Word: Fortitude"] = "?化?言術:?",
		["Improved Power Word: Shield"] = "?化?言術:盾",
		["Improved Prayer of Healing"] = "?化治療禱言",
		["Improved Psychic Scream"] = "?化心靈尖嘯",
		["Improved Regrowth"] = "?化癒合",
		["Improved Reincarnation"] = "?化復生",
		["Improved Rejuvenation"] = "?化回春術",
		["Improved Rend"] = "?化?裂",
		["Improved Renew"] = "?化恢復",
		["Improved Retribution Aura"] = "?化懲罰光環",
		["Improved Revenge"] = "?化復仇",
		["Improved Revive Pet"] = "?化復活寵物",
		["Improved Righteous Fury"] = "?化正義之怒",
		["Improved Rupture"] = "?化割裂",
		["Improved Scorch"] = "?化灼燒",
		["Improved Scorpid Sting"] = "?化毒?釘刺",
		["Improved Seal of Righteousness"] = "?化正義聖印",
		["Improved Seal of the Crusader"] = "?化十字軍聖印",
		["Improved Searing Pain"] = "?化灼熱之痛",
		["Improved Serpent Sting"] = "?化毒蛇釘刺",
		["Improved Shadow Bolt"] = "?化暗影箭",
		["Improved Shadow Word: Pain"] = "?化暗言術:痛",
		["Improved Shield Bash"] = "?化盾擊",
		["Improved Shield Block"] = "?化盾牌格?",
		["Improved Shield Wall"] = "?化盾牆",
		["Improved Sinister Strike"] = "?化邪惡攻擊",
		["Improved Slam"] = "?化猛擊",
		["Improved Slice and Dice"] = "?化切割",
		["Improved Sprint"] = "?化疾?",
		["Improved Stings"] = "?化釘刺",
		["Improved Succubus"] = "?化魅魔",
		["Improved Sunder Armor"] = "?化破甲攻擊",
		["Improved Taunt"] = "?化嘲諷",
		["Improved Thunder Clap"] = "?化雷霆一擊",
		["Improved Tranquility"] = "?化寧靜",
		["Improved Vampiric Embrace"] = "?化吸血鬼的擁抱",
		["Improved Vanish"] = "?化消失",
		["Improved Voidwalker"] = "?化虛無行者",
		["Improved Weapon Totems"] = "?化武器系圖騰",
		["Improved Whirlwind"] = "?化旋風斬",
		["Improved Wing Clip"] = "?化?絆",
		["Incinerate"] = "燒盡",
		["Incineration"] = "焚化",
		["Inferno"] = "地獄火",
		["Initiative"] = "先發制人",
		["Innkeeper"] = "旅館主人",
		["Inner Fire"] = "心靈之火",
		["Inner Focus"] = "心靈專注",
		["Innervate"] = "?動",
		["Insect Swarm"] = "蟲群",
		["Insidious Whisper"] = "陰險之語",
		["Insignifigance"] = "攻擊無效",
		["Inspiration"] = "靈感",
		["Instant Poison"] = "速效毒藥",
		["Instant Poison II"] = "速效毒藥 II",
		["Instant Poison III"] = "速效毒藥 III",
		["Instant Poison IV"] = "速效毒藥 IV",
		["Instant Poison V"] = "速效毒藥 V",
		["Instant Poison VI"] = "速效毒藥 VI",
		["Instant Poison VII"] = "速效毒藥 VII",
		["Intensity"] = "激化",
		["Intercept"] = "?截",
		["Intercept Stun"] = "?截昏迷",
		["Intervene"] = "阻擾",
		["Intimidating Shout"] = "破膽怒吼",
		["Intimidation"] = "脅迫",
		["Invisibility"] = "隱形術",
		["Iron Will"] = "鋼鐵意志",
		["Jewelcrafting"] = "珠寶設計",
		["Jom Gabbar"] = "姜姆·蓋伯",
		["Judgement"] = "審判",
		["Judgement of Blood"] = "血之審判",
		["Judgement of Command"] = "命令審判",
		["Judgement of Justice"] = "公正審判",
		["Judgement of Light"] = "光明審判",
		["Judgement of Reckoning"] = "懲罰審判",
		["Judgement of Righteousness"] = "正義審判",
		["Judgement of Wisdom"] = "智慧審判",
		["Judgement of the Crusader"] = "十字軍審判",
		["Kick"] = "??",
		["Kick - Silenced"] = "?? - ?默",
		["Kidney Shot"] = "腎擊",
		["Kill Command"] = "擊殺命令",
		["Killer Instinct"] = "殺戮本能",
		["Kiss of the Spider"] = "蜘蛛之吻",
		["Kodo Riding"] = "騎術:科多獸",
		["Lacerate"] = "割裂",
		["Lash of Pain"] = "劇痛鞭笞",
		["Last Stand"] = "破釜?舟",
		["Lay on Hands"] = "聖療術",
		["Leader of the Pack"] = "獸群領袖",
		["Leather"] = "皮革",
		["Leatherworking"] = "製皮",
		["Lesser Heal"] = "次級治療術",
		["Lesser Healing Wave"] = "次級治療波",
		["Lesser Invisibility"] = "次級隱形術",
		["Lethal Shots"] = "奪命射擊",
		["Lethality"] = "致命?襲",
		["Levitate"] = "漂浮術",
		["Libram"] = "聖契",
		["Life Tap"] = "生命分流",
		["Lifebloom"] = "生命之花",
		["Light's Grace"] = "光明賜福",
		["Lightning Bolt"] = "閃電箭",
		["Lightning Breath"] = "閃電吐息",
		["Lightning Mastery"] = "精通閃電",
		["Lightning Reflexes"] = "閃電反射",
		["Lightning Shield"] = "閃電之盾",
		["Lightning Speed"] = "閃電速度",
		["Lightwell"] = "光束泉",
		["Lightwell Renew"] = "光束泉恢復",
		["Lockpicking"] = "開鎖",
		["Long Daze"] = "長時間暈眩",
		["Lust for Battle"] = "戰?慾望",
		["Mace Specialization"] = "錘類武器專精",
		["Mace Stun Effect"] = "錘擊昏迷效果",
		["Mage Armor"] = "魔甲術",
		["Magic Absorption"] = "魔法吸收",
		["Magic Attunement"] = "魔法調和",
		["Magma Totem"] = "熔岩圖騰",
		["Mail"] = "鎖甲",
		["Maim"] = "傷殘術",
		["Major Dreamless Sleep"] = "極效昏睡",
		["Malediction"] = "憎惡",
		["Malice"] = "惡意",
		["Mana Burn"] = "法力燃燒",
		["Mana Feed"] = "法力?食",
		["Mana Shield"] = "法力護盾",
		["Mana Spring"] = "法力之泉",
		["Mana Spring Totem"] = "法力之泉圖騰",
		["Mana Tap"] = "法力吸取",
		["Mana Tide"] = "法力之潮",
		["Mana Tide Totem"] = "法力之潮圖騰",
		["Mangle"] = "割碎",
		["Mangle (Bear)"] = "割碎(熊形態)",
		["Mangle (Cat)"] = "割碎(獵豹形態)",
		["Mark of the Wild"] = "野性印記",
		["Martyrdom"] = "殉難",
		["Mass Dispel"] = "群體驅魔",
		["Master Conjuror"] = "魔石專精",
		["Master Demonologist"] = "惡魔學識大師",
		["Master Summoner"] = "召喚大師",
		["Master Tactician"] = "戰術大師",
		["Master of Deception"] = "欺詐大師",
		["Master of Elements"] = "元素大師",
		["Master of Subtlety"] = "敏銳大師",
		["Maul"] = "槌擊",
		["Mechanostrider Piloting"] = "騎術:機械陸行鳥",
		["Meditation"] = "冥想",
		["Melee Specialization"] = "近戰專精",
		["Melt Armor"] = "熔化護甲",
		["Mend Pet"] = "治療寵物",
		["Mental Agility"] = "精神敏銳",
		["Mental Strength"] = "心靈之力",
		["Mind Blast"] = "心靈震爆",
		["Mind Control"] = "精神控制",
		["Mind Flay"] = "精神鞭笞",
		["Mind Mastery"] = "精通心靈",
		["Mind Soothe"] = "安撫心靈",
		["Mind Vision"] = "心靈幻象",
		["Mind-numbing Poison"] = "麻?毒藥",
		["Mind-numbing Poison II"] = "麻?毒藥 II",
		["Mind-numbing Poison III"] = "麻?毒藥 III",
		["Mining"] = "採?",
		["Misdirection"] = "誤導",
		["Misery"] = "苦難",
		["Mocking Blow"] = "懲戒痛擊",
		["Molten Armor"] = "熔火護甲",
		["Molten Fury"] = "熔岩之怒",
		["Mongoose Bite"] = "???咬",
		["Monster Slaying"] = "怪物殺手",
		["Moonfire"] = "月火術",
		["Moonfury"] = "月怒",
		["Moonglow"] = "月光",
		["Moonkin Aura"] = "梟獸光環",
		["Moonkin Form"] = "梟獸形態",
		["Mortal Shots"] = "致死射擊",
		["Mortal Strike"] = "致死打擊",
		["Multi-Shot"] = "多重射擊",
		["Murder"] = "謀殺",
		["Mutilate"] = "截肢",
		["Natural Armor"] = "自然護甲",
		["Natural Perfection"] = "自然完美",
		["Natural Shapeshifter"] = "自然變形",
		["Naturalist"] = "?化治療之觸",
		["Nature Resistance"] = "自然抗性",
		["Nature Resistance Totem"] = "自然抗性圖騰",
		["Nature Weakness"] = "自然虛弱",
		["Nature's Focus"] = "自然集中",
		["Nature's Grace"] = "自然之賜",
		["Nature's Grasp"] = "自然之握",
		["Nature's Guidance"] = "自然引導",
		["Nature's Reach"] = "自然延伸",
		["Nature's Swiftness"] = "自然迅捷",
		["Negative Charge"] = "負級效應",
		["Nether Protection"] = "虛空保護",
		["Netherstorm Flag"] = "虛空風暴旗標",
		["Nightfall"] = "夜幕",
		["Nurturing Instinct"] = "培育天性",
		["Omen of Clarity"] = "??預兆",
		["One-Handed Axes"] = "單手斧",
		["One-Handed Maces"] = "單手錘",
		["One-Handed Swords"] = "單手劍",
		["One-Handed Weapon Specialization"] = "單手武器專精",
		["Opening"] = "開?",
		["Opening - No Text"] = "開? - 無文字",
		["Opportunity"] = "伺機而動",
		["Overpower"] = "壓制",
		["Pain Suppression"] = "痛苦?壓",
		["Panic"] = "恐慌",
		["Paranoia"] = "多疑",
		["Parasitic Shadowfiend"] = "寄生暗影惡魔",
		["Parry"] = "招架",
		["Pathfinding"] = "尋路",
		["Perceived Weakness"] = "察覺弱點",
		["Perception"] = "感知",
		["Permafrost"] = "極寒?霜",
		["Pet Aggression"] = "寵物好?",
		["Pet Hardiness"] = "寵物耐久",
		["Pet Recovery"] = "寵物恢復",
		["Pet Resistance"] = "寵物抗性",
		["Phase Shift"] = "相位變換",
		["Pick Lock"] = "開鎖",
		["Pick Pocket"] = "?竊",
		["Piercing Howl"] = "刺耳怒吼",
		["Piercing Ice"] = "刺骨寒?",
		["Plate Mail"] = "鎧甲",
		["Playing with Fire"] = "玩火",
		["Poison Cleansing Totem"] = "?毒圖騰",
		["Poison Spit"] = "毒液噴射",
		["Poisons"] = "毒藥",
		["Polearms"] = "長柄武器",
		["Poleaxe Specialization"] = "長柄和斧專精",
		["Polymorph"] = "變形術",
		["Polymorph: Pig"] = "變?術",
		["Polymorph: Turtle"] = "變龜術",
		["Portal: Darnassus"] = "傳送門:達納蘇斯",
		["Portal: Exodar"] = "傳送門:艾克索達",
		["Portal: Ironforge"] = "傳送門:鐵爐堡",
		["Portal: Orgrimmar"] = "傳送門:奧格瑪",
		["Portal: Shattrath"] = "傳送門:撒塔斯",
		["Portal: Silvermoon"] = "傳送門:銀月城",
		["Portal: Stormwind"] = "傳送門:暴風城",
		["Portal: Thunder Bluff"] = "傳送門:雷霆崖",
		["Portal: Undercity"] = "傳送門:幽暗城",
		["Positive Charge"] = "正級效應",
		["Pounce"] = "突襲",
		["Pounce Bleed"] = "血襲",
		["Power Infusion"] = "注入能量",
		["Power Word: Fortitude"] = "?言術:?",
		["Power Word: Shield"] = "?言術:盾",
		["Prayer of Fortitude"] = "堅?禱言",
		["Prayer of Healing"] = "治療禱言",
		["Prayer of Mending"] = "癒合禱言",
		["Prayer of Shadow Protection"] = "暗影防護禱言",
		["Prayer of Spirit"] = "精神禱言",
		["Precision"] = "精準",
		["Predatory Instincts"] = "猛獸天性",
		["Predatory Strikes"] = "猛獸攻擊",
		["Premeditation"] = "預謀",
		["Preparation"] = "準備",
		["Presence of Mind"] = "氣定神閒",
		["Primal Fury"] = "原始狂怒",
		["Prismatic Cloak"] = "稜彩庇護",
		["Profession Trainers"] = "專業訓練師",
		["Prospecting"] = "勘探",
		["Prowl"] = "潛行",
		["Psychic Scream"] = "心靈尖嘯",
		["Pummel"] = "拳擊",
		["Purge"] = "淨化術",
		["Purification"] = "淨化",
		["Purify"] = "純淨術",
		["Purifying Power"] = "淨化能量",
		["Pursuit of Justice"] = "正義追擊",
		["Pyroblast"] = "炎爆術",
		["Pyroclasm"] = "火焰衝撞",
		["Pyromaniac"] = "火焰狂熱",
		["Quick Recovery"] = "快速恢復",
		["Quick Shots"] = "快速射擊",
		["Quickness"] = "迅捷",
		["Rage of the Unraveller"] = "破壞者之怒",
		["Rain of Fire"] = "火焰之雨",
		["Rake"] = "掃擊",
		["Ram Riding"] = "騎術:羊",
		["Rampage"] = "暴怒",
		["Ranged Weapon Specialization"] = "遠程武器專精",
		["Rapid Fire"] = "急速射擊",
		["Rapid Killing"] = "急速殺戮",
		["Raptor Riding"] = "騎術:迅猛龍",
		["Raptor Strike"] = "猛禽一擊",
		["Ravage"] = "?滅",
		["Readiness"] = "準備就?",
		["Reagents"] = "藥劑",
		["Rebirth"] = "復生",
		["Reckless Charge"] = "無畏衝鋒",
		["Recklessness"] = "魯莽",
		["Reckoning"] = "?算",
		["Redemption"] = "救贖",
		["Redoubt"] = "盾牌壁壘",
		["Reflection"] = "反射",
		["Regeneration"] = "再生",
		["Regrowth"] = "癒合",
		["Reincarnation"] = "復生效果",
		["Reinforced Shield"] = "?化盾牌",
		["Rejuvenation"] = "回春術",
		["Relentless Strikes"] = "無情打擊",
		["Remorseless"] = "冷酷",
		["Remorseless Attacks"] = "冷酷攻擊",
		["Remote Toy"] = "遙控玩具",
		["Remove Curse"] = "解除詛?",
		["Remove Insignia"] = "解除徽記",
		["Remove Lesser Curse"] = "解除次級詛?",
		["Rend"] = "?裂",
		["Renew"] = "恢復",
		["Repair"] = "修理",
		["Repentance"] = "懺悔",
		["Restless Strength"] = "充沛之力",
		["Restorative Totems"] = "?化恢復系圖騰",
		["Resurrection"] = "復活術",
		["Retaliation"] = "反擊風暴",
		["Retribution Aura"] = "懲罰光環",
		["Revenge"] = "復仇",
		["Revenge Stun"] = "復仇昏迷",
		["Reverberation"] = "?響",
		["Revive Pet"] = "復活寵物",
		["Righteous Defense"] = "正義防禦",
		["Righteous Fury"] = "正義之怒",
		["Rip"] = "??",
		["Riposte"] = "還擊",
		["Ritual of Doom"] = "末日儀式",
		["Ritual of Doom Effect"] = "末日儀式效果",
		["Ritual of Souls"] = "靈魂儀式",
		["Ritual of Summoning"] = "召喚儀式",
		["Rockbiter Weapon"] = "石化武器",
		["Rough Sharpening Stone"] = "劣質磨刀石",
		["Ruin"] = "?滅",
		["Rupture"] = "割裂",
		["Ruthlessness"] = "無情",
		["Sacrifice"] = "犧牲",
		["Safe Fall"] = "安全降落",
		["Sanctified Crusader"] = "聖化十字軍",
		["Sanctified Judgement"] = "聖化審判",
		["Sanctified Light"] = "聖化之光",
		["Sanctity Aura"] = "聖潔光環",
		["Sap"] = "悶棍",
		["Savage Fury"] = "野蠻暴怒",
		["Savage Strikes"] = "猛烈?擊",
		["Scare Beast"] = "恐?野獸",
		["Scatter Shot"] = "驅散射擊",
		["Scorch"] = "灼燒",
		["Scorpid Poison"] = "?毒",
		["Scorpid Sting"] = "毒?釘刺",
		["Screech"] = "尖嘯",
		["Seal Fate"] = "封印命運",
		["Seal of Blood"] = "血之聖印",
		["Seal of Command"] = "命令聖印",
		["Seal of Justice"] = "公正聖印",
		["Seal of Light"] = "光明聖印",
		["Seal of Righteousness"] = "正義聖印",
		["Seal of Vengeance"] = "復仇聖印",
		["Seal of Wisdom"] = "智慧聖印",
		["Seal of the Crusader"] = "十字軍聖印",
		["Searing Light"] = "灼熱之光",
		["Searing Pain"] = "灼熱之痛",
		["Searing Totem"] = "灼熱圖騰",
		["Second Wind"] = "復甦之風",
		["Seduction"] = "誘惑",
		["Seed of Corruption"] = "腐蝕種子",
		["Seethe"] = "激動",
		["Sense Demons"] = "感知惡魔",
		["Sense Undead"] = "感知不死生物",
		["Sentry Totem"] = "崗哨圖騰",
		["Serpent Sting"] = "毒蛇釘刺",
		["Serrated Blades"] = "鋸刃",
		["Setup"] = "算計",
		["Shackle Undead"] = "束縛不死生物",
		["Shadow Affinity"] = "暗影親和",
		["Shadow Bolt"] = "暗影箭",
		["Shadow Embrace"] = "暗影之擁",
		["Shadow Focus"] = "暗影集中",
		["Shadow Mastery"] = "精通暗影",
		["Shadow Power"] = "暗影?化",
		["Shadow Protection"] = "暗影防護",
		["Shadow Reach"] = "暗影延伸",
		["Shadow Resistance"] = "暗影抗性",
		["Shadow Resistance Aura"] = "暗影抗性光環",
		["Shadow Trance"] = "暗影冥思",
		["Shadow Vulnerability"] = "暗影易傷",
		["Shadow Ward"] = "防護暗影結界",
		["Shadow Weakness"] = "暗影虛弱",
		["Shadow Weaving"] = "暗影交織",
		["Shadow Word: Death"] = "暗言術:死",
		["Shadow Word: Pain"] = "暗言術:痛",
		["Shadow and Flame"] = "暗影與火焰",
		["Shadow of Death"] = "死亡之影",
		["Shadowburn"] = "暗影灼燒",
		["Shadowfiend"] = "暗影惡魔",
		["Shadowform"] = "暗影形態",
		["Shadowfury"] = "暗影之怒",
		["Shadowguard"] = "暗影守衛",
		["Shadowmeld"] = "影遁",
		["Shadowmeld Passive"] = "影遁",
		["Shadowstep"] = "暗影閃現",
		["Shamanistic Rage"] = "薩滿之怒",
		["Sharpened Claws"] = "鋒利獸爪",
		["Shatter"] = "碎?",
		["Shell Shield"] = "甲殼護盾",
		["Shield"] = "盾牌",
		["Shield Bash"] = "盾擊",
		["Shield Bash - Silenced"] = "盾擊 - ?默",
		["Shield Block"] = "盾牌格?",
		["Shield Slam"] = "盾牌猛擊",
		["Shield Specialization"] = "盾牌專精",
		["Shield Wall"] = "盾牆",
		["Shiv"] = "毒襲",
		["Shoot"] = "射擊",
		["Shoot Bow"] = "弓射擊",
		["Shoot Gun"] = "火槍射擊",
		["Shred"] = "?碎",
		["Shredding Attacks"] = "?碎攻擊",
		["Silence"] = "?默",
		["Silencing Shot"] = "?默射擊",
		["Silent Resolve"] = "無聲消退",
		["Silverwing Flag"] = "銀翼旌旗",
		["Sinister Strike"] = "邪惡攻擊",
		["Siphon Life"] = "生命虹吸",
		["Skinning"] = "剝皮",
		["Slam"] = "猛擊",
		["Slayer's Crest"] = "屠殺紋飾",
		["Sleep"] = "催眠術",
		["Slice and Dice"] = "切割",
		["Slow"] = "減速術",
		["Slow Fall"] = "緩落術",
		["Smelting"] = "熔煉",
		["Smite"] = "懲擊",
		["Snake Trap"] = "毒蛇陷?",
		["Solid Sharpening Stone"] = "堅固的磨刀石",
		["Sonic Burst"] = "音爆",
		["Soothe Animal"] = "安撫動物",
		["Soothing Kiss"] = "安撫之吻",
		["Soul Fire"] = "靈魂之火",
		["Soul Leech"] = "靈魂汲取",
		["Soul Link"] = "靈魂?結",
		["Soul Siphon"] = "靈魂虹吸",
		["Soulshatter"] = "靈魂粉碎",
		["Soulstone Resurrection"] = "靈魂石復活",
		["Spell Haste"] = "施法加速",
		["Spell Lock"] = "法術封鎖",
		["Spell Power"] = "法術能量",
		["Spell Reflection"] = "法術反射",
		["Spell Vulnerability"] = "法術易傷",
		["Spell Warding"] = "抗法結界",
		["Spellsteal"] = "法術竊取",
		["Spirit Bond"] = "靈魂聯結",
		["Spirit Tap"] = "精神分流",
		["Spirit of Redemption"] = "救贖之靈",
		["Spiritual Attunement"] = "精神調和",
		["Spiritual Focus"] = "精神集中",
		["Spiritual Guidance"] = "精神導引",
		["Spiritual Healing"] = "精神治療",
		["Spiteful Fury"] = "惡意的憤怒",
		["Sprint"] = "疾?",
		["StableMaster"] = "獸欄管理員",
		["Stance Mastery"] = "精通姿態",
		["Starfire"] = "星火術",
		["Starfire Stun"] = "星火昏迷",
		["Starlight Wrath"] = "?化憤怒",
		["Starshards"] = "星辰裂片",
		["Static Charge"] = "靜電衝鋒",
		["Staves"] = "法杖",
		["Steady Shot"] = "穩固射擊",
		["Stealth"] = "潛行",
		["Stoneclaw Stun"] = "石爪昏迷",
		["Stoneclaw Totem"] = "石爪圖騰",
		["Stoneform"] = "石像形態",
		["Stoneskin"] = "石甲術",
		["Stoneskin Totem"] = "石甲圖騰",
		["Stormstrike"] = "風暴打擊",
		["Strength of Earth"] = "大地之力",
		["Strength of Earth Totem"] = "大地之力圖騰",
		["Strength of the Halaani"] = "哈剌尼之力",
		["Stuck"] = "?死",
		["Stun"] = "擊昏",
		["Subtlety"] = "微妙",
		["Suffering"] = "受難",
		["Summon Charger"] = "召喚戰馬",
		["Summon Dreadsteed"] = "召喚恐懼戰馬",
		["Summon Felguard"] = "召喚惡魔守衛",
		["Summon Felhunter"] = "召喚惡魔獵犬",
		["Summon Felsteed"] = "召喚惡魔戰馬",
		["Summon Imp"] = "召喚小鬼",
		["Summon Succubus"] = "召喚魅魔",
		["Summon Voidwalker"] = "召喚虛無行者",
		["Summon Warhorse"] = "召喚戰馬",
		["Summon Water Elemental"] = "召喚水元素",
		["Sunder Armor"] = "破甲攻擊",
		["Suppression"] = "?壓",
		["Surefooted"] = "穩固",
		["Surge of Light"] = "光之澎湃",
		["Surprise Attacks"] = "出奇攻擊",
		["Survivalist"] = "生存專家",
		["Sweeping Strikes"] = "橫掃攻擊",
		["Swift Flight Form"] = "迅捷飛行形態",
		["Swiftmend"] = "迅癒",
		["Swipe"] = "揮擊",
		["Sword Specialization"] = "劍類武器專精",
		["Symbol of Hope"] = "希望符記",
		["Tactical Mastery"] = "精通戰術",
		["Tailoring"] = "裁縫",
		["Tainted Blood"] = "腐壞之血",
		["Tainted Mind"] = "?濁之魂",
		["Tame Beast"] = "馴服野獸",
		["Taunt"] = "嘲諷",
		["Teleport: Darnassus"] = "傳送:達納蘇斯",
		["Teleport: Exodar"] = "傳送:艾克索達",
		["Teleport: Ironforge"] = "傳送:鐵爐堡",
		["Teleport: Moonglade"] = "傳送:月光林地",
		["Teleport: Orgrimmar"] = "傳送:奧格瑪",
		["Teleport: Shattrath"] = "傳送:撒塔斯",
		["Teleport: Silvermoon"] = "傳送:銀月城",
		["Teleport: Stormwind"] = "傳送:暴風城",
		["Teleport: Thunder Bluff"] = "傳送:雷霆崖",
		["Teleport: Undercity"] = "傳送:幽暗城",
		["Temporal Rift"] = "時光裂縫",
		["The Beast Within"] = "獸心",
		["The Human Spirit"] = "人類精魂",
		["Thick Hide"] = "厚皮",
		["Thorns"] = "荊棘術",
		["Thrill of the Hunt"] = "追獵回饋",
		["Throw"] = "投擲",
		["Throwing Specialization"] = "投擲專精",
		["Thrown"] = "投擲武器",
		["Thunder Clap"] = "雷霆一擊",
		["Thunderfury"] = "雷霆之怒",
		["Thundering Strikes"] = "雷鳴猛擊",
		["Thunderstomp"] = "雷霆踐踏",
		["Tidal Focus"] = "潮汐集中",
		["Tidal Mastery"] = "精通潮汐",
		["Tiger Riding"] = "騎術:豹",
		["Tiger's Fury"] = "猛虎之怒",
		["Time's Favor"] = "時間的恩惠",
		["Torment"] = "折磨",
		["Totem"] = "圖騰",
		["Totem of Wrath"] = "憤怒圖騰",
		["Totemic Call"] = "圖騰的呼喚",
		["Totemic Focus"] = "圖騰集中",
		["Touch of Shadow"] = "暗影之觸",
		["Touch of Weakness"] = "虛弱之觸",
		["Toughness"] = "堅?",
		["Traces of Silithyst"] = "希利蘇斯的痕跡",
		["Track Beasts"] = "追?野獸",
		["Track Demons"] = "追?惡魔",
		["Track Dragonkin"] = "追?龍類",
		["Track Elementals"] = "追?元素生物",
		["Track Giants"] = "追?巨人",
		["Track Hidden"] = "追?隱藏生物",
		["Track Humanoids"] = "追?人型生物",
		["Track Undead"] = "追?不死生物",
		["Tranquil Air"] = "寧靜之風",
		["Tranquil Air Totem"] = "寧靜之風圖騰",
		["Tranquil Spirit"] = "寧靜之魂",
		["Tranquility"] = "寧靜",
		["Tranquilizing Shot"] = "寧神射擊",
		["Trap Mastery"] = "精通陷?",
		["Travel Form"] = "旅行形態",
		["Tree of Life"] = "生命之樹",
		["Tremor Totem"] = "戰慄圖騰",
		["Tribal Leatherworking"] = "部族製皮",
		["Trueshot Aura"] = "?擊光環",
		["Turn Undead"] = "超渡不死生物",
		["Twin Spire Blessing"] = "雙塔祝福",
		["Two-Handed Axes"] = "雙手斧",
		["Two-Handed Axes and Maces"] = "雙手斧和錘",
		["Two-Handed Maces"] = "雙手錘",
		["Two-Handed Swords"] = "雙手劍",
		["Two-Handed Weapon Specialization"] = "雙手武器專精",
		["Unarmed"] = "徒手戰?",
		["Unbreakable Will"] = "堅定意志",
		["Unbridled Wrath"] = "怒不可?",
		["Undead Horsemanship"] = "騎術:骸骨戰馬",
		["Underwater Breathing"] = "水下呼吸",
		["Unending Breath"] = "魔息術",
		["Unholy Power"] = "邪惡?化",
		["Unleashed Fury"] = "狂怒釋放",
		["Unleashed Rage"] = "怒不可抑",
		["Unstable Affliction"] = "痛苦動?",
		["Unstable Power"] = "能量無常",
		["Unyielding Faith"] = "不滅信仰",
		["Vampiric Embrace"] = "吸血鬼的擁抱",
		["Vampiric Touch"] = "吸血之觸",
		["Vanish"] = "消失",
		["Vanished"] = "消失",
		["Vengeance"] = "復仇",
		["Venomous Totem"] = "毒性圖騰",
		["Victory Rush"] = "勝利衝擊",
		["Vigor"] = "精力",
		["Vile Beam"] = "卑鄙波動",
		["Vile Poisons"] = "惡性毒藥",
		["Vindication"] = "辯護",
		["Viper Sting"] = "?蛇釘刺",
		["Volley"] = "亂射",
		["Wand Specialization"] = "魔杖專精",
		["Wands"] = "魔杖",
		["War Stomp"] = "戰爭踐踏",
		["Warp"] = "?曲傳送",
		["Warsong Flag"] = "戰歌旌旗",
		["Water Breathing"] = "水下呼吸",
		["Water Shield"] = "水之盾",
		["Water Tomb"] = "水之墳",
		["Water Walking"] = "水上行走",
		["Waterbolt"] = "水箭",
		["Watery Grave"] = "水之墓",
		["Weakened Soul"] = "虛弱靈魂",
		["Weapon Mastery"] = "精通武器",
		["Weaponsmith"] = "武器鑄造",
		["Whirlwind"] = "旋風斬",
		["Will of the Forsaken"] = "亡靈意志",
		["Windfury"] = "風怒",
		["Windfury Attack"] = "風怒攻擊",
		["Windfury Totem"] = "風怒圖騰",
		["Windfury Weapon"] = "風怒武器",
		["Windwall"] = "風牆",
		["Windwall Totem"] = "風牆圖騰",
		["Wing Clip"] = "?絆",
		["Winter's Chill"] = "深冬之寒",
		["Wisp Spirit"] = "幽光之魂",
		["Wolf Riding"] = "騎術:狼",
		["Wound Poison"] = "致傷毒藥",
		["Wound Poison II"] = "致傷毒藥 II",
		["Wound Poison III"] = "致傷毒藥 III",
		["Wound Poison IV"] = "致傷毒藥 IV",
		["Wound Poison V"] = "致傷毒藥 V",
		["Wrath"] = "憤怒",
		["Wrath of Air Totem"] = "風懲圖騰",
		["Wrath of Cenarius"] = "塞納留斯之怒",
		["Wrath of the Astromancer"] = "星術師之怒",
		["Wyvern Sting"] = "翼龍釘刺",
	}
elseif GAME_LOCALE == "koKR" then
	lib:SetCurrentTranslations {
		["Abolish Disease"] = "질병 해제",
		["Abolish Poison"] = "독 해제",
		["Abolish Poison Effect"] = "독 해제 효과",
		["Activate MG Turret"] = "기관포",
		["Adrenaline Rush"] = "아드레날린 촉진",
		["Aftermath"] = "재앙의 여파",
		["Aggression"] = "공격성",
		["Aimed Shot"] = "조준 사격",
		["Alchemy"] = "연금술",
		["Ambush"] = "매복",
		["Ammunition"] = "탄약",  -- Check
		["Amplify Curse"] = "저주 증폭",
		["Amplify Magic"] = "마법 증폭",
		["Ancestral Fortitude"] = "선인의 인내력",
		["Ancestral Healing"] = "선인의 치유력",
		["Ancestral Knowledge"] = "선인의 지혜",
		["Ancestral Spirit"] = "고대의 영혼",
		["Ancient Hysteria"] = "고대의 격분",
		["Anesthetic Poison"] = "정신 마취 독",
		["Anger Management"] = "분노 제어",
		["Anguish"] = "고뇌",
		["Anticipation"] = "직감",
		["Aquatic Form"] = "바다표범 변신",
		["Arcane Blast"] = "비전 작렬",
		["Arcane Brilliance"] = "신비한 총명함",
		["Arcane Concentration"] = "신비한 정신집중",
		["Arcane Energy"] = "비전 에너지",
		["Arcane Explosion"] = "신비한 폭발",
		["Arcane Focus"] = "신비한 집중",
		["Arcane Fortitude"] = "신비한 인내력",
		["Arcane Impact"] = "신비한 충돌",
		["Arcane Instability"] = "신비한 불안정성",
		["Arcane Intellect"] = "신비한 지능",
		["Arcane Meditation"] = "신비한 명상",
		["Arcane Mind"] = "신비한 정신",
		["Arcane Missiles"] = "신비한 화살",
		["Arcane Potency"] = "신비한 잠재력",
		["Arcane Power"] = "신비의 마법 강화",
		["Arcane Resistance"] = "비전 저항력",
		["Arcane Shot"] = "신비한 사격",
		["Arcane Shroud"] = "신비의 장막",
		["Arcane Subtlety"] = "신비한 미묘함",
		["Arcane Torrent"] = "비전 격류",
		["Arcane Weakness"] = "비전 약점",
		["Arctic Reach"] = "혹한의 손길",
		["Arctic Winds"] = "북극의 바람",
		["Armor of Faith"] = "신념의 갑옷",
		["Armorsmith"] = "방어구제작",
		["Aspect of the Beast"] = "야수의 상",
		["Aspect of the Cheetah"] = "치타의 상",
		["Aspect of the Hawk"] = "매의 상",
		["Aspect of the Monkey"] = "원숭이의 상",
		["Aspect of the Pack"] = "치타 무리의 상",
		["Aspect of the Viper"] = "독사의 상",
		["Aspect of the Wild"] = "야생의 상",
		["Astral Recall"] = "영혼의 귀환",
		["Attack"] = "공격",
		["Attacking"] = "파괴 중",
		["Auto Shot"] = "자동 사격",
		["Avenger's Shield"] = "응징의 방패",
		["Avenging Wrath"] = "응징의 격노",
		["Avoidance"] = "마력 회피",
		["Axe Specialization"] = "도끼류 전문화",
		["Backlash"] = "반발력",
		["Backstab"] = "기습",
		["Badge of the Swarmguard"] = "전투감시병의 휘장",
		["Balance of Power"] = "힘의 균형",
		["Bane"] = "파멸",
		["Banish"] = "추방",
		["Banker"] = "은행원",
		["Banshee Curse"] = "밴시의 저주",
		["Barkskin"] = "나무 껍질",
		["Barrage"] = "탄막",
		["Bash"] = "강타",
		["Basic Campfire"] = "작은 모닥불",
		["Battle Rush"] = "전투 돌격",
		["Battle Shout"] = "전투의 외침",
		["Battle Stance"] = "전투 태세",
		["Battle Stance Passive"] = "전투 태세",
		["BattleMaster"] = "전투의 대가",  -- Check 2.3 패치 미니맵 찾기 기능? 전투모병관?
		["Bear Form"] = "곰 변신",
		["Beast Lore"] = "야수 연구",
		["Beast Slaying"] = "야수 사냥 전문화",
		["Beast Training"] = "야수 조련",
		["Benediction"] = "축복의 기도",
		["Berserker Rage"] = "광전사의 격노",
		["Berserker Stance"] = "광폭 태세",
		["Berserker Stance Passive"] = "광폭 태세 지속효과",
		["Berserking"] = "광폭화",
		["Bestial Discipline"] = "야수 훈련",
		["Bestial Swiftness"] = "야수의 신속함",
		["Bestial Wrath"] = "야수의 격노",
		["Binding Heal"] = "결속의 치유",
		["Bite"] = "물기",
		["Black Arrow"] = "검은 화살",
		["Blackout"] = "의식 상실",
		["Blacksmithing"] = "대장기술",
		["Blade Flurry"] = "폭풍의 칼날",
		["Blade Turning"] = "칼날 전환",
		["Blade Twisting"] = "칼날 비틀기",
		["Blast Wave"] = "화염 폭풍",
		["Blazing Speed"] = "타오르는 속도",
		["Blessed Recovery"] = "축복받은 회복력",
		["Blessed Resilience"] = "축복받은 탄력성",
		["Blessing of Auchindoun"] = "아킨둔의 축복",
		["Blessing of Freedom"] = "자유의 축복",
		["Blessing of Kings"] = "왕의 축복",
		["Blessing of Light"] = "빛의 축복",
		["Blessing of Might"] = "힘의 축복",
		["Blessing of Protection"] = "보호의 축복",
		["Blessing of Sacrifice"] = "희생의 축복",
		["Blessing of Salvation"] = "구원의 축복",
		["Blessing of Sanctuary"] = "성역의 축복",
		["Blessing of Wisdom"] = "지혜의 축복",
		["Blind"] = "실명",
		["Blinding Powder"] = "실명 가루",
		["Blink"] = "점멸",
		["Blizzard"] = "눈보라",
		["Block"] = "방어",
		["Blood Craze"] = "피의 광기",
		["Blood Frenzy"] = "피의 광기",
		["Blood Fury"] = "피의 격노",
		["Blood Pact"] = "피의 서약",
		["Bloodlust"] = "피의 욕망",
		["Bloodrage"] = "피의 분노",
		["Bloodthirst"] = "피의 갈증",
		["Boar Charge"] = "멧돼지 돌진",
		["Booming Voice"] = "우렁찬 음성",
		["Bow Specialization"] = "활류 전문화",
		["Bows"] = "활",
		["Bright Campfire"] = "밝은 모닥불",
		["Brittle Armor"] = "불완전한 갑옷",
		["Brutal Impact"] = "야수의 습격",
		["Burning Adrenaline"] = "불타는 아드레날린",
		["Burning Soul"] = "불타는 영혼",
		["Burning Wish"] = "불타는 소원",
		["Call Pet"] = "야수 부르기",
		["Call of Flame"] = "불꽃의 부름",
		["Call of Thunder"] = "천둥의 부름",
		["Call of the Nexus"] = "연합의 부름",
		["Camouflage"] = "위장술",
		["Cannibalize"] = "시체먹기",
		["Cat Form"] = "표범 변신",
		["Cataclysm"] = "재앙",
		["Celestial Focus"] = "하늘의 정신 집중",
		["Chain Heal"] = "연쇄 치유",
		["Chain Lightning"] = "연쇄 번개",
		["Challenging Roar"] = "도전의 포효",
		["Challenging Shout"] = "도전의 외침",
		["Charge"] = "돌진",
		["Charge Rage Bonus Effect"] = "보너스 분노 충전 효과",
		["Charge Stun"] = "돌진 기절",
		["Cheap Shot"] = "비열한 습격",
		["Chilled"] = "빙결",
		["Circle of Healing"] = "치유의 마법진",
		["Class Trainer"] = "직업 상급자",
		["Claw"] = "할퀴기",
		["Cleanse"] = "정화",
		["Clearcasting"] = "정신 집중",
		["Cleave"] = "회전베기",
		["Clever Traps"] = "덫 개량",
		["Cloak of Shadows"] = "그림자 망토",
		["Closing"] = "닫는 중",
		["Cloth"] = "천",
		["Coarse Sharpening Stone"] = "일반 숫돌",
		["Cobra Reflexes"] = "코브라의 반사신경",
		["Cold Blood"] = "냉혈",
		["Cold Snap"] = "매서운 한파",
		["Combat Endurance"] = "전투 지구력",
		["Combustion"] = "발화",
		["Command"] = "지배",
		["Commanding Presence"] = "위엄 있는 풍채",
		["Commanding Shout"] = "지휘의 외침",
		["Concentration Aura"] = "집중의 오라",
		["Concussion"] = "촉발",
		["Concussion Blow"] = "충격의 일격",
		["Concussive Barrage"] = "집중 포화",
		["Concussive Shot"] = "충격포",
		["Cone of Cold"] = "냉기 돌풍",
		["Conflagrate"] = "점화",
		["Conflagration"] = "거대한 불길",
		["Conjure Food"] = "음식 창조",
		["Conjure Mana Agate"] = "마나 마노 창조",
		["Conjure Mana Citrine"] = "마나 황수정 창조",
		["Conjure Mana Emerald"] = "마나 에메랄드 창조",
		["Conjure Mana Jade"] = "마나 비취 창조",
		["Conjure Mana Ruby"] = "마나 루비 창조",
		["Conjure Water"] = "음료 창조",
		["Consecration"] = "신성화",
		["Consume Magic"] = "마법 삼키기",
		["Consume Shadows"] = "어둠 흡수",
		["Contagion"] = "전염",
		["Convection"] = "기의 흐름",
		["Conviction"] = "자각",
		["Cooking"] = "요리",
		["Corruption"] = "부패",
		["Counterattack"] = "역습",
		["Counterspell"] = "마법 차단",
		["Counterspell - Silenced"] = "마법 차단 - 침묵",
		["Cower"] = "웅크리기",
		["Create Firestone"] = "화염석 창조",
		["Create Firestone (Greater)"] = "화염석 창조 (상급)",
		["Create Firestone (Lesser)"] = "화염석 창조 (하급)",
		["Create Firestone (Major)"] = "화염석 창조 (최상급)",
		["Create Healthstone"] = "생명석 창조",
		["Create Healthstone (Greater)"] = "생명석 창조 (상급)",
		["Create Healthstone (Lesser)"] = "생명석 창조 (하급)",
		["Create Healthstone (Major)"] = "생명석 창조 (최상급)",
		["Create Healthstone (Minor)"] = "생명석 창조 (최하급)",
		["Create Soulstone"] = "영혼석 창조",
		["Create Soulstone (Greater)"] = "영혼석 창조 (상급)",
		["Create Soulstone (Lesser)"] = "영혼석 창조 (하급)",
		["Create Soulstone (Major)"] = "영혼석 창조 (최상급)",
		["Create Soulstone (Minor)"] = "영혼석 창조 (최하급)",
		["Create Spellstone"] = "주문석 창조",
		["Create Spellstone (Greater)"] = "주문석 창조 (상급)",
		["Create Spellstone (Major)"] = "주문석 창조 (최상급)",
		["Create Spellstone (Master)"] = "주문석 창조 (일급)",
		["Cripple"] = "신경 마비",
		["Crippling Poison"] = "신경 마비 독",
		["Crippling Poison II"] = "신경 마비 독 II",
		["Critical Mass"] = "화염 결집",
		["Crossbows"] = "석궁",
		["Cruelty"] = "무자비함",
		["Crusade"] = "성전",
		["Crusader Aura"] = "성전사의 오라",
		["Crusader Strike"] = "성전사의 일격",
		["Cultivation"] = "재배",
		["Cure Disease"] = "질병 치료",
		["Cure Poison"] = "해독",
		["Curse of Agony"] = "고통의 저주",
		["Curse of Doom"] = "파멸의 저주",
		["Curse of Doom Effect"] = "파멸의 저주 효과",
		["Curse of Exhaustion"] = "피로의 저주",
		["Curse of Idiocy"] = "무지의 저주",
		["Curse of Recklessness"] = "무모함의 저주",
		["Curse of Shadow"] = "어둠의 저주",
		["Curse of Tongues"] = "언어의 저주",
		["Curse of Weakness"] = "무력화 저주",
		["Curse of the Elements"] = "원소의 저주",
		["Cyclone"] = "회오리바람",
		["Dagger Specialization"] = "단검류 전문화",
		["Daggers"] = "단검",
		["Dampen Magic"] = "마법 감쇠",
		["Dark Pact"] = "암흑의 계약",
		["Darkness"] = "어둠",
		["Dash"] = "질주",
		["Dawnstone Crab"] = "여명석 게",
		["Dazed"] = "멍해짐",
		["Deadly Interrupt Effect"] = "죽음의 투척 방해 효과",
		["Deadly Poison"] = "맹독",
		["Deadly Poison II"] = "맹독 II",
		["Deadly Poison III"] = "맹독 III",
		["Deadly Poison IV"] = "맹독 IV",
		["Deadly Poison V"] = "맹독 V",
		["Deadly Poison VI"] = "맹독 VI",
		["Deadly Poison VII"] = "맹독 VII",
		["Deadly Throw"] = "죽음의 투척",
		["Death Coil"] = "죽음의 고리",
		["Death Wish"] = "죽음의 소원",
		["Deep Wound"] = "치명상",
		["Deep Wounds"] = "치명상",
		["Defense"] = "방어",
		["Defensive Stance"] = "방어 태세",
		["Defensive Stance Passive"] = "방어 태세 지속효과",
		["Defiance"] = "도전",
		["Deflection"] = "재빠른 손놀림",
		["Delusions of Jin'do"] = "진도의 망상",
		["Demon Armor"] = "악마의 갑옷",
		["Demon Skin"] = "악마의 피부",
		["Demonic Aegis"] = "악마의 보호",
		["Demonic Embrace"] = "악마의 은총",
		["Demonic Frenzy"] = "악마의 광기",
		["Demonic Knowledge"] = "악마의 지식",
		["Demonic Resilience"] = "악마의 탄력성",
		["Demonic Sacrifice"] = "악의 제물",
		["Demonic Tactics"] = "악마의 술책",
		["Demoralizing Roar"] = "위협의 포효",
		["Demoralizing Shout"] = "사기의 외침",
		["Dense Sharpening Stone"] = "강도 높은 숫돌",
		["Desperate Prayer"] = "구원의 기도",
		["Destructive Reach"] = "파괴의 테두리",
		["Detect"] = "감지",
		["Detect Greater Invisibility"] = "상급 투명체 감지",
		["Detect Invisibility"] = "투명체 감지",
		["Detect Lesser Invisibility"] = "하급 투명체 감지",
		["Detect Magic"] = "마법 감지",
		["Detect Traps"] = "함정 감지",
		["Deterrence"] = "공격 저지",
		["Devastate"] = "압도",
		["Devastation"] = "황폐",
		["Devotion Aura"] = "기원의 오라",
		["Devour Magic"] = "마법 삼키기",
		["Devour Magic Effect"] = "마법 삼키기 효과",
		["Devouring Plague"] = "파멸의 역병",
		["Diplomacy"] = "외교",
		["Dire Bear Form"] = "광포한 곰 변신",
		["Dirty Deeds"] = "비열한 행위",
		["Dirty Tricks"] = "비열한 속임수",
		["Disarm"] = "무장 해제",
		["Disarm Trap"] = "함정 해제",
		["Disease Cleansing Totem"] = "질병 정화 토템",
		["Disenchant"] = "마력 추출",
		["Disengage"] = "철수",
		["Dismiss Pet"] = "야수 소환 해제",
		["Dispel Magic"] = "마법 무효화",
		["Distract"] = "혼란",
		["Distracting Shot"] = "견제 사격",
		["Dive"] = "급강하",
		["Divine Favor"] = "신의 은총",
		["Divine Fury"] = "신의 격노",
		["Divine Illumination"] = "신의 계시",
		["Divine Intellect"] = "천상의 지능",
		["Divine Intervention"] = "성스러운 중재",
		["Divine Protection"] = "신의 가호",
		["Divine Shield"] = "천상의 보호막",
		["Divine Spirit"] = "천상의 정신",
		["Divine Strength"] = "천상의 힘",
		["Divine Wrath"] = "신성한 격노",
		["Dodge"] = "회피",
		["Doomfire"] = "파멸의 불",
		["Dragon's Breath"] = "용의 숨결",
		["Dragonscale Leatherworking"] = "용비늘 가죽세공",
		["Drain Life"] = "생명력 흡수",
		["Drain Mana"] = "마나 흡수",
		["Drain Soul"] = "영혼 흡수",
		["Dreamless Sleep"] = "숙면",
		["Drink"] = "음료",
		["Dual Wield"] = "쌍수 무기",
		["Dual Wield Specialization"] = "쌍수 무기 전문화",
		["Duel"] = "주문 7266",
		["Dust Cloud"] = "먼지 구름",
		["Eagle Eye"] = "독수리의 눈",
		["Earth Elemental Totem"] = "대지의 정령 토템",
		["Earth Shield"] = "대지의 보호막",
		["Earth Shock"] = "대지 충격",
		["Earthbind"] = "대지의 속박",
		["Earthbind Totem"] = "속박의 토템",
		["Earthstrike"] = "대지의 격동",
		["Efficiency"] = "사격술",
		["Elemental Devastation"] = "자연의 파괴력",
		["Elemental Focus"] = "정기의 집중",
		["Elemental Fury"] = "자연의 격노",
		["Elemental Leatherworking"] = "원소 가죽세공",
		["Elemental Mastery"] = "정기의 깨달음",
		["Elemental Precision"] = "정기의 정밀함",
		["Elemental Sharpening Stone"] = "원소 숫돌",
		["Elemental Weapons"] = "자연의 무기",
		["Elune's Grace"] = "엘룬의 은총",
		["Elusiveness"] = "약삭빠름",
		["Emberstorm"] = "불보라",
		["Empowered Arcane Missiles"] = "신비한 화살 강화",
		["Empowered Corruption"] = "부패 강화",
		["Empowered Fireball"] = "화염구 강화",
		["Empowered Frostbolt"] = "얼음 화살 강화",
		["Empowered Healing"] = "치유 강화",
		["Empowered Rejuvenation"] = "회복 강화",
		["Empowered Touch"] = "치유의 손길 강화",
		["Enamored Water Spirit"] = "사로잡힌 물의 정령",
		["Enchanting"] = "마법부여",
		["Endurance"] = "인내력",
		["Endurance Training"] = "지구력 훈련",
		["Engineering"] = "기계공학",
		["Engineering Specialization"] = "기계공학 전문화",
		["Enrage"] = "분노",
		["Enriched Manna Biscuit"] = "맛좋은 만나빵",
		["Enslave Demon"] = "악마 지배",
		["Entangling Roots"] = "휘감는 뿌리",
		["Entrapment"] = "올가미",
		["Envenom"] = "독살",
		["Escape Artist"] = "탈출의 명수",
		["Evasion"] = "회피",
		["Eviscerate"] = "절개",
		["Evocation"] = "환기",
		["Execute"] = "마무리 일격",
		["Exorcism"] = "퇴마술",
		["Expansive Mind"] = "영리함",
		["Explosive Trap"] = "폭발의 덫",
		["Explosive Trap Effect"] = "폭발의 덫",
		["Expose Armor"] = "약점 노출",
		["Expose Weakness"] = "결점 노출",
		["Extract Gas"] = "가스 추출",
		["Eye for an Eye"] = "눈에는 눈",
		["Eye of Kilrogg"] = "킬로그의 눈",
		["Eye of the Storm"] = "폭풍의 눈",
		["Eyes of the Beast"] = "야수의 눈",
		["Fade"] = "소실",
		["Faerie Fire"] = "요정의 불꽃",
		["Faerie Fire (Feral)"] = "요정의 불꽃 (야성)",
		["Fanaticism"] = "광신",
		["Far Sight"] = "천리안",
		["Fatal Attraction"] = "치명적인 매력",
		["Fear"] = "공포",
		["Fear Ward"] = "공포의 수호물",
		["Feed Pet"] = "먹이주기",
		["Feed Pet Effect"] = "먹이주기 효과",
		["Feedback"] = "역순환",
		["Feign Death"] = "죽은척하기",
		["Feint"] = "교란",
		["Fel Armor"] = "마의 갑옷",
		["Fel Concentration"] = "마의 정신집중",
		["Fel Domination"] = "마의 지배",
		["Fel Energy"] = "마의 에너지",
		["Fel Intellect"] = "마의 지능",
		["Fel Rage"] = "마의 분노",
		["Fel Stamina"] = "마의 체력",
		["Felfire"] = "지옥불",
		["Feline Grace"] = "살쾡이의 우아함",
		["Feral Aggression"] = "야생의 공격성",
		["Feral Charge"] = "야성의 돌진",
		["Feral Instinct"] = "야생의 본능",
		["Feral Swiftness"] = "야생의 기민함",
		["Ferocious Bite"] = "흉포한 이빨",
		["Ferocious Inspiration"] = "야성의 감응",
		["Ferocity"] = "야수의 본성",
		["Fetish"] = "우상",
		["Find Fish"] = "물고기 찾기",
		["Find Herbs"] = "약초 찾기",
		["Find Minerals"] = "광물 찾기",
		["Find Treasure"] = "보물 찾기",
		["Find Weakness"] = "약점 포착",
		["Fire Blast"] = "화염 작렬",
		["Fire Breath"] = "불의 숨결",
		["Fire Elemental Totem"] = "불의 정령 토템",
		["Fire Nova Totem"] = "불꽃 회오리 토템",
		["Fire Power"] = "화염 마법 강화",
		["Fire Resistance"] = "화염 마법 저항",
		["Fire Resistance Aura"] = "화염 저항의 오라",
		["Fire Resistance Totem"] = "화염 저항 토템",
		["Fire Shield"] = "화염 보호막",
		["Fire Vulnerability"] = "화염 저항력 약화",
		["Fire Ward"] = "화염계 수호",
		["Fire Weakness"] = "화염 약점",
		["Fireball"] = "화염구",
		["Firebolt"] = "불화살",
		["First Aid"] = "응급치료",
		["Fishing"] = "낚시",
		["Fishing Poles"] = "낚싯대",
		["Fist Weapon Specialization"] = "장착 무기류 전문화",
		["Fist Weapons"] = "장착 무기류",
		["Flame Shock"] = "화염 충격",
		["Flame Throwing"] = "화염 발사",
		["Flamestrike"] = "불기둥",
		["Flamethrower"] = "화염방사기",
		["Flametongue Attack"] = "불꽃의 공격",
		["Flametongue Totem"] = "불꽃의 토템",
		["Flametongue Weapon"] = "불꽃의 무기",
		["Flare"] = "섬광",
		["Flash Heal"] = "순간 치유",
		["Flash of Light"] = "빛의 섬광",
		["Flight Form"] = "폭풍까마귀 변신",
		["FlightMaster"] = "비행조련사",
		["Flurry"] = "질풍",
		["Focused Casting"] = "집중력",
		["Focused Mind"] = "흐트러짐 없는 마음",
		["Focused Power"] = "집중된 마력",
		["Focused Rage"] = "분노 집중",
		["Focused Starlight"] = "별빛 집중",
		["Food"] = "음식",
		["Food & Drink"] = "음식과 음료",
		["Forbearance"] = "참을성",
		["Force of Nature"] = "자연의 군대",
		["Force of Will"] = "의지의 힘",
		["Freezing Trap"] = "얼음의 덫",
		["Freezing Trap Effect"] = "얼음의 덫",
		["Frenzied Regeneration"] = "광포한 재생력",
		["Frenzy"] = "광기",
		["Frenzy Effect"] = "광기",
		["Frost Armor"] = "냉기 갑옷",
		["Frost Blast"] = "냉기 작렬",
		["Frost Channeling"] = "냉기계 정신집중",
		["Frost Nova"] = "얼음 회오리",
		["Frost Resistance"] = "냉기 마법 저항",
		["Frost Resistance Aura"] = "냉기 저항의 오라",
		["Frost Resistance Totem"] = "냉기 저항 토템",
		["Frost Shock"] = "냉기 충격",
		["Frost Trap"] = "냉기의 덫",
		["Frost Trap Aura"] = "냉기의 덫",
		["Frost Ward"] = "냉기계 수호",
		["Frost Warding"] = "냉기의 수호",
		["Frost Weakness"] = "냉기 약점",
		["Frostbite"] = "동상",
		["Frostbolt"] = "얼음 화살",
		["Frostbrand Attack"] = "냉기의 무기 공격",
		["Frostbrand Weapon"] = "냉기의 무기",
		["Frozen Core"] = "얼어붙은 핵",
		["Furious Howl"] = "사나운 울음소리",
		["Furor"] = "광란",
		["Fury of the Crashing Waves"] = "몰아치는 파도의 격노",
		["Garrote"] = "목조르기",
		["Garrote - Silence"] = "목조르기 - 침묵",
		["Ghost Wolf"] = "늑대 정령",
		["Ghostly Strike"] = "그림자 일격",
		["Gift of Life"] = "생명의 선물",
		["Gift of Nature"] = "자연의 선물",
		["Gift of the Naaru"] = "나루의 선물",
		["Gift of the Wild"] = "야생의 선물",
		["Gouge"] = "후려치기",
		["Grace of Air"] = "바람의 은총",
		["Grace of Air Totem"] = "은총의 토템",
		["Great Stamina"] = "강인한 체력",
		["Greater Blessing of Kings"] = "상급 왕의 축복",
		["Greater Blessing of Light"] = "상급 빛의 축복",
		["Greater Blessing of Might"] = "상급 힘의 축복",
		["Greater Blessing of Salvation"] = "상급 구원의 축복",
		["Greater Blessing of Sanctuary"] = "상급 성역의 축복",
		["Greater Blessing of Wisdom"] = "상급 지혜의 축복",
		["Greater Dreamless Sleep"] = "상급 숙면",
		["Greater Heal"] = "상급 치유",
		["Grim Reach"] = "냉혹의 테두리",
		["Grounding Totem"] = "마법정화 토템",
		["Grounding Totem Effect"] = "마법정화 토템 효과",
		["Grovel"] = "주문 7267",
		["Growl"] = "포효",
		["Guardian's Favor"] = "수호신의 은총",
		["Gun Specialization"] = "총기류 전문화",
		["Guns"] = "총",
		["Hammer of Justice"] = "심판의 망치",
		["Hammer of Wrath"] = "천벌의 망치",
		["Hamstring"] = "무력화",
		["Harass"] = "괴롭히기",
		["Hardiness"] = "강인함",
		["Haste"] = "신속",
		["Hawk Eye"] = "매의 눈",
		["Heal"] = "치유",
		["Healing Focus"] = "치유의 집중",
		["Healing Light"] = "치유의 빛",
		["Healing Stream"] = "치유의 물결",
		["Healing Stream Totem"] = "치유의 토템",
		["Healing Touch"] = "치유의 손길",
		["Healing Wave"] = "치유의 물결",
		["Healing Way"] = "치유의 길",
		["Health Funnel"] = "생명력 집중",
		["Heart of the Wild"] = "야생의 정수",
		["Heavy Sharpening Stone"] = "단단한 숫돌",
		["Hellfire"] = "지옥의 불길",
		["Hellfire Effect"] = "지옥의 불길 효과",
		["Hellfire Superiority"] = "지옥불 사기충전",
		["Hemorrhage"] = "과다출혈",
		["Herb Gathering"] = "약초채집",
		["Herbalism"] = "약초 채집",
		["Heroic Strike"] = "영웅의 일격",
		["Heroism"] = "영웅심",
		["Hex of Weakness"] = "무력의 주술",
		["Hibernate"] = "겨울잠",
		["Holy Fire"] = "신성한 불꽃",
		["Holy Light"] = "성스러운 빛",
		["Holy Nova"] = "신성한 폭발",
		["Holy Power"] = "신성 마법 강화",
		["Holy Reach"] = "신성한 테두리",
		["Holy Shield"] = "신성한 방패",
		["Holy Shock"] = "신성 충격",
		["Holy Specialization"] = "신성 마법 전문화",
		["Holy Wrath"] = "신의 격노",
		["Honorless Target"] = "명예 점수 없음",
		["Horse Riding"] = "말 타기",
		["Howl of Terror"] = "공포의 울부짖음",
		["Humanoid Slaying"] = "인간형 사냥술",
		["Hunter's Mark"] = "사냥꾼의 징표",
		["Hurricane"] = "허리케인",
		["Hypothermia"] = "저체온증",
		["Ice Armor"] = "얼음 갑옷",
		["Ice Barrier"] = "얼음 보호막",
		["Ice Block"] = "얼음 방패",
		["Ice Floes"] = "빙하",
		["Ice Lance"] = "얼음창",
		["Ice Shards"] = "얼음 파편",
		["Ignite"] = "작열",
		["Ignite Mana"] = "마나 점화",
		["Illumination"] = "계시",
		["Immolate"] = "제물",
		["Immolation Trap"] = "제물의 덫",
		["Immolation Trap Effect"] = "제물의 덫",
		["Impact"] = "충돌",
		["Impale"] = "꿰뚫기",
		["Impaling Spine"] = "꿰뚫는 돌기",
		["Improved Ambush"] = "매복 연마",
		["Improved Arcane Missiles"] = "신비한 화살 연마",
		["Improved Arcane Shot"] = "신비한 사격 연마",
		["Improved Aspect of the Hawk"] = "매의 상 연마",
		["Improved Aspect of the Monkey"] = "원숭이의 상 연마",
		["Improved Backstab"] = "기습 연마",
		["Improved Barrage"] = "탄막 연마",
		["Improved Berserker Rage"] = "광전사의 격노 연마",
		["Improved Blessing of Might"] = "힘의 축복 연마",
		["Improved Blessing of Wisdom"] = "지혜의 축복 연마",
		["Improved Blink"] = "점멸 연마",
		["Improved Blizzard"] = "눈보라 연마",
		["Improved Bloodrage"] = "피의 분노 연마",
		["Improved Chain Heal"] = "연쇄 치유 연마",
		["Improved Chain Lightning"] = "연쇄 번개 연마",
		["Improved Challenging Shout"] = "도전의 외침 연마",
		["Improved Charge"] = "돌진 연마",
		["Improved Cleave"] = "회전베기 연마",
		["Improved Concentration Aura"] = "집중의 오라 연마",
		["Improved Concussive Shot"] = "충격포 연마",
		["Improved Cone of Cold"] = "냉기 돌풍 연마",
		["Improved Corruption"] = "부패 연마",
		["Improved Counterspell"] = "마법 차단 연마",
		["Improved Curse of Agony"] = "고통의 저주 연마",
		["Improved Curse of Weakness"] = "무력화 저주 연마",
		["Improved Demoralizing Shout"] = "사기의 외침 연마",
		["Improved Devotion Aura"] = "기원의 오라 연마",
		["Improved Disarm"] = "무장 해제 연마",
		["Improved Drain Life"] = "생명력 흡수 연마",
		["Improved Drain Soul"] = "영혼 흡수 연마",
		["Improved Enrage"] = "분노 연마",
		["Improved Enslave Demon"] = "악마 지배 연마",
		["Improved Eviscerate"] = "절개 연마",
		["Improved Execute"] = "마무리 일격 연마",
		["Improved Expose Armor"] = "약점 노출 연마",
		["Improved Eyes of the Beast"] = "야수의 눈 연마",
		["Improved Fade"] = "소실 연마",
		["Improved Feign Death"] = "죽은척하기 연마",
		["Improved Fire Blast"] = "화염 작렬 연마",
		["Improved Fire Totems"] = "불의 토템 연마",
		["Improved Fire Ward"] = "화염계 수호 연마",
		["Improved Fireball"] = "화염구 연마",
		["Improved Firebolt"] = "불화살 연마",
		["Improved Flamestrike"] = "불기둥 연마",
		["Improved Flash of Light"] = "빛의 섬광 연마",
		["Improved Frost Nova"] = "얼음 회오리 연마",
		["Improved Frostbolt"] = "얼음 화살 연마",
		["Improved Ghost Wolf"] = "늑대 정령 연마",
		["Improved Gouge"] = "후려치기 연마",
		["Improved Hammer of Justice"] = "심판의 망치 연마",
		["Improved Hamstring"] = "무력화 연마",
		["Improved Healing"] = "치유 연마",
		["Improved Healing Touch"] = "치유의 손길 연마",
		["Improved Healing Wave"] = "치유의 물결 연마",
		["Improved Health Funnel"] = "생명력 집중 연마",
		["Improved Healthstone"] = "생명석 연마",
		["Improved Heroic Strike"] = "영웅의 일격 연마",
		["Improved Holy Shield"] = "신성한 방패 연마",
		["Improved Howl of Terror"] = "공포의 울부짖음 연마",
		["Improved Hunter's Mark"] = "사냥꾼의 징표 연마",
		["Improved Immolate"] = "제물 연마",
		["Improved Imp"] = "임프 연마",
		["Improved Inner Fire"] = "내면의 열정 연마",
		["Improved Intercept"] = "봉쇄 연마",
		["Improved Intimidating Shout"] = "위협의 외침 연마",
		["Improved Judgement"] = "심판 연마",
		["Improved Kick"] = "발차기 연마",
		["Improved Kidney Shot"] = "급소 가격 연마",
		["Improved Lash of Pain"] = "고통의 채찍 연마",
		["Improved Lay on Hands"] = "신의 축복 연마",
		["Improved Leader of the Pack"] = "무리의 우두머리 연마",
		["Improved Life Tap"] = "생명력 전환 연마",
		["Improved Lightning Bolt"] = "번개 화살 연마",
		["Improved Lightning Shield"] = "번개 보호막 연마",
		["Improved Magma Totem"] = "용암 토템 연마",
		["Improved Mana Burn"] = "마나 연소 연마",
		["Improved Mana Shield"] = "마나 보호막 연마",
		["Improved Mana Spring Totem"] = "회복의 토템",
		["Improved Mark of the Wild"] = "야생의 징표 연마",
		["Improved Mend Pet"] = "동물 치료 연마",
		["Improved Mind Blast"] = "정신 분열 연마",
		["Improved Moonfire"] = "달빛 섬광 연마",
		["Improved Mortal Strike"] = "죽음의 일격 연마",
		["Improved Nature's Grasp"] = "자연의 손아귀 연마",
		["Improved Overpower"] = "제압 연마",
		["Improved Power Word: Fortitude"] = "신의 권능: 인내 연마",
		["Improved Power Word: Shield"] = "신의 권능: 보호막 연마",
		["Improved Prayer of Healing"] = "치유의 기원 연마",
		["Improved Psychic Scream"] = "영혼의 절규 연마",
		["Improved Regrowth"] = "재생 연마",
		["Improved Reincarnation"] = "윤회 연마",
		["Improved Rejuvenation"] = "회복 연마",
		["Improved Rend"] = "분쇄 연마",
		["Improved Renew"] = "소생 연마",
		["Improved Retribution Aura"] = "응보의 오라 연마",
		["Improved Revenge"] = "복수 연마",
		["Improved Revive Pet"] = "야수 되살리기 연마",
		["Improved Righteous Fury"] = "정의의 격노 연마",
		["Improved Rupture"] = "파열 연마",
		["Improved Scorch"] = "불태우기 연마",
		["Improved Scorpid Sting"] = "전갈 쐐기 연마",
		["Improved Seal of Righteousness"] = "정의의 문장 연마",
		["Improved Seal of the Crusader"] = "성전사의 문장 연마",
		["Improved Searing Pain"] = "불타는 고통 연마",
		["Improved Serpent Sting"] = "독사 쐐기 연마",
		["Improved Shadow Bolt"] = "어둠의 화살 연마",
		["Improved Shadow Word: Pain"] = "어둠의 권능: 고통 연마",
		["Improved Shield Bash"] = "방패 가격 연마",
		["Improved Shield Block"] = "방패 막기 연마",
		["Improved Shield Wall"] = "방패의 벽 연마",
		["Improved Sinister Strike"] = "사악한 일격 연마",
		["Improved Slam"] = "격돌 연마",
		["Improved Slice and Dice"] = "난도질 연마",
		["Improved Sprint"] = "전력 질주 연마",
		["Improved Stings"] = "쐐기 연마",
		["Improved Succubus"] = "서큐버스 연마",
		["Improved Sunder Armor"] = "방어구 가르기 연마",
		["Improved Taunt"] = "도발 연마",
		["Improved Thunder Clap"] = "천둥벼락 연마",
		["Improved Tranquility"] = "평온 연마",
		["Improved Vampiric Embrace"] = "흡혈의 선물 연마",
		["Improved Vanish"] = "소멸 연마",
		["Improved Voidwalker"] = "보이드워커 연마",
		["Improved Weapon Totems"] = "무기 토템 연마",
		["Improved Whirlwind"] = "소용돌이 연마",
		["Improved Wing Clip"] = "날개 절단 연마",
		["Incinerate"] = "소각",
		["Incineration"] = "소각",
		["Inferno"] = "불지옥",
		["Initiative"] = "선제 공격",
		["Innkeeper"] = "여관 주인",
		["Inner Fire"] = "내면의 열정",
		["Inner Focus"] = "내면의 집중력",
		["Innervate"] = "정신 자극",
		["Insect Swarm"] = "곤충 떼",
		["Insidious Whisper"] = "음흉한 속삭임",
		["Insignifigance"] = "무의미함",
		["Inspiration"] = "신의 계시",
		["Instant Poison"] = "순간 효과 독",
		["Instant Poison II"] = "순간 효과 독 II",
		["Instant Poison III"] = "순간 효과 독 III",
		["Instant Poison IV"] = "순간 효과 독 IV",
		["Instant Poison V"] = "순간 효과 독 V",
		["Instant Poison VI"] = "순간 효과 독 VI",
		["Instant Poison VII"] = "순간 효과 독 VII",
		["Intensity"] = "격렬",
		["Intercept"] = "봉쇄",
		["Intercept Stun"] = "봉쇄 기절",
		["Intervene"] = "가로막기",
		["Intimidating Shout"] = "위협의 외침",
		["Intimidation"] = "위협",
		["Invisibility"] = "투명화",
		["Iron Will"] = "강건한 의지",
		["Jewelcrafting"] = "보석세공",
		["Jom Gabbar"] = "좀 가바르",
		["Judgement"] = "심판",
		["Judgement of Blood"] = "피의 심판",
		["Judgement of Reckoning"] = "징벌의 심판",
		["Judgement of Command"] = "지휘의 심판",
		["Judgement of Justice"] = "응징의 심판",
		["Judgement of Light"] = "빛의 심판",
		["Judgement of Righteousness"] = "정의의 심판",
		["Judgement of Wisdom"] = "지혜의 심판",
		["Judgement of the Crusader"] = "성전사의 심판",
		["Kick"] = "발차기",
		["Kick - Silenced"] = "발차기 침묵",
		["Kidney Shot"] = "급소 가격",
		["Kill Command"] = "살상 명령",
		["Killer Instinct"] = "살수의 본능",
		["Kiss of the Spider"] = "거미의 입맞춤",
		["Kodo Riding"] = "코도 타기",
		["Lacerate"] = "가르기",
		["Lash of Pain"] = "고통의 채찍",
		["Last Stand"] = "최후의 저항",
		["Lay on Hands"] = "신의 축복",
		["Leader of the Pack"] = "무리의 우두머리",
		["Leather"] = "가죽",
		["Leatherworking"] = "가죽 세공",
		["Lesser Heal"] = "하급 치유",
		["Lesser Healing Wave"] = "하급 치유의 물결",
		["Lesser Invisibility"] = "하급 투명화",
		["Lethal Shots"] = "정밀한 사격",
		["Lethality"] = "치명상",
		["Levitate"] = "공중 부양",
		["Libram"] = "성서",
		["Life Tap"] = "생명력 전환",
		["Lifebloom"] = "피어나는 생명",
		["Light's Grace"] = "빛의 은총",
		["Lightning Bolt"] = "번개 화살",
		["Lightning Breath"] = "번개 숨결",
		["Lightning Mastery"] = "번개 전문화",
		["Lightning Reflexes"] = "번개같은 반사 신경",
		["Lightning Shield"] = "번개 보호막",
		["Lightning Speed"] = "번개같은 속도",
		["Lightwell"] = "빛샘",
		["Lightwell Renew"] = "빛샘의 소생",
		["Lockpicking"] = "자물쇠 따기",
		["Long Daze"] = "오랜 멍해짐",
		["Lust for Battle"] = "전투의 욕망",
		["Mace Specialization"] = "둔기류 전문화",
		["Mace Stun Effect"] = "철퇴 기절 효과",
		["Mage Armor"] = "마법사 갑옷",
		["Magic Absorption"] = "마법 흡수",
		["Magic Attunement"] = "마법의 조화",
		["Magma Totem"] = "용암 토템",
		["Mail"] = "사슬",
		["Maim"] = "무력화",
		["Major Dreamless Sleep"] = "최상급 숙면",
		["Malediction"] = "재앙의 저주",
		["Malice"] = "원한",
		["Mana Burn"] = "마나 연소",
		["Mana Feed"] = "마나 섭취",
		["Mana Shield"] = "마나 보호막",
		["Mana Spring"] = "마나샘",
		["Mana Spring Totem"] = "마나샘 토템",
		["Mana Tap"] = "마나 추출",
		["Mana Tide"] = "마나 해일",
		["Mana Tide Totem"] = "마나 해일 토템",
		["Mangle"] = "짓이기기",
		["Mangle (Bear)"] = "짓이기기 (곰)",
		["Mangle (Cat)"] = "짓이기기 (표범)",
		["Mark of the Wild"] = "야생의 징표",
		["Martyrdom"] = "헌신",
		["Mass Dispel"] = "대규모 무효화",
		["Master Conjuror"] = "창조의 대가",
		["Master Demonologist"] = "악령술의 대가",
		["Master Summoner"] = "소환의 대가",
		["Master Tactician"] = "전술의 대가",
		["Master of Deception"] = "속임수의 대가",
		["Master of Elements"] = "원소 마법의 대가",
		["Master of Subtlety"] = "잠행의 대가",
		["Maul"] = "후려치기",
		["Mechanostrider Piloting"] = "기계타조 조종",
		["Meditation"] = "명상",
		["Melee Specialization"] = "근접 무기 전문화",
		["Melt Armor"] = "방어구 녹이기",
		["Mend Pet"] = "동물 치료",
		["Mental Agility"] = "마음의 기민함",
		["Mental Strength"] = "정신력",
		["Mind Blast"] = "정신 분열",
		["Mind Control"] = "정신 지배",
		["Mind Flay"] = "정신의 채찍",
		["Mind Mastery"] = "정신 단련",
		["Mind Soothe"] = "평정",
		["Mind Vision"] = "마음의 눈",
		["Mind-numbing Poison"] = "정신 마비 독",
		["Mind-numbing Poison II"] = "정신 마비 독 II",
		["Mind-numbing Poison III"] = "정신 마비 독 III",
		["Mining"] = "채광",
		["Misdirection"] = "눈속임",
		["Misery"] = "불행",
		["Mocking Blow"] = "도발의 일격",
		["Molten Armor"] = "타오르는 갑옷",
		["Molten Fury"] = "타오르는 격노",
		["Mongoose Bite"] = "살쾡이의 이빨",
		["Monster Slaying"] = "몬스터 사냥술",
		["Moonfire"] = "달빛 섬광",
		["Moonfury"] = "달의 분노",
		["Moonglow"] = "달빛",
		["Moonkin Aura"] = "달빛야수 오라",
		["Moonkin Form"] = "달빛야수 변신",
		["Mortal Shots"] = "죽음의 사격",
		["Mortal Strike"] = "죽음의 일격",
		["Multi-Shot"] = "일제 사격",
		["Murder"] = "학살",
		["Mutilate"] = "절단",
		["Natural Armor"] = "무쇠 가죽",
		["Natural Perfection"] = "자연의 완전무결함",
		["Natural Shapeshifter"] = "변신의 대가",
		["Naturalist"] = "자연의 탐구자",
		["Nature Resistance"] = "자연 마법 저항",
		["Nature Resistance Totem"] = "자연 저항 토템",
		["Nature Weakness"] = "자연 약점",
		["Nature's Focus"] = "자연의 정신 집중",
		["Nature's Grace"] = "자연의 은혜",
		["Nature's Grasp"] = "자연의 손아귀",
		["Nature's Guidance"] = "자연의 가르침",
		["Nature's Reach"] = "자연의 테두리",
		["Nature's Swiftness"] = "자연의 신속함",
		["Negative Charge"] = "음전하",
		["Nether Protection"] = "황천의 보호",
		["Netherstorm Flag"] = "황천의 폭풍 깃발",
		["Nightfall"] = "일몰",
		["Nurturing Instinct"] = "회복의 본능",
		["Omen of Clarity"] = "청명의 전조",
		["One-Handed Axes"] = "한손 도끼",
		["One-Handed Maces"] = "한손 철퇴",
		["One-Handed Swords"] = "한손 검",
		["One-Handed Weapon Specialization"] = "한손 무기류 전문화",
		["Opening"] = "열기",
		["Opening - No Text"] = "열기",
		["Opportunity"] = "기회 포착",
		["Overpower"] = "제압",
		["Pain Suppression"] = "고통 억제",
		["Panic"] = "공황",
		["Paranoia"] = "망상",
		["Parasitic Shadowfiend"] = "어둠의 흡혈마귀",
		["Parry"] = "무기 막기",
		["Pathfinding"] = "길 찾기",
		["Perceived Weakness"] = "간파된 약점",
		["Perception"] = "직관력",
		["Permafrost"] = "영구 결빙",
		["Pet Aggression"] = "야수의 공격성",
		["Pet Hardiness"] = "야수의 강인함",
		["Pet Recovery"] = "야수의 회복력",
		["Pet Resistance"] = "야수의 저항력",
		["Phase Shift"] = "위상 변화",
		["Pick Lock"] = "자물쇠 따기",
		["Pick Pocket"] = "훔치기",
		["Piercing Howl"] = "날카로운 고함",
		["Piercing Ice"] = "사무치는 냉기",
		["Plate Mail"] = "판금 갑옷",
		["Playing with Fire"] = "불장난",
		["Poison Cleansing Totem"] = "독 정화 토템",
		["Poison Spit"] = "독액", -- 독화살
		["Poisons"] = "독 조제",
		["Polearms"] = "장창류",
		["Poleaxe Specialization"] = "도끼류 및 장창류 전문화",
		["Polymorph"] = "변이",
		["Polymorph: Pig"] = "변이: 돼지",
		["Polymorph: Turtle"] = "변이: 거북이",
		["Portal: Darnassus"] = "차원의 문: 다르나서스",
		["Portal: Exodar"] = "차원의 문: 엑소다르",
		["Portal: Ironforge"] = "차원의 문: 아이언포지",
		["Portal: Orgrimmar"] = "차원의 문: 오그리마",
		["Portal: Shattrath"] = "차원의 문: 샤트라스",
		["Portal: Silvermoon"] = "차원의 문: 실버문",
		["Portal: Stormwind"] = "차원의 문: 스톰윈드",
		["Portal: Thunder Bluff"] = "차원의 문: 썬더 블러프",
		["Portal: Undercity"] = "차원의 문: 언더시티",
		["Positive Charge"] = "양전하",
		["Pounce"] = "암습",
		["Pounce Bleed"] = "암습 피해",
		["Power Infusion"] = "마력 주입",
		["Power Word: Fortitude"] = "신의 권능: 인내",
		["Power Word: Shield"] = "신의 권능: 보호막",
		["Prayer of Fortitude"] = "인내의 기원",
		["Prayer of Healing"] = "치유의 기원",
		["Prayer of Mending"] = "회복의 기원",
		["Prayer of Shadow Protection"] = "암흑 보호의 기원",
		["Prayer of Spirit"] = "정신력의 기원",
		["Precision"] = "정밀함",
		["Predatory Instincts"] = "포식자의 본능",
		["Predatory Strikes"] = "야생의 포식자",
		["Premeditation"] = "사전계획",
		["Preparation"] = "마음가짐",
		["Presence of Mind"] = "냉정",
		["Primal Fury"] = "야수의 분노",
		["Prismatic Cloak"] = "굴절의 망토",
		["Profession Trainers"] = "기술 전문가",
		["Prospecting"] = "보석 추출",
		["Prowl"] = "숨기",
		["Psychic Scream"] = "영혼의 절규",
		["Pummel"] = "자루 공격",
		["Purge"] = "정화",
		["Purification"] = "심신의 정화",
		["Purify"] = "순화",
		["Purifying Power"] = "정화의 힘",
		["Pursuit of Justice"] = "심판의 추격",
		["Pyroblast"] = "불덩이 작렬",
		["Pyroclasm"] = "화염 파열",
		["Pyromaniac"] = "광기의 화염술사",
		["Quick Recovery"] = "신속한 회복력",
		["Quick Shots"] = "신속 사격",
		["Quickness"] = "민첩",
		["Rage of the Unraveller"] = "해결사의 분노",
		["Rain of Fire"] = "불의 비",
		["Rake"] = "갈퀴 발톱",
		["Ram Riding"] = "산양 타기",
		["Rampage"] = "광란",
		["Ranged Weapon Specialization"] = "원거리 무기 전문화",
		["Rapid Fire"] = "속사",
		["Rapid Killing"] = "신속한 사냥",
		["Raptor Riding"] = "랩터 타기",
		["Raptor Strike"] = "랩터의 일격",
		["Ravage"] = "찢어발기기",
		["Readiness"] = "만반의 준비",
		["Reagents"] = "마법 재료",
		["Rebirth"] = "환생",
		["Reckless Charge"] = "무모한 돌진",
		["Recklessness"] = "무모한 희생",
		["Reckoning"] = "징벌",
		["Redemption"] = "구원",
		["Redoubt"] = "보루",
		["Reflection"] = "반사",
		["Regeneration"] = "재생력",
		["Regrowth"] = "재생",
		["Reincarnation"] = "윤회",
		["Reinforced Shield"] = "강화된 방패",
		["Rejuvenation"] = "회복",
		["Relentless Strikes"] = "가혹한 일격",
		["Remorseless"] = "냉혹함",
		["Remorseless Attacks"] = "냉혹함",
		["Remote Toy"] = "원격조종 장난감",
		["Remove Curse"] = "저주 해제",
		["Remove Insignia"] = "계급장 제거",
		["Remove Lesser Curse"] = "하급 저주 해제",
		["Rend"] = "분쇄",
		["Renew"] = "소생",
		["Repair"] = "장비 수리",
		["Repentance"] = "참회",
		["Restless Strength"] = "불안정한 힘",
		["Restorative Totems"] = "회복의 토템",
		["Resurrection"] = "부활",
		["Retaliation"] = "보복",
		["Retribution Aura"] = "응보의 오라",
		["Revenge"] = "복수",
		["Revenge Stun"] = "복수 기절",
		["Reverberation"] = "산울림",
		["Revive Pet"] = "야수 되살리기",
		["Righteous Defense"] = "정의의 방어",
		["Righteous Fury"] = "정의의 격노",
		["Rip"] = "도려내기",
		["Riposte"] = "반격",
		["Ritual of Doom"] = "파멸의 의식",
		["Ritual of Doom Effect"] = "파멸의 의식",
		["Ritual of Souls"] = "영혼의 의식",
		["Ritual of Summoning"] = "소환 의식",
		["Rockbiter Weapon"] = "대지의 무기",
		["Rough Sharpening Stone"] = "조잡한 숫돌",
		["Ruin"] = "붕괴",
		["Rupture"] = "파열",
		["Ruthlessness"] = "무정함",
		["Sacrifice"] = "희생",
		["Safe Fall"] = "낙법",
		["Sanctified Crusader"] = "신성한 성전사",
		["Sanctified Judgement"] = "신성한 심판",
		["Sanctified Light"] = "축복받은 빛",
		["Sanctity Aura"] = "고결의 오라",
		["Sap"] = "기절시키기",
		["Savage Fury"] = "맹렬한 격노",
		["Savage Strikes"] = "야생의 일격",
		["Scare Beast"] = "야수 겁주기",
		["Scatter Shot"] = "산탄 사격",
		["Scorch"] = "불태우기",
		["Scorpid Poison"] = "전갈독",
		["Scorpid Sting"] = "전갈 쐐기",
		["Screech"] = "날카로운 울음소리",
		["Seal Fate"] = "운명의 낙인",
		["Seal of Blood"] = "피의 문장",
		["Seal of Command"] = "지휘의 문장",
		["Seal of Justice"] = "응징의 문장",
		["Seal of Light"] = "빛의 문장",
		["Seal of Righteousness"] = "정의의 문장",
		["Seal of Vengeance"] = "복수의 문장",
		["Seal of Wisdom"] = "지혜의 문장",
		["Seal of the Crusader"] = "성전사의 문장",
		["Searing Light"] = "타오르는 빛",
		["Searing Pain"] = "불타는 고통",
		["Searing Totem"] = "불타는 토템",
		["Second Wind"] = "재기의 바람",
		["Seduction"] = "유혹",
		["Seed of Corruption"] = "부패의 씨앗",
		["Seethe"] = "노여움",
		["Sense Demons"] = "악마 감지",
		["Sense Undead"] = "언데드 감지",
		["Sentry Totem"] = "감시의 토템",
		["Serpent Sting"] = "독사 쐐기",
		["Serrated Blades"] = "톱니 칼날",
		["Setup"] = "사전 준비",
		["Shackle Undead"] = "언데드 속박",
		["Shadow Affinity"] = "암흑 마법 친화",
		["Shadow Bolt"] = "어둠의 화살",
		["Shadow Embrace"] = "어둠의 선물",
		["Shadow Focus"] = "암흑 마법 집중",
		["Shadow Mastery"] = "암흑 마법 전문화",
		["Shadow Power"] = "어둠의 힘",
		["Shadow Protection"] = "어둠의 보호",
		["Shadow Reach"] = "어둠의 테두리",
		["Shadow Resistance"] = "암흑 마법 저항",
		["Shadow Resistance Aura"] = "암흑 저항의 오라",
		["Shadow Trance"] = "어둠의 무아지경",
		["Shadow Vulnerability"] = "암흑 저항력 약화",
		["Shadow Ward"] = "암흑계 수호",
		["Shadow Weakness"] = "암흑 약점",
		["Shadow Weaving"] = "어둠의 매듭",
		["Shadow Word: Death"] = "어둠의 권능: 죽음",
		["Shadow Word: Pain"] = "어둠의 권능: 고통",
		["Shadow and Flame"] = "어둠과 불길",
		["Shadow of Death"] = "죽음의 어둠",
		["Shadowburn"] = "어둠의 연소",
		["Shadowfiend"] = "어둠의 마귀",
		["Shadowform"] = "어둠의 형상",
		["Shadowfury"] = "어둠의 격노",
		["Shadowguard"] = "어둠의 수호",
		["Shadowmeld"] = "그림자 숨기",
		["Shadowmeld Passive"] = "그림자 숨기",
		["Shadowstep"] = "그림자 밟기",
		["Shamanistic Rage"] = "주술의 분노",
		["Sharpened Claws"] = "날카로운 발톱",
		["Shatter"] = "산산조각",
		["Shell Shield"] = "껍질 방패",
		["Shield"] = "방패",
		["Shield Bash"] = "방패 가격",
		["Shield Bash - Silenced"] = "방패 가격 - 침묵",
		["Shield Block"] = "방패 막기",
		["Shield Slam"] = "방패 밀쳐내기",
		["Shield Specialization"] = "방패 전문화",
		["Shield Wall"] = "방패의 벽",
		["Shiv"] = "독칼",
		["Shoot"] = "마법봉 발사",
		["Shoot Bow"] = "활 발사",
		["Shoot Gun"] = "총 발사",
		["Shred"] = "칼날 발톱",
		["Shredding Attacks"] = "죽음의 발톱",
		["Silence"] = "침묵",
		["Silencing Shot"] = "침묵의 사격",
		["Silent Resolve"] = "무언의 결심",
		["Silverwing Flag"] = "은빛날개 깃발",
		["Sinister Strike"] = "사악한 일격",
		["Siphon Life"] = "생명력 착취",
		["Skinning"] = "무두질",
		["Slam"] = "격돌",
		["Slayer's Crest"] = "학살자의 문장",
		["Sleep"] = "수면",
		["Slice and Dice"] = "난도질",
		["Slow"] = "감속",
		["Slow Fall"] = "저속 낙하",
		["Smelting"] = "제련술",
		["Smite"] = "성스러운 일격",
		["Snake Trap"] = "뱀 덫",
		["Solid Sharpening Stone"] = "견고한 숫돌",
		["Sonic Burst"] = "음파 폭발",
		["Soothe Animal"] = "동물 달래기",
		["Soothing Kiss"] = "유혹의 입맞춤",
		["Soul Fire"] = "영혼의 불꽃",
		["Soul Leech"] = "영혼 갈취",
		["Soul Link"] = "영혼의 고리",
		["Soul Siphon"] = "영혼 착취",
		["Soulshatter"] = "영혼 붕괴",
		["Soulstone Resurrection"] = "영혼석 부활",
		["Spell Haste"] = "주문 가속",
		["Spell Lock"] = "주문 잠금",
		["Spell Power"] = "주문 강화",
		["Spell Reflection"] = "주문 반사",
		["Spell Vulnerability"] = "주문 저항 약화",
		["Spell Warding"] = "주문 수호",
		["Spellsteal"] = "마법 훔치기",
		["Spirit Bond"] = "정신의 결속",
		["Spirit Tap"] = "정신력 누출",
		["Spirit of Redemption"] = "구원의 영혼",
		["Spiritual Attunement"] = "영혼의 조화",
		["Spiritual Focus"] = "영적인 집중력",
		["Spiritual Guidance"] = "영혼의 길잡이",
		["Spiritual Healing"] = "영혼의 치유",
		["Spiteful Fury"] = "악의의 격노",
		["Sprint"] = "전력 질주",
		["StableMaster"] = "야수 관리인",
		["Stance Mastery"] = "태세 숙련",
		["Starfire"] = "별빛 섬광",
		["Starfire Stun"] = "별빛 섬광 기절",
		["Starlight Wrath"] = "별빛 천벌",
		["Starshards"] = "별조각",
		["Static Charge"] = "전기 충전",
		["Staves"] = "지팡이",
		["Steady Shot"] = "고정 사격",
		["Stealth"] = "은신",
		["Stoneclaw Stun"] = "돌발톱 기절",
		["Stoneclaw Totem"] = "돌발톱 토템",
		["Stoneform"] = "석화",
		["Stoneskin"] = "돌가죽",
		["Stoneskin Totem"] = "돌가죽 토템",
		["Stormstrike"] = "폭풍의 일격",
		["Strength of Earth"] = "대지력",
		["Strength of Earth Totem"] = "대지력 토템",
		["Strength of the Halaani"] = "할라아니의 힘",
		["Stuck"] = "고립 상태 벗어나기",
		["Stun"] = "기절",
		["Subtlety"] = "영혼의 길잡이",
		["Suffering"] = "고통",
		["Summon Charger"] = "군마 소환",
		["Summon Dreadsteed"] = "공포마 소환",
		["Summon Felguard"] = "지옥수호병 소환",
		["Summon Felhunter"] = "지옥사냥개 소환",
		["Summon Felsteed"] = "지옥마 소환",
		["Summon Imp"] = "임프 소환",
		["Summon Succubus"] = "서큐버스 소환",
		["Summon Voidwalker"] = "보이드워커 소환",
		["Summon Warhorse"] = "군마 소환",
		["Summon Water Elemental"] = "물의 정령 소환",
		["Sunder Armor"] = "방어구 가르기",
		["Suppression"] = "억제",
		["Surefooted"] = "침착함",
		["Surge of Light"] = "빛의 쇄도",
		["Surprise Attacks"] = "급습",
		["Survivalist"] = "생존의 대가",
		["Sweeping Strikes"] = "휩쓸기 일격",
		["Swift Flight Form"] = "빠른 폭풍까마귀 변신",
		["Swiftmend"] = "신속한 치유",
		["Swipe"] = "휘둘러치기",
		["Sword Specialization"] = "도검류 전문화",
		["Symbol of Hope"] = "희망의 상징",
		["Tactical Mastery"] = "전술 숙련",
		["Tailoring"] = "재봉술",
		["Tainted Blood"] = "얼룩진 피",
		["Tainted Mind"] = "부패한 정신",
		["Tame Beast"] = "야수 길들이기",
		["Taunt"] = "도발",
		["Teleport: Darnassus"] = "순간이동: 다르나서스",
		["Teleport: Exodar"] = "순간이동: 엑소다르",
		["Teleport: Ironforge"] = "순간이동: 아이언포지",
		["Teleport: Moonglade"] = "순간이동: 달의 숲",
		["Teleport: Orgrimmar"] = "순간이동: 오그리마",
		["Teleport: Shattrath"] = "순간이동: 샤트라스",
		["Teleport: Silvermoon"] = "순간이동: 실버문",
		["Teleport: Stormwind"] = "순간이동: 스톰윈드",
		["Teleport: Thunder Bluff"] = "순간이동: 썬더 블러프",
		["Teleport: Undercity"] = "순간이동: 언더시티",
		["Temporal Rift"] = "시간의 균열",
		["The Beast Within"] = "내면의 야수",
		["The Human Spirit"] = "인간의 정신력",
		["Thick Hide"] = "두꺼운 가죽",
		["Thorns"] = "가시",
		["Thrill of the Hunt"] = "사냥의 전율",
		["Throw"] = "투척",
		["Throwing Specialization"] = "투척술 전문화",
		["Thrown"] = "투척",
		["Thunder Clap"] = "천둥벼락",
		["Thunderfury"] = "우레폭풍",
		["Thundering Strikes"] = "우레의 일격",
		["Thunderstomp"] = "천둥 발구르기",
		["Tidal Focus"] = "해일의 집중",
		["Tidal Mastery"] = "해일의 깨달음",
		["Tiger Riding"] = "호랑이 타기",
		["Tiger's Fury"] = "맹공격",
		["Time's Favor"] = "시간의 선물",
		["Torment"] = "고문",
		["Totem"] = "토템",
		["Totem of Wrath"] = "격노의 토템",
		["Totemic Call"] = "토템의 부름",
		["Totemic Focus"] = "토템 집중",
		["Touch of Shadow"] = "어둠의 손길",
		["Touch of Weakness"] = "무력의 손길",
		["Toughness"] = "강인함",
		["Traces of Silithyst"] = "실리시스트의 자취",
		["Track Beasts"] = "야수 추적",
		["Track Demons"] = "악마 추적",
		["Track Dragonkin"] = "용족 추적",
		["Track Elementals"] = "정령 추적",
		["Track Giants"] = "거인 추적",
		["Track Hidden"] = "은신 추적",
		["Track Humanoids"] = "인간형 추적",
		["Track Undead"] = "언데드 추적",
		["Tranquil Air"] = "평온의 토템",
		["Tranquil Air Totem"] = "평온의 토템",
		["Tranquil Spirit"] = "평온한 정신",
		["Tranquility"] = "평온",
		["Tranquilizing Shot"] = "평정의 사격",
		["Trap Mastery"] = "덫 숙련",
		["Travel Form"] = "치타 변신",
		["Tree of Life"] = "생명의 나무",
		["Tremor Totem"] = "진동의 토템",
		["Tribal Leatherworking"] = "전통 가죽세공",
		["Trueshot Aura"] = "정조준 오라",
		["Turn Undead"] = "언데드 퇴치",
		["Twin Spire Blessing"] = "쌍둥이 첨탑의 축복",
		["Two-Handed Axes"] = "양손 도끼",
		["Two-Handed Axes and Maces"] = "양손 도끼류 및 둔기류",
		["Two-Handed Maces"] = "양손 철퇴",
		["Two-Handed Swords"] = "양손 검",
		["Two-Handed Weapon Specialization"] = "양손 무기류 전문화",
		["Unarmed"] = "맨손",
		["Unbreakable Will"] = "굳은 의지",
		["Unbridled Wrath"] = "분노 해방",
		["Undead Horsemanship"] = "언데드 승마술",
		["Underwater Breathing"] = "수중 호흡",
		["Unending Breath"] = "영원의 숨결",
		["Unholy Power"] = "부정의 힘",
		["Unleashed Fury"] = "격노 폭발",
		["Unleashed Rage"] = "해방된 분노",
		["Unstable Affliction"] = "불안정한 고통",
		["Unstable Power"] = "불안정한 마력",
		["Unyielding Faith"] = "굳은 신념",
		["Vampiric Embrace"] = "흡혈의 선물",
		["Vampiric Touch"] = "흡혈의 손길",
		["Vanish"] = "소멸",
		["Vanished"] = "소멸",
		["Vengeance"] = "복수",
		["Venomous Totem"] = "맹독의 토템",
		["Victory Rush"] = "승리의 돌진",
		["Vigor"] = "강한 체력",
		["Vile Beam"] = "타락의 광선",
		["Vile Poisons"] = "치명적인 독",
		["Vindication"] = "비호",
		["Viper Sting"] = "살무사 쐐기",
		["Volley"] = "연발 사격",
		["Wand Specialization"] = "마법봉류 전문화",
		["Wands"] = "마법봉",
		["War Stomp"] = "전투 발구르기",
		["Warp"] = "공간이동",
		["Warsong Flag"] = "전쟁노래 깃발",
		["Water Breathing"] = "수중 호흡",
		["Water Shield"] = "물의 보호막",
		["Water Tomb"] = "수중 무덤",
		["Water Walking"] = "수면 걷기",
		["Waterbolt"] = "물화살",
		["Watery Grave"] = "수중 무덤",
		["Weakened Soul"] = "약화된 영혼",
		["Weapon Mastery"] = "무기 전문화",
		["Weaponsmith"] = "무기제작",
		["Whirlwind"] = "소용돌이",
		["Will of the Forsaken"] = "포세이큰의 의지",
		["Windfury"] = "질풍",
		["Windfury Attack"] = "질풍의 공격",
		["Windfury Totem"] = "질풍의 토템",
		["Windfury Weapon"] = "질풍의 무기",
		["Windwall"] = "바람막이",
		["Windwall Totem"] = "바람막이 토템",
		["Wing Clip"] = "날개 절단",
		["Winter's Chill"] = "혹한의 추위",
		["Wisp Spirit"] = "위습의 영혼",
		["Wolf Riding"] = "늑대 타기",
		["Wound Poison"] = "상처 감염 독",
		["Wound Poison II"] = "상처 감염 독 II",
		["Wound Poison III"] = "상처 감염 독 III",
		["Wound Poison IV"] = "상처 감염 독 IV",
		["Wound Poison V"] = "상처 감염 독 V",
		["Wrath"] = "천벌",
		["Wrath of Air Totem"] = "천벌의 토템",
		["Wrath of Cenarius"] = "세나리우스의 천벌",
		["Wrath of the Astromancer"] = "점성술사의 격노",
		["Wyvern Sting"] = "비룡 쐐기",
	}
elseif GAME_LOCALE == "esES" then
	lib:SetCurrentTranslations {
		["Abolish Disease"] = "Suprimir enfermedad",
		["Abolish Poison"] = "Suprimir veneno",
		["Abolish Poison Effect"] = "Efecto de Suprimir veneno",  -- check
		["Activate MG Turret"] = "Activar Torreta MG",  -- check
		["Adrenaline Rush"] = "Subid\195\179n de adrenalina",
		["Aftermath"] = "Secuelas",
		["Aggression"] = "Agresi\195\179n",
		["Aimed Shot"] = "Disparo de punter\195\173a",
		["Alchemy"] = "Alquimia",
		["Ambush"] = "Emboscada",
		["Ammunition"] = "Ammunition",      -- fix
		["Amplify Curse"] = "Amplificar maldici\195\179n",
		["Amplify Magic"] = "Amplificar magia",
		["Ancestral Fortitude"] = "Entereza ancestral", -- check
		["Ancestral Healing"] = "Sanaci\195\179n ancestral",
		["Ancestral Knowledge"] = "Conocimiento ancestral",
		["Ancestral Spirit"] = "Esp\195\173ritu ancestral",
		["Ancient Hysteria"] = "Histeria ancestral",   -- fix
		["Anesthetic Poison"] = "Veneno anest\195\169sico",  -- check
		["Anger Management"] = "Control de inquina",
		["Anguish"] = "Angustia",
		["Anticipation"] = "Anticipaci\195\179n",
		["Aquatic Form"] = "Forma acu\195\161tica",    -- check
		["Arcane Blast"] = "Deflagraci\195\179n Arcana",
		["Arcane Brilliance"] = "Brillantez Arcana",  -- check
		["Arcane Concentration"] = "Concentraci\195\179n Arcana",
		["Arcane Energy"] = "Energia Arcana",      -- fix
		["Arcane Explosion"] = "Deflagraci\195\179n arcana",
		["Arcane Focus"] = "Enfoque Arcano",
		["Arcane Fortitude"] = "Entereza Arcana",  -- check
		["Arcane Impact"] = "Impacto Arcano",   -- check
		["Arcane Instability"] = "Inestabilidad Arcana",
		["Arcane Intellect"] = "Intelecto arcano",
		["Arcane Meditation"] = "Meditaci\195\179n Arcana",
		["Arcane Mind"] = "Mente Arcana",
		["Arcane Missiles"] = "Misiles Arcanos",
		["Arcane Potency"] = "Potencia Arcana",  -- check
		["Arcane Power"] = "Poder Arcano",
		["Arcane Resistance"] = "Resistencia a lo Arcano",
		["Arcane Shot"] = "Disparo Arcano",
		["Arcane Shroud"] = "Sudario arcano",   -- fix
		["Arcane Subtlety"] = "Sutileza Arcana",
		["Arcane Torrent"] = "Torrente Arcano",
		["Arcane Weakness"] = "Debilidad Arcana",  -- check
		["Arctic Reach"] = "Alcance \195\161rtico",
		["Arctic Winds"] = "Vientos \195\161rticos",   -- check
		["Armor of Faith"] = "Armadura de fe", -- check
		["Armorsmith"] = "Forjador de armaduras",    -- check
		["Aspect of the Beast"] = "Aspecto de la bestia",
		["Aspect of the Cheetah"] = "Aspecto de chita", -- check
		["Aspect of the Hawk"] = "Aspecto del Halc\195\179n",
		["Aspect of the Monkey"] = "Aspecto del mono",
		["Aspect of the Pack"] = "Aspecto de la manada",
		["Aspect of the Viper"] = "Aspecto de v\195\173bora",  -- check
		["Aspect of the Wild"] = "Aspecto salvaje",
		["Astral Recall"] = "Regreso astral",
		["Attack"] = "Ataque",
		["Attacking"] = "Atacando",
		["Auto Shot"] = "Disparo autom\195\161tico",
		["Avenger's Shield"] = "Escudo de vengador",
		["Avenging Wrath"] = "C\195\179lera vengativa",
		["Avoidance"] = "Eludir",   -- check
		["Axe Specialization"] = "Especializaci\195\179n en hachas",
		["Backlash"] = "Contragolpe",
		["Backstab"] = "Pu\195\177alada",
		["Badge of the Swarmguard"] = "Badge of the Swarmguard",   -- fix
		["Balance of Power"] = "Equilibrio de poder",  -- check
		["Bane"] = "Aterrar",
		["Banker"] = "Banker",   -- fix
		["Banish"] = "Desterrar",
		["Barkskin"] = "Piel de corteza",
		["Barrage"] = "Tromba",
		["Bash"] = "Azote",
		["Basic Campfire"] = "Hoguera b\195\161sica",
		["Battle Rush"] = "Frenesi de batalla",  -- check
		["Battle Shout"] = "Grito de batalla",
		["Battle Stance"] = "Actitud de batalla",
		["Battle Stance Passive"] = "Actitud de batalla pasiva",  -- check
		["Bear Form"] = "Forma de oso",
		["BattleMaster"] = "BattleMaster",   -- fix
		["Beast Lore"] = "Tradici\195\179n de las bestias",
		["Beast Slaying"] = "Matanza de bestias",
		["Beast Training"] = "Adiestramiento de bestias",
		["Benediction"] = "Oraci\195\179n",
		["Berserker Rage"] = "Ira rabiosa",
		["Berserker Stance"] = "Actitud rabiosa",
		["Berserker Stance Passive"] = "Actitud rabiosa pasiva",    -- check
		["Berserking"] = "Rabiar",
		["Bestial Discipline"] = "Disciplina de las bestias",
		["Bestial Swiftness"] = "Presteza de las bestias",
		["Bestial Wrath"] = "C\195\179lera de las bestias",
		["Binding Heal"] = "Nexo de sanaci\195\179n",     -- check
		["Bite"] = "Morder",  -- check
		["Black Arrow"] = "Flecha Negra",  -- check
		["Blackout"] = "Desmayo",
		["Blacksmithing"] = "Herrer\195\173a",
		["Blade Flurry"] = "Aluvi\195\179n de acero",
		["Blade Turning"] = "Giro de hoja", -- check
		["Blade Twisting"] = "Retorcer hoja",  -- check
		["Blast Wave"] = "Ola explosiva",
		["Blazing Speed"] = "Velocidad llameante",
		["Blessed Recovery"] = "Recuperaci\195\179n bendita",
		["Blessed Resilience"] = "Temple bendito", -- check
		["Blessing of Auchindoun"] = "Bendicion de Auchindoun",    -- check
		["Blessing of Freedom"] = "Bendici\195\179n de libertad",
		["Blessing of Kings"] = "Bendici\195\179n de los Reyes",
		["Blessing of Light"] = "Bendici\195\179n de Luz",
		["Blessing of Might"] = "Bendici\195\179n de poder\195\173o",
		["Blessing of Protection"] = "Bendici\195\179n de protecci\195\179n",
		["Blessing of Sacrifice"] = "Bendici\195\179n de sacrificio",
		["Blessing of Salvation"] = "Bendici\195\179n de salvaci\195\179n",
		["Blessing of Sanctuary"] = "Bendici\195\179n de salvaguardia",
		["Blessing of Wisdom"] = "Bendici\195\179n de sabidur\195\173a",
		["Blind"] = "Ceguera",
		["Blinding Powder"] = "Part\195\173culas cegadoras",
		["Blink"] = "Traslaci\195\179n",
		["Blizzard"] = "Ventisca",
		["Block"] = "Bloqueo",
		["Blood Craze"] = "Man\195\173a sangrienta",
		["Blood Frenzy"] = "Frenesi sangriento",  -- check
		["Blood Fury"] = "Furia sangrienta",
		["Blood Pact"] = "Pacto de sangre",
		["Bloodlust"] = "Ansia de sangre",  -- check
		["Bloodrage"] = "Ira sangrienta",
		["Bloodthirst"] = "Sed de sangre",
		["Boar Charge"] = "Carga de jabali",  -- check
		["Booming Voice"] = "Voz retumbante",
		["Bow Specialization"] = "Especializaci\195\179n en arcos",
		["Bows"] = "Arcos",
		["Bright Campfire"] = "Fogata brillante",  -- check
		["Brittle Armor"] = "Brittle Armor",   -- fix
		["Brutal Impact"] = "Impacto brutal",
		["Burning Adrenaline"] = "Adrenalina ardiente",  -- check
		["Burning Soul"] = "Alma ardiente",
		["Burning Wish"] = "Deseo ardiente",        -- check
		["Call Pet"] = "llamar a mascota",
		["Call of Flame"] = "Llamada de las llamas",
		["Call of Thunder"] = "Llamada del trueno",
		["Call of the Nexus"] = "Llamada del nexo",    -- fix
		["Camouflage"] = "Camuflaje",
		["Cannibalize"] = "Canibalizar",
		["Cat Form"] = "Forma felina",
		["Cataclysm"] = "Cataclismo",
		["Celestial Focus"] = "Fuego estelar mejorado",
		["Chain Heal"] = "Sanaci\195\179n en cadena",
		["Chain Lightning"] = "Cadena de rel\195\161mpagos",
		["Challenging Roar"] = "Rugido desafiante",
		["Challenging Shout"] = "Grito desafiante",
		["Charge"] = "Cargar",
		["Charge Rage Bonus Effect"] = "Efecto de bono de rabia de cargar",      -- check
		["Charge Stun"] = "Aturdimiento de cargar",    -- check
		["Cheap Shot"] = "Golpe bajo",
		["Chilled"] = "Enfriado",  -- check
		["Circle of Healing"] = "C\195\173rculo de sanaci\195\179n",
		["Claw"] = "Zarpa",
		["Class Trainer"] = "Class Trainer",    -- fix
		["Cleanse"] = "Limpiar",
		["Clearcasting"] = "Lanzamiento claro",   -- check
		["Cleave"] = "Rajar",
		["Clever Traps"] = "Trampas inteligentes",
		["Cloak of Shadows"] = "Capa de las Sombras",
		["Closing"] = "Cerrando",
		["Cloth"] = "Pa\195\177o",
		["Coarse Sharpening Stone"] = "Piedra de afilar burda",
		["Cobra Reflexes"] = "Reflejos de cobra",   -- check
		["Cold Blood"] = "Sangre fr\195\173a",
		["Cold Snap"] = "Mordedura de fr\195\173o",
		["Combat Endurance"] = "Robustez de combate",   -- check
		["Combustion"] = "Combusti\195\179n",
		["Command"] = "Ordenar",
		["Commanding Presence"] = "Grito de batalla mejorado",
		["Commanding Shout"] = "Grito de orden",
		["Concentration Aura"] = "Aura de concentraci\195\179n",
		["Concussion"] = "Conmoci\195\179n",
		["Concussion Blow"] = "Arremetida de conmoci\195\179n",
		["Concussive Barrage"] = "Concussive Barrage",   -- fix
		["Concussive Shot"] = "Disparo de conmoci\195\179n",
		["Cone of Cold"] = "Cono de fr\195\173o",
		["Conflagrate"] = "Conflagrar",
		["Conjure Food"] = "Crear comida",
		["Conjure Mana Agate"] = "Crear \195\161gata de man\195\161",
		["Conjure Mana Citrine"] = "Crear citrino de man\195\161",
		["Conjure Mana Emerald"] = "Crear esmeralda de man\195\161",
		["Conjure Mana Jade"] = "Crear jade de man\195\161",
		["Conjure Mana Ruby"] = "Crear rub\195\173 de man\195\161",
		["Conjure Water"] = "Crear agua",
		["Consecration"] = "Consagraci\195\179n",
		["Consume Magic"] = "Consumir magia",  -- check
		["Consume Shadows"] = "Consumir Sombras",
		["Contagion"] = "Contagio",  -- check
		["Convection"] = "Convecci\195\179n",
		["Conviction"] = "Convicci\195\179n",
		["Cooking"] = "Cocina",
		["Corruption"] = "Corrupci\195\179n",
		["Counterattack"] = "Contraataque",
		["Counterspell"] = "Contrahechizo",
		["Counterspell - Silenced"] = "Contrahechizo - Silenciado",  -- check
		["Cower"] = "Agazapar",
		["Create Firestone"] = "Crear piedra de fuego",
		["Create Firestone (Greater)"] = "Crear piedra de fuego (superior)",
		["Create Firestone (Lesser)"] = "Crear piedra de fuego (inferior)",
		["Create Firestone (Major)"] = "Crear piedra de fuego (sublime)",
		["Create Healthstone"] = "Crear piedra de salud",
		["Create Healthstone (Greater)"] = "Crear piedra de salud (superior)",
		["Create Healthstone (Lesser)"] = "Crear piedra de salud (inferior)",
		["Create Healthstone (Major)"] = "Crear piedra de salud (sublime)",
		["Create Healthstone (Minor)"] = "Crear piedra de salud (menor)",
		["Create Soulstone"] = "Crear piedra de alma",
		["Create Soulstone (Greater)"] = "Crear piedra de alma (superior)",
		["Create Soulstone (Lesser)"] = "Crear piedra de alma (inferior)",
		["Create Soulstone (Major)"] = "Crear piedra de alma (sublime)",
		["Create Soulstone (Minor)"] = "Crear piedra de alma (menor)",
		["Create Spellstone"] = "Crear piedra de hechizo",
		["Create Spellstone (Greater)"] = "Crear piedra de hechizo (superior)",
		["Create Spellstone (Major)"] = "Crear piedra de hechizo (sublime)",
		["Create Spellstone (Master)"] = "Crear piedra de hechizo (maestra)",
		["Cripple"] = "Entorpecer",   -- check
		["Crippling Poison"] = "Veneno entorpecedor",
		["Crippling Poison II"] = "Veneno entorpecedor II",
		["Critical Mass"] = "Masa cr\195\173tica",
		["Crossbows"] = "Ballestas",
		["Cruelty"] = "Crueldad",
		["Crusade"] = "Cruzada",  -- check
		["Crusader Aura"] = "Aura de cruzado",   -- check
		["Crusader Strike"] = "Golpe de cruzado",
		["Cultivation"] = "Cultivo",
		["Cure Disease"] = "Curar enfermedad",
		["Cure Poison"] = "Curar envenenamiento",
		["Curse of Agony"] = "Maldici\195\179n de agon\195\173a",
		["Curse of Doom"] = "Maldici\195\179n del Apocalipsis",
		["Curse of Doom Effect"] = "Efecto de Maldici\195\179n del Apocalipsis",  -- check
		["Curse of Exhaustion"] = "Maldici\195\179n de agotamiento",
		["Curse of Idiocy"] = "Maldici\195\179n de idiotez",   -- check
		["Curse of Recklessness"] = "Maldici\195\179n de temeridad",
		["Curse of Shadow"] = "Maldici\195\179n de las Sombras",
		["Curse of Tongues"] = "Maldici\195\179n de las lenguas",
		["Curse of Weakness"] = "Maldici\195\179n de debilidad",
		["Curse of the Elements"] = "Maldici\195\179n de los Elementos",
		["Cyclone"] = "Cicl\195\179n",
		["Dagger Specialization"] = "Especializaci\195\179n en dagas",
		["Daggers"] = "Dagas",
		["Dampen Magic"] = "Atenuar magia",
		["Dark Pact"] = "Pacto oscuro",
		["Darkness"] = "Oscuridad",
		["Dash"] = "Carrerilla",
		["Dawnstone Crab"] = "Dawnstone Crab",  -- fix
		["Dazed"] = "Atontado",  -- check - aturdido?
		["Deadly Interrupt Effect"] = "Efecto de Interrupcion mortal",   -- check
		["Deadly Poison"] = "Veneno mortal",
		["Deadly Poison II"] = "Veneno mortal II",
		["Deadly Poison III"] = "Veneno mortal III",
		["Deadly Poison IV"] = "Veneno mortal IV",
		["Deadly Poison V"] = "Veneno mortal V",
		["Deadly Poison VI"] = "Veneno mortal VI",
		["Deadly Poison VII"] = "Veneno mortal VI",
		["Deadly Throw"] = "Lanzamiento mortal",
		["Death Coil"] = "Espiral de la muerte",
		["Death Wish"] = "Deseo de la Muerte",
		["Deep Wound"] = "Herida profunda",
		["Deep Wounds"] = "Heridas profundas",
		["Defense"] = "Defensa",
		["Defensive Stance"] = "Actitud defensiva",
		["Defensive Stance Passive"] = "Actitud defensiva pasiva",   -- check
		["Defiance"] = "Desaf\195\173o",
		["Deflection"] = "Desv\195\173o",
		["Delusions of Jin'do"] = "Delusions of Jin'do",   -- fix
		["Demon Armor"] = "Armadura demon\195\173aca",
		["Demon Skin"] = "Piel de demonio",
		["Demonic Aegis"] = "\195\137gida demon\195\173aca",
		["Demonic Embrace"] = "Abrazo demon\195\173aco",
		["Demonic Frenzy"] = "Frenes\195\173 demon\195\173aco",     -- check
		["Demonic Knowledge"] = "Conocimiento demon\195\173aco",
		["Demonic Resilience"] = "Temple demon\195\173aco",
		["Demonic Sacrifice"] = "Sacrificio demon\195\173aco",
		["Demonic Tactics"] = "T\195\161cticas demon\195\173acas",
		["Demoralizing Roar"] = "Rugido desmoralizador",
		["Demoralizing Shout"] = "Grito desmoralizador",
		["Dense Sharpening Stone"] = "Piedra de afilar densa",
		["Desperate Prayer"] = "Rezo desesperado",   -- check
		["Destructive Reach"] = "Alcance destructivo",
		["Detect"] = "Detectar",
		["Detect Greater Invisibility"] = "Detectar Invisibilidad mayor",       -- not used
		["Detect Invisibility"] = "Detectar Invisibilidad",
		["Detect Lesser Invisibility"] = "Detectar Invisibilidad menor",        -- not used
		["Detect Magic"] = "Detectar magia",
		["Detect Traps"] = "Detectar trampas",
		["Deterrence"] = "Disuasi\195\179n",
		["Devastate"] = "Devastar",      -- check
		["Devastation"] = "Devastaci\195\179n",
		["Devotion Aura"] = "Aura de devoci\195\179n",
		["Devour Magic"] = "Devorar magia",
		["Devour Magic Effect"] = "Efecto de Devorar Magia",    -- check
		["Devouring Plague"] = "Plaga devoradora",       -- check
		["Diplomacy"] = "Diplomacia",
		["Dire Bear Form"] = "Forma de oso temible",
		["Dirty Deeds"] = "Dirty Deeds", -- Needs localization.
		["Dirty Tricks"] = "Zapar mejorado",
		["Disarm"] = "Desarmar",
		["Disarm Trap"] = "Desactivar trampa",
		["Disease Cleansing Totem"] = "T\195\179tem de limpieza de enfermedades",
		["Disenchant"] = "Desencantar",
		["Disengage"] = "Separaci\195\179n",
		["Dismiss Pet"] = "Retirar mascota",
		["Dispel Magic"] = "Disipar magia",
		["Distract"] = "Distraer",
		["Distracting Shot"] = "Disparo de distracci\195\179n",
		["Dive"] = "Bucear",     -- check
  		["Divine Favor"] = "Favor divino",
		["Divine Fury"] = "Furia divina",
		["Divine Illumination"] = "Iluminaci\195\179n divina",
		["Divine Intellect"] = "Intelecto divino",
		["Divine Intervention"] = "Intervenci\195\179n divina",
		["Divine Protection"] = "Protecci\195\179n divina",
		["Divine Shield"] = "Escudo divino",
		["Divine Spirit"] = "Esp\195\173ritu divino",
		["Divine Strength"] = "Fortaleza divina",
		["Dodge"] = "Esquivar",
		["Dragon's Breath"] = "Aliento de drag\195\179n",
		["Dragonscale Leatherworking"] = "Peleter\195\173a dragontina",   -- check
		["Drain Life"] = "Drenar vida",
		["Drain Mana"] = "Drenar man\195\161",
		["Drain Soul"] = "Drenar alma",
		["Dreamless Sleep"] = "Dreamless Sleep",  -- fix
		["Drink"] = "Beber",
		["Dual Wield"] = "Doble empu\195\177adura",
		["Dual Wield Specialization"] = "Especializaci\195\179n en doble empu\195\177adura",
		["Duel"] = "Duelo",
		["Dust Cloud"] = "Nube de polvo",  -- fix
		["Eagle Eye"] = "Ojo de \195\161guila",
		["Earth Elemental Totem"] = "T\195\179tem Elemental de tierra",    -- check
		["Earth Shield"] = "Escudo de tierra",
		["Earth Shock"] = "Choque de tierra",
		["Earthbind"] = "Nexo terrestre",
		["Earthbind Totem"] = "T\195\179tem Nexo terrestre",
		["Earthstrike"] = "Earthstrike",   -- fix
		["Efficiency"] = "Eficacia",
		["Elemental Devastation"] = "Devastacion elemental",   -- fix
		["Elemental Focus"] = "Enfoque elemental",
		["Elemental Fury"] = "Furia elemental",
		["Elemental Leatherworking"] = "PPeleter\195\173a elemental",   -- check
		["Elemental Mastery"] = "Maestr\195\173a elemental",
		["Elemental Precision"] = "Precisi\195\179n elemental",   -- check
		["Elemental Sharpening Stone"] = "Piedra de afilar elemental",
		["Elemental Weapons"] = "Elemental Weapons",  -- Needs localization.
		["Elune's Grace"] = "Gracia de Elune",    -- check
		["Elusiveness"] = "Elusi\195\179n",
		["Emberstorm"] = "Tormenta de brasales",
		["Empowered Arcane Missiles"] = "Misiles Arcanos empoderados",    -- check
		["Empowered Corruption"] = "Corrupci\195\179n empoderada",       -- check
		["Empowered Fireball"] = "Bola de fuego empoderada",     -- check
		["Empowered Frostbolt"] = "Descarga de Escarcha empoderada",    -- check
		["Empowered Healing"] = "Sanaci\195\179n empoderada",   -- check
		["Empowered Rejuvenation"] = "Rejuvenecimiento empoderado",    -- check
		["Empowered Touch"] = "Toque empoderado",       -- check
		["Enamored Water Spirit"] = "Esp\195\173ritu de agua enamorado",  -- check
		["Enchanting"] = "Encantamiento",
		["Endurance"] = "Robustez",
		["Endurance Training"] = "Adiestramiento en robustez",
		["Engineering"] = "Ingenier\195\173a",
		["Engineering Specialization"] = "Especializaci\195\179n de ingenier\195\173a",
		["Enrage"] = "Enfurecer",
		["Enriched Manna Biscuit"] = "Galleta enriquecida con man\195\161",
		["Enslave Demon"] = "Esclavizar demonio",
		["Entangling Roots"] = "Ra\195\173ces enredadoras",
		["Entrapment"] = "Incitaci\195\179n",
		["Envenom"] = "Emponzo\195\177ar",
		["Escape Artist"] = "Artista del escape",
		["Evasion"] = "Evasi\195\179n",
		["Eviscerate"] = "Eviscerar",
		["Evocation"] = "Evocaci\195\179n",
		["Execute"] = "Ejecutar",
		["Exorcism"] = "Exorcismo",
		["Expansive Mind"] = "Mente expansiva",
		["Explosive Trap"] = "Trampa explosiva",
		["Explosive Trap Effect"] = "Efecto de Trampa explosiva",     -- check
		["Expose Armor"] = "Exponer armadura",
		["Expose Weakness"] = "Exponer debilidad", -- check
		["Extract Gas"] = "Extraer gas",    -- check
		["Eye for an Eye"] = "Ojo por ojo",
		["Eye of Kilrogg"] = "Ojo de Kilrogg",
		["Eye of the Storm"] = "Ojo de la tormenta",    -- fix
		["Eyes of the Beast"] = "Ojos de la bestia",
		["Fade"] = "Desvanecerse",
		["Faerie Fire"] = "Fuego fe\195\169rico",
		["Faerie Fire (Feral)"] = "Fuego fe\195\169rico (feral)",
		["Fanaticism"] = "Fanatismo",   -- check
		["Far Sight"] = "Vista lejana",
		["Fear"] = "Miedo",
		["Fear Ward"] = "Resguardo contra el miedo",  -- check
		["Feed Pet"] = "Alimentar mascota",
		["Feed Pet Effect"] = "Efecto de Alimentar mascota",  -- check
		["Feedback"] = "Reacci\195\179n", -- check
		["Feign Death"] = "Fingir muerte",
		["Feint"] = "Amago",
		["Fel Armor"] = "Armadura vil",
		["Fel Concentration"] = "Concentraci\195\179n vil",
		["Fel Domination"] = "Dominio vil",
		["Fel Energy"] = "Energia vil",   -- fix
		["Fel Intellect"] = "Intelecto vil",
		["Fel Rage"] = "Ira vil",		-- check
		["Fel Stamina"] = "Aguante vil",
		["Felfire"] = "Fuego vil",  -- check
		["Feline Grace"] = "Gracia felina",
		["Feral Aggression"] = "Agresi\195\179n feral",
		["Feral Charge"] = "Carga feral",
		["Feral Instinct"] = "Instinto feral",
		["Feral Swiftness"] = "Presteza feral",
		["Ferocious Bite"] = "Mordedura feroz",
		["Ferocious Inspiration"] = "Inspiraci\195\179n feroz",  -- check
		["Ferocity"] = "Ferocidad",
		["Fetish"] = "Fetiche",   -- check
		["Find Fish"] = "Find Fish",  -- check
		["Find Herbs"] = "Buscar hierbas",
		["Find Minerals"] = "Buscar minerales",
		["Find Treasure"] = "Encontrar tesoro",
		["Find Weakness"] = "Descubrir debilidad",
		["Fire Blast"] = "Explosi\195\179n de Fuego",
		["Fire Breath"] = "Aliento de Fuego",  -- check
		["Fire Elemental Totem"] = "T\195\179tem Elemental de Fuego",   -- check
		["Fire Nova Totem"] = "T\195\179tem Nova de Fuego",
		["Fire Power"] = "Poder de Fuego",
		["Fire Resistance"] = "Resistencia al Fuego",
		["Fire Resistance Aura"] = "Aura de resistencia al Fuego",
		["Fire Resistance Totem"] = "T\195\179tem de resistencia al Fuego",
		["Fire Shield"] = "Escudo de Fuego",
		["Fire Vulnerability"] = "Vulnerabilidad al Fuego",    -- check
		["Fire Ward"] = "Resguardo contra el Fuego",
		["Fire Weakness"] = "Debilidad al Fuego",  -- check
		["Fireball"] = "Bola de Fuego",
		["Firebolt"] = "Descarga de Fuego",
		["First Aid"] = "Primeros auxilios",
		["Fishing"] = "Pesca",
		["Fishing Poles"] = "Ca\195\177as de pescar",
		["Fist Weapon Specialization"] = "Especializaci\195\179n en armas de pu\195\177o",
		["Fist Weapons"] = "Armas de pu\195\177o",
		["Flame Shock"] = "Choque de llamas",
		["Flame Throwing"] = "Lanzamiento de llamas",   -- check
		["Flamestrike"] = "Fogonazo",
		["Flamethrower"] = "Lanzallamas",   -- check
		-- ["Flametongue Attack"] = "???",
		["Flametongue Totem"] = "T\195\179tem Lengua de fuego",
		["Flametongue Weapon"] = "Arma Lengua de fuego",
		["Flare"] = "Bengala",
		["Flash Heal"] = "Sanaci\195\179n rel\195\161mpago",
		["Flash of Light"] = "Destello de Luz",
		["Flight Form"] = "Forma de vuelo",     -- check
		["FlightMaster"] = "FlightMaster",   -- fix
		["Flurry"] = "Aluvi\195\179n",
		["Focused Casting"] = "Lanzamiento enfocado",  -- check
		["Focused Mind"] = "Mente enfocada",   -- check
		["Focused Power"] = "Poder enfocado",     -- fix
		["Focused Rage"] = "Focused Rage",  -- Needs localization.
		["Focused Starlight"] = "Luz estelar enfocada",  -- check
		["Food"] = "Comida",
		["Food & Drink"] = "Food & Drink",
		["Forbearance"] = "Abstenci\195\179n",   -- check
		["Force of Nature"] = "Fuerza de la Naturaleza",
		["Force of Will"] = "Fuerza de voluntad",
		["Freezing Trap"] = "Trampa congelante",
		["Freezing Trap Effect"] = "Efecto de Trampa congelante",   -- check
		["Frenzied Regeneration"] = "Regeneraci\195\179n fren\195\169tica",
		["Frenzy"] = "Frenes\195\173",
		["Frost Armor"] = "Armadura de Escarcha",
		["Frost Blast"] = "Frost Blast",   -- fix
		["Frost Channeling"] = "Canalizaci\195\179n de Escarcha",
		["Frost Nova"] = "Nova de Escarcha",
		["Frost Resistance"] = "Resistencia a la Escarcha",
		["Frost Resistance Aura"] = "Aura de resistencia a la Escarcha",
		["Frost Resistance Totem"] = "T\195\179tem de resistencia a la Escarcha",
		["Frost Shock"] = "Choque de Escarcha",
		["Frost Trap"] = "Trampa de Escarcha",   -- check
		["Frost Trap Aura"] = "Efecto de Trampa de Escarcha",   -- check
		["Frost Ward"] = "Resguardo contra la Escarcha",
		["Frost Warding"] = "Guardia contra la Escarcha",  -- check
		["Frost Weakness"] = "Debilidad a la Escarcha",   -- check
		["Frostbite"] = "Mordedura de Escarcha",
		["Frostbolt"] = "Descarga de Escarcha",
		["Frostbrand Attack"] = "Ataque de Estigma de Escarcha",   -- check
		["Frostbrand Weapon"] = "Arma Estigma de Escarcha",
		["Frozen Core"] = "N\195\186cleo de Escarcha",  -- check
		["Furious Howl"] = "Aullido furioso",  -- check
		["Furor"] = "Furor",
		["Fury of the Crashing Waves"] = "Fury of the Crashing Waves",   -- fix
		["Garrote"] = "Garrote",
		["Garrote - Silence"] = "Garrote - Silencio",  -- check
		["Ghost Wolf"] = "Lobo fantasmal",
		["Ghostly Strike"] = "Golpe fantasmal",
		["Gift of Life"] = "Ofrenda de vida",   -- check
		["Gift of Nature"] = "Ofrenda de la Naturaleza",
		["Gift of the Naaru"] = "Ofrenda de los Naaru",
		["Gift of the Wild"] = "Don de lo Salvaje",
		["Gouge"] = "Gubia",
		["Grace of Air"] = "Gracia del aire",
		["Grace of Air Totem"] = "T\195\179tem Gracia del aire",
		["Great Stamina"] = "Gran aguante",
		["Greater Blessing of Kings"] = "Bendici\195\179n de reyes superior",
		["Greater Blessing of Light"] = "Bendici\195\179n de luz superior",
		["Greater Blessing of Might"] = "Bendici\195\179n de poder\195\173o superior",
		["Greater Blessing of Salvation"] = "Bendici\195\179n de salvaci\195\179n superior",
		["Greater Blessing of Sanctuary"] = "Bendici\195\179n de salvaguardia superior",
		["Greater Blessing of Wisdom"] = "Bendici\195\179n de sabidur\195\173a superior",
		["Greater Dreamless Sleep"] = "Greater Dreamless Sleep",   -- fix
		["Greater Heal"] = "Sanaci\195\179n superior",
		["Grim Reach"] = "Alcance macabro",
		["Grounding Totem"] = "T\195\179tem derribador",
		["Grounding Totem Effect"] = "Efecto de totem derribador",
		["Grovel"] = "Humillarse",  -- check
		["Growl"] = "Bramido",
		["Guardian's Favor"] = "Favor del Guardi\195\161n",
		["Gun Specialization"] = "Especializaci\195\179n en armas de fuego",
		["Guns"] = "Armas de fuego",
		["Hammer of Justice"] = "Martillo de justicia",
		["Hammer of Wrath"] = "Martillo de c\195\179lera",
		["Hamstring"] = "Seccionar",
		["Harass"] = "Acosar",  -- check
		["Hardiness"] = "Dureza",   -- check
		["Haste"] = "Apresurar",   -- fix
		["Hawk Eye"] = "Ojo de halc\195\179n",
		["Heal"] = "Sanar",
		["Healing Focus"] = "Enfoque de sanaci\195\179n",
		["Healing Light"] = "Luz de sanaci\195\179n",
		["Healing Stream"] = "Corriente de sanacion",
		["Healing Stream Totem"] = "T\195\179tem Corriente de sanaci\195\179n",
		["Healing Touch"] = "Toque de sanaci\195\179n",
		["Healing Wave"] = "Ola de sanaci\195\179n",
		["Healing Way"] = "Forma de sanaci\195\179n",
		["Health Funnel"] = "Cauce de salud",
		["Heart of the Wild"] = "Coraz\195\179n de fiera",
		["Heavy Sharpening Stone"] = "Piedra de afilar pesada",
		["Hellfire"] = "Llamas infernales",
		["Hellfire Effect"] = "Efecto de Llamas infernales",    -- check
		["Hellfire Superiority"] = "Superioridad de llamas infernales",   -- check
		["Hemorrhage"] = "Hemorragia",
		["Herb Gathering"] = "Recolectar hierbas",
		["Herbalism"] = "Bot\195\161nica",   -- Herborister\195\173a / Bot\195\161nica
		["Heroic Strike"] = "Golpe heroico",
		["Heroism"] = "Hero\195\173smo",
		["Hex of Weakness"] = "Maleficio de debilidad",
		["Hibernate"] = "Hivernar",
		["Holy Fire"] = "Fuego Sagrado",
		["Holy Light"] = "Luz Sagrada",
		["Holy Nova"] = "Nova Sagrada",
		["Holy Power"] = "Poder Sagrado",
		["Holy Reach"] = "Alcance Sagrado",
		["Holy Shield"] = "Escudo Sagrado",
		["Holy Shock"] = "Choque Sagrado",
		["Holy Specialization"] = "Especializaci\195\179n Sagrada",
		["Holy Wrath"] = "C\195\179lera sagrada",
		["Honorless Target"] = "Objetivo sin honor",
		["Horse Riding"] = "Equitaci\195\179n",   -- check
		["Howl of Terror"] = "Aullido de terror",
		["Humanoid Slaying"] = "Matanza de humanoides",
		["Hunter's Mark"] = "Marca del cazador",
		["Hurricane"] = "Hurac\195\161n",
		["Hypothermia"] = "Hipot\195\169rmia",   -- check
		["Ice Armor"] = "Armadura de hielo",
		["Ice Barrier"] = "Barrera de hielo",
		["Ice Block"] = "Bloque de hielo",
		["Ice Floes"] = "T\195\169mpanos de hielo",   -- check
		["Ice Lance"] = "Lanza de hielo",
		["Ice Shards"] = "Fragmentos de hielo",
		["Ignite"] = "Ignici\195\179n",
		["Ignite Mana"] = "Ignite Mana", -- fix
		["Illumination"] = "Iluminaci\195\179n",   -- check
		["Immolate"] = "Inmolar",
		["Immolation Trap"] = "Trampa de inmolaci\195\179n",
		["Immolation Trap Effect"] = "Efecto de Trampa de inmolaci\195\179n",   -- check
		["Impact"] = "Impacto",
		["Impale"] = "Empalar",
		["Improved Ambush"] = "Emboscada mejorada",
		["Improved Arcane Missiles"] = "Misiles Arcanos mejorados",
		["Improved Arcane Shot"] = "Disparo Arcano mejorado",
		["Improved Aspect of the Hawk"] = "Aspecto del Halc\195\179n mejorado",
		["Improved Aspect of the Monkey"] = "Aspecto del mono mejorado",
		["Improved Backstab"] = "Pu\195\177alada mejorada",
		["Improved Barrage"] = "Improved Barrage",  -- Needs localization.
		["Improved Berserker Rage"] = "Ira rabiosa mejorada",
		["Improved Blessing of Might"] = "Bendici\195\179n de poder\195\173o mejorada",
		["Improved Blessing of Wisdom"] = "Bendici\195\179n de sabidur\195\173a mejorada",
		["Improved Blink"] = "Traslaci\195\179n mejorada",   -- check
		["Improved Blizzard"] = "Ventisca mejorada",
		["Improved Bloodrage"] = "Ira sangrienta mejorada",
		["Improved Chain Heal"] = "Sanaci\195\179n en cadena mejorada",
		["Improved Chain Lightning"] = "Cadena de rel\195\161mpagos mejorada",   -- check
		["Improved Challenging Shout"] = "Grito desafiante mejorado",    -- check
		["Improved Charge"] = "Cargar mejorado",
		["Improved Cleave"] = "Rajar mejorado",   -- check
		["Improved Concentration Aura"] = "Aura de concentraci\195\179n mejorada",
		["Improved Concussive Shot"] = "Disparo de conmoci\195\179n mejorado",
		["Improved Cone of Cold"] = "Cono de fr\195\173o mejorado",
		["Improved Corruption"] = "Corrupci\195\179n empoderada",
		["Improved Counterspell"] = "Contrahechizo mejorado",
		["Improved Curse of Agony"] = "Maldici\195\179n de agon\195\173a mejorada",
		["Improved Curse of Weakness"] = "Maldici\195\179n de debilidad mejorada",
		["Improved Demoralizing Shout"] = "Grito desmoralizador mejorado",
		["Improved Devotion Aura"] = "Aura de devoci\195\179n mejorada",
		["Improved Disarm"] = "Desarmar mejorado",
		["Improved Drain Life"] = "Drenar vida mejorado",   -- non existant
		["Improved Drain Soul"] = "Drenar alma mejorado",
		["Improved Enrage"] = "Enfurecer mejorado",  -- check
		["Improved Enslave Demon"] = "Esclavizar demonio mejorado",
		["Improved Eviscerate"] = "Eviscerar mejorado",
		["Improved Execute"] = "Ejecutar mejorado",
		["Improved Expose Armor"] = "Exponer armadura mejorado",
		["Improved Eyes of the Beast"] = "Ojos de la bestia mejorado",    -- check
		["Improved Fade"] = "Desvanecer mejorado",
		["Improved Feign Death"] = "Fingir muerte mejorado",
		["Improved Fire Blast"] = "Explosi\195\179n de Fuego mejorada",
		["Improved Fire Ward"] = "Resguardo contra el Fuego mejorado",
		["Improved Fireball"] = "Bola de Fuego mejorada",
		["Improved Firebolt"] = "Descarga de Fuego mejorada",
		["Improved Flamestrike"] = "Fogonazo mejorado",
		["Improved Flash of Light"] = "Destello de Luz mejorado",   -- check
		["Improved Frost Nova"] = "Nova de Escarcha mejorada",
		["Improved Frostbolt"] = "Descarga de Escarcha mejorada",
		["Improved Ghost Wolf"] = "Lobo fantasmal mejorado",
		["Improved Gouge"] = "Gubia mejorada",
		["Improved Hammer of Justice"] = "Martillo de justicia mejorado",
		["Improved Hamstring"] = "Seccionar mejorado",
		["Improved Healing"] = "Sanaci\195\179n mejorada",
		["Improved Healing Touch"] = "Toque de sanaci\195\179n mejorado",   -- check
		["Improved Healing Wave"] = "Ola de sanaci\195\179n mejorada",
		["Improved Health Funnel"] = "Cauce de salud mejorado",
		["Improved Healthstone"] = "Piedra de salud mejorada",
		["Improved Heroic Strike"] = "Golpe heroico mejorado",
		["Improved Holy Shield"] = "Improved Holy Shield",  -- Needs localization.
		["Improved Howl of Terror"] = "Aullido de terror mejorado",  -- check
		["Improved Hunter's Mark"] = "Marca del cazador mejorada",
		["Improved Immolate"] = "Inmolar mejorado",
		["Improved Imp"] = "Diablillo mejorado",
		["Improved Inner Fire"] = "Fuego interno mejorado",
		["Improved Intercept"] = "Intercepci\195\179n mejorada",
		["Improved Intimidating Shout"] = "Grito intimidador mejorado",   -- check
		["Improved Judgement"] = "Sentencia mejorada",
		["Improved Kick"] = "Patada mejorada",
		["Improved Kidney Shot"] = "Golpe en los ri\195\177ones mejorado",
		["Improved Lash of Pain"] = "Latigazo doloroso mejorado",
		["Improved Lay on Hands"] = "Imposici\195\179n de manos mejorada",
		["Improved Leader of the Pack"] = "L\195\173der mejorado de la manada",	-- check
		["Improved Life Tap"] = "Transfusi\195\179n de vida mejorada",
		["Improved Lightning Bolt"] = "Descarga de rel\195\161mpagos mejorada",  -- check
		["Improved Lightning Shield"] = "Escudo de rel\195\161mpagos mejorado",
		["Improved Magma Totem"] = "T\195\179tem de magma mejorado",  -- check
		["Improved Mana Burn"] = "Quemadura de man\195\161 mejorado",
		["Improved Mana Shield"] = "Escudo de man\195\161 mejorado",
		["Improved Mana Spring Totem"] = "T\195\179tem Fuente de man\195\161 mejorado",  -- check
		["Improved Mark of the Wild"] = "Marca de lo salvaje mejorada",
		["Improved Mend Pet"] = "Aliviar mascota mejorado",
		["Improved Mind Blast"] = "Explosi\195\179n mental mejorada",
		["Improved Moonfire"] = "Fuego lunar mejorado",
		["Improved Mortal Strike"] = "Improved Mortal Strike",  -- Needs localization.
		["Improved Nature's Grasp"] = "Trabaz\195\179n con la Naturaleza mejorada",
		["Improved Overpower"] = "Abrumar mejorado",
		["Improved Power Word: Fortitude"] = "Palabra de poder mejorada: entereza",
		["Improved Power Word: Shield"] = "Palabra de poder mejorada: escudo",
		["Improved Prayer of Healing"] = "Rezo de sanaci\195\179n mejorado",   -- check
		["Improved Psychic Scream"] = "Alarido ps\195\173quico mejorado",
		["Improved Regrowth"] = "Recrecimiento mejorado",
		["Improved Reincarnation"] = "Reencarnaci\195\179n mejorada",
		["Improved Rejuvenation"] = "Rejuvenecimiento mejorado",
		["Improved Rend"] = "Desgarrar mejorado",
		["Improved Renew"] = "Renovar mejorado",
		["Improved Retribution Aura"] = "Aura de sanci\195\179n mejorada",
		["Improved Revenge"] = "Revancha mejorada",
		["Improved Revive Pet"] = "Revivir mascota mejorado",
		["Improved Righteous Fury"] = "Furia justa mejorada",
		["Improved Rupture"] = "Ruptura mejorada",  -- check
		["Improved Scorch"] = "Agostar mejorado",
		["Improved Scorpid Sting"] = "Picadura de esc\195\179rpido mejorada",  -- check
		["Improved Seal of Righteousness"] = "Sello de rectitud mejorado",
		["Improved Seal of the Crusader"] = "Sello del cruzado mejorado",
		["Improved Searing Pain"] = "Dolor abrasador mejorado",
		["Improved Serpent Sting"] = "Picadura de serpiente mejorada",   -- check
		["Improved Shadow Bolt"] = "Descarga de las Sombras mejorada",
		["Improved Shadow Word: Pain"] = "Palabra de las Sombras: dolor mejorada",
		["Improved Shield Bash"] = "Azote de escudo mejorado",
		["Improved Shield Block"] = "Bloquear con escudo mejorado",
		["Improved Shield Wall"] = "Muro de escudo mejorado",
		["Improved Sinister Strike"] = "Golpe siniestro mejorado",
		["Improved Slam"] = "Embate mejorado",
		["Improved Slice and Dice"] = "Hacer picadillo mejorado",
		["Improved Sprint"] = "Sprint mejorado",
		["Improved Stings"] = "Improved Stings",  -- Needs localization.
		["Improved Succubus"] = "S\195\186cubo mejorado",
		["Improved Sunder Armor"] = "Hender armadura mejorado",
		["Improved Taunt"] = "Provocar mejorado",
		["Improved Thunder Clap"] = "Atronar mejorado",
		["Improved Tranquility"] = "Tranquilidad mejorada",
		["Improved Vampiric Embrace"] = "Abrazo vamp\195\173rico mejorado",
		["Improved Vanish"] = "Esfumarse mejorado",   -- check
		["Improved Voidwalker"] = "Abisario mejorado",
		["Improved Weapon Totems"] = "Improved Weapon Totems",  -- Needs localization.
		["Improved Whirlwind"] = "Improved Whirlwind",  -- Needs localization.
		["Improved Wing Clip"] = "Cortar alas mejorado",
		["Incinerate"] = "Incinerar",
		["Incineration"] = "Incineraci\195\179n",
		["Inferno"] = "Inferno",
		["Initiative"] = "Iniciativa",
		["Inner Fire"] = "Fuego interno",
		["Inner Focus"] = "Enfoque interno",
		["Innervate"] = "Enervar",
		["Innkeeper"] = "Innkeeper",  -- fix
		["Insect Swarm"] = "Enjambre de insectos",
		["Inspiration"] = "Inspiraci\195\179n",
		["Insignifigance"] = "Insignificancia",  -- fix
		["Instant Poison"] = "Veneno instant\195\161neo",
		["Instant Poison II"] = "Veneno instant\195\161neo II",
		["Instant Poison III"] = "Veneno instant\195\161neo III",
		["Instant Poison IV"] = "Veneno instant\195\161neo IV",
		["Instant Poison V"] = "Veneno instant\195\161neo V",
		["Instant Poison VI"] = "Veneno instant\195\161neo VI",
		["Instant Poison VII"] = "Veneno instant\195\161neo VII",
		["Intensity"] = "Intensidad",
		["Intercept"] = "Interceptar",
		["Intercept Stun"] = "Aturdimiento de Interceptar",   -- check
		["Intervene"] = "Intervenir",
		["Intimidating Shout"] = "Grito intimidador",
		["Intimidation"] = "Intimidaci\195\179n",
		["Invisibility"] = "Invisibilidad",
		["Iron Will"] = "Voluntad de hierro",
		["Jewelcrafting"] = "Joyer\195\173a",
		["Jom Gabbar"] = "Jom Gabbar",   -- fix
		["Judgement"] = "Sentencia",
--		["Judgement of Blood"] = true,
--		["Judgement of Reckoning"] = true,
		["Judgement of Command"] = "Sentencia de orden",     -- check
		["Judgement of Justice"] = "Sentencia de justicia",   -- check
		["Judgement of Light"] = "Sentencia de Luz",          -- check
		["Judgement of Righteousness"] = "Sentencia de rectitud",  -- check
		["Judgement of Wisdom"] = "Sentencia de sabidur\195\173a",         -- check
		["Judgement of the Crusader"] = "Sentencia de cruzado",     -- check
		["Kick"] = "Patada",
		["Kick - Silenced"] = "Patada - Silenciado",  -- check
		["Kidney Shot"] = "Golpe en los ri\195\177ones",
		["Kill Command"] = "Orden de muerte",  -- check
		["Killer Instinct"] = "Instinto asesino",
		["Kiss of the Spider"] = "Beso de la arana",   -- fix
		["Kodo Riding"] = "Cabalgar kodo",   -- check
		["Lacerate"] = "Lacerar",
		["Lash of Pain"] = "Latigazo doloroso",
		["Last Stand"] = "\195\154ltima carga",
		["Lay on Hands"] = "Imposici\195\179n de manos",
		["Leader of the Pack"] = "L\195\173der de la manada",
		["Leather"] = "Cuero",
		["Leatherworking"] = "Peleter\195\173a",
		["Lesser Heal"] = "Sanaci\195\179n inferior",
		["Lesser Healing Wave"] = "Ola de sanaci\195\179n inferior",
		["Lesser Invisibility"] = "Invisibilidad inferior",  -- check
		["Lethal Shots"] = "Disparos letales",
		["Lethality"] = "Letalidad",
		["Levitate"] = "Levitar",
		["Libram"] = "Tratado",   -- check
		["Life Tap"] = "Transfusi\195\179n de vida",
		["Lifebloom"] = "Flor de vida",
		["Light's Grace"] = "Gracia de la luz",   -- fix
		["Lightning Bolt"] = "Descarga de rel\195\161mpagos",
		["Lightning Breath"] = "Aliento de rel\195\161mpagos",    -- check
		["Lightning Mastery"] = "Maestr\195\173a en rel\195\161mpagos",
		["Lightning Reflexes"] = "Reflejos de rel\195\161mpago",
		["Lightning Shield"] = "Escudo de rel\195\161mpagos",
		["Lightning Speed"] = "Lightning Speed",    -- fix
		["Lightwell"] = "Pozo de luz",
		["Lightwell Renew"] = "Renovaci\195\179n de Pozo de Luz",   -- check
		["Lockpicking"] = "Abriendo cerradura",  -- check
		["Long Daze"] = "Aturdimiento largo",  -- check
		["Lust for Battle"] = "Lust for Battle",    -- fix
		["Mace Specialization"] = "Especializaci\195\179n con mazas",
		["Mace Stun Effect"] = "Efecto de aturdimiento de maza",  -- check
		["Mage Armor"] = "Armadura de mago",
		["Magic Absorption"] = "Absorci\195\179n m\195\161gica",   -- check
		["Magic Attunement"] = "Ajuste m\195\161gico",      -- check
		["Magma Totem"] = "T\195\179tem de magma",
		["Mail"] = "Malla",
		["Maim"] = "Mutilar",  -- check
		["Major Dreamless Sleep"] = "Major Dreamless Sleep",   -- fix
		["Malediction"] = "Maldici\195\179n",  -- check
		["Malice"] = "Maldad",
		["Mana Burn"] = "Quemadura de man\195\161",
		["Mana Feed"] = "Alimentar man\195\161",
		["Mana Shield"] = "Escudo de man\195\161",
		["Mana Spring"] = "Fuente de mana",
		["Mana Spring Totem"] = "T\195\179tem Fuente de man\195\161",
		["Mana Tap"] = "Transfusion de mana",
		["Mana Tide"] = "Marea de mana",
		["Mana Tide Totem"] = "T\195\179tem Marea de man\195\161",
		["Mangle"] = "Destrozar",
		["Mangle (Bear)"] = "Destrozar (oso)",
		["Mangle (Cat)"] = "Destrozar (felino)",
		["Mark of the Wild"] = "Marca de lo Salvaje",
		["Martyrdom"] = "Martirio",
		["Mass Dispel"] = "Disipaci\195\179n en masa",
		["Master Conjuror"] = "Maestro conjurador",
		["Master Demonologist"] = "Maestro demon\195\179logo",
		["Master Summoner"] = "Maestro invocador",
		["Master Tactician"] = "Maestro tactico",
		["Master of Deception"] = "Maestro del enga\195\177o",
		["Master of Elements"] = "Maestro de los elementos",   -- check
		["Master of Subtlety"] = "Maestro de la sutileza",   -- check
		["Maul"] = "Magullar",
		["Mechanostrider Piloting"] = "Pilotar mecazancudo",  -- check
		["Meditation"] = "Meditaci\195\179n",
		["Melee Specialization"] = "Especializaci\195\179n en cuerpo a cuerpo",  -- check
		["Mend Pet"] = "Aliviar mascota",
		["Mental Agility"] = "Agilidad mental",
		["Mental Strength"] = "Fortaleza mental",
		["Mind Blast"] = "Explosi\195\179n mental",
		["Mind Control"] = "Control mental",
		["Mind Flay"] = "Tortura mental",
		["Mind Mastery"] = "Maestr\195\173a mental",    -- check
		["Mind Soothe"] = "Calma mental",
		["Mind Vision"] = "Visi\195\179n mental",
		["Mind-numbing Poison"] = "Veneno de aturdimiento mental",
		["Mind-numbing Poison II"] = "Veneno de aturdimiento mental II",
		["Mind-numbing Poison III"] = "Veneno de aturdimiento mental III",
		["Mining"] = "Miner\195\173a",
		["Misdirection"] = "Redirecci\195\179n",
		["Misery"] = "Miseria",  -- check
		["Mocking Blow"] = "Falsa arremetida",
		["Molten Armor"] = "Armadura de n\195\186cleo",  -- check
		["Molten Fury"] = "Furia del n\195\186cleo",  -- check
		["Mongoose Bite"] = "Mordedura de mangosta",
		["Monster Slaying"] = "Matanza de monstruos",
		["Moonfire"] = "Fuego lunar",
		["Moonfury"] = "Furia de luna",
		["Moonglow"] = "Resplandor lunar",
		["Moonkin Aura"] = "Aura de lech\195\186cico lunar",  -- check
		["Moonkin Form"] = "Forma de lech\195\186cico lunar",
		["Mortal Shots"] = "Disparos mortales",
		["Mortal Strike"] = "Golpe mortal",
		["Multi-Shot"] = "Multidisparo",
		["Murder"] = "Asesinar",
		["Mutilate"] = "Mutilar",
		["Natural Armor"] = "Armadura natural",
		["Natural Perfection"] = "Perfecci\195\179n natural",  -- check
		["Natural Shapeshifter"] = "Cambio de forma natural",
		["Naturalist"] = "Naturalista",   -- check
		["Nature Resistance"] = "Resistencia a la Naturaleza",
		["Nature Resistance Totem"] = "T\195\179tem de resistencia a la Naturaleza",
		["Nature Weakness"] = "Debilidad a la Naturaleza",    -- check
		["Nature's Focus"] = "Enfoque de la Naturaleza",
		["Nature's Grace"] = "Gracia de la Naturaleza",
		["Nature's Grasp"] = "Trabaz\195\179n con la Naturaleza",
		["Nature's Guidance"] = "Nature's Guidance",  -- Needs localization.
		["Nature's Reach"] = "Alcance de la Naturaleza",
		["Nature's Swiftness"] = "Presteza de la Naturaleza",
		["Negative Charge"] = "Carga negativa",  -- check
		["Nether Protection"] = "Protecci\195\179n abisal",
		["Netherstorm Flag"] = "Bandera de Tormenta abisal",  -- fix
		["Nightfall"] = "Ocaso",
		["Nurturing Instinct"] = "Instinto de nutricion",
		["Omen of Clarity"] = "Augurio de claridad",
		["One-Handed Axes"] = "Hachas",
		["One-Handed Maces"] = "Mazas",
		["One-Handed Swords"] = "Espadas",
		["One-Handed Weapon Specialization"] = "Especializaci\195\179n en armas de una mano",
		["Opening"] = "Apertura",
		["Opening - No Text"] = "Apertura - Sin texto",
		["Opportunity"] = "Oportunidad",
		["Overpower"] = "Abrumar",
		["Pain Suppression"] = "Supresi\195\179n de dolor",
		["Paranoia"] = "Paranoia",
		["Parry"] = "Parar",
		["Pathfinding"] = "Encontrar camino",
		["Perceived Weakness"] = "Debilidad percivida",   -- fix
		["Perception"] = "Percepci\195\179n",
		["Permafrost"] = "Escarcha permanente",
		["Pet Aggression"] = "Agresi\195\179n de la mascota",    -- check
		["Pet Hardiness"] = "Dureza de la mascota",       -- check
		["Pet Recovery"] = "Recuperaci\195\179n de la mascota",   -- check
		["Pet Resistance"] = "Resistencia de la mascota",    -- check
		["Phase Shift"] = "Cambio de fase",
		["Pick Lock"] = "Forzar cerradura",
		["Pick Pocket"] = "Robar",
		["Piercing Howl"] = "Aullido penetrante",
		["Piercing Ice"] = "Hielo penetrante",
		["Plate Mail"] = "Malla de placas",
		["Playing with Fire"] = "Jugando con Fuego",  -- check
		["Poison Cleansing Totem"] = "T\195\179tem contraveneno",
		["Poison Spit"] = "Escupir veneno",  -- check
		["Poisons"] = "Venenos",
		["Polearms"] = "Armas de asta",
		["Poleaxe Specialization"] = "Especializaci\195\179n en armas de asta",      -- check
		["Polymorph"] = "Polimorfia",
		["Polymorph: Pig"] = "Polimorfia: Cerdo",   -- check
		["Polymorph: Turtle"] = "Polimorfia: Tortuga",   -- check
		["Portal: Darnassus"] = "Portal a: Darnassus",     -- check
		["Portal: Exodar"] = "Portal a: Exodar",     -- check
		["Portal: Ironforge"] = "Portal a: Forjaz",     -- check
		["Portal: Orgrimmar"] = "Portal a: Orgrimmar",     -- check
		["Portal: Shattrath"] = "Portal a: Shattrath",     -- check
		["Portal: Silvermoon"] = "Portal a: Lunargenta",     -- check
		["Portal: Stormwind"] = "Portal a: Ventormenta",     -- check
		["Portal: Thunder Bluff"] = "Portal a: Cima del Trueno",     -- check,
		["Portal: Undercity"] = "Portal a: Entra\195\177as",     -- check
		["Positive Charge"] = "Carga positiva",   -- check
		["Pounce"] = "Abalanzarse",
		["Pounce Bleed"] = "Hemorragia de abalanzarse",  -- check
		["Power Infusion"] = "Infusi\195\179n de poder",
		["Power Word: Fortitude"] = "Palabra de poder: entereza",
		["Power Word: Shield"] = "Palabra de poder: escudo",
		["Prayer of Fortitude"] = "Rezo de entereza",   -- check
		["Prayer of Healing"] = "Rezo de sanaci\195\179n",
		["Prayer of Mending"] = "Rezo de alivio",
		["Prayer of Shadow Protection"] = "Rezo de protecci\195\179n contra las Sombras",    -- check
		["Prayer of Spirit"] = "Rezo de esp\195\173ritu",
		["Precision"] = "Precisi\195\179n",
		["Predatory Instincts"] = "Predatory Instincts",  -- Needs localization.
		["Predatory Strikes"] = "Golpes depredadores",
		["Premeditation"] = "Premeditaci\195\179n",
		["Preparation"] = "Preparaci\195\179n",
		["Presence of Mind"] = "Presencia mental",
		["Primal Fury"] = "Furia primigenia",
		["Prismatic Cloak"] = "Capa prism\195\161tica",  -- check
		["Profession Trainers"] = "Profession Trainers",   -- fix
		["Prospecting"] = "Buscando",  -- check
		["Prowl"] = "Acechar",
		["Psychic Scream"] = "Alarido ps\195\173quico",
		["Pummel"] = "Zurrar",
		["Purge"] = "Purgar",
		["Purification"] = "Purificaci\195\179n",
		["Purify"] = "Purificar",
		["Purifying Power"] = "Poder purificador",  -- check
		["Pursuit of Justice"] = "B\195\186squeda de justicia",
		["Pyroblast"] = "Piroexplosi\195\179n",
		["Pyroclasm"] = "Piroclasma",
		["Pyromaniac"] = "Pir\195\179mano",   -- check
		["Quick Recovery"] = "Recuperaci\195\179n r\195\161pida", -- check
		["Quick Shots"] = "Disparos r\195\161pidos", -- check
		["Quickness"] = "Rapidez",  -- check
		["Rage of the Unraveller"] = "Rage of the Unraveller",   -- fix
		["Rain of Fire"] = "Lluvia de fuego",
		["Rake"] = "Ara\195\177azo",
		["Ram Riding"] = "Cabalgar carnero",  -- check
		["Rampage"] = "Desenfreno",
		["Ranged Weapon Specialization"] = "Especializaci\195\179n en armas a distancia",
		["Rapid Fire"] = "Fuego r\195\161pido",
		["Rapid Killing"] = "Matanza r\195\161pida",   -- check
		["Raptor Riding"] = "Cabalgar raptor",  -- check
		["Raptor Strike"] = "Golpe de raptor",
		["Ravage"] = "Devastar",
		["Readiness"] = "Disposici\195\179n",
		["Reagents"] = "Reagents",   -- fix
		["Rebirth"] = "Renacer",
		["Reckless Charge"] = "Carga temeraria",  -- check
		["Recklessness"] = "Temeridad",
		["Reckoning"] = "Expiaci\195\179n",
		["Redemption"] = "Redenci\195\179n",
		["Redoubt"] = "Baluarte",
		["Reflection"] = "Reflejo", -- check
		["Regeneration"] = "Regeneraci\195\179n",
		["Regrowth"] = "Recrecimiento",
		["Reincarnation"] = "Reencarnaci\195\179n",
		["Reinforced Shield"] = "Escudo reforzado",  -- check
		["Rejuvenation"] = "Rejuvenecimiento",
		["Relentless Strikes"] = "Golpes despiadados",
		["Remorseless"] = "Sin remordimientos",  -- check
		["Remorseless Attacks"] = "Ataques sin remordimientos",
		["Remove Curse"] = "Deshacer maldici\195\179n",
		["Remove Insignia"] = "Quitar insignia",   -- check
		["Remove Lesser Curse"] = "Deshacer maldici\195\179n inferior",
		["Rend"] = "Desgarrar",
		["Renew"] = "Renovar",
		["Repair"] = "Repair",   -- fix
		["Repentance"] = "Arrepentimiento",
		["Restless Strength"] = "Fortaleza incansable",   -- fix
		["Restorative Totems"] = "T\195\179tems reconstituyentes",   -- check
		["Resurrection"] = "Resurrecci\195\179n",
		["Retaliation"] = "Represalias",
		["Retribution Aura"] = "Aura de sanci\195\179n",
		["Revenge"] = "Revancha",
		["Revenge Stun"] = "Aturdimiento de Revancha", -- check
		["Reverberation"] = "Reverberaci\195\179n",
		["Revive Pet"] = "Revivir mascota",
		["Righteous Defense"] = "Defensa justa",  -- check
		["Righteous Fury"] = "Furia justa",
		["Rip"] = "Destripar",
		["Riposte"] = "Contestaci\195\179n",
		["Ritual of Doom"] = "Ritual del Apocalipsis",
		["Ritual of Doom Effect"] = "Efecto de Ritual del Apocalipsis",    -- check
		["Ritual of Souls"] = "Ritual de almas",
		["Ritual of Summoning"] = "Ritual de invocaci\195\179n",
		["Rockbiter Weapon"] = "Arma Muerdepiedras",
		["Rough Sharpening Stone"] = "Piedra de afilar f\195\169rrea",
		["Ruin"] = "Ruina",
		["Rupture"] = "Ruptura",
		["Ruthlessness"] = "Crueldad",
		["Sacrifice"] = "Sacrificio",
		["Safe Fall"] = "Ca\195\173da segura",
		["Sanctified Crusader"] = "Cruzado santificado",   -- check
		["Sanctified Judgement"] = "Sanctified Judgement",  -- Needs localization.
		["Sanctified Light"] = "Luz santificada",   -- check
		["Sanctity Aura"] = "Aura de santidad",
		["Sap"] = "Porrazo",
		["Savage Fury"] = "Furia cruel",
		["Savage Strikes"] = "Golpes crueles",
		["Scare Beast"] = "Asustar bestia",
		["Scatter Shot"] = "Disparo disperso",
		["Scorch"] = "Agostar",
		["Scorpid Poison"] = "Veneno de esc\195\179rpido",
		["Scorpid Sting"] = "Picadura de esc\195\179rpido",
		["Screech"] = "Chirrido",
		["Seal Fate"] = "Sellar destino",
		["Seal of Blood"] = "Sello de sangre",
		["Seal of Command"] = "Sello de orden",
		["Seal of Justice"] = "Sello de justicia",
		["Seal of Light"] = "Sello de Luz",
		["Seal of Righteousness"] = "Sello de rectitud",
		["Seal of Vengeance"] = "Sello de venganza",        -- check
		["Seal of Wisdom"] = "Sello de sabidur\195\173a",
		["Seal of the Crusader"] = "Sello del cruzado",
		["Searing Light"] = "Luz abrasadora",
		["Searing Pain"] = "Dolor abrasador",
		["Searing Totem"] = "T\195\179tem abrasador",
		["Second Wind"] = "Segundo aliento",
		["Seduction"] = "Seducci\195\179n",
		["Seed of Corruption"] = "Semilla de corrupci\195\179n",      -- check
		["Seethe"] = "Rugido desafiante",
		["Sense Demons"] = "Captar demonios",
		["Sense Undead"] = "Captar no-muertos",
		["Sentry Totem"] = "T\195\179tem avizor",
		["Serpent Sting"] = "Picadura de serpiente",
		["Serrated Blades"] = "Serrated Blades", -- Needs localization.
		["Setup"] = "Establecer",
		["Shackle Undead"] = "Encadenar no-muerto",
		["Shadow Affinity"] = "Afinidad de las Sombras",
		["Shadow Bolt"] = "Descarga de las Sombras",
		["Shadow Embrace"] = "Abrazo de las Sombras",
		["Shadow Focus"] = "Enfoque de las Sombras",
		["Shadow Mastery"] = "Maestr\195\173a de las Sombras",
		["Shadow Power"] = "Poder de las Sombras", -- check
		["Shadow Protection"] = "Protecci\195\179n contra las Sombras",
		["Shadow Reach"] = "Alcance de las Sombras ",
		["Shadow Resistance"] = "Resistencia a las Sombras",
		["Shadow Resistance Aura"] = "Aura de resistencia a las Sombras",
		["Shadow Trance"] = "Trance de las Sombras",
		["Shadow Vulnerability"] = "Vulnerabilidad a las Sombras",
		["Shadow Ward"] = "Resguardo contra las Sombras",
		["Shadow Weakness"] = "Debilidad a las Sombras",     -- check
		["Shadow Weaving"] = "Tejido de las Sombras",
		["Shadow Word: Death"] = "Palabra de las Sombras: muerte",
		["Shadow Word: Pain"] = "Palabra de las Sombras: dolor",
		["Shadow and Flame"] = "Sombras y llamas",
		["Shadowburn"] = "Quemadura de las Sombras",
		["Shadowfiend"] = "Maligno de las Sombras",
		["Shadowform"] = "Forma de las Sombras",
		["Shadowfury"] = "Furia de las Sombras",
		["Shadowguard"] = "Guardia de las Sombras",
		["Shadowmeld"] = "Fusi\195\179n de las Sombras",
		["Shadowmeld Passive"] = "Fusi\195\179n de las Sombras pasivo",    -- check
		["Shadowstep"] = "Paso de las Sombras",
		["Shamanistic Rage"] = "Ira del cham\195\161n",
		["Sharpened Claws"] = "Garras afiladas",
		["Shatter"] = "Trizar",
		["Shell Shield"] = "Caparaz\195\179n de escudo",       -- check
		["Shield"] = "Escudo",
		["Shield Bash"] = "Azote de escudo",
		["Shield Bash - Silenced"] = "Azote de escudo - Silenciado",        -- check
		["Shield Block"] = "Bloquear con escudo",
		["Shield Slam"] = "Embate con escudo",
		["Shield Specialization"] = "Especializaci\195\179n en escudos",
		["Shield Wall"] = "Muro de escudo",
		["Shiv"] = "Chafarote",            -- check
		["Shoot"] = "Disparar",
		["Shoot Bow"] = "Disparar arco",
		["Shoot Gun"] = "Disparar arma de fuego",
		["Shred"] = "Triturar",
		["Shredding Attacks"] = "Shredding Attacks",  -- Needs localization.
		["Silence"] = "Silencio",
		["Silencing Shot"] = "Disparo silenciador",
		["Silent Resolve"] = "Resoluci\195\179n silenciosa",
		["Silverwing Flag"] = "Bandera de Ala Plateada", -- fix
		["Sinister Strike"] = "Golpe siniestro",
		["Siphon Life"] = "Succionar vida",
		["Skinning"] = "Desuello",
		["Slam"] = "Embate",
		["Slayer's Crest"] = "Slayer's Crest",  -- fix
		["Sleep"] = "Dormir",         -- check
		["Slice and Dice"] = "Hacer picadillo",
		["Slow"] = "Ralentizar",
		["Slow Fall"] = "Ca\195\173da lenta",
		["Smelting"] = "Fundici\195\179n",
		["Smite"] = "Mamporro",
		["Snake Trap"] = "Trampa con culebras",
		["Solid Sharpening Stone"] = "Piedra de afilar s\195\179lida",
		["Sonic Burst"] = "Estallido sonico",  -- fix
		["Soothe Animal"] = "Calmar animal",
		["Soothing Kiss"] = "Beso calmante",
		["Soul Fire"] = "Fuego de alma",
		["Soul Leech"] = "Succi\195\179n de alma",
		["Soul Link"] = "Enlace de alma",
		["Soul Siphon"] = "Succi\195\179n de alma",
		["Soulshatter"] = "Despedazar alma",
		["Soulstone Resurrection"] = "Resurrecci\195\179n de piedra de alma",         -- check
		["Spell Haste"] = "Apresurar hechizo",   -- check
		["Spell Lock"] = "Bloqueo de hechizo",
		["Spell Power"] = "Poder con hechizos",    -- check
		["Spell Reflection"] = "Reflejo de hechizos",
		["Spell Vulnerability"] = "Vulnerabilidad a hechizos",   -- check
		["Spell Warding"] = "Amparo de hechizos",
		["Spellsteal"] = "Robar hechizo",
		["Spirit Bond"] = "V\195\173nculo de esp\195\173ritu",
		["Spirit Tap"] = "Transfusi\195\179n de esp\195\173ritu",
		["Spirit of Redemption"] = "Esp\195\173ritu redentor",
		["Spiritual Attunement"] = "Ajuste espiritual",            -- check
		["Spiritual Focus"] = "Enfoque espiritual",
		["Spiritual Guidance"] = "Gu\195\173a espiritual",
		["Spiritual Healing"] = "Sanaci\195\179n espiritual",
		["Spiteful Fury"] = "Furia llena de maldad",    -- fix
		["Sprint"] = "Sprint",
		["StableMaster"] = "StableMaster",    -- fix
		["Stance Mastery"] = "Maestr\195\173a en actitudes",
		["Starfire"] = "Fuego estelar",
		["Starfire Stun"] = "Aturdimiento de Fuego estelar",     -- check
		["Starlight Wrath"] = "C\195\179lera de luz estelar",    -- check
		["Starshards"] = "Fragmentos de estrella",        -- check
		["Staves"] = "Bastones",
		["Steady Shot"] = "Tiro firme",
		["Stealth"] = "Sigilo",
		["Stoneclaw Stun"] = "Aturdimiento de Garra de piedra",   -- check
		["Stoneclaw Totem"] = "T\195\179tem Garra de piedra",
		["Stoneform"] = "Forma de piedra",
		["Stoneskin"] = "Piel p\195\169trea",     -- check
		["Stoneskin Totem"] = "T\195\179tem Piel de piedra",
		["Stormstrike"] = "Golpe de tormenta",
		["Strength of Earth"] = "Fortaleza de la tierra",
		["Strength of Earth Totem"] = "T\195\179tem Fortaleza de la tierra",
		["Strength of the Halaani"] = "Fortaleza de los Halaani",  -- check
		["Stuck"] = "Atascado",     -- check
		["Stun"] = "Aturdir",  -- fix
		["Subtlety"] = "Sutileza",
		["Suffering"] = "Sufrimiento",
		["Summon Charger"] = "Invocar a cargador", -- check
		["Summon Dreadsteed"] = "Invocar a corcel nefasto",
		["Summon Felguard"] = "Invocar a guardia maldito",
		["Summon Felhunter"] = "Invocar a man\195\161fago",
		["Summon Felsteed"] = "Invocar a corcel vil",
		["Summon Imp"] = "Invocar a diablillo",
		["Summon Succubus"] = "Invocar a s\195\186cubo",
		["Summon Voidwalker"] = "Invocar a abisario",
		["Summon Warhorse"] = "Invocar a caballo de guerra",
		["Summon Water Elemental"] = "Invocar a elemental de agua",
		["Sunder Armor"] = "Hender armadura",
		["Suppression"] = "Supresi\195\179n",      -- check
		["Surefooted"] = "Pies de plomo",
		["Surge of Light"] = "Surge of Light",  -- fix
		["Surprise Attacks"] = "Surprise Attacks", -- Needs localization.
		["Survivalist"] = "Superviviente",
		["Sweeping Strikes"] = "Golpes de barrido",
		["Swift Flight Form"] = "Forma voladora presta",     -- check
		["Swiftmend"] = "Alivio presto",
		["Swipe"] = "Flagelo",
		["Sword Specialization"] = "Especializaci\195\179n en espada",
		["Symbol of Hope"] = "Simbolo de esperanza",  -- check
		["Tactical Mastery"] = "Maestr\195\173a t\195\161ctica",
		["Tailoring"] = "Sastrer\195\173a",
		["Tainted Blood"] = "Sangre m\195\161cula",
		["Tainted Mind"] = "Mente macula",  -- fix
		["Tame Beast"] = "Domesticar bestia",
		["Taunt"] = "Provocar",
		["Teleport: Darnassus"] = "Teletransporte a: Darnassus",       -- check
		["Teleport: Exodar"] = "Teletransporte a: Exodar",   -- check
		["Teleport: Ironforge"] = "Teletransporte a: Forjaz",        -- check
		["Teleport: Moonglade"] = "Teletransporte a: Claro de la Luna",
		["Teleport: Orgrimmar"] = "Teletransporte a: Orgrimmar",           -- check
		["Teleport: Shattrath"] = "Teletransporte a: Shattrath", -- check
		["Teleport: Silvermoon"] = "Teletransporte a: Lunargenta", -- check
		["Teleport: Stormwind"] = "Teletransporte a: Ventormenta",        -- check
		["Teleport: Thunder Bluff"] = "Teletransporte a: Cima del Trueno",     -- check
		["Teleport: Undercity"] = "Teletransporte a: Entra\195\177as",          -- check
		["The Beast Within"] = "Bestia interna",
		["The Human Spirit"] = "El espir\195\173tu humano",
		["Thick Hide"] = "Pellejo grueso",
		["Thorns"] = "Espinas",
		["Thrill of the Hunt"] = "Thrill of the Hunt",  -- Needs localization.
		["Throw"] = "Lanzar",
		["Throwing Specialization"] = "Especializaci\195\179n en lanzamiento",
		["Thrown"] = "Armas arrojadizas",           -- check
		["Thunder Clap"] = "Atronar",
		["Thunderfury"] = "Furia de trueno",   -- fix
		["Thundering Strikes"] = "Golpes de trueno",
		["Thunderstomp"] = "Pisot\195\179n de trueno",     -- check
		["Tidal Focus"] = "Enfoque de las mareas",
		["Tidal Mastery"] = "Dominio de las mareas",
		["Tiger Riding"] = "Cabalgar tigre",     -- check
		["Tiger's Fury"] = "Furia de tigre",
		["Time's Favor"] = "Favor del tiempo",   -- fix
		["Torment"] = "Tormento",
		["Totem"] = "T\195\179tem",
		["Totem of Wrath"] = "T\195\179tem de c\195\179lera",
		["Totemic Call"] = "Llamada tot\195\169mica",
		["Totemic Focus"] = "Enfoque tot\195\169mico",
		["Touch of Shadow"] = "Toque de las Sombras",  -- check
		["Touch of Weakness"] = "Toque de Debilidad",     -- check
		["Toughness"] = "Consistencia",
		["Traces of Silithyst"] = "Rastros de sitilista",  -- check
		["Track Beasts"] = "Rastrear bestias",
		["Track Demons"] = "Rastrear demonios",
		["Track Dragonkin"] = "Rastrear dragonante",
		["Track Elementals"] = "Rastrear elementales",
		["Track Giants"] = "Rastrear gigantes",
		["Track Hidden"] = "Rastrear lo Oculto",
		["Track Humanoids"] = "Rastrear humanoides",
		["Track Undead"] = "Rastrear no-muertos",
		["Tranquil Air"] = "Aire sosegado",
		["Tranquil Air Totem"] = "T\195\179tem de Aire sosegado",
		["Tranquil Spirit"] = "Esp\195\173ritu sosegado",
		["Tranquility"] = "Tranquilidad",
		["Tranquilizing Shot"] = "Disparo tranquilizante",
		["Trap Mastery"] = "Maestr\195\173a en trampas",
		["Travel Form"] = "Forma de viaje",
		["Tree of Life"] = "\195\129rbol de vida",
		["Tremor Totem"] = "T\195\179tem de tremor",
		["Tribal Leatherworking"] = "Peleter\195\173a tribal",      -- check
		["Trueshot Aura"] = "Aura de disparo certero",
		["Turn Undead"] = "Ahuyentar a no-muerto",
		["Twin Spire Blessing"] = "Bendicion de la aguja gemela",   -- check
		["Two-Handed Axes"] = "Hachas de dos manos",
		["Two-Handed Axes and Maces"] = "Hachas y mazas de dos manos",
		["Two-Handed Maces"] = "Mazas de dos manos",
		["Two-Handed Swords"] = "Espadas de dos manos",
		["Two-Handed Weapon Specialization"] = "Especializaci\195\179n en armas de dos manos",
		["Unarmed"] = "Sin armas",
		["Unbreakable Will"] = "Voluntad inquebrantable",
		["Unbridled Wrath"] = "C\195\179lera desbocada",
		["Undead Horsemanship"] = "Cabalgar caballo esquel\195\169tico",      -- check
		["Underwater Breathing"] = "Respiraci\195\179n subacu\195\161tica",
		["Unending Breath"] = "Aliento inagotable",
		["Unholy Power"] = "Poder profano",
		["Unleashed Fury"] = "Furia desatada",
		["Unleashed Rage"] = "Ira desatada",
		["Unstable Affliction"] = "Aflicci\195\179n inestable",
		["Unstable Power"] = "Poder inestable",   -- fix
		["Unyielding Faith"] = "Fe implacable",
		["Vampiric Embrace"] = "Abrazo vamp\195\173rico",
		["Vampiric Touch"] = "Toque vamp\195\173rico",
		["Vanish"] = "Esfumarse",
		["Vanished"] = "Esfumado",         -- check
		["Vengeance"] = "Venganza",
		["Venomous Totem"] = "Totem venenoso",   -- fix
		["Victory Rush"] = "Ataque de la victoria",
		["Vigor"] = "Vigor",
		["Vile Poisons"] = "Venenos inmundos",
		["Vindication"] = "Vindicaci\195\179n",
		["Viper Sting"] = "Picadura de v\195\173bora",
		["Volley"] = "Volear",       -- check
		["Wand Specialization"] = "Especializaci\195\179n en varitas",
		["Wands"] = "Varitas",
		["War Stomp"] = "Pisot\195\179n de guerra",
		["Warp"] = "Combar",  -- check
		["Warsong Flag"] = "Bandera de Grito de Guerra", -- check
		["Water Breathing"] = "Respiraci\195\179n acu\195\161tica",
		["Water Shield"] = "Escudo de agua",
		["Water Tomb"] = "Tumba de agua",  -- fix
	 	["Water Walking"] = "Caminar sobre el agua",
		["Waterbolt"] =	"Descarga de agua",        -- check
		["Watery Grave"] = "Watery Grave",  -- fix
		["Weakened Soul"] = "Alma debilitada",       -- check
		["Weapon Mastery"] = "Weapon Mastery",  -- Needs localization.
		["Weaponsmith"] = "Forjador de armas",        -- check
		["Whirlwind"] = "Torbellino",
		["Will of the Forsaken"] = "Voluntad de los Renegados",
		--["Windfury"] = true,	NOTE: This is the shaman Windfury Weapon enchant name on the weapon itself i.e. Windfury 5
		-- ["Windfury Attack"] = "???",
		["Windfury Totem"] = "T\195\179tem Viento Furioso",
		["Windfury Weapon"] = "Arma Viento Furioso",
		["Windwall"] = "Muro de viento",
		["Windwall Totem"] = "T\195\179tem Muro de viento",
		["Wing Clip"] = "Cortar alas",
		["Winter's Chill"] = "Escalofr\195\173o invernal",
		["Wisp Spirit"] = "Esp\195\173ritu de fuego fatuo",
		["Wolf Riding"] = "Cabalgar lobo",       -- check
		["Wound Poison"] = "Veneno hiriente",
		["Wound Poison II"] = "Veneno hiriente II",
		["Wound Poison III"] = "Veneno hiriente III",
		["Wound Poison IV"] = "Veneno hiriente IV",
		["Wound Poison V"] = "Veneno hiriente V",
		["Wrath"] = "C\195\179lera",
		["Wrath of Air Totem"] = "T\195\179tem c\195\179lera de aire",
		["Wrath of Cenarius"] = "C\195\179lera de Cenario",   -- check
		["Wyvern Sting"] = "Picadura de dracole\195\179n",
	}
else
	error(("%s: Locale %q not supported"):format(MAJOR_VERSION, GAME_LOCALE))
end

local spellIcons = {
	["Abolish Disease"] = "Spell_Nature_NullifyDisease",
	["Abolish Poison"] = "Spell_Nature_NullifyPoison_02",
	["Abolish Poison Effect"] = "Spell_Nature_NullifyPoison_02",
	["Activate MG Turret"] = "INV_Weapon_Rifle_10",
	["Adrenaline Rush"] = "Spell_Shadow_ShadowWordDominate",
	["Aftermath"] = "Spell_Fire_Fire",
	["Aggression"] = "Ability_Racial_Avatar",
	["Aimed Shot"] = "INV_Spear_07",
	["Alchemy"] = "Trade_Alchemy",
	["Ambush"] = "Ability_Rogue_Ambush",
--	["Ammunition"] = true,
	["Amplify Curse"] = "Spell_Shadow_Contagion",
	["Amplify Magic"] = "Spell_Holy_FlashHeal",
	["Ancestral Fortitude"] = "Spell_Nature_UndyingStrength",
	["Ancestral Healing"] = "Spell_Nature_UndyingStrength",
	["Ancestral Knowledge"] = "Spell_Shadow_GrimWard",
	["Ancestral Spirit"] = "Spell_Nature_Regenerate",
	["Ancient Hysteria"] = "Spell_Shadow_UnholyFrenzy",
	["Anesthetic Poison"] = "Spell_Nature_SlowPoison",
	["Anger Management"] = "Spell_Holy_BlessingOfStamina",
	["Anguish"] = "Spell_Shadow_GatherShadows",
	["Anticipation"] = "Spell_Nature_MirrorImage",
	["Aquatic Form"] = "Ability_Druid_AquaticForm",
	["Arcane Blast"] = "Spell_Arcane_Blast",
	["Arcane Brilliance"] = "Spell_Holy_ArcaneIntellect",
	["Arcane Concentration"] = "Spell_Shadow_ManaBurn",
	["Arcane Energy"] = "Spell_Holy_MindVision",
	["Arcane Explosion"] = "Spell_Nature_WispSplode",
	["Arcane Focus"] = "Spell_Holy_Devotion",
	["Arcane Fortitude"] = "Spell_Arcane_ArcaneResilience",
	["Arcane Impact"] = "Spell_Nature_WispSplode",
	["Arcane Instability"] = "Spell_Shadow_Teleport",
	["Arcane Intellect"] = "Spell_Holy_MagicalSentry",
	["Arcane Meditation"] = "Spell_Shadow_SiphonMana",
	["Arcane Mind"] = "Spell_Shadow_Charm",
	["Arcane Missiles"] = "Spell_Nature_StarFall",
	["Arcane Potency"] = "Spell_Arcane_ArcanePotency",
	["Arcane Power"] = "Spell_Nature_Lightning",
	["Arcane Resistance"] = "Spell_Nature_StarFall",
	["Arcane Shot"] = "Ability_ImpalingBolt",
	["Arcane Shroud"] = "Spell_Magic_LesserInvisibilty",
	["Arcane Subtlety"] = "Spell_Holy_DispelMagic",
	["Arcane Torrent"] = "Spell_Shadow_Teleport",
	["Arcane Weakness"] = "Spell_Shadow_SoulLeech_2",
	["Arctic Reach"] = "Spell_Shadow_DarkRitual",
	["Arctic Winds"] = "Spell_Frost_ArcticWinds",
	["Armor of Faith"] = "Spell_Holy_BlessingOfProtection",
	["Armorsmith"] = "Trade_BlackSmithing",
	["Aspect of the Beast"] = "Ability_Mount_PinkTiger",
	["Aspect of the Cheetah"] = "Ability_Mount_JungleTiger",
	["Aspect of the Hawk"] = "Spell_Nature_RavenForm",
	["Aspect of the Monkey"] = "Ability_Hunter_AspectOfTheMonkey",
	["Aspect of the Pack"] = "Ability_Mount_WhiteTiger",
	["Aspect of the Viper"] = "Ability_Hunter_AspectoftheViper",
	["Aspect of the Wild"] = "Spell_Nature_ProtectionformNature",
	["Astral Recall"] = "Spell_Nature_AstralRecal",
	["Attack"] = "Temp",
	["Attacking"] = "Temp",
	["Auto Shot"] = "Ability_Whirlwind",
	["Avenger's Shield"] = "Spell_Holy_AvengersShield",
	["Avenging Wrath"] = "Spell_Holy_AvengineWrath",
	["Avoidance"] = "Spell_Magic_LesserInvisibilty",
	["Axe Specialization"] = "INV_Axe_06",
	["Backlash"] = "Spell_Fire_PlayingWithFire",
	["Backstab"] = "Ability_BackStab",
	["Badge of the Swarmguard"] = "INV_Misc_AhnQirajTrinket_04",
	["Balance of Power"] = "Ability_Druid_BalanceofPower",
	["Bane"] = "Spell_Shadow_DeathPact",
	["Banish"] = "Spell_Shadow_Cripple",
--	["Banker"] = true,
--	["Banshee Curse"] = true,
	["Barkskin"] = "Spell_Nature_StoneClawTotem",
	["Barrage"] = "Ability_UpgradeMoonGlaive",
	["Bash"] = "Ability_Druid_Bash",
	["Basic Campfire"] = "Spell_Fire_Fire",
	["Battle Rush"] = "Ability_Whirlwind",
	["Battle Shout"] = "Ability_Warrior_BattleShout",
	["Battle Stance"] = "Ability_Warrior_OffensiveStance",
	["Battle Stance Passive"] = "Ability_Warrior_OffensiveStance",
--	["BattleMaster"] = true,
	["Bear Form"] = "Ability_Racial_BearForm",
	["Beast Lore"] = "Ability_Physical_Taunt",
	["Beast Slaying"] = "INV_Misc_Pelt_Bear_Ruin_02",
	["Beast Training"] = "Ability_Hunter_BeastCall02",
	["Benediction"] = "Spell_Frost_WindWalkOn",
	["Berserker Rage"] = "Spell_Nature_AncestralGuardian",
	["Berserker Stance"] = "Ability_Racial_Avatar",
	["Berserker Stance Passive"] = "Ability_Racial_Avatar",
	["Berserking"] = "Racial_Troll_Berserk",
	["Bestial Discipline"] = "Spell_Nature_AbolishMagic",
	["Bestial Swiftness"] = "Ability_Druid_Dash",
	["Bestial Wrath"] = "Ability_Druid_FerociousBite",
	["Binding Heal"] = "Spell_Holy_BlindingHeal",
	["Bite"] = "Ability_Racial_Cannibalize",
	["Black Arrow"] = "Ability_TheBlackArrow",
	["Blackout"] = "Spell_Shadow_GatherShadows",
	["Blacksmithing"] = "Trade_BlackSmithing",
	["Blade Flurry"] = "Ability_Warrior_PunishingBlow",
	["Blade Turning"] = "Ability_Warrior_Challange",
	["Blade Twisting"] = "Ability_Rogue_BladeTwisting",
	["Blast Wave"] = "Spell_Holy_Excorcism_02",
	["Blazing Speed"] = "Spell_Fire_BurningSpeed",
	["Blessed Recovery"] = "Spell_Holy_BlessedRecovery",
	["Blessed Resilience"] = "Spell_Holy_BlessedResillience",
	["Blessing of Auchindoun"] = "INV_Battery_02",
	["Blessing of Freedom"] = "Spell_Holy_SealOfValor",
	["Blessing of Kings"] = "Spell_Magic_MageArmor",
	["Blessing of Light"] = "Spell_Holy_PrayerOfHealing02",
	["Blessing of Might"] = "Spell_Holy_FistOfJustice",
	["Blessing of Protection"] = "Spell_Holy_SealOfProtection",
	["Blessing of Sacrifice"] = "Spell_Holy_SealOfSacrifice",
	["Blessing of Salvation"] = "Spell_Holy_SealOfSalvation",
	["Blessing of Sanctuary"] = "Spell_Nature_LightningShield",
	["Blessing of Wisdom"] = "Spell_Holy_SealOfWisdom",
	["Blind"] = "Spell_Shadow_MindSteal",
	["Blinding Powder"] = "INV_Misc_Ammo_Gunpowder_02",
	["Blink"] = "Spell_Arcane_Blink",
	["Blizzard"] = "Spell_Frost_IceStorm",
	["Block"] = "Ability_Defend",
	["Blood Craze"] = "Spell_Shadow_SummonImp",
	["Blood Frenzy"] = "Ability_Warrior_BloodFrenzy",
	["Blood Fury"] = "Racial_Orc_BerserkerStrength",
	["Blood Pact"] = "Spell_Shadow_BloodBoil",
	["Bloodlust"] = "Spell_Nature_BloodLust",
	["Bloodrage"] = "Ability_Racial_BloodRage",
	["Bloodthirst"] = "Spell_Nature_BloodLust",
	["Boar Charge"] = "Spell_Shadow_VampiricAura",
	["Booming Voice"] = "Spell_Nature_Purge",
	["Bow Specialization"] = "INV_Weapon_Bow_12",
	["Bows"] = "INV_Weapon_Bow_05",
	["Bright Campfire"] = "Spell_Fire_Fire",
	["Brittle Armor"] = "Spell_Shadow_GrimWard",
	["Brutal Impact"] = "Ability_Druid_Bash",
	["Burning Adrenaline"] = "INV_Gauntlets_03",
	["Burning Soul"] = "Spell_Fire_Fire",
	["Burning Wish"] = "Spell_Shadow_PsychicScream",
	["Call Pet"] = "Ability_Hunter_BeastCall",
	["Call of Flame"] = "Spell_Fire_Immolation",
	["Call of Thunder"] = "Spell_Nature_CallStorm",
	["Call of the Nexus"] = "Spell_Holy_MindVision",
	["Camouflage"] = "Ability_Stealth",
	["Cannibalize"] = "Ability_Racial_Cannibalize",
	["Cat Form"] = "Ability_Druid_CatForm",
	["Cataclysm"] = "Spell_Fire_WindsofWoe",
	["Celestial Focus"] = "Spell_Arcane_StarFire",
	["Chain Heal"] = "Spell_Nature_HealingWaveGreater",
	["Chain Lightning"] = "Spell_Nature_ChainLightning",
	["Challenging Roar"] = "Ability_Druid_ChallangingRoar",
	["Challenging Shout"] = "Ability_BullRush",
	["Charge"] = "Ability_Warrior_Charge",
	["Charge Rage Bonus Effect"] = "Ability_Warrior_Charge",
	["Charge Stun"] = "Spell_Frost_Stun",
	["Cheap Shot"] = "Ability_CheapShot",
	["Chilled"] = "Spell_Frost_IceStorm",
	["Circle of Healing"] = "Spell_Holy_CircleOfRenewal",
--	["Class Trainer"] = true,
	["Claw"] = "Ability_Druid_Rake",
	["Cleanse"] = "Spell_Holy_Renew",
	["Clearcasting"] = "Spell_Shadow_ManaBurn",
	["Cleave"] = "Ability_Warrior_Cleave",
	["Clever Traps"] = "Spell_Nature_TimeStop",
	["Cloak of Shadows"] = "Spell_Shadow_NetherCloak",
	["Closing"] = "Temp",
	["Cloth"] = "INV_Chest_Cloth_21",
	["Coarse Sharpening Stone"] = "INV_Stone_SharpeningStone_02",
	["Cobra Reflexes"] = "Spell_Nature_GuardianWard",
	["Cold Blood"] = "Spell_Ice_Lament",
	["Cold Snap"] = "Spell_Frost_WizardMark",
	["Combat Endurance"] = "Spell_Nature_AncestralGuardian",
	["Combustion"] = "Spell_Fire_SealOfFire",
	["Command"] = "Ability_Warrior_WarCry",
	["Commanding Presence"] = "Ability_Warrior_BattleShout",
	["Commanding Shout"] = "Ability_Warrior_RallyingCry",
	["Concentration Aura"] = "Spell_Holy_MindSooth",
	["Concussion"] = "Spell_Fire_Fireball",
	["Concussion Blow"] = "Ability_ThunderBolt",
	["Concussive Barrage"] = "Spell_Arcane_StarFire",
	["Concussive Shot"] = "Spell_Frost_Stun",
	["Cone of Cold"] = "Spell_Frost_Glacier",
	["Conflagrate"] = "Spell_Fire_Fireball",
--	["Conflagration"] = true,
	["Conjure Food"] = "INV_Misc_Food_10",
	["Conjure Mana Agate"] = "INV_Misc_Gem_Emerald_01",
	["Conjure Mana Citrine"] = "INV_Misc_Gem_Opal_01",
	["Conjure Mana Emerald"] = "INV_Misc_Gem_Stone_01",
	["Conjure Mana Jade"] = "INV_Misc_Gem_Emerald_02",
	["Conjure Mana Ruby"] = "INV_Misc_Gem_Ruby_01",
	["Conjure Water"] = "INV_Drink_06",
	["Consecration"] = "Spell_Holy_InnerFire",
	["Consume Magic"] = "Spell_Arcane_StudentOfMagic",
	["Consume Shadows"] = "Spell_Shadow_AntiShadow",
	["Contagion"] = "Spell_Shadow_PainfulAfflictions",
	["Convection"] = "Spell_Nature_WispSplode",
	["Conviction"] = "Spell_Holy_RetributionAura",
	["Cooking"] = "INV_Misc_Food_15",
	["Corruption"] = "Spell_Shadow_AbominationExplosion",
	["Counterattack"] = "Ability_Warrior_Challange",
	["Counterspell"] = "Spell_Frost_IceShock",
	["Counterspell - Silenced"] = "Spell_Frost_IceShock",
	["Cower"] = "Ability_Druid_Cower",
	["Create Firestone"] = "INV_Ammo_FireTar",
	["Create Firestone (Greater)"] = "INV_Ammo_FireTar",
	["Create Firestone (Lesser)"] = "INV_Ammo_FireTar",
	["Create Firestone (Major)"] = "INV_Ammo_FireTar",
	["Create Healthstone"] = "INV_Stone_04",
	["Create Healthstone (Greater)"] = "INV_Stone_04",
	["Create Healthstone (Lesser)"] = "INV_Stone_04",
	["Create Healthstone (Major)"] = "INV_Stone_04",
	["Create Healthstone (Minor)"] = "INV_Stone_04",
	["Create Soulstone"] = "Spell_Shadow_SoulGem",
	["Create Soulstone (Greater)"] = "Spell_Shadow_SoulGem",
	["Create Soulstone (Lesser)"] = "Spell_Shadow_SoulGem",
	["Create Soulstone (Major)"] = "Spell_Shadow_SoulGem",
	["Create Soulstone (Minor)"] = "Spell_Shadow_SoulGem",
	["Create Spellstone"] = "INV_Misc_Gem_Sapphire_01",
	["Create Spellstone (Greater)"] = "INV_Misc_Gem_Sapphire_01",
	["Create Spellstone (Major)"] = "INV_Misc_Gem_Sapphire_01",
	["Create Spellstone (Master)"] = "INV_Misc_Gem_Sapphire_01",
	["Cripple"] = "Spell_Shadow_Cripple",
	["Crippling Poison"] = "Ability_PoisonSting",
	["Crippling Poison II"] = "Ability_PoisonSting",
	["Critical Mass"] = "Spell_Nature_WispHeal",
	["Crossbows"] = "INV_Weapon_Crossbow_01",
	["Cruelty"] = "Ability_Rogue_Eviscerate",
	["Crusade"] = "Spell_Holy_Crusade",
	["Crusader Aura"] = "Spell_Holy_CrusaderAura",
	["Crusader Strike"] = "Spell_Holy_CrusaderStrike",
	["Cultivation"] = "INV_Misc_Flower_01",
	["Cure Disease"] = "Spell_Holy_NullifyDisease",
	["Cure Poison"] = "Spell_Nature_NullifyPoison",
	["Curse of Agony"] = "Spell_Shadow_CurseOfSargeras",
	["Curse of Doom"] = "Spell_Shadow_AuraOfDarkness",
	["Curse of Doom Effect"] = "Spell_Shadow_AuraOfDarkness",
	["Curse of Exhaustion"] = "Spell_Shadow_GrimWard",
	["Curse of Idiocy"] = "Spell_Shadow_MindRot",
	["Curse of Recklessness"] = "Spell_Shadow_UnholyStrength",
	["Curse of Shadow"] = "Spell_Shadow_CurseOfAchimonde",
	["Curse of Tongues"] = "Spell_Shadow_CurseOfTounges",
	["Curse of Weakness"] = "Spell_Shadow_CurseOfMannoroth",
	["Curse of the Elements"] = "Spell_Shadow_ChillTouch",
	["Cyclone"] = "Spell_Nature_EarthBind",
	["Dagger Specialization"] = "INV_Weapon_ShortBlade_05",
	["Daggers"] = "Ability_SteelMelee",
	["Dampen Magic"] = "Spell_Nature_AbolishMagic",
	["Dark Pact"] = "Spell_Shadow_DarkRitual",
	["Darkness"] = "Spell_Shadow_Twilight",
	["Dash"] = "Ability_Druid_Dash",
	["Dawnstone Crab"] = "Ability_Hunter_Pet_Crab",
	["Dazed"] = "Spell_Frost_Stun",
	["Deadly Interrupt Effect"] = "INV_ThrowingKnife_06",
	["Deadly Poison"] = "Ability_Rogue_DualWeild",
	["Deadly Poison II"] = "Ability_Rogue_DualWeild",
	["Deadly Poison III"] = "Ability_Rogue_DualWeild",
	["Deadly Poison IV"] = "Ability_Rogue_DualWeild",
	["Deadly Poison V"] = "Ability_Rogue_DualWeild",
	["Deadly Poison VI"] = "Ability_Rogue_DualWeild",
	["Deadly Poison VII"] = "Ability_Rogue_DualWeild",
	["Deadly Throw"] = "INV_ThrowingKnife_06",
	["Death Coil"] = "Spell_Shadow_DeathCoil",
	["Death Wish"] = "Spell_Shadow_DeathPact",
	["Deep Wound"] = "Ability_BackStab", --Debuff
	["Deep Wounds"] = "Ability_BackStab", -- Talent
	["Defense"] = "Ability_Racial_ShadowMeld",
	["Defensive Stance"] = "Ability_Warrior_DefensiveStance",
	["Defensive Stance Passive"] = "Ability_Warrior_DefensiveStance",
	["Defiance"] = "Ability_Warrior_InnerRage",
	["Deflection"] = "Ability_Parry",
	["Delusions of Jin'do"] = "Spell_Shadow_UnholyFrenzy",
	["Demon Armor"] = "Spell_Shadow_RagingScream",
	["Demon Skin"] = "Spell_Shadow_RagingScream",
	["Demonic Aegis"] = "Spell_Shadow_RagingScream",
	["Demonic Embrace"] = "Spell_Shadow_Metamorphosis",
	["Demonic Frenzy"] = "Spell_Shadow_DeathPact",
	["Demonic Knowledge"] = "Spell_Shadow_ImprovedVampiricEmbrace",
	["Demonic Resilience"] = "Spell_Shadow_DemonicFortitude",
	["Demonic Sacrifice"] = "Spell_Shadow_PsychicScream",
	["Demonic Tactics"] = "Spell_Shadow_DemonicTactics",
	["Demoralizing Roar"] = "Ability_Druid_DemoralizingRoar",
	["Demoralizing Shout"] = "Ability_Warrior_WarCry",
	["Dense Sharpening Stone"] = "INV_Stone_SharpeningStone_05",
	["Desperate Prayer"] = "Spell_Holy_Restoration",
	["Destructive Reach"] = "Spell_Shadow_CorpseExplode",
	["Detect"] = "Ability_Hibernation",
	["Detect Greater Invisibility"] = "Spell_Shadow_DetectInvisibility",
	["Detect Invisibility"] = "Spell_Shadow_DetectInvisibility",
	["Detect Lesser Invisibility"] = "Spell_Shadow_DetectLesserInvisibility",
	["Detect Magic"] = "Spell_Holy_Dizzy",
	["Detect Traps"] = "Ability_Spy",
	["Deterrence"] = "Ability_Whirlwind",
	["Devastate"] = "INV_Sword_11",
	["Devastation"] = "Spell_Fire_FlameShock",
	["Devotion Aura"] = "Spell_Holy_DevotionAura",
	["Devour Magic"] = "Spell_Nature_Purge",
	["Devour Magic Effect"] = "Spell_Nature_Purge",
	["Devouring Plague"] = "Spell_Shadow_BlackPlague",
	["Diplomacy"] = "INV_Misc_Note_02",
	["Dire Bear Form"] = "Ability_Racial_BearForm",
--	["Dirty Deeds"] = true,
	["Dirty Tricks"] = "Ability_Sap",
	["Disarm"] = "Ability_Warrior_Disarm",
	["Disarm Trap"] = "Spell_Shadow_GrimWard",
	["Disease Cleansing Totem"] = "Spell_Nature_DiseaseCleansingTotem",
	["Disenchant"] = "Spell_Holy_RemoveCurse",
	["Disengage"] = "Ability_Rogue_Feint",
	["Dismiss Pet"] = "Spell_Nature_SpiritWolf",
	["Dispel Magic"] = "Spell_Holy_DispelMagic",
	["Distract"] = "Ability_Rogue_Distract",
	["Distracting Shot"] = "Spell_Arcane_Blink",
	["Dive"] = "Spell_Shadow_BurningSpirit",
	["Divine Favor"] = "Spell_Holy_Heal",
	["Divine Fury"] = "Spell_Holy_SealOfWrath",
	["Divine Illumination"] = "Spell_Holy_DivineIllumination",
	["Divine Intellect"] = "Spell_Nature_Sleep",
	["Divine Intervention"] = "Spell_Nature_TimeStop",
	["Divine Protection"] = "Spell_Holy_Restoration",
	["Divine Shield"] = "Spell_Holy_DivineIntervention",
	["Divine Spirit"] = "Spell_Holy_DivineSpirit",
	["Divine Strength"] = "Ability_GolemThunderClap",
--	["Divine Wrath"] = true,
	["Dodge"] = "Spell_Nature_Invisibilty",
--	["Doomfire"] = true,
	["Dragon's Breath"] = "INV_Misc_Head_Dragon_01",
	["Dragonscale Leatherworking"] = "INV_Misc_MonsterScales_03",
	["Drain Life"] = "Spell_Shadow_LifeDrain02",
	["Drain Mana"] = "Spell_Shadow_SiphonMana",
	["Drain Soul"] = "Spell_Shadow_Haunting",
	["Dreamless Sleep"] = "Spell_Nature_Sleep",
	["Drink"] = "INV_Drink_07",
	["Dual Wield"] = "Ability_DualWield",
	["Dual Wield Specialization"] = "Ability_DualWield",
	["Duel"] = "Temp",
	["Dust Cloud"] = "Ability_Hibernation",
	["Eagle Eye"] = "Ability_Hunter_EagleEye",
	["Earth Elemental Totem"] = "Spell_Nature_EarthElemental_Totem",
	["Earth Shield"] = "Spell_Nature_SkinofEarth",
	["Earth Shock"] = "Spell_Nature_EarthShock",
	["Earthbind"] = "Spell_Nature_StrengthOfEarthTotem02",
	["Earthbind Totem"] = "Spell_Nature_StrengthOfEarthTotem02",
	["Earthstrike"] = "Spell_Nature_AbolishMagic",
	["Efficiency"] = "Spell_Frost_WizardMark",
	["Elemental Devastation"] = "Spell_Fire_ElementalDevastation",
	["Elemental Focus"] = "Spell_Shadow_ManaBurn",
	["Elemental Fury"] = "Spell_Fire_Volcano",
	["Elemental Leatherworking"] = "Trade_LeatherWorking",
	["Elemental Mastery"] = "Spell_Nature_WispHeal",
	["Elemental Precision"] = "Spell_Nature_ElementalPrecision_1", -- Shaman and Mage Talents with different icons
	["Elemental Sharpening Stone"] = "INV_Stone_02",
--	["Elemental Weapons"] = true,
	["Elune's Grace"] = "Spell_Holy_ElunesGrace",
	["Elusiveness"] = "Spell_Magic_LesserInvisibilty",
	["Emberstorm"] = "Spell_Fire_SelfDestruct",
	["Empowered Arcane Missiles"] = "Spell_Nature_StarFall",
	["Empowered Corruption"] = "Spell_Shadow_AbominationExplosion",
	["Empowered Fireball"] = "Spell_Fire_FlameBolt",
	["Empowered Frostbolt"] = "Spell_Frost_FrostBolt02",
	["Empowered Healing"] = "Spell_Holy_GreaterHeal",
	["Empowered Rejuvenation"] = "Ability_Druid_EmpoweredRejuvination",
	["Empowered Touch"] = "Ability_Druid_EmpoweredTouch",
	["Enamored Water Spirit"] = "INV_Wand_01",
	["Enchanting"] = "Trade_Engraving",
	["Endurance"] = "Spell_Nature_UnyeildingStamina",
	["Endurance Training"] = "Spell_Nature_Reincarnation",
	["Engineering"] = "Trade_Engineering",
	["Engineering Specialization"] = "INV_Misc_Gear_01",
	["Enrage"] = "Ability_Druid_Enrage",
	["Enriched Manna Biscuit"] = "INV_Misc_Fork&Knife",
	["Enslave Demon"] = "Spell_Shadow_EnslaveDemon",
	["Entangling Roots"] = "Spell_Nature_StrangleVines",
	["Entrapment"] = "Spell_Nature_StrangleVines",
	["Envenom"] = "Ability_Rogue_Disembowel",
	["Escape Artist"] = "Ability_Rogue_Trip",
	["Evasion"] = "Spell_Shadow_ShadowWard",
	["Eviscerate"] = "Ability_Rogue_Eviscerate",
	["Evocation"] = "Spell_Nature_Purge",
	["Execute"] = "INV_Sword_48",
	["Exorcism"] = "Spell_Holy_Excorcism_02",
	["Expansive Mind"] = "INV_Enchant_EssenceEternalLarge",
	["Explosive Trap"] = "Spell_Fire_SelfDestruct",
	["Explosive Trap Effect"] = "Spell_Fire_SelfDestruct",
	["Expose Armor"] = "Ability_Warrior_Riposte",
	["Expose Weakness"] = "Ability_Hunter_SniperShot",
	["Extract Gas"] = "Spell_Nature_AbolishMagic",
	["Eye for an Eye"] = "Spell_Holy_EyeforanEye",
	["Eye of Kilrogg"] = "Spell_Shadow_EvilEye",
	["Eye of the Storm"] = "Spell_Shadow_SoulLeech_2",
	["Eyes of the Beast"] = "Ability_EyeOfTheOwl",
	["Fade"] = "Spell_Magic_LesserInvisibilty",
	["Faerie Fire"] = "Spell_Nature_FaerieFire",
	["Faerie Fire (Feral)"] = "Spell_Nature_FaerieFire",
	["Fanaticism"] = "Spell_Holy_Fanaticism",
	["Far Sight"] = "Spell_Nature_FarSight",
--	["Fatal Attraction"] = true,
	["Fear"] = "Spell_Shadow_Possession",
	["Fear Ward"] = "Spell_Holy_Excorcism",
	["Feed Pet"] = "Ability_Hunter_BeastTraining",
	["Feed Pet Effect"] = "Ability_Hunter_BeastTraining",
	["Feedback"] = "Spell_Shadow_RitualOfSacrifice",
	["Feign Death"] = "Ability_Rogue_FeignDeath",
	["Feint"] = "Ability_Rogue_Feint",
	["Fel Armor"] = "Spell_Shadow_FelArmour",
	["Fel Concentration"] = "Spell_Shadow_FingerOfDeath",
	["Fel Domination"] = "Spell_Nature_RemoveCurse",
	["Fel Energy"] = "Spell_Shadow_PsychicScream",
	["Fel Intellect"] = "Spell_Holy_MagicalSentry",
	["Fel Rage"] = "Spell_Fire_ElementalDevastation",
	["Fel Stamina"] = "Spell_Shadow_AntiShadow",
	["Felfire"] = "Spell_Fire_Fireball",
	["Feline Grace"] = "INV_Feather_01",
	["Feral Aggression"] = "Ability_Druid_DemoralizingRoar",
	["Feral Charge"] = "Ability_Hunter_Pet_Bear",
	["Feral Instinct"] = "Ability_Ambush",
	["Feral Swiftness"] = "Spell_Nature_SpiritWolf",
	["Ferocious Bite"] = "Ability_Druid_FerociousBite",
	["Ferocious Inspiration"] = "Ability_Hunter_FerociousInspiration",
	["Ferocity"] = "INV_Misc_MonsterClaw_04",
	["Fetish"] = "INV_Misc_Horn_01",
--	["Find Fish"] = true,
	["Find Herbs"] = "INV_Misc_Flower_02",
	["Find Minerals"] = "Spell_Nature_Earthquake",
	["Find Treasure"] = "Racial_Dwarf_FindTreasure",
	["Find Weakness"] = "Ability_Rogue_FindWeakness",
	["Fire Blast"] = "Spell_Fire_Fireball",
	["Fire Breath"] = "Spell_Fire_Burnout",
	["Fire Elemental Totem"] = "Spell_Fire_Elemental_Totem",
	["Fire Nova Totem"] = "Spell_Fire_SealOfFire",
	["Fire Power"] = "Spell_Fire_Immolation",
	["Fire Resistance"] = "Spell_Fire_FireArmor",
	["Fire Resistance Aura"] = "Spell_Fire_SealOfFire",
	["Fire Resistance Totem"] = "Spell_FireResistanceTotem_01",
	["Fire Shield"] = "Spell_Fire_FireArmor",
	["Fire Vulnerability"] = "Spell_Fire_SoulBurn",
	["Fire Ward"] = "Spell_Fire_FireArmor",
	["Fire Weakness"] = "INV_Misc_QirajiCrystal_02",
	["Fireball"] = "Spell_Fire_FlameBolt",
	["Firebolt"] = "Spell_Fire_FireBolt",
	["First Aid"] = "Spell_Holy_SealOfSacrifice",
	["Fishing"] = "Trade_Fishing",
	["Fishing Poles"] = "Trade_Fishing",
	["Fist Weapon Specialization"] = "INV_Gauntlets_04",
	["Fist Weapons"] = "INV_Gauntlets_04",
	["Flame Shock"] = "Spell_Fire_FlameShock",
	["Flame Throwing"] = "Spell_Fire_Flare",
	["Flamestrike"] = "Spell_Fire_SelfDestruct",
	["Flamethrower"] = "Spell_Fire_Incinerate",
	["Flametongue Attack"] = "Spell_Fire_FlameTounge",
	["Flametongue Totem"] = "Spell_Nature_GuardianWard",
	["Flametongue Weapon"] = "Spell_Fire_FlameTounge",
	["Flare"] = "Spell_Fire_Flare",
	["Flash Heal"] = "Spell_Holy_FlashHeal",
	["Flash of Light"] = "Spell_Holy_FlashHeal",
	["Flight Form"] = "Ability_Druid_FlightForm",
--	["FlightMaster"] = true,
	["Flurry"] = "Ability_GhoulFrenzy",
	["Focused Casting"] = "Spell_Arcane_Blink",
	["Focused Mind"] = "Spell_Nature_FocusedMind",
	["Focused Power"] = "Spell_Shadow_FocusedPower",
--	["Focused Rage"] = true,
	["Focused Starlight"] = "INV_Staff_01",
	["Food"] = "INV_Misc_Fork&Knife",
--	["Food & Drink"] = true,
	["Forbearance"] = "Spell_Holy_RemoveCurse",
	["Force of Nature"] = "Ability_Druid_ForceofNature",
	["Force of Will"] = "Spell_Nature_SlowingTotem",
	["Freezing Trap"] = "Spell_Frost_ChainsOfIce",
	["Freezing Trap Effect"] = "Spell_Frost_ChainsOfIce",
	["Frenzied Regeneration"] = "Ability_BullRush",
	["Frenzy"] = "INV_Misc_MonsterClaw_03",
--	["Frenzy Effect"] = true,
	["Frost Armor"] = "Spell_Frost_FrostArmor02",
	["Frost Blast"] = "Spell_Frost_FrostBolt02",
	["Frost Channeling"] = "Spell_Frost_Stun",
	["Frost Nova"] = "Spell_Frost_FrostNova",
	["Frost Resistance"] = "Spell_Frost_FrostWard",
	["Frost Resistance Aura"] = "Spell_Frost_WizardMark",
	["Frost Resistance Totem"] = "Spell_FrostResistanceTotem_01",
	["Frost Shock"] = "Spell_Frost_FrostShock",
	["Frost Trap"] = "Spell_Frost_FreezingBreath",
	["Frost Trap Aura"] = "Spell_Frost_FrostNova",
	["Frost Ward"] = "Spell_Frost_FrostWard",
	["Frost Warding"] = "Spell_Frost_FrostWard",
	["Frost Weakness"] = "INV_Misc_QirajiCrystal_04",
	["Frostbite"] = "Spell_Frost_FrostArmor",
	["Frostbolt"] = "Spell_Frost_FrostBolt02",
	["Frostbrand Attack"] = "Spell_Frost_FrostBrand",
	["Frostbrand Weapon"] = "Spell_Frost_FrostBrand",
	["Frozen Core"] = "Spell_Frost_FrozenCore",
	["Furious Howl"] = "Ability_Hunter_Pet_Wolf",
	["Furor"] = "Spell_Holy_BlessingOfStamina",
	["Fury of the Crashing Waves"] = "Spell_Nature_UnrelentingStorm",
	["Garrote"] = "Ability_Rogue_Garrote",
	["Garrote - Silence"] = "Ability_Rogue_Garrote",
	["Ghost Wolf"] = "Spell_Nature_SpiritWolf",
	["Ghostly Strike"] = "Spell_Shadow_Curse",
	["Gift of Life"] = "INV_Misc_Gem_Pearl_05",
	["Gift of Nature"] = "Spell_Nature_ProtectionformNature",
	["Gift of the Naaru"] = "Spell_Holy_HolyProtection",
	["Gift of the Wild"] = "Spell_Nature_Regeneration",
	["Gouge"] = "Ability_Gouge",
	["Grace of Air"] = "Spell_Nature_InvisibilityTotem",
	["Grace of Air Totem"] = "Spell_Nature_InvisibilityTotem",
	["Great Stamina"] = "Spell_Nature_UnyeildingStamina",
	["Greater Blessing of Kings"] = "Spell_Magic_GreaterBlessingofKings",
	["Greater Blessing of Light"] = "Spell_Holy_GreaterBlessingofLight",
	["Greater Blessing of Might"] = "Spell_Holy_GreaterBlessingofKings",
	["Greater Blessing of Salvation"] = "Spell_Holy_GreaterBlessingofSalvation",
	["Greater Blessing of Sanctuary"] = "Spell_Holy_GreaterBlessingofSanctuary",
	["Greater Blessing of Wisdom"] = "Spell_Holy_GreaterBlessingofWisdom",
	["Greater Dreamless Sleep"] = "Spell_Nature_Sleep",
	["Greater Heal"] = "Spell_Holy_GreaterHeal",
	["Grim Reach"] = "Spell_Shadow_CallofBone",
	["Grounding Totem"] = "Spell_Nature_GroundingTotem",
	["Grounding Totem Effect"] = "Spell_Nature_GroundingTotem",
	["Grovel"] = "Temp",
	["Growl"] = "Ability_Physical_Taunt",
	["Guardian's Favor"] = "Spell_Holy_SealOfProtection",
	["Gun Specialization"] = "INV_Musket_03",
	["Guns"] = "INV_Weapon_Rifle_01",
	["Hammer of Justice"] = "Spell_Holy_SealOfMight",
	["Hammer of Wrath"] = "Ability_ThunderClap",
	["Hamstring"] = "Ability_ShockWave",
	["Harass"] = "Ability_Hunter_Harass",
	["Hardiness"] = "INV_Helmet_23",
	["Haste"] = "INV_Potion_108", -- there are a lot of icons for Haste
	["Hawk Eye"] = "Ability_TownWatch",
	["Heal"] = "Spell_Holy_Heal",
	["Healing Focus"] = "Spell_Holy_HealingFocus",
	["Healing Light"] = "Spell_Holy_HolyBolt",
	["Healing Stream"] = "INV_Spear_04",
	["Healing Stream Totem"] = "INV_Spear_04",
	["Healing Touch"] = "Spell_Nature_HealingTouch",
	["Healing Wave"] = "Spell_Nature_MagicImmunity",
	["Healing Way"] = "Spell_Nature_HealingWay",
	["Health Funnel"] = "Spell_Shadow_LifeDrain",
	["Heart of the Wild"] = "Spell_Holy_BlessingOfAgility",
	["Heavy Sharpening Stone"] = "INV_Stone_SharpeningStone_03",
	["Hellfire"] = "Spell_Fire_Incinerate",
	["Hellfire Effect"] = "Spell_Fire_Incinerate",
	["Hellfire Superiority"] = "INV_BannerPVP_02", -- Horde and Alliance have different icons
	["Hemorrhage"] = "Spell_Shadow_LifeDrain",
	["Herb Gathering"] = "Spell_Nature_NatureTouchGrow",
	["Herbalism"] = "Spell_Nature_NatureTouchGrow",
	["Heroic Strike"] = "Ability_Rogue_Ambush",
	["Heroism"] = "Ability_Shaman_Heroism",
	["Hex of Weakness"] = "Spell_Shadow_FingerOfDeath",
	["Hibernate"] = "Spell_Nature_Sleep",
	["Holy Fire"] = "Spell_Holy_SearingLight",
	["Holy Light"] = "Spell_Holy_HolyBolt",
	["Holy Nova"] = "Spell_Holy_HolyNova",
	["Holy Power"] = "Spell_Holy_Power",
	["Holy Reach"] = "Spell_Holy_Purify",
	["Holy Shield"] = "Spell_Holy_BlessingOfProtection",
	["Holy Shock"] = "Spell_Holy_SearingLight",
	["Holy Specialization"] = "Spell_Holy_SealOfSalvation",
	["Holy Wrath"] = "Spell_Holy_Excorcism",
	["Honorless Target"] = "Spell_Magic_LesserInvisibilty",
	["Horse Riding"] = "Spell_Nature_Swiftness",
	["Howl of Terror"] = "Spell_Shadow_DeathScream",
	["Humanoid Slaying"] = "Spell_Holy_PrayerOfHealing",
	["Hunter's Mark"] = "Ability_Hunter_SniperShot",
	["Hurricane"] = "Spell_Nature_Cyclone",
	["Hypothermia"] = "Spell_Fire_BlueImmolation",
	["Ice Armor"] = "Spell_Frost_FrostArmor02",
	["Ice Barrier"] = "Spell_Ice_Lament",
	["Ice Block"] = "Spell_Frost_Frost",
	["Ice Floes"] = "Spell_Frost_IceFloes",
	["Ice Lance"] = "Spell_Frost_FrostBlast",
	["Ice Shards"] = "Spell_Frost_IceShard",
	["Ignite"] = "Spell_Fire_Incinerate",
	["Ignite Mana"] = "Spell_Fire_Incinerate",
	["Illumination"] = "Spell_Holy_GreaterHeal",
	["Immolate"] = "Spell_Fire_Immolation",
	["Immolation Trap"] = "Spell_Fire_FlameShock",
	["Immolation Trap Effect"] = "Spell_Fire_FlameShock",
	["Impact"] = "Spell_Fire_MeteorStorm",
	["Impale"] = "Ability_SearingArrow",
--	["Impaling Spine"] = true,
	["Improved Ambush"] = "Ability_Rogue_Ambush",
	["Improved Arcane Missiles"] = "Spell_Nature_StarFall",
	["Improved Arcane Shot"] = "Ability_ImpalingBolt",
	["Improved Aspect of the Hawk"] = "Spell_Nature_RavenForm",
	["Improved Aspect of the Monkey"] = "Ability_Hunter_AspectOfTheMonkey",
	["Improved Backstab"] = "Ability_BackStab",
--	["Improved Barrage"] = true,
	["Improved Berserker Rage"] = "Spell_Nature_AncestralGuardian",
	["Improved Blessing of Might"] = "Spell_Holy_FistOfJustice",
	["Improved Blessing of Wisdom"] = "Spell_Holy_SealOfWisdom",
	["Improved Blink"] = "Spell_Arcane_Blink",
	["Improved Blizzard"] = "Spell_Frost_IceStorm",
	["Improved Bloodrage"] = "Ability_Racial_BloodRage",
	["Improved Chain Heal"] = "Spell_Nature_HealingWaveGreater",
	["Improved Chain Lightning"] = "Spell_Nature_ChainLightning",
	["Improved Challenging Shout"] = "Ability_Warrior_Challange",
	["Improved Charge"] = "Ability_Warrior_Charge",
	["Improved Cleave"] = "Ability_Warrior_Cleave",
	["Improved Concentration Aura"] = "Spell_Holy_MindSooth",
	["Improved Concussive Shot"] = "Spell_Frost_Stun",
	["Improved Cone of Cold"] = "Spell_Frost_Glacier",
	["Improved Corruption"] = "Spell_Shadow_AbominationExplosion",
	["Improved Counterspell"] = "Spell_Frost_IceShock",
	["Improved Curse of Agony"] = "Spell_Shadow_CurseOfSargeras",
	["Improved Curse of Weakness"] = "Spell_Shadow_CurseOfMannoroth",
	["Improved Demoralizing Shout"] = "Ability_Warrior_WarCry",
	["Improved Devotion Aura"] = "Spell_Holy_DevotionAura",
	["Improved Disarm"] = "Ability_Warrior_Disarm",
	["Improved Drain Life"] = "Spell_Shadow_LifeDrain02",
	["Improved Drain Soul"] = "Spell_Shadow_Haunting",
	["Improved Enrage"] = "Ability_Druid_Enrage",
	["Improved Enslave Demon"] = "Spell_Shadow_EnslaveDemon",
	["Improved Eviscerate"] = "Ability_Rogue_Eviscerate",
	["Improved Execute"] = "INV_Sword_48",
	["Improved Expose Armor"] = "Ability_Warrior_Riposte",
	["Improved Eyes of the Beast"] = "Ability_EyeOfTheOwl",
	["Improved Fade"] = "Spell_Magic_LesserInvisibilty",
	["Improved Feign Death"] = "Ability_Rogue_FeignDeath",
	["Improved Fire Blast"] = "Spell_Fire_Fireball",
	["Improved Fire Totems"] = "Spell_Fire_SealOfFire",
	["Improved Fire Ward"] = "Spell_Fire_FireArmor",
	["Improved Fireball"] = "Spell_Fire_FlameBolt",
	["Improved Firebolt"] = "Spell_Fire_FireBolt",
	["Improved Flamestrike"] = "Spell_Fire_SelfDestruct",
	["Improved Flash of Light"] = "Spell_Holy_FlashHeal",
	["Improved Frost Nova"] = "Spell_Frost_FreezingBreath",
	["Improved Frostbolt"] = "Spell_Frost_FrostBolt02",
	["Improved Ghost Wolf"] = "Spell_Nature_SpiritWolf",
	["Improved Gouge"] = "Ability_Gouge",
	["Improved Hammer of Justice"] = "Spell_Holy_SealOfMight",
	["Improved Hamstring"] = "Ability_ShockWave",
	["Improved Healing"] = "Spell_Holy_Heal02",
	["Improved Healing Touch"] = "Spell_Nature_HealingTouch",
	["Improved Healing Wave"] = "Spell_Nature_MagicImmunity",
	["Improved Health Funnel"] = "Spell_Shadow_LifeDrain",
	["Improved Healthstone"] = "INV_Stone_04",
	["Improved Heroic Strike"] = "Ability_Rogue_Ambush",
--	["Improved Holy Shield"] = true,
	["Improved Howl of Terror"] = "Spell_Shadow_DeathScream",
	["Improved Hunter's Mark"] = "Ability_Hunter_SniperShot",
	["Improved Immolate"] = "Spell_Fire_Immolation",
	["Improved Imp"] = "Spell_Shadow_SummonImp",
	["Improved Inner Fire"] = "Spell_Holy_InnerFire",
	["Improved Intercept"] = "Ability_Rogue_Sprint",
	["Improved Intimidating Shout"] = "Ability_GolemThunderClap",
	["Improved Judgement"] = "Spell_Holy_RighteousFury",
	["Improved Kick"] = "Ability_Kick",
	["Improved Kidney Shot"] = "Ability_Rogue_KidneyShot",
	["Improved Lash of Pain"] = "Spell_Shadow_Curse",
	["Improved Lay on Hands"] = "Spell_Holy_LayOnHands",
	["Improved Leader of the Pack"] = "Spell_Nature_UnyeildingStamina",
	["Improved Life Tap"] = "Spell_Shadow_BurningSpirit",
	["Improved Lightning Bolt"] = "Spell_Nature_Lightning",
	["Improved Lightning Shield"] = "Spell_Nature_LightningShield",
	["Improved Magma Totem"] = "Spell_Fire_SelfDestruct",
	["Improved Mana Burn"] = "Spell_Shadow_ManaBurn",
	["Improved Mana Shield"] = "Spell_Shadow_DetectLesserInvisibility",
	["Improved Mana Spring Totem"] = "Spell_Nature_ManaRegenTotem",
	["Improved Mark of the Wild"] = "Spell_Nature_Regeneration",
	["Improved Mend Pet"] = "Ability_Hunter_MendPet",
	["Improved Mind Blast"] = "Spell_Shadow_UnholyFrenzy",
	["Improved Moonfire"] = "Spell_Nature_StarFall",
--	["Improved Mortal Strike"] = true,
	["Improved Nature's Grasp"] = "Spell_Nature_NaturesWrath",
	["Improved Overpower"] = "INV_Sword_05",
	["Improved Power Word: Fortitude"] = "Spell_Holy_WordFortitude",
	["Improved Power Word: Shield"] = "Spell_Holy_PowerWordShield",
	["Improved Prayer of Healing"] = "Spell_Holy_PrayerOfHealing02",
	["Improved Psychic Scream"] = "Spell_Shadow_PsychicScream",
	["Improved Regrowth"] = "Spell_Nature_ResistNature",
	["Improved Reincarnation"] = "Spell_Nature_Reincarnation",
	["Improved Rejuvenation"] = "Spell_Nature_Rejuvenation",
	["Improved Rend"] = "Ability_Gouge",
	["Improved Renew"] = "Spell_Holy_Renew",
	["Improved Retribution Aura"] = "Spell_Holy_AuraOfLight",
	["Improved Revenge"] = "Ability_Warrior_Revenge",
	["Improved Revive Pet"] = "Ability_Hunter_BeastSoothe",
	["Improved Righteous Fury"] = "Spell_Holy_SealOfFury",
	["Improved Rupture"] = "Ability_Rogue_Rupture",
	["Improved Scorch"] = "Spell_Fire_SoulBurn",
	["Improved Scorpid Sting"] = "Ability_Hunter_CriticalShot",
	["Improved Seal of Righteousness"] = "Ability_ThunderBolt",
	["Improved Seal of the Crusader"] = "Spell_Holy_HolySmite",
	["Improved Searing Pain"] = "Spell_Fire_SoulBurn",
	["Improved Serpent Sting"] = "Ability_Hunter_Quickshot",
	["Improved Shadow Bolt"] = "Spell_Shadow_ShadowBolt",
	["Improved Shadow Word: Pain"] = "Spell_Shadow_ShadowWordPain",
	["Improved Shield Bash"] = "Ability_Warrior_ShieldBash",
	["Improved Shield Block"] = "Ability_Defend",
	["Improved Shield Wall"] = "Ability_Warrior_ShieldWall",
	["Improved Sinister Strike"] = "Spell_Shadow_RitualOfSacrifice",
	["Improved Slam"] = "Ability_Warrior_DecisiveStrike",
	["Improved Slice and Dice"] = "Ability_Rogue_SliceDice",
	["Improved Sprint"] = "Ability_Rogue_Sprint",
--	["Improved Stings"] = true,
	["Improved Succubus"] = "Spell_Shadow_SummonSuccubus",
	["Improved Sunder Armor"] = "Ability_Warrior_Sunder",
	["Improved Taunt"] = "Spell_Nature_Reincarnation",
	["Improved Thunder Clap"] = "Ability_ThunderClap",
	["Improved Tranquility"] = "Spell_Nature_Tranquility",
	["Improved Vampiric Embrace"] = "Spell_Shadow_ImprovedVampiricEmbrace",
	["Improved Vanish"] = "Ability_Vanish",
	["Improved Voidwalker"] = "Spell_Shadow_SummonVoidWalker",
--	["Improved Weapon Totems"] = true,
--	["Improved Whirlwind"] = true,
	["Improved Wing Clip"] = "Ability_Rogue_Trip",
	["Incinerate"] = "Spell_Fire_Burnout",
	["Incineration"] = "Spell_Fire_FlameShock",
	["Inferno"] = "Spell_Shadow_SummonInfernal",
	["Initiative"] = "Spell_Shadow_Fumble",
--	["Innkeeper"] = true,
	["Inner Fire"] = "Spell_Holy_InnerFire",
	["Inner Focus"] = "Spell_Frost_WindWalkOn",
	["Innervate"] = "Spell_Nature_Lightning",
	["Insect Swarm"] = "Spell_Nature_InsectSwarm",
	["Insidious Whisper"] = "Spell_Shadow_ManaFeed",
	["Insignifigance"] = "Ability_Hibernation",
	["Inspiration"] = "Spell_Holy_LayOnHands",
	["Instant Poison"] = "Ability_Poisons",
	["Instant Poison II"] = "Ability_Poisons",
	["Instant Poison III"] = "Ability_Poisons",
	["Instant Poison IV"] = "Ability_Poisons",
	["Instant Poison V"] = "Ability_Poisons",
	["Instant Poison VI"] = "Ability_Poisons",
	["Instant Poison VII"] = "Ability_Poisons",
	["Intensity"] = "Spell_Fire_LavaSpawn",
	["Intercept"] = "Ability_Rogue_Sprint",
	["Intercept Stun"] = "Spell_Frost_Stun",
	["Intervene"] = "Ability_Warrior_VictoryRush",
	["Intimidating Shout"] = "Ability_GolemThunderClap",
	["Intimidation"] = "Ability_Devour",
	["Invisibility"] = "Ability_Mage_Invisibility",
	["Iron Will"] = "Spell_Magic_MageArmor",
	["Jewelcrafting"] = "INV_Misc_Gem_02",
	["Jom Gabbar"] = "INV_Misc_EngGizmos_19",
	["Judgement"] = "Spell_Holy_RighteousFury",
	["Judgement of Blood"] = "Spell_Shadow_LifeDrain",
	["Judgement of Command"] = "Ability_Warrior_InnerRage",
	["Judgement of Justice"] = "Spell_Holy_SealOfWrath",
	["Judgement of Light"] = "Spell_Holy_HealingAura",
	["Judgement of Reckoning"] = "Ability_Warrior_InnerRage",
	["Judgement of Righteousness"] = "Ability_ThunderBolt",
	["Judgement of Wisdom"] = "Spell_Holy_RighteousnessAura",
	["Judgement of the Crusader"] = "Spell_Holy_HolySmite",
	["Kick"] = "Ability_Kick",
	["Kick - Silenced"] = "Ability_Kick",
	["Kidney Shot"] = "Ability_Rogue_KidneyShot",
	["Kill Command"] = "Ability_Hunter_KillCommand",
	["Killer Instinct"] = "Spell_Holy_BlessingOfStamina",
	["Kiss of the Spider"] = "INV_Trinket_Naxxramas04",
	["Kodo Riding"] = "Spell_Nature_Swiftness",
	["Lacerate"] = "Ability_Druid_Lacerate",
	["Lash of Pain"] = "Spell_Shadow_Curse",
	["Last Stand"] = "Spell_Holy_AshesToAshes",
	["Lay on Hands"] = "Spell_Holy_LayOnHands",
	["Leader of the Pack"] = "Spell_Nature_UnyeildingStamina",
	["Leather"] = "INV_Chest_Leather_09",
	["Leatherworking"] = "INV_Misc_ArmorKit_17",
	["Lesser Heal"] = "Spell_Holy_LesserHeal",
	["Lesser Healing Wave"] = "Spell_Nature_HealingWaveLesser",
	["Lesser Invisibility"] = "Spell_Magic_LesserInvisibilty",
	["Lethal Shots"] = "Ability_SearingArrow",
	["Lethality"] = "Ability_CriticalStrike",
	["Levitate"] = "Spell_Holy_LayOnHands",
	["Libram"] = "INV_Misc_Book_11",
	["Life Tap"] = "Spell_Shadow_BurningSpirit",
	["Lifebloom"] = "INV_Misc_Herb_Felblossom",
	["Light's Grace"] = "Spell_Holy_LightsGrace",
	["Lightning Bolt"] = "Spell_Nature_Lightning",
	["Lightning Breath"] = "Spell_Nature_Lightning",
	["Lightning Mastery"] = "Spell_Lightning_LightningBolt01",
	["Lightning Reflexes"] = "Spell_Nature_Invisibilty",
	["Lightning Shield"] = "Spell_Nature_LightningShield",
	["Lightning Speed"] = "Spell_Nature_UnrelentingStorm",
	["Lightwell"] = "Spell_Holy_SummonLightwell",
	["Lightwell Renew"] = "Spell_Holy_SummonLightwell",
	["Lockpicking"] = "Spell_Nature_MoonKey",
	["Long Daze"] = "Spell_Frost_Stun",
	["Lust for Battle"] = "Spell_Shadow_DeathPact",
	["Mace Specialization"] = "INV_Mace_01",
	["Mace Stun Effect"] = "Spell_Frost_Stun",
	["Mage Armor"] = "Spell_MageArmor",
	["Magic Absorption"] = "Spell_Nature_AstralRecalGroup",
	["Magic Attunement"] = "Spell_Nature_AbolishMagic",
	["Magma Totem"] = "Spell_Fire_SelfDestruct",
	["Mail"] = "INV_Chest_Chain_05",
	["Maim"] = "Ability_Druid_Mangle",
	["Major Dreamless Sleep"] = "Spell_Nature_Sleep",
	["Malediction"] = "Spell_Shadow_CurseOfAchimonde",
	["Malice"] = "Ability_Racial_BloodRage",
	["Mana Burn"] = "Spell_Shadow_ManaBurn",
	["Mana Feed"] = "Spell_Shadow_ManaFeed",
	["Mana Shield"] = "Spell_Shadow_DetectLesserInvisibility",
	["Mana Spring"] = "Spell_Nature_ManaRegenTotem",
	["Mana Spring Totem"] = "Spell_Nature_ManaRegenTotem",
	["Mana Tap"] = "Spell_Arcane_ManaTap",
	["Mana Tide"] = "Spell_Frost_SummonWaterElemental",
	["Mana Tide Totem"] = "Spell_Frost_SummonWaterElemental",
	["Mangle"] = "Ability_Druid_Mangle",
	["Mangle (Bear)"] = "Ability_Druid_Mangle2",
	["Mangle (Cat)"] = "Ability_Druid_Mangle2",
	["Mark of the Wild"] = "Spell_Nature_Regeneration",
	["Martyrdom"] = "Spell_Nature_Tranquility",
	["Mass Dispel"] = "Spell_Arcane_MassDispel",
	["Master Conjuror"] = "INV_Ammo_FireTar",
	["Master Demonologist"] = "Spell_Shadow_ShadowPact",
	["Master Summoner"] = "Spell_Shadow_ImpPhaseShift",
	["Master Tactician"] = "Ability_Hunter_MasterTactitian",
	["Master of Deception"] = "Spell_Shadow_Charm",
	["Master of Elements"] = "Spell_Fire_MasterOfElements",
	["Master of Subtlety"] = "Ability_Rogue_MasterOfSubtlety",
	["Maul"] = "Ability_Druid_Maul",
	["Mechanostrider Piloting"] = "Spell_Nature_Swiftness",
	["Meditation"] = "Spell_Nature_Sleep",
	["Melee Specialization"] = "INV_Axe_02",
--	["Melt Armor"] = true,
	["Mend Pet"] = "Ability_Hunter_MendPet",
	["Mental Agility"] = "Ability_Hibernation",
	["Mental Strength"] = "Spell_Nature_EnchantArmor",
	["Mind Blast"] = "Spell_Shadow_UnholyFrenzy",
	["Mind Control"] = "Spell_Shadow_ShadowWordDominate",
	["Mind Flay"] = "Spell_Shadow_SiphonMana",
	["Mind Mastery"] = "Spell_Arcane_MindMastery",
	["Mind Soothe"] = "Spell_Holy_MindSooth",
	["Mind Vision"] = "Spell_Holy_MindVision",
	["Mind-numbing Poison"] = "Spell_Nature_NullifyDisease",
	["Mind-numbing Poison II"] = "Spell_Nature_NullifyDisease",
	["Mind-numbing Poison III"] = "Spell_Nature_NullifyDisease",
	["Mining"] = "Spell_Fire_FlameBlades",
	["Misdirection"] = "Ability_Hunter_Misdirection",
	["Misery"] = "Spell_Shadow_Misery",
	["Mocking Blow"] = "Ability_Warrior_PunishingBlow",
	["Molten Armor"] = "Ability_Mage_MoltenArmor",
	["Molten Fury"] = "Spell_Fire_MoltenBlood",
	["Mongoose Bite"] = "Ability_Hunter_SwiftStrike",
	["Monster Slaying"] = "INV_Misc_Head_Dragon_Black",
	["Moonfire"] = "Spell_Nature_StarFall",
	["Moonfury"] = "Spell_Nature_MoonGlow",
	["Moonglow"] = "Spell_Nature_Sentinal",
	["Moonkin Aura"] = "Spell_Nature_MoonGlow",
	["Moonkin Form"] = "Spell_Nature_ForceOfNature",
	["Mortal Shots"] = "Ability_PierceDamage",
	["Mortal Strike"] = "Ability_Warrior_SavageBlow",
	["Multi-Shot"] = "Ability_UpgradeMoonGlaive",
	["Murder"] = "Spell_Shadow_DeathScream",
	["Mutilate"] = "Ability_Rogue_ShadowStrikes",
	["Natural Armor"] = "Spell_Nature_SpiritArmor",
	["Natural Perfection"] = "Ability_Druid_NaturalPerfection",
	["Natural Shapeshifter"] = "Spell_Nature_WispSplode",
	["Naturalist"] = "Spell_Nature_HealingTouch",
	["Nature Resistance"] = "Spell_Nature_ResistNature",
	["Nature Resistance Totem"] = "Spell_Nature_NatureResistanceTotem",
	["Nature Weakness"] = "INV_Misc_QirajiCrystal_03",
	["Nature's Focus"] = "Spell_Nature_HealingWaveGreater",
	["Nature's Grace"] = "Spell_Nature_NaturesBlessing",
	["Nature's Grasp"] = "Spell_Nature_NaturesWrath",
--	["Nature's Guidance"] = true,
	["Nature's Reach"] = "Spell_Nature_NatureTouchGrow",
	["Nature's Swiftness"] = "Spell_Nature_RavenForm",
	["Negative Charge"] = "Spell_ChargeNegative",
	["Nether Protection"] = "Spell_Shadow_NetherProtection",
	["Netherstorm Flag"] = "INV_Misc_Summerfest_BrazierGreen",
	["Nightfall"] = "Spell_Shadow_Twilight",
	["Nurturing Instinct"] = "Ability_Druid_HealingInstincts",
	["Omen of Clarity"] = "Spell_Nature_CrystalBall",
	["One-Handed Axes"] = "INV_Axe_01",
	["One-Handed Maces"] = "INV_Mace_01",
	["One-Handed Swords"] = "Ability_MeleeDamage",
	["One-Handed Weapon Specialization"] = "INV_Sword_20",
	["Opening"] = "Temp",
	["Opening - No Text"] = "Temp",
	["Opportunity"] = "Ability_Warrior_WarCry",
	["Overpower"] = "Ability_MeleeDamage",
	["Pain Suppression"] = "Spell_Holy_PainSupression",
	["Panic"] = "INV_Misc_Drum_06",
	["Paranoia"] = "Spell_Shadow_AuraOfDarkness",
--	["Parasitic Shadowfiend"] = true,
	["Parry"] = "Ability_Parry",
	["Pathfinding"] = "Ability_Mount_JungleTiger",
	["Perceived Weakness"] = "Spell_Holy_ArcaneIntellect",
	["Perception"] = "Spell_Nature_Sleep",
	["Permafrost"] = "Spell_Frost_Wisp",
	["Pet Aggression"] = "Ability_Druid_Maul",
	["Pet Hardiness"] = "Ability_BullRush",
	["Pet Recovery"] = "Ability_Hibernation",
	["Pet Resistance"] = "Spell_Holy_BlessingOfAgility",
	["Phase Shift"] = "Spell_Shadow_ImpPhaseShift",
	["Pick Lock"] = "Spell_Nature_MoonKey",
	["Pick Pocket"] = "INV_Misc_Bag_11",
	["Piercing Howl"] = "Spell_Shadow_DeathScream",
	["Piercing Ice"] = "Spell_Frost_Frostbolt",
	["Plate Mail"] = "INV_Chest_Plate01",
	["Playing with Fire"] = "Spell_Fire_PlayingWithFire",
	["Poison Cleansing Totem"] = "Spell_Nature_PoisonCleansingTotem",
	["Poison Spit"] = "Spell_Nature_CorrosiveBreath",
	["Poisons"] = "Trade_BrewPoison",
	["Polearms"] = "INV_Spear_06",
	["Poleaxe Specialization"] = "INV_Weapon_Halbard_01",
	["Polymorph"] = "Spell_Nature_Polymorph",
	["Polymorph: Pig"] = "Spell_Magic_PolymorphPig",
	["Polymorph: Turtle"] = "Ability_Hunter_Pet_Turtle",
	["Portal: Darnassus"] = "Spell_Arcane_PortalDarnassus",
	["Portal: Exodar"] = "Spell_Arcane_PortalExodar",
	["Portal: Ironforge"] = "Spell_Arcane_PortalIronForge",
	["Portal: Orgrimmar"] = "Spell_Arcane_PortalOrgrimmar",
	["Portal: Shattrath"] = "Spell_Arcane_PortalShattrath",
	["Portal: Silvermoon"] = "Spell_Arcane_PortalSilvermoon",
	["Portal: Stormwind"] = "Spell_Arcane_PortalStormWind",
	["Portal: Thunder Bluff"] = "Spell_Arcane_PortalThunderBluff",
	["Portal: Undercity"] = "Spell_Arcane_PortalUnderCity",
	["Positive Charge"] = "Spell_ChargePositive",
	["Pounce"] = "Ability_Druid_SupriseAttack",
	["Pounce Bleed"] = "Ability_Druid_SupriseAttack",
	["Power Infusion"] = "Spell_Holy_PowerInfusion",
	["Power Word: Fortitude"] = "Spell_Holy_WordFortitude",
	["Power Word: Shield"] = "Spell_Holy_PowerWordShield",
	["Prayer of Fortitude"] = "Spell_Holy_PrayerOfFortitude",
	["Prayer of Healing"] = "Spell_Holy_PrayerOfHealing02",
	["Prayer of Mending"] = "Spell_Holy_PrayerOfMendingtga",
	["Prayer of Shadow Protection"] = "Spell_Holy_PrayerofShadowProtection",
	["Prayer of Spirit"] = "Spell_Holy_PrayerofSpirit",
	["Precision"] = "Ability_Marksmanship",
--	["Predatory Instincts"] = true,
	["Predatory Strikes"] = "Ability_Hunter_Pet_Cat",
	["Premeditation"] = "Spell_Shadow_Possession",
	["Preparation"] = "Spell_Shadow_AntiShadow",
	["Presence of Mind"] = "Spell_Nature_EnchantArmor",
	["Primal Fury"] = "Ability_Racial_Cannibalize",
	["Prismatic Cloak"] = "Spell_Arcane_PrismaticCloak",
--	["Profession Trainers"] = true,
	["Prospecting"] = "INV_Misc_Gem_BloodGem_01",
	["Prowl"] = "Ability_Druid_SupriseAttack",
	["Psychic Scream"] = "Spell_Shadow_PsychicScream",
	["Pummel"] = "INV_Gauntlets_04",
	["Purge"] = "Spell_Nature_Purge",
	["Purification"] = "Spell_Frost_WizardMark",
	["Purify"] = "Spell_Holy_Purify",
	["Purifying Power"] = "Spell_Holy_PurifyingPower",
	["Pursuit of Justice"] = "Spell_Holy_PersuitofJustice",
	["Pyroblast"] = "Spell_Fire_Fireball02",
	["Pyroclasm"] = "Spell_Fire_Volcano",
	["Pyromaniac"] = "Spell_Fire_Burnout",
	["Quick Recovery"] = "Ability_Rogue_QuickRecovery",
	["Quick Shots"] = "Ability_Warrior_InnerRage",
	["Quickness"] = "Ability_Racial_ShadowMeld",
	["Rage of the Unraveller"] = "Racial_Orc_BerserkerStrength",
	["Rain of Fire"] = "Spell_Shadow_RainOfFire",
	["Rake"] = "Ability_Druid_Disembowel",
	["Ram Riding"] = "Spell_Nature_Swiftness",
	["Rampage"] = "Ability_Warrior_Rampage",
	["Ranged Weapon Specialization"] = "INV_Weapon_Rifle_06",
	["Rapid Fire"] = "Ability_Hunter_RunningShot",
	["Rapid Killing"] = "Ability_Hunter_RapidKilling",
	["Raptor Riding"] = "Spell_Nature_Swiftness",
	["Raptor Strike"] = "Ability_MeleeDamage",
	["Ravage"] = "Ability_Druid_Ravage",
	["Readiness"] = "Ability_Hunter_Readiness",
--	["Reagents"] = true,
	["Rebirth"] = "Spell_Nature_Reincarnation",
	["Reckless Charge"] = "Spell_Nature_AstralRecal",
	["Recklessness"] = "Ability_CriticalStrike",
	["Reckoning"] = "Spell_Holy_BlessingOfStrength",
	["Redemption"] = "Spell_Holy_Resurrection",
	["Redoubt"] = "Ability_Defend",
	["Reflection"] = "Spell_Frost_WindWalkOn",
	["Regeneration"] = "Spell_Nature_Regenerate",
	["Regrowth"] = "Spell_Nature_ResistNature",
	["Reincarnation"] = "Spell_Nature_Reincarnation",
	["Reinforced Shield"] = "INV_Shield_06",
	["Rejuvenation"] = "Spell_Nature_Rejuvenation",
	["Relentless Strikes"] = "Ability_Warrior_DecisiveStrike",
	["Remorseless"] = "Ability_FiegnDead",
	["Remorseless Attacks"] = "Ability_FiegnDead",
--	["Remote Toy"] = true,
	["Remove Curse"] = "Spell_Holy_RemoveCurse",
	["Remove Insignia"] = "Temp",
	["Remove Lesser Curse"] = "Spell_Nature_RemoveCurse",
	["Rend"] = "Ability_Gouge",
	["Renew"] = "Spell_Holy_Renew",
--	["Repair"] = true,
	["Repentance"] = "Spell_Holy_PrayerOfHealing",
	["Restless Strength"] = "Ability_CriticalStrike",
	["Restorative Totems"] = "Spell_Nature_ManaRegenTotem",
	["Resurrection"] = "Spell_Holy_Resurrection",
	["Retaliation"] = "Ability_Warrior_Challange",
	["Retribution Aura"] = "Spell_Holy_AuraOfLight",
	["Revenge"] = "Ability_Warrior_Revenge",
	["Revenge Stun"] = "Ability_Warrior_Revenge",
	["Reverberation"] = "Spell_Frost_FrostWard",
	["Revive Pet"] = "Ability_Hunter_BeastSoothe",
	["Righteous Defense"] = "INV_Shoulder_37",
	["Righteous Fury"] = "Spell_Holy_SealOfFury",
	["Rip"] = "Ability_GhoulFrenzy",
	["Riposte"] = "Ability_Warrior_Challange",
	["Ritual of Doom"] = "Spell_Shadow_AntiMagicShell",
	["Ritual of Doom Effect"] = "Spell_Arcane_PortalDarnassus",
	["Ritual of Souls"] = "Spell_Shadow_Shadesofdarkness",
	["Ritual of Summoning"] = "Spell_Shadow_Twilight",
	["Rockbiter Weapon"] = "Spell_Nature_RockBiter",
	["Rough Sharpening Stone"] = "INV_Stone_SharpeningStone_01",
	["Ruin"] = "Spell_Shadow_ShadowWordPain",
	["Rupture"] = "Ability_Rogue_Rupture",
	["Ruthlessness"] = "Ability_Druid_Disembowel",
	["Sacrifice"] = "Spell_Shadow_SacrificialShield",
	["Safe Fall"] = "INV_Feather_01",
	["Sanctified Crusader"] = "Spell_Holy_HolySmite",
--	["Sanctified Judgement"] = true,
	["Sanctified Light"] = "Spell_Holy_HealingAura",
	["Sanctity Aura"] = "Spell_Holy_MindVision",
	["Sap"] = "Ability_Sap",
	["Savage Fury"] = "Ability_Druid_Ravage",
	["Savage Strikes"] = "Ability_Racial_BloodRage",
	["Scare Beast"] = "Ability_Druid_Cower",
	["Scatter Shot"] = "Ability_GolemStormBolt",
	["Scorch"] = "Spell_Fire_SoulBurn",
	["Scorpid Poison"] = "Ability_PoisonSting",
	["Scorpid Sting"] = "Ability_Hunter_CriticalShot",
	["Screech"] = "Ability_Hunter_Pet_Bat",
	["Seal Fate"] = "Spell_Shadow_ChillTouch",
	["Seal of Blood"] = "Spell_Holy_SealOfBlood",
	["Seal of Command"] = "Ability_Warrior_InnerRage",
	["Seal of Justice"] = "Spell_Holy_SealOfWrath",
	["Seal of Light"] = "Spell_Holy_HealingAura",
	["Seal of Righteousness"] = "Ability_ThunderBolt",
	["Seal of Vengeance"] = "Spell_Holy_SealOfVengeance",
	["Seal of Wisdom"] = "Spell_Holy_RighteousnessAura",
	["Seal of the Crusader"] = "Spell_Holy_HolySmite",
	["Searing Light"] = "Spell_Holy_SearingLightPriest",
	["Searing Pain"] = "Spell_Fire_SoulBurn",
	["Searing Totem"] = "Spell_Fire_SearingTotem",
	["Second Wind"] = "Ability_Hunter_Harass",
	["Seduction"] = "Spell_Shadow_MindSteal",
	["Seed of Corruption"] = "Spell_Shadow_SeedOfDestruction",
	["Seethe"] = "Ability_Druid_ChallangingRoar",
	["Sense Demons"] = "Spell_Shadow_Metamorphosis",
	["Sense Undead"] = "Spell_Holy_SenseUndead",
	["Sentry Totem"] = "Spell_Nature_RemoveCurse",
	["Serpent Sting"] = "Ability_Hunter_Quickshot",
--	["Serrated Blades"] = true,
	["Setup"] = "Spell_Nature_MirrorImage",
	["Shackle Undead"] = "Spell_Nature_Slow",
	["Shadow Affinity"] = "Spell_Shadow_ShadowWard",
	["Shadow Bolt"] = "Spell_Shadow_ShadowBolt",
	["Shadow Embrace"] = "Spell_Shadow_ShadowEmbrace",
	["Shadow Focus"] = "Spell_Shadow_BurningSpirit",
	["Shadow Mastery"] = "Spell_Shadow_ShadeTrueSight",
	["Shadow Power"] = "Spell_Shadow_ShadowPower",
	["Shadow Protection"] = "Spell_Shadow_AntiShadow",
	["Shadow Reach"] = "Spell_Shadow_ChillTouch",
	["Shadow Resistance"] = "Spell_Shadow_AntiShadow",
	["Shadow Resistance Aura"] = "Spell_Shadow_SealOfKings",
	["Shadow Trance"] = "Spell_Shadow_Twilight",
	["Shadow Vulnerability"] = "Spell_Shadow_ShadowBolt",
	["Shadow Ward"] = "Spell_Shadow_AntiShadow",
	["Shadow Weakness"] = "INV_Misc_QirajiCrystal_05",
	["Shadow Weaving"] = "Spell_Shadow_BlackPlague",
	["Shadow Word: Death"] = "Spell_Shadow_DemonicFortitude",
	["Shadow Word: Pain"] = "Spell_Shadow_ShadowWordPain",
	["Shadow and Flame"] = "Spell_Shadow_ShadowandFlame",
--	["Shadow of Death"] = true,
	["Shadowburn"] = "Spell_Shadow_ScourgeBuild",
	["Shadowfiend"] = "Spell_Shadow_Shadowfiend",
	["Shadowform"] = "Spell_Shadow_Shadowform",
	["Shadowfury"] = "Spell_Shadow_Shadowfury",
	["Shadowguard"] = "Spell_Nature_LightningShield",
	["Shadowmeld"] = "Ability_Ambush",
	["Shadowmeld Passive"] = "Ability_Ambush",
	["Shadowstep"] = "Ability_Rogue_Shadowstep",
	["Shamanistic Rage"] = "Spell_Nature_ShamanRage",
	["Sharpened Claws"] = "INV_Misc_MonsterClaw_04",
	["Shatter"] = "Spell_Frost_FrostShock",
	["Shell Shield"] = "Ability_Hunter_Pet_Turtle",
	["Shield"] = "INV_Shield_04",
	["Shield Bash"] = "Ability_Warrior_ShieldBash",
	["Shield Bash - Silenced"] = "Ability_Warrior_ShieldBash",
	["Shield Block"] = "Ability_Defend",
	["Shield Slam"] = "INV_Shield_05",
	["Shield Specialization"] = "INV_Shield_06",
	["Shield Wall"] = "Ability_Warrior_ShieldWall",
	["Shiv"] = "INV_ThrowingKnife_04",
	["Shoot"] = "Ability_ShootWand",
	["Shoot Bow"] = "Ability_Marksmanship",
	["Shoot Gun"] = "Ability_Marksmanship",
	["Shred"] = "Spell_Shadow_VampiricAura",
--	["Shredding Attacks"] = true,
	["Silence"] = "Spell_Shadow_ImpPhaseShift",
	["Silencing Shot"] = "Ability_TheBlackArrow",
	["Silent Resolve"] = "Spell_Nature_ManaRegenTotem",
	["Silverwing Flag"] = "INV_BannerPVP_02",
	["Sinister Strike"] = "Spell_Shadow_RitualOfSacrifice",
	["Siphon Life"] = "Spell_Shadow_Requiem",
	["Skinning"] = "INV_Misc_Pelt_Wolf_01",
	["Slam"] = "Ability_Warrior_DecisiveStrike",
	["Slayer's Crest"] = "INV_Trinket_Naxxramas03",
	["Sleep"] = "Spell_Nature_Sleep",
	["Slice and Dice"] = "Ability_Rogue_SliceDice",
	["Slow"] = "Spell_Nature_Slow",
	["Slow Fall"] = "Spell_Magic_FeatherFall",
	["Smelting"] = "Spell_Fire_FlameBlades",
	["Smite"] = "Spell_Holy_HolySmite",
	["Snake Trap"] = "Ability_Hunter_SnakeTrap",
	["Solid Sharpening Stone"] = "INV_Stone_SharpeningStone_04",
	["Sonic Burst"] = "Spell_Shadow_Teleport",
	["Soothe Animal"] = "Ability_Hunter_BeastSoothe",
	["Soothing Kiss"] = "Spell_Shadow_SoothingKiss",
	["Soul Fire"] = "Spell_Fire_Fireball02",
	["Soul Leech"] = "Spell_Shadow_SoulLeech_3",
	["Soul Link"] = "Spell_Shadow_GatherShadows",
	["Soul Siphon"] = "Spell_Shadow_LifeDrain02",
	["Soulshatter"] = "Spell_Arcane_Arcane01",
	["Soulstone Resurrection"] = "INV_Misc_Orb_04",
	["Spell Haste"] = "Spell_Holy_SearingLight",
	["Spell Lock"] = "Spell_Shadow_MindRot",
	["Spell Power"] = "Spell_Arcane_ArcaneTorrent",
	["Spell Reflection"] = "Ability_Warrior_ShieldReflection",
	["Spell Vulnerability"] = "Spell_Holy_ElunesGrace",
	["Spell Warding"] = "Spell_Holy_SpellWarding",
	["Spellsteal"] = "Spell_Arcane_Arcane02",
	["Spirit Bond"] = "Ability_Druid_DemoralizingRoar",
	["Spirit Tap"] = "Spell_Shadow_Requiem",
	["Spirit of Redemption"] = "INV_Enchant_EssenceEternalLarge",
	["Spiritual Attunement"] = "Spell_Holy_ReviveChampion",
	["Spiritual Focus"] = "Spell_Arcane_Blink",
	["Spiritual Guidance"] = "Spell_Holy_SpiritualGuidence",
	["Spiritual Healing"] = "Spell_Nature_MoonGlow",
	["Spiteful Fury"] = "Ability_Warrior_Rampage",
	["Sprint"] = "Ability_Rogue_Sprint",
--	["StableMaster"] = true,
	["Stance Mastery"] = "Spell_Nature_EnchantArmor",
	["Starfire"] = "Spell_Arcane_StarFire",
	["Starfire Stun"] = "Spell_Arcane_StarFire",
	["Starlight Wrath"] = "Spell_Nature_AbolishMagic",
	["Starshards"] = "Spell_Arcane_StarFire",
	["Static Charge"] = "Spell_Nature_WispSplode",
	["Staves"] = "INV_Staff_08",
	["Steady Shot"] = "Ability_Hunter_SteadyShot",
	["Stealth"] = "Ability_Stealth",
	["Stoneclaw Stun"] = "Spell_Nature_StoneClawTotem",
	["Stoneclaw Totem"] = "Spell_Nature_StoneClawTotem",
	["Stoneform"] = "Spell_Shadow_UnholyStrength",
	["Stoneskin"] = "Spell_Nature_StoneSkinTotem",
	["Stoneskin Totem"] = "Spell_Nature_StoneSkinTotem",
	["Stormstrike"] = "Spell_Holy_SealOfMight",
	["Strength of Earth"] = "Spell_Nature_EarthBindTotem",
	["Strength of Earth Totem"] = "Spell_Nature_EarthBindTotem",
	["Strength of the Halaani"] = "INV_Trinket_Naxxramas01",
	["Stuck"] = "Spell_Shadow_Teleport",
	["Stun"] = "Spell_Frost_Stun",
	["Subtlety"] = "Ability_EyeOfTheOwl",
	["Suffering"] = "Spell_Shadow_BlackPlague",
	["Summon Charger"] = "Ability_Mount_Charger",
	["Summon Dreadsteed"] = "Ability_Mount_Dreadsteed",
	["Summon Felguard"] = "Spell_Shadow_SummonFelGuard",
	["Summon Felhunter"] = "Spell_Shadow_SummonFelHunter",
	["Summon Felsteed"] = "Spell_Nature_Swiftness",
	["Summon Imp"] = "Spell_Shadow_SummonImp",
	["Summon Succubus"] = "Spell_Shadow_SummonSuccubus",
	["Summon Voidwalker"] = "Spell_Shadow_SummonVoidWalker",
	["Summon Warhorse"] = "Spell_Nature_Swiftness",
	["Summon Water Elemental"] = "Spell_Frost_SummonWaterElemental_2",
	["Sunder Armor"] = "Ability_Warrior_Sunder",
	["Suppression"] = "Spell_Shadow_UnsummonBuilding",
	["Surefooted"] = "Ability_Kick",
	["Surge of Light"] = "Spell_Holy_SurgeOfLight",
--	["Surprise Attacks"] = true,
	["Survivalist"] = "Spell_Shadow_Twilight",
	["Sweeping Strikes"] = "Ability_Rogue_SliceDice",
	["Swift Flight Form"] = "Ability_Druid_FlightForm",
	["Swiftmend"] = "INV_Relics_IdolofRejuvenation",
	["Swipe"] = "INV_Misc_MonsterClaw_03",
	["Sword Specialization"] = "INV_Sword_27",
	["Symbol of Hope"] = "Spell_Holy_SymbolOfHope",
	["Tactical Mastery"] = "Spell_Nature_EnchantArmor",
	["Tailoring"] = "Trade_Tailoring",
	["Tainted Blood"] = "Spell_Shadow_LifeDrain",
	["Tainted Mind"] = "Spell_Shadow_ShadowPact",
	["Tame Beast"] = "Ability_Hunter_BeastTaming",
	["Taunt"] = "Spell_Nature_Reincarnation",
	["Teleport: Darnassus"] = "Spell_Arcane_TeleportDarnassus",
	["Teleport: Exodar"] = "Spell_Arcane_TeleportExodar",
	["Teleport: Ironforge"] = "Spell_Arcane_TeleportIronForge",
	["Teleport: Moonglade"] = "Spell_Arcane_TeleportMoonglade",
	["Teleport: Orgrimmar"] = "Spell_Arcane_TeleportOrgrimmar",
	["Teleport: Shattrath"] = "Spell_Arcane_TeleportShattrath",
	["Teleport: Silvermoon"] = "Spell_Arcane_TeleportSilvermoon",
	["Teleport: Stormwind"] = "Spell_Arcane_TeleportStormWind",
	["Teleport: Thunder Bluff"] = "Spell_Arcane_TeleportThunderBluff",
	["Teleport: Undercity"] = "Spell_Arcane_TeleportUnderCity",
	["Temporal Rift"] = "Spell_Nature_TimeStop",
	["The Beast Within"] = "Ability_Hunter_BeastWithin",
	["The Human Spirit"] = "INV_Enchant_ShardBrilliantSmall",
	["Thick Hide"] = "INV_Misc_Pelt_Bear_03",
	["Thorns"] = "Spell_Nature_Thorns",
--	["Thrill of the Hunt"] = true,
	["Throw"] = "Ability_Throw",
	["Throwing Specialization"] = "INV_ThrowingAxe_03",
	["Thrown"] = "INV_ThrowingKnife_02",
	["Thunder Clap"] = "Spell_Nature_ThunderClap",
	["Thunderfury"] = "Spell_Nature_Cyclone",
	["Thundering Strikes"] = "Ability_ThunderBolt",
	["Thunderstomp"] = "Ability_Hunter_Pet_Gorilla",
	["Tidal Focus"] = "Spell_Frost_ManaRecharge",
	["Tidal Mastery"] = "Spell_Nature_Tranquility",
	["Tiger Riding"] = "Spell_Nature_Swiftness",
	["Tiger's Fury"] = "Ability_Mount_JungleTiger",
	["Time's Favor"] = "Ability_Rogue_FleetFooted",
	["Torment"] = "Spell_Shadow_GatherShadows",
	["Totem"] = "Spell_Nature_StoneClawTotem",
	["Totem of Wrath"] = "Spell_Fire_TotemOfWrath",
	["Totemic Call"] = "Spell_unused",
	["Totemic Focus"] = "Spell_Nature_MoonGlow",
	["Touch of Shadow"] = "Spell_Shadow_PsychicScream",
	["Touch of Weakness"] = "Spell_Shadow_DeadofNight",
	["Toughness"] = "Spell_Holy_Devotion",
	["Traces of Silithyst"] = "Spell_Nature_TimeStop",
	["Track Beasts"] = "Ability_Tracking",
	["Track Demons"] = "Spell_Shadow_SummonFelHunter",
	["Track Dragonkin"] = "INV_Misc_Head_Dragon_01",
	["Track Elementals"] = "Spell_Frost_SummonWaterElemental",
	["Track Giants"] = "Ability_Racial_Avatar",
	["Track Hidden"] = "Ability_Stealth",
	["Track Humanoids"] = "Spell_Holy_PrayerOfHealing",
	["Track Undead"] = "Spell_Shadow_DarkSummoning",
	["Tranquil Air"] = "Spell_Nature_Brilliance",
	["Tranquil Air Totem"] = "Spell_Nature_Brilliance",
	["Tranquil Spirit"] = "Spell_Holy_ElunesGrace",
	["Tranquility"] = "Spell_Nature_Tranquility",
	["Tranquilizing Shot"] = "Spell_Nature_Drowsy",
	["Trap Mastery"] = "Ability_Ensnare",
	["Travel Form"] = "Ability_Druid_TravelForm",
	["Tree of Life"] = "Ability_Druid_TreeofLife",
	["Tremor Totem"] = "Spell_Nature_TremorTotem",
	["Tribal Leatherworking"] = "Spell_Nature_NullWard",
	["Trueshot Aura"] = "Ability_TrueShot",
	["Turn Undead"] = "Spell_Holy_TurnUndead",
	["Twin Spire Blessing"] = "Spell_Nature_ElementalPrecision_1",
	["Two-Handed Axes"] = "INV_Axe_04",
	["Two-Handed Axes and Maces"] = "INV_Axe_10",
	["Two-Handed Maces"] = "INV_Mace_04",
	["Two-Handed Swords"] = "Ability_MeleeDamage",
	["Two-Handed Weapon Specialization"] = "INV_Axe_09",
	["Unarmed"] = "Ability_GolemThunderClap",
	["Unbreakable Will"] = "Spell_Magic_MageArmor",
	["Unbridled Wrath"] = "Spell_Nature_StoneClawTotem",
	["Undead Horsemanship"] = "Spell_Nature_Swiftness",
	["Underwater Breathing"] = "Spell_Shadow_DemonBreath",
	["Unending Breath"] = "Spell_Shadow_DemonBreath",
	["Unholy Power"] = "Spell_Shadow_ShadowWordDominate",
	["Unleashed Fury"] = "Ability_BullRush",
	["Unleashed Rage"] = "Spell_Nature_UnleashedRage",
	["Unstable Affliction"] = "Spell_Shadow_UnstableAffliction_3",
	["Unstable Power"] = "Spell_Lightning_LightningBolt01",
	["Unyielding Faith"] = "Spell_Holy_UnyieldingFaith",
	["Vampiric Embrace"] = "Spell_Shadow_UnsummonBuilding",
	["Vampiric Touch"] = "Spell_Holy_Stoicism",
	["Vanish"] = "Ability_Vanish",
	["Vanished"] = "Ability_Vanish",
	["Vengeance"] = "Spell_Nature_Purge",
	["Venomous Totem"] = "Spell_Totem_WardOfDraining",
	["Victory Rush"] = "Ability_Warrior_Devastate",
	["Vigor"] = "Spell_Nature_EarthBindTotem",
--	["Vile Beam"] = true,
	["Vile Poisons"] = "Ability_Rogue_FeignDeath",
	["Vindication"] = "Spell_Holy_Vindication",
	["Viper Sting"] = "Ability_Hunter_AimedShot",
	["Volley"] = "Ability_Marksmanship",
	["Wand Specialization"] = "INV_Wand_01",
	["Wands"] = "Ability_ShootWand",
	["War Stomp"] = "Ability_WarStomp",
	["Warp"] = "Spell_Arcane_Arcane04",
	["Warsong Flag"] = "INV_BannerPVP_01",
	["Water Breathing"] = "Spell_Shadow_DemonBreath",
	["Water Shield"] = "Ability_Shaman_WaterShield",
	["Water Tomb"] = "Spell_Frost_ManaRecharge",
	["Water Walking"] = "Spell_Frost_WindWalkOn",
	["Waterbolt"] = "Spell_Frost_FrostBolt",
	["Watery Grave"] = "Spell_Shadow_DemonBreath",
	["Weakened Soul"] = "Spell_Holy_AshesToAshes",
--	["Weapon Mastery"] = true,
	["Weaponsmith"] = "INV_Sword_25",
	["Whirlwind"] = "Ability_Whirlwind",
	["Will of the Forsaken"] = "Spell_Shadow_RaiseDead",
	["Windfury"] = "Spell_Nature_Cyclone",
	["Windfury Attack"] = "Spell_Nature_Cyclone",
	["Windfury Totem"] = "Spell_Nature_Windfury",
	["Windfury Weapon"] = "Spell_Nature_Cyclone",
	["Windwall"] = "Spell_Nature_EarthBind",
	["Windwall Totem"] = "Spell_Nature_EarthBind",
	["Wing Clip"] = "Ability_Rogue_Trip",
	["Winter's Chill"] = "Spell_Frost_ChillingBlast",
	["Wisp Spirit"] = "Spell_Nature_WispSplode",
	["Wolf Riding"] = "Spell_Nature_Swiftness",
	["Wound Poison"] = "INV_Misc_Herb_16",
	["Wound Poison II"] = "INV_Misc_Herb_16",
	["Wound Poison III"] = "INV_Misc_Herb_16",
	["Wound Poison IV"] = "INV_Misc_Herb_16",
	["Wound Poison V"] = "INV_Misc_Herb_16",
	["Wrath"] = "Spell_Nature_AbolishMagic",
	["Wrath of Air Totem"] = "Spell_Nature_SlowingTotem",
	["Wrath of Cenarius"] = "Ability_Druid_TwilightsWrath",
	["Wrath of the Astromancer"] = "Spell_Arcane_Arcane02",
	["Wyvern Sting"] = "INV_Spear_02",
}

-- #FORCE_DOC
--[[---------------------------------------------------------------------------
Arguments:
	string - name of the spell in either English or the current locale.
Returns:
	string or nil - the full path to the icon or nil if it doesn't exist
Example:
	local BS = LibStub("LibBabble-Spell-3.0")
	assert(BS:GetSpellIcon("Wyvern Sting") == "Interface\\Icons\\INV_Spear_02")
-----------------------------------------------------------------------------]]
function lib:GetSpellIcon(spell)
	if type(spell) ~= "string" then
		error(("Bad argument #2 to `GetSpellIcon'. Expected %q, got %q."):format("string", type(spell)), 2)
	end
	local icon = spellIcons[spell] or spellIcons[self:GetReverseLookupTable()[spell]]
	if not icon then
		return nil
	end
	return "Interface\\Icons\\" .. icon
end

-- #FORCE_DOC
--[[---------------------------------------------------------------------------
Arguments:
	string - name of the spell in either English or the current locale.
Returns:
	string or nil - the name of the icon or nil if it doesn't exist
Example:
	local BS = LibStub("LibBabble-Spell-3.0")
	assert(BS:GetSpellIcon("Wyvern Sting") == "INV_Spear_02")
-----------------------------------------------------------------------------]]
function lib:GetShortSpellIcon(spell)
	if type(spell) ~= "string" then
		error(("Bad argument #2 to `GetShortSpellIcon'. Expected %q, got %q."):format("string", type(spell)), 2)
	end
	return spellIcons[spell] or spellIcons[self:GetReverseLookupTable()[spell]] or nil
end
